(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    107165,       2666]
NotebookOptionsPosition[     97617,       2368]
NotebookOutlinePosition[     98077,       2387]
CellTagsIndexPosition[     98034,       2384]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["A Data Type for Collections of Cartesian Vectors", "Section",
 CellChangeTimes->{{3.410695214875*^9, 3.410695218*^9}}],

Cell["\<\
 Richard L. Fearn, Professor Emeritus, Mechanical and Aerospace Engineering, \
University of Florida, Gainesville, Florida\
\>", "Text",
 CellChangeTimes->{{3.4204666790505023`*^9, 3.4204667126588287`*^9}, {
  3.420466747458869*^9, 3.4204667487707553`*^9}}],

Cell["Copyright 2006-2009, Richard L. Fearn , All Rights Reserved", "Text",
 CellChangeTimes->{{3.4204663156779985`*^9, 3.4204663350859056`*^9}, 
   3.4204663759346433`*^9, {3.420466407029355*^9, 3.420466418926462*^9}, {
   3.42046656167172*^9, 3.420466575721923*^9}, {3.420466617952648*^9, 
   3.420466659742739*^9}, {3.44084140731004*^9, 3.4408414079409475`*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Version 7.0.1.0\nPackage Version 1.1.0.  12/01/09"
}], "Text",
 CellChangeTimes->{{3.400833022484375*^9, 3.40083303303125*^9}, {
  3.410521828109375*^9, 3.410521874078125*^9}, {3.410694370296875*^9, 
  3.410694371390625*^9}, {3.410694408609375*^9, 3.41069443165625*^9}, {
  3.417767474484375*^9, 3.4177674815*^9}, {3.418376642903555*^9, 
  3.418376643754779*^9}, {3.4204664483487697`*^9, 3.42046648389989*^9}, {
  3.440841412677758*^9, 3.4408414457152643`*^9}, {3.441023443046995*^9, 
  3.4410234437279744`*^9}, {3.4462177236942*^9, 3.4462177288266*^9}, {
  3.467027743360939*^9, 3.4670277594757395`*^9}}],

Cell[CellGroupData[{

Cell["Reference", "Subsection"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell["\<\
This package defines a data type to simplify the manipulation of large \
collections of vectors.  Using a data type simplifies pattern matching for \
input arguments for exported functions in other packages.  The properties of \
the data type are defined by overloading existing Mathematica functions \
whenever feasible.\
\>", "Text",
 CellChangeTimes->{{3.4008330783125*^9, 3.40083310896875*^9}, {
  3.41777069465625*^9, 3.41777069528125*^9}, {3.4408416949135933`*^9, 
  3.4408416963857107`*^9}}],

Cell[TextData[{
 "The initial application of this package is for formulating and solving \
panel methods for two-dimensional potential flow over airfoils.  Although \
some thought was given to more general usage, most of the exported functions \
and overloads of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions are defined to support the operations needed in the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " software.  In other words, this is a support package and is being \
developed as needed."
}], "Text",
 CellChangeTimes->{{3.4408417416307697`*^9, 3.440841781468053*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell[TextData[{
 "Maeder, Roman E., ",
 StyleBox["Computer Science with",
  FontSlant->"Italic"],
 " ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", Cambridge University Press, 2000."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[" Limitations", "Subsubsection"],

Cell[TextData[{
 "This package is incomplete in terms of operations and relationships, and \
those specified are not always as general as they could be.  Operations and \
relationships are added as needed to handle specific tasks during the \
development of ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".\n\nThere is one specific problems where I was not able to accomplish what \
I wanted. I have been unable to overload ",
 StyleBox["Times", "Output"],
 " such that multiplication of a data type ",
 StyleBox["CartesianVectors", "Output"],
 " by a list mimics the behavior of the multiplication of two lists.  An \
exported function ",
 StyleBox["MultiplyByList", "Output"],
 " is defined to accomplish this task. "
}], "Text",
 CellChangeTimes->{{3.40083316321875*^9, 3.400833163921875*^9}, {
  3.440841825691643*^9, 3.440841828776078*^9}, {3.440842237273469*^9, 
  3.4408422458658237`*^9}, {3.4408422869348783`*^9, 3.4408423194316063`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Discussion", "Subsubsection"],

Cell[TextData[{
 "There are two straightforward choices for representing collections of \
vectors as nested lists.  One choice is to use the convention of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for plotting points in a two-dimensional space, ",
 StyleBox["ListPlot[r]", "Output"],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["y", "1"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "2"], ",", 
        SubscriptBox["y", "2"]}], "}"}], ",", 
      RowBox[{"...", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "n"], ",", 
         SubscriptBox["y", "n"]}], "}"}]}]}], "}"}]}], TraditionalForm]]],
 ".  The form chosen for this package, however, is to group each component \
into a separate list so that the collection of vectors is represented by  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"], ",", 
        RowBox[{"...", "  ", 
         SubscriptBox["x", "n"]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["y", "1"], ",", 
        SubscriptBox["y", "2"], ",", 
        RowBox[{"...", 
         SubscriptBox["y", "n"]}]}], "}"}]}], "}"}]}], TraditionalForm]]],
 ".  The representation of collections of vectors in this form is generalized \
to n-dimensional space and formalized as a data type, ",
 StyleBox["CartesianVectors", "Output"],
 "."
}], "Text",
 CellChangeTimes->{{3.4008332705*^9, 3.400833271828125*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Set up package context", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "BeginPackage", "[", "\"\<Aerodynamics`CartesianVectors`\>\"", "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.396611939234375*^9, 3.396612066515625*^9, 
  3.397907845984375*^9, 3.440842122848934*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Interface", "Subsection"],

Cell[CellGroupData[{

Cell[" Usage messages", "Subsubsection",
 CellChangeTimes->{{3.41777479271875*^9, 3.417774794359375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CartesianVectors", "::", "usage"}], "=", 
   "\"\<is the name of a data type specifying a collection of n-dimensional \
vectors in a rectangular coordinate system.  CartesianVectors is also the \
name of the package defining the data type.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.444986787450461*^9, 3.444986882657261*^9}, {
   3.4488065123518*^9, 3.4488065377174*^9}, 3.4524384059566*^9, 
   3.458036489501*^9, {3.4580366229278*^9, 3.4580366769505997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ComplexToCartesianVectors", "::", "usage"}], "=", 
   "\"\<ComplexToCartesianVectors converts a list of complex numbers to a \
collection of two-dimensional vectors of the data type \
CartesianVectors.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4449876952768607`*^9, 3.444987699332861*^9}, 
   3.4449877350412607`*^9, 3.4449890857280607`*^9, {3.448287592013959*^9, 
   3.448287592232359*^9}, {3.4482876516323586`*^9, 3.448287700491559*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Components", "::", "usage"}], "=", 
   "\"\<Components selects the lists of components from a collection of \
vectors of the data type CartesianVectors.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.411378908484375*^9, {3.444989121389661*^9, 3.444989188922061*^9}, {
   3.448287329350959*^9, 3.4482873843409586`*^9}, {3.4525231013912*^9, 
   3.4525231018904*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ExtendXyToXyz", "::", "usage"}], "=", 
   "\"\<ExtendXyToXyz[u] extends a collection of two-dimensional vectors to \
three-dimensions by padding the z component with zeros.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4449877647280607`*^9, 3.4449878408716607`*^9}, 
   3.4449891000488605`*^9, {3.448287532796359*^9, 3.4482875533259587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ExtendXzToXyz", "::", "usage"}], "=", 
   "\"\<ExtendXzToXyz[u] extends a collection of two-dimensional vectors to \
three-dimensions by padding the y component with zeros.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.444987870605261*^9, 3.4449879130840607`*^9}, 
   3.4449891064604607`*^9, {3.4486126713025923`*^9, 3.448612672534992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeCartesianVectors", "::", "usage"}], "=", 
   "\"\<MakeCartesianVectors[{u1, u2, u3, ... }] constructs the data type \
CartesianVectors for a collection of \!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)-dimensional vectors.  The structure of each list of \
components, ui, is either a simple list or a matrix. All lists in the input \
arguments must have the same dimensions.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41112117653125*^9, 3.4111211793125*^9}, {
   3.411376943734375*^9, 3.411376987671875*^9}, {3.4113770206875*^9, 
   3.411377056046875*^9}, {3.4113771075625*^9, 3.41137710946875*^9}, {
   3.41137722696875*^9, 3.4113772303125*^9}, {3.411377418046875*^9, 
   3.4113774755625*^9}, {3.411377597328125*^9, 3.411377599359375*^9}, {
   3.41137770834375*^9, 3.411377708578125*^9}, {3.41137773996875*^9, 
   3.411378227921875*^9}, {3.41137826415625*^9, 3.411378417125*^9}, {
   3.411378750984375*^9, 3.411378764921875*^9}, {3.411379027046875*^9, 
   3.411379093734375*^9}, {3.41137912821875*^9, 3.411379129765625*^9}, 
   3.4192447606801395`*^9, 3.419244809530382*^9, {3.444987946140461*^9, 
   3.444988076696861*^9}, 3.4452465012497597`*^9, 3.44524655212136*^9, {
   3.44524681378016*^9, 3.4452468374453597`*^9}, 3.4452468796745596`*^9, {
   3.4452469254449596`*^9, 3.44524692968816*^9}, {3.448612768767192*^9, 
   3.4486128351139917`*^9}, {3.448612879573992*^9, 3.448612960927992*^9}, {
   3.4529513839737997`*^9, 3.4529514943594*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MirrorXAxis", "::", "usage"}], "=", 
   "\"\<MirrorXAxis[r] reflects a collection of 2-D vectors r through the x \
axis.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4105221121875*^9, 3.410522170015625*^9}, 
   3.410522669546875*^9, {3.410541098359375*^9, 3.410541127359375*^9}, 
   3.420453523253395*^9, {3.448613117156192*^9, 3.448613142303392*^9}, {
   3.452954810233*^9, 3.4529548107166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MultiplyByList", "::", "usage"}], "=", 
   "\"\<MultiplyByList[a,u] multiplies a collection of vectors u by a list a.\
\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.444988101563261*^9, 3.4449881686900606`*^9}, {
  3.448613228098592*^9, 3.448613252481392*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NumberOfVectors", "::", "usage"}], "=", 
   "\"\<NumberOfVectors[u] counts the number of vectors in a collection of \
vectors u.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4449882640060606`*^9, 3.4449883062196608`*^9}, {
  3.4486133085731916`*^9, 3.448613336653192*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ReplicateVector", "::", "usage"}], "=", 
   "\"\<ReplicateVector[{x1,x2,x3,...,xn},m] returns a collection of vectors \
consisting of \!\(\*
StyleBox[\"m\", \"TI\"]\) copies of a single n-dimensional vector.\n\
ReplicateVector[u,m] returns a collection of vectors consisting of \!\(\*
StyleBox[\"m\", \"TI\"]\) copies of the collection of vectors \!\(\*
StyleBox[\"u\", \"TI\"]\).\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.406888755421875*^9, 3.406888878140625*^9}, {
  3.4449883452196608`*^9, 3.444988390724861*^9}, {3.4538234505014*^9, 
  3.4538234681605997`*^9}, {3.4538235033854*^9, 3.4538236537382*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ThreeDimQ", "::", "usage"}], "=", 
   "\"\<ThreeDimQ[u] returns True if u is a collection of three-dimensional \
vectors of the data type CartesianVectors, False if not.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4449884226892605`*^9, 3.444988537770461*^9}, {
  3.448613493004792*^9, 3.448613557557592*^9}, {3.448613611049992*^9, 
  3.448613613249592*^9}, {3.4547795915825634`*^9, 3.4547795953733635`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TwoDimQ", "::", "usage"}], "=", 
   "\"\<TwoDimQ[u] returns True if u is a collection of two-dimensional \
vectors of the data type CartesianVectors, False if not.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.444988551451661*^9, 3.444988578533261*^9}, {
  3.448613574280792*^9, 3.448613652701992*^9}, {3.4547795671841636`*^9, 
  3.4547795717237635`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Error messages for the exported functions", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeCartesianVectors", "::", "form"}], "=", 
   "\"\<Form of input is incorrect.  Enclose lists of components with {} to \
make one argument that is a list.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.417768276640625*^9, 3.4177684306875*^9}, 
   3.4177685981875*^9, {3.4177686909375*^9, 3.417768855359375*^9}, 
   3.417768984234375*^9, {3.41776908065625*^9, 3.41776908175*^9}, {
   3.417769174765625*^9, 3.417769199296875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeCartesianVectors", "::", "dimensions"}], "=", 
   "\"\<The dimensions of the lists of components must be equal.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Implementation", "Subsection"],

Cell[CellGroupData[{

Cell[" Begin private context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Begin", "[", "\"\<Aerodynamics`CartesianVectors`Private`\>\"", "]"}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Unprotect and set attributes of exported functions", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", 
   RowBox[{
   "CartesianVectors", ",", "ComplexToCartesianVectors", ",", "Components", 
    ",", "ExtendXyToXyz", ",", "ExtendXzToXyz", ",", "MakeCartesianVectors", 
    ",", "MirrorXAxis", ",", "MultiplyByList", ",", "NumberOfVectors", ",", 
    "ReplicateVector", ",", "ThreeDimQ", ",", "TwoDimQ"}], "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.397310076125*^9, 3.397310079984375*^9}, 
   3.3973130833125*^9, {3.39789586596875*^9, 3.397895866359375*^9}, {
   3.397901325890625*^9, 3.3979013261875*^9}, 3.3979024798125*^9, 
   3.397920363296875*^9, {3.398068210515625*^9, 3.398068210828125*^9}, 
   3.399883766484375*^9, {3.399894132765625*^9, 3.39989415503125*^9}, {
   3.4002335794375*^9, 3.400233584578125*^9}, 3.40083355646875*^9, {
   3.4008338150625*^9, 3.400833817421875*^9}, 3.417339030859375*^9, 
   3.417770949390625*^9, 3.418375759022597*^9, 3.418376511264267*^9, 
   3.440842411734331*^9}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "CartesianVectors", ",", "ComplexToCartesianVectors", ",", "Components", 
     ",", "ExtendXyToXyz", ",", "ExtendXzToXyz", ",", "MakeCartesianVectors", 
     ",", "MirrorXAxis", ",", "MultiplyByList", ",", "NumberOfVectors", ",", 
     "ReplicateVector"}], "}"}], ",", "NumericFunction"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.397895877265625*^9, 3.397895879203125*^9}, {
   3.39790133365625*^9, 3.39790133390625*^9}, 3.397902481078125*^9, 
   3.399883779671875*^9, {3.40022812240625*^9, 3.40022813015625*^9}, {
   3.40023359134375*^9, 3.40023359765625*^9}, {3.40083624125*^9, 
   3.40083624353125*^9}, 3.41733903671875*^9, {3.41777120484375*^9, 
   3.417771233421875*^9}, {3.440842421217968*^9, 3.440842422660042*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ExtendXzToXyz", ",", "ExtendXyToXyz"}], "}"}], ",", "Listable"}],
   "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4155223393125*^9, 3.415522353984375*^9}, 
   3.41552277634375*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Constructor and selector", "Subsubsection"],

Cell["\<\
Collections of vectors in a Cartesian coordinate system can be represented by \
nested lists where each sublist represents one component of the vector.  For \
example, a collection of four three-dimensional vectors could be represented \
as follows.\
\>", "Text",
 CellChangeTimes->{{3.41111902003125*^9, 3.411119503890625*^9}, {
  3.411119570921875*^9, 3.41111957903125*^9}, {3.4111197251875*^9, 
  3.411119897046875*^9}, {3.411119931578125*^9, 3.4111199850625*^9}, {
  3.412350119640625*^9, 3.412350126*^9}, {3.41235017746875*^9, 
  3.412350180515625*^9}, {3.414158609453125*^9, 3.4141586120625*^9}}],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["u", "x1"], ",", " ", 
        SubscriptBox["u", "x2"], ",", 
        SubscriptBox["u", "x3"], ",", " ", 
        SubscriptBox["u", "x4"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["u", "y1"], ",", " ", 
        SubscriptBox["u", "y2"], ",", " ", 
        SubscriptBox["u", "y3"], ",", " ", 
        SubscriptBox["u", "y4"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["u", "z1"], ",", " ", 
        SubscriptBox["u", "z2"], ",", " ", 
        SubscriptBox["u", "z3"], ",", " ", 
        SubscriptBox["u", "z4"]}], "}"}]}], "}"}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4111195203125*^9, 3.411119547578125*^9}, {
  3.411119996046875*^9, 3.41112004325*^9}, {3.411120081453125*^9, 
  3.411120193375*^9}, {3.411120254015625*^9, 3.41112034890625*^9}, {
  3.412349991921875*^9, 3.41235005190625*^9}}],

Cell[TextData[{
 "Construct the data type ",
 StyleBox["CartesianVectors", "Output"],
 " by replacing the head ",
 StyleBox["List", "Output"],
 " with the head ",
 StyleBox["CartesianVectors", "Output"],
 ".  Simple lists and lists that can be represented as matrices are allowed \
for components."
}], "Text",
 CellChangeTimes->{{3.41112045546875*^9, 3.411120490671875*^9}, {
  3.414158650515625*^9, 3.41415877140625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeCartesianVectors", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vx_", "?", "VectorQ"}], ",", 
      RowBox[{"vy__", "?", "VectorQ"}]}], "}"}], "]"}], "/;", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Length", "/@", 
     RowBox[{"{", 
      RowBox[{"vx", ",", "vy"}], "}"}]}], "==", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Length", "[", "vx", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", 
          RowBox[{"{", "vx", "}"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"Dimensions", "[", 
          RowBox[{"{", "vy", "}"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}]}], ":=", 
  RowBox[{"CartesianVectors", "@@", 
   RowBox[{"{", 
    RowBox[{"vx", ",", "vy"}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQzcBwxTYn86UjQ0O6C4R+4wemGcL8IXyDGAgtEguh
52ZD6Iv5EJqtHKK+EEI3zG+A8I82QmjOLgi9GkpbT4SoS4TSddMh9GUoLfGt
A6zOjqETTO8PANMN20Mh/Lw8CJ+pGMLXbIDQq9og9IF+iDzPJAjNMQMi/m0m
hL8jpg9Mz4iF0FLGRlkgeT0TCB1jAaFtbSB0bh6ENsgH0QAf4Xf/
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MakeCartesianVectors", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vx_", "?", "MatrixQ"}], ",", 
      RowBox[{"vy__", "?", "MatrixQ"}]}], "}"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{"Dimensions", ",", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy"}], "}"}]}], "]"}], "\[Equal]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Dimensions", "[", "vx", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", 
          RowBox[{"vx", ",", "vy"}], "}"}], "]"}]}], "}"}]}], "]"}]}]}], ":=", 
  RowBox[{"CartesianVectors", "@@", 
   RowBox[{"{", 
    RowBox[{"vx", ",", "vy"}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410715118625*^9, 3.41071512271875*^9}, {
   3.410775487109375*^9, 3.41077549059375*^9}, {3.410775521875*^9, 
   3.410775538265625*^9}, 3.410775956578125*^9, {3.410785112109375*^9, 
   3.410785116453125*^9}, {3.411120661625*^9, 3.411120678921875*^9}}],

Cell["\<\
Return message if components are not specified as a single list.\
\>", "Text",
 CellChangeTimes->{{3.41776803446875*^9, 3.417768084296875*^9}, {
  3.41776812653125*^9, 3.4177681675625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"vx_List", ",", "vy__List"}], "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"MakeCartesianVectors", "::", "form"}], ",", 
    "\"\<MakeCartesianVectors\>\""}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399279192796875*^9, 3.399279195671875*^9}, {
  3.3992792790625*^9, 3.399279285765625*^9}, {3.410706579859375*^9, 
  3.41070658478125*^9}, {3.41078274790625*^9, 3.41078275115625*^9}, {
  3.410785244203125*^9, 3.41078525003125*^9}, {3.410786337484375*^9, 
  3.410786362734375*^9}, {3.411120727734375*^9, 3.411120733765625*^9}, {
  3.414161925109375*^9, 3.41416192921875*^9}, {3.41776818603125*^9, 
  3.417768191296875*^9}, {3.417768477578125*^9, 3.417768478421875*^9}, {
  3.417769102546875*^9, 3.41776910340625*^9}}],

Cell["\<\
Return message if lists of components do not have the same dimensions.\
\>", "Text",
 CellChangeTimes->{{3.410782736859375*^9, 3.410782738703125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{"vx_List", ",", "vy__List"}], "}"}], "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"MakeCartesianVectors", "::", "dimensions"}], ",", 
    "\"\<MakeCartesianVectors\>\""}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399279192796875*^9, 3.399279195671875*^9}, {
  3.3992792790625*^9, 3.399279285765625*^9}, {3.410706579859375*^9, 
  3.41070658478125*^9}, {3.41078274790625*^9, 3.41078275115625*^9}, {
  3.410785244203125*^9, 3.41078525003125*^9}, {3.410786337484375*^9, 
  3.410786362734375*^9}, {3.411120727734375*^9, 3.411120733765625*^9}, {
  3.414161925109375*^9, 3.41416192921875*^9}}],

Cell["Select lists of components of vectors.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Components", "[", 
   RowBox[{"CartesianVectors", "[", 
    RowBox[{"vx_", ",", "vy__"}], "]"}], "]"}], ":=", 
  RowBox[{"List", "@@", 
   RowBox[{"CartesianVectors", "[", 
    RowBox[{"vx", ",", "vy"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3992785391875*^9, 3.399278552875*^9}, {
  3.411120827984375*^9, 3.41112084503125*^9}, {3.411121090765625*^9, 
  3.411121094265625*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Other exported functions", "Subsubsection",
 CellChangeTimes->{{3.4204476578293295`*^9, 3.42044766566059*^9}}],

Cell[TextData[{
 "The functions ",
 StyleBox["MultiplyByList", "Output"],
 ", ",
 StyleBox["NumberOfVectors ", "Output"],
 "and ",
 StyleBox["ReplicateVector", "Output"],
 " are valid for n-dimensional space."
}], "Text",
 CellChangeTimes->{{3.417776042359375*^9, 3.417776120015625*^9}, {
  3.417776160359375*^9, 3.417776161140625*^9}, {3.440842447235379*^9, 
  3.440842470739176*^9}}],

Cell[TextData[{
 "The exported function ",
 StyleBox["MultiplyByList", "Output"],
 " represents my failure to define a successful overload for ",
 StyleBox["Times", "Output"],
 " between a list and a collection of vectors represented by the data type ",
 StyleBox["CartesianVectors", "Output"],
 "."
}], "Text",
 CellChangeTimes->{{3.4119955735*^9, 3.411995604765625*^9}, 
   3.4119956810625*^9, {3.41251364703125*^9, 3.412513792796875*^9}, {
   3.412513822984375*^9, 3.4125138289375*^9}, {3.412513861171875*^9, 
   3.412513976765625*^9}, 3.41545683084375*^9}],

Cell["\<\
If the length of the list is equal to the dimensionality of the vector space, \
each component of the collection of vectors is multiplied by the \
corresponding element of the list.\
\>", "Text",
 CellChangeTimes->{{3.415456839515625*^9, 3.415456840125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MultiplyByList", "[", 
    RowBox[{"a_List", ",", "v_CartesianVectors"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", "a", "]"}], "===", 
    RowBox[{"Length", "[", "v", "]"}]}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"a", "*", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411995505078125*^9, 3.411995513421875*^9}, {
   3.4119955479375*^9, 3.41199554821875*^9}, {3.41199575796875*^9, 
   3.411995758203125*^9}, {3.4125143544375*^9, 3.412514358296875*^9}, {
   3.4154547376875*^9, 3.41545474865625*^9}, {3.41545506440625*^9, 
   3.415455075765625*^9}, 3.415457426859375*^9, {3.415457559234375*^9, 
   3.4154575885625*^9}, {3.415458504609375*^9, 3.415458528171875*^9}, {
   3.415458641953125*^9, 3.41545866378125*^9}, 3.41545871553125*^9, {
   3.415525815109375*^9, 3.415525815609375*^9}, {3.4155259433125*^9, 
   3.415525980125*^9}, 3.41552611540625*^9, {3.415526195140625*^9, 
   3.415526260921875*^9}, {3.415526339734375*^9, 3.41552635415625*^9}, {
   3.41552640359375*^9, 3.415526429890625*^9}, {3.41552648696875*^9, 
   3.41552648965625*^9}, {3.415526608046875*^9, 3.415526620046875*^9}, {
   3.415526683265625*^9, 3.41552668603125*^9}, {3.415526756859375*^9, 
   3.415526792078125*^9}, {3.4155268510625*^9, 3.4155268546875*^9}, {
   3.417771388078125*^9, 3.41777141425*^9}}],

Cell["\<\
If the dimensions of the list are equal to the dimensions of each list of \
components, each vector is multiplied by an element of the list.\
\>", "Text",
 CellChangeTimes->{{3.41545686203125*^9, 3.41545696346875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MultiplyByList", "[", 
    RowBox[{"a_List", ",", "v_CartesianVectors"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Times", ",", 
      RowBox[{"Dimensions", "[", "a", "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"NumberOfVectors", "[", "v", "]"}]}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "#"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41199551803125*^9, 3.41199551853125*^9}, {
  3.41199564478125*^9, 3.411995644984375*^9}, {3.412514403359375*^9, 
  3.412514407359375*^9}, {3.415454825890625*^9, 3.415454830796875*^9}, {
  3.415455206140625*^9, 3.41545520903125*^9}, {3.415457001140625*^9, 
  3.41545700603125*^9}, {3.415527522953125*^9, 3.4155275255625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MultiplyByList", "[", 
   RowBox[{"v_CartesianVectors", ",", "a_List"}], "]"}], ":=", 
  RowBox[{"MultiplyByList", "[", 
   RowBox[{"a", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41199551803125*^9, 3.41199551853125*^9}, {
  3.41199564478125*^9, 3.411995644984375*^9}, {3.412003407984375*^9, 
  3.412003438546875*^9}, {3.412003474265625*^9, 3.412003482078125*^9}, {
  3.412003539078125*^9, 3.412003539828125*^9}, {3.4154548375*^9, 
  3.415454841515625*^9}, {3.41545521475*^9, 3.415455219984375*^9}}],

Cell["Count the number of vectors in a collection.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NumberOfVectors", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"Times", ",", 
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{"Dimensions", "[", "v", "]"}], ",", "1"}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell["Make copies of a single vector or a simple list of vectors.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReplicateVector", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_", ",", "y__"}], "}"}], ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", "n", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.419680607486659*^9, 3.419680765734208*^9}, {
  3.419681008963955*^9, 3.4196810672978354`*^9}, {3.419681184947006*^9, 
  3.419681198726821*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ReplicateVector", "[", 
    RowBox[{"r_CartesianVectors", ",", "n_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "r", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Components", "[", "r", "]"}], "]"}], ",", 
      RowBox[{"{", "n", "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReplicateVector", "[", 
   RowBox[{"r_CartesianVectors", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Thread", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Components", "[", "r", "]"}], ",", 
      RowBox[{"{", "n", "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
The remainder of the exported functions are restricted to two- or \
three-dimensional space.\
\>", "Text",
 CellChangeTimes->{{3.417776023859375*^9, 3.4177760275625*^9}, {
  3.417776195875*^9, 3.417776259796875*^9}}],

Cell[TextData[{
 "Test if the argument is a collection of three-dimensional vectors of the \
data type ",
 StyleBox["CartesianVectors", "Output"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ThreeDimQ", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{
   RowBox[{"Length", "[", "v", "]"}], "\[Equal]", "3"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "Convert a list of complex numbers to a collection of vectors of the data \
type ",
 StyleBox["CartesianVectors", "Output"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ComplexToCartesianVectors", "[", "c_List", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", "c", "]"}], ",", 
     RowBox[{"Im", "[", "c", "]"}]}], "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41726902640625*^9, 3.417269029796875*^9}, {
  3.4177723171875*^9, 3.417772354484375*^9}, {3.4177725548125*^9, 
  3.41777255896875*^9}, {3.417772670671875*^9, 3.417772678234375*^9}, {
  3.432554887307168*^9, 3.4325548890196304`*^9}, {3.432556601672304*^9, 
  3.4325566292519617`*^9}}],

Cell["\<\
Extend a collection of two-dimensional vectors to three-dimensional vectors \
by padding the third component with zeros.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExtendXyToXyz", "[", 
   RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "vz", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy"}], "}"}], "=", 
      RowBox[{"Components", "[", "v", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vz", "=", 
      RowBox[{"0", " ", "vx"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.417338614234375*^9, 3.41733861740625*^9}}],

Cell["\<\
Extend a collection of two-dimensional vectors to three-dimensional vectors \
by padding the second component with zeros.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExtendXzToXyz", "[", 
   RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "vy", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"vx", ",", "vz"}], "}"}], "=", 
      RowBox[{"Components", "[", "v", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vy", "=", 
      RowBox[{"0", " ", "vx"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy", ",", "vz"}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.417338622703125*^9, 3.417338625890625*^9}}],

Cell["\<\
Reflect a collection of points in two-dimensional space through the x axis, \
and rearrange order of vectors to maintain clockwise convention for numbering \
panels.\
\>", "Text",
 CellChangeTimes->{{3.417776293078125*^9, 3.4177763011875*^9}, {
  3.4438730689780784`*^9, 3.4438731159456143`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MirrorXAxis", "[", 
   RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vx", ",", "vy"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"vx", ",", "vy"}], "}"}], "=", 
      RowBox[{"Components", "[", "v", "]"}]}], ";", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Reverse", "[", "vx", "]"}], ",", 
        RowBox[{"-", 
         RowBox[{"Reverse", "[", "vy", "]"}]}]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4173590025*^9, 3.417359006046875*^9}, 
   3.420447741229253*^9, {3.443873139539541*^9, 3.4438731780849667`*^9}}],

Cell[TextData[{
 "Test if the argument is a collection of two-dimensional vectors of the data \
type ",
 StyleBox["CartesianVectors", "Output"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoDimQ", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{
   RowBox[{"Length", "[", "v", "]"}], "\[Equal]", "2"}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Overload existing operators", "Subsubsection"],

Cell[TextData[{
 "There are two guidelines for overloading existing operations for use with \
the data type ",
 StyleBox["CartesianVectors", "Output"],
 ".  First, list-type operations are usually applied to each component of ",
 StyleBox["CartesianVectors", "Output"],
 " and, if appropriate, the results are reassembled into the data type \
CartesianVectors.  Second, operations defined for collections vectors are \
overloaded so that the operation is applied element-by-element."
}], "Text",
 CellChangeTimes->{{3.41777286778125*^9, 3.417772909109375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", " ", "/:", " ", 
  RowBox[{"u_CartesianVectors", "+", "v_CartesianVectors"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Components", "[", "u", "]"}], "+", 
     RowBox[{"Components", "[", "v", "]"}]}], ")"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410793716359375*^9, 3.410793755859375*^9}, {
  3.410793806078125*^9, 3.410793823234375*^9}, {3.41112234803125*^9, 
  3.41112235515625*^9}, {3.411122467578125*^9, 3.41112246975*^9}, {
  3.411122543046875*^9, 3.41112254765625*^9}, {3.41777293134375*^9, 
  3.41777296265625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", " ", "/:", " ", 
  RowBox[{"-", "v_CartesianVectors"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"(", 
    RowBox[{"-", 
     RowBox[{"Components", "[", "v", "]"}]}], ")"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41079394015625*^9, 3.410793964890625*^9}, {
  3.41112236328125*^9, 3.411122373453125*^9}, {3.41112247353125*^9, 
  3.4111224751875*^9}, {3.411122557375*^9, 3.41112256159375*^9}, {
  3.417772968703125*^9, 3.41777297615625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", " ", "/:", " ", 
  RowBox[{
   RowBox[{"a_", "*", "v_CartesianVectors"}], "/;", 
   RowBox[{
    RowBox[{"Head", "[", "a", "]"}], "=!=", "CartesianVectors"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"(", 
    RowBox[{"a", "*", 
     RowBox[{"Components", "[", "v", "]"}]}], ")"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410794066296875*^9, 3.410794084203125*^9}, {
  3.41112238146875*^9, 3.411122389453125*^9}, {3.411122478078125*^9, 
  3.411122479390625*^9}, {3.41112256790625*^9, 3.411122571609375*^9}, {
  3.4113814335*^9, 3.41138143771875*^9}, {3.4113830965625*^9, 
  3.411383120390625*^9}, {3.41199167475*^9, 3.411991679*^9}, {
  3.41199532878125*^9, 3.41199534846875*^9}, {3.41250989896875*^9, 
  3.41250990309375*^9}, {3.412513560453125*^9, 3.412513567515625*^9}, {
  3.41552475928125*^9, 3.415524764640625*^9}, {3.41552490425*^9, 
  3.41552490815625*^9}, {3.415525103*^9, 3.41552510765625*^9}, {
  3.415525500109375*^9, 3.415525503375*^9}, {3.41777301075*^9, 
  3.417773019265625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{"u_CartesianVectors", ",", "elem_List"}], "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Dimensions", "[", "u", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
    RowBox[{"Length", "[", "elem", "]"}]}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"MapThread", "[", 
    RowBox[{"Append", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Components", "[", "u", "]"}], ",", "elem"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41112661540625*^9, 3.411126657421875*^9}, {
   3.41112750790625*^9, 3.4111275159375*^9}, {3.411127630125*^9, 
   3.4111276371875*^9}, 3.411127688125*^9, {3.411127804859375*^9, 
   3.4111278183125*^9}, {3.411128354921875*^9, 3.411128394140625*^9}, {
   3.41112842521875*^9, 3.411128471875*^9}, {3.411128529015625*^9, 
   3.41112852921875*^9}, {3.411128569703125*^9, 3.411128604765625*^9}, {
   3.411128654390625*^9, 3.411128681703125*^9}, {3.41112886578125*^9, 
   3.4111288701875*^9}, {3.41112890678125*^9, 3.411128927078125*^9}, 
   3.411129048734375*^9, {3.41112911603125*^9, 3.4111291261875*^9}, {
   3.41112918015625*^9, 3.411129264046875*^9}, {3.411129325875*^9, 
   3.411129343875*^9}, {3.411129503734375*^9, 3.41112955409375*^9}, {
   3.411129632109375*^9, 3.4111296396875*^9}, {3.4177730455*^9, 
   3.417773057921875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Arrow", "[", 
   RowBox[{"rT_CartesianVectors", ",", "rH_CartesianVectors"}], "]"}], ":=", 
  RowBox[{"Arrow", "/@", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Components", "[", "rT", "]"}], "]"}], ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Components", "[", "rH", "]"}], "]"}]}], "}"}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4411010856290703`*^9, 3.4411011607470846`*^9}, {
   3.4411012399810176`*^9, 3.4411012424545746`*^9}, {3.44110150832688*^9, 
   3.4411015411440687`*^9}, {3.441102104464083*^9, 3.441102106817467*^9}, {
   3.441102196085829*^9, 3.4411022036166573`*^9}, {3.4411022823298416`*^9, 
   3.4411022890495043`*^9}, {3.4411023745424366`*^9, 3.441102384236376*^9}, {
   3.4411035740372257`*^9, 3.441103587586709*^9}, {3.4462159936474*^9, 
   3.4462160189974003`*^9}, 3.4462161095086*^9, {3.4462161506458*^9, 
   3.446216171815*^9}, {3.4462162581921997`*^9, 3.4462163472214003`*^9}, 
   3.446216644807*^9}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{"u_CartesianVectors", ",", "v___CartesianVectors"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "u", "]"}], "]"}], "===", "2"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"MapThread", "[", 
     RowBox[{"Cross", ",", 
      RowBox[{"Transpose", "/@", 
       RowBox[{"Components", "/@", 
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}]}]}]}], "]"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.412003868546875*^9, 3.4120038854375*^9}, {
   3.4120039710625*^9, 3.4120039776875*^9}, {3.4120041046875*^9, 
   3.4120041075625*^9}, 3.412004846703125*^9, {3.412004925078125*^9, 
   3.41200493965625*^9}, {3.41200498359375*^9, 3.412004994875*^9}, {
   3.41200817221875*^9, 3.412008185859375*^9}, {3.412008246984375*^9, 
   3.412008281609375*^9}, {3.412339953609375*^9, 3.41233995546875*^9}, {
   3.4123401288125*^9, 3.412340147046875*^9}, {3.41234025953125*^9, 
   3.412340260875*^9}, {3.41234034996875*^9, 3.41234035484375*^9}, {
   3.412340550796875*^9, 3.41234055265625*^9}, {3.412340686125*^9, 
   3.412340714234375*^9}, {3.41234084784375*^9, 3.4123408564375*^9}, {
   3.4123409283125*^9, 3.41234093740625*^9}, {3.41261147275*^9, 
   3.412611506125*^9}, {3.41261155115625*^9, 3.412611555109375*^9}, {
   3.412611675421875*^9, 3.412611679890625*^9}, {3.412611747625*^9, 
   3.41261174825*^9}, {3.41261181484375*^9, 3.41261181896875*^9}, {
   3.412611880625*^9, 3.412611885578125*^9}, {3.412611972078125*^9, 
   3.4126119988125*^9}, {3.412612214734375*^9, 3.412612235953125*^9}, {
   3.41261233609375*^9, 3.41261234078125*^9}, {3.412612413125*^9, 
   3.41261242315625*^9}, {3.41261245534375*^9, 3.412612464875*^9}, {
   3.4126127316875*^9, 3.412612732984375*^9}, {3.412612769203125*^9, 
   3.41261277828125*^9}, {3.4126129115625*^9, 3.412612915390625*^9}, {
   3.4126129954375*^9, 3.412613012109375*^9}, {3.415438365578125*^9, 
   3.415438371125*^9}, {3.415438465578125*^9, 3.415438525828125*^9}, {
   3.415438882609375*^9, 3.41543890403125*^9}, {3.41543903209375*^9, 
   3.41543903690625*^9}, {3.415439105671875*^9, 3.415439119921875*^9}, {
   3.415439194375*^9, 3.41543920690625*^9}, {3.41543937371875*^9, 
   3.415439375765625*^9}, {3.41543955690625*^9, 3.415439568328125*^9}, {
   3.415439646109375*^9, 3.415439650609375*^9}, {3.415439727046875*^9, 
   3.415439740265625*^9}, {3.415439813515625*^9, 3.415439825921875*^9}, {
   3.415443632296875*^9, 3.415443636109375*^9}, 3.415443716234375*^9, {
   3.41544389459375*^9, 3.415443901515625*^9}, {3.41544408315625*^9, 
   3.41544413121875*^9}, 3.415444166984375*^9, {3.415444305125*^9, 
   3.415444330359375*^9}, {3.41544438703125*^9, 3.41544441690625*^9}, {
   3.41544447928125*^9, 3.415444479734375*^9}, 3.415444547421875*^9, {
   3.4154448798125*^9, 3.415444923296875*^9}, {3.415445040640625*^9, 
   3.415445045671875*^9}, {3.416151398375*^9, 3.4161514083125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{"u_CartesianVectors", ",", "v__CartesianVectors"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "u", "]"}], "]"}], "===", "3"}]}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "n", "}"}], ",", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Last", "[", 
       RowBox[{"Dimensions", "[", "u", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{"#", ",", "n"}], "]"}], "&"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"MapThread", "[", 
          RowBox[{"Cross", ",", 
           RowBox[{"Transpose", "/@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Flatten", "/@", 
               RowBox[{"Components", "[", "u", "]"}]}], ",", 
              RowBox[{"Flatten", "/@", 
               RowBox[{"Components", "[", "v", "]"}]}]}], "}"}]}]}], "]"}], 
         "]"}]}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.412003868546875*^9, 3.4120038854375*^9}, {
   3.4120039710625*^9, 3.4120039776875*^9}, {3.4120041046875*^9, 
   3.4120041075625*^9}, 3.412004846703125*^9, {3.412004925078125*^9, 
   3.41200493965625*^9}, {3.41200498359375*^9, 3.412004994875*^9}, {
   3.41200817221875*^9, 3.412008185859375*^9}, {3.412008246984375*^9, 
   3.412008281609375*^9}, {3.412339953609375*^9, 3.41233995546875*^9}, {
   3.4123401288125*^9, 3.412340147046875*^9}, {3.41234025953125*^9, 
   3.412340260875*^9}, {3.41234034996875*^9, 3.41234035484375*^9}, {
   3.412340550796875*^9, 3.41234055265625*^9}, {3.412340686125*^9, 
   3.412340714234375*^9}, {3.41234084784375*^9, 3.4123408564375*^9}, {
   3.4123409283125*^9, 3.41234093740625*^9}, {3.41261147275*^9, 
   3.412611506125*^9}, {3.41261155115625*^9, 3.412611555109375*^9}, {
   3.412611675421875*^9, 3.412611679890625*^9}, {3.412611747625*^9, 
   3.41261174825*^9}, {3.41261181484375*^9, 3.41261181896875*^9}, {
   3.412611880625*^9, 3.412611885578125*^9}, {3.412611972078125*^9, 
   3.4126119988125*^9}, {3.412612214734375*^9, 3.412612235953125*^9}, {
   3.41261233609375*^9, 3.41261234078125*^9}, {3.412612413125*^9, 
   3.41261242315625*^9}, {3.41261245534375*^9, 3.412612464875*^9}, {
   3.4126127316875*^9, 3.412612732984375*^9}, {3.412612769203125*^9, 
   3.41261277828125*^9}, {3.4126129115625*^9, 3.412612915390625*^9}, {
   3.4126129954375*^9, 3.412613012109375*^9}, {3.415438365578125*^9, 
   3.415438371125*^9}, {3.415438465578125*^9, 3.415438525828125*^9}, {
   3.415438882609375*^9, 3.41543890403125*^9}, {3.41543903209375*^9, 
   3.41543903690625*^9}, {3.415439105671875*^9, 3.415439119921875*^9}, {
   3.415439194375*^9, 3.41543920690625*^9}, {3.41543937371875*^9, 
   3.415439375765625*^9}, {3.41543955690625*^9, 3.415439568328125*^9}, {
   3.415439646109375*^9, 3.415439650609375*^9}, {3.415439727046875*^9, 
   3.415439740265625*^9}, {3.415439813515625*^9, 3.415439825921875*^9}, {
   3.415443632296875*^9, 3.415443636109375*^9}, 3.415443716234375*^9, {
   3.41544389459375*^9, 3.415443901515625*^9}, {3.41544408315625*^9, 
   3.41544413121875*^9}, 3.415444166984375*^9, {3.415444305125*^9, 
   3.415444330359375*^9}, {3.41544438703125*^9, 3.41544441690625*^9}, {
   3.41544447928125*^9, 3.415444479734375*^9}, 3.415444547421875*^9, {
   3.4154448798125*^9, 3.415444923296875*^9}, {3.415445040640625*^9, 
   3.415445045671875*^9}, {3.41544510584375*^9, 3.41544510665625*^9}, {
   3.415445205140625*^9, 3.415445276875*^9}, 3.415445405375*^9, {
   3.41544544790625*^9, 3.415445478078125*^9}, {3.415445515921875*^9, 
   3.415445550078125*^9}, {3.415445688421875*^9, 3.41544574753125*^9}, {
   3.415445815640625*^9, 3.41544582459375*^9}, 3.41615048359375*^9, {
   3.41615138190625*^9, 3.416151394375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{"u_CartesianVectors", "?", "TwoDimQ"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "u", "]"}], "]"}], "===", "3"}]}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "n", "}"}], ",", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Last", "[", 
       RowBox[{"Dimensions", "[", "u", "]"}], "]"}]}], ";", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{"#", ",", "n"}], "]"}], "&"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Cross", "/@", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Flatten", "/@", 
            RowBox[{"Components", "[", "u", "]"}]}], "]"}]}], "]"}]}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.412003868546875*^9, 3.4120038854375*^9}, {
   3.4120039710625*^9, 3.4120039776875*^9}, {3.4120041046875*^9, 
   3.4120041075625*^9}, 3.412004846703125*^9, {3.412004925078125*^9, 
   3.41200493965625*^9}, {3.41200498359375*^9, 3.412004994875*^9}, {
   3.41200817221875*^9, 3.412008185859375*^9}, {3.412008246984375*^9, 
   3.412008281609375*^9}, {3.412339953609375*^9, 3.41233995546875*^9}, {
   3.4123401288125*^9, 3.412340147046875*^9}, {3.41234025953125*^9, 
   3.412340260875*^9}, {3.41234034996875*^9, 3.41234035484375*^9}, {
   3.412340550796875*^9, 3.41234055265625*^9}, {3.412340686125*^9, 
   3.412340714234375*^9}, {3.41234084784375*^9, 3.4123408564375*^9}, {
   3.4123409283125*^9, 3.41234093740625*^9}, {3.41261147275*^9, 
   3.412611506125*^9}, {3.41261155115625*^9, 3.412611555109375*^9}, {
   3.412611675421875*^9, 3.412611679890625*^9}, {3.412611747625*^9, 
   3.41261174825*^9}, {3.41261181484375*^9, 3.41261181896875*^9}, {
   3.412611880625*^9, 3.412611885578125*^9}, {3.412611972078125*^9, 
   3.4126119988125*^9}, {3.412612214734375*^9, 3.412612235953125*^9}, {
   3.41261233609375*^9, 3.41261234078125*^9}, {3.412612413125*^9, 
   3.41261242315625*^9}, {3.41261245534375*^9, 3.412612464875*^9}, {
   3.4126127316875*^9, 3.412612732984375*^9}, {3.412612769203125*^9, 
   3.41261277828125*^9}, {3.4126129115625*^9, 3.412612915390625*^9}, {
   3.4126129954375*^9, 3.412613012109375*^9}, {3.415438365578125*^9, 
   3.415438371125*^9}, {3.415438465578125*^9, 3.415438525828125*^9}, {
   3.415438882609375*^9, 3.41543890403125*^9}, {3.41543903209375*^9, 
   3.41543903690625*^9}, {3.415439105671875*^9, 3.415439119921875*^9}, {
   3.415439194375*^9, 3.41543920690625*^9}, {3.41543937371875*^9, 
   3.415439375765625*^9}, {3.41543955690625*^9, 3.415439568328125*^9}, {
   3.415439646109375*^9, 3.415439650609375*^9}, {3.415439727046875*^9, 
   3.415439740265625*^9}, {3.415439813515625*^9, 3.415439825921875*^9}, {
   3.415443632296875*^9, 3.415443636109375*^9}, 3.415443716234375*^9, {
   3.41544389459375*^9, 3.415443901515625*^9}, {3.41544408315625*^9, 
   3.41544413121875*^9}, 3.415444166984375*^9, {3.415444305125*^9, 
   3.415444330359375*^9}, {3.41544438703125*^9, 3.41544441690625*^9}, {
   3.41544447928125*^9, 3.415444479734375*^9}, 3.415444547421875*^9, {
   3.4154448798125*^9, 3.415444923296875*^9}, {3.415445040640625*^9, 
   3.415445045671875*^9}, {3.41544510584375*^9, 3.41544510665625*^9}, {
   3.415445205140625*^9, 3.415445276875*^9}, 3.415445405375*^9, {
   3.41544544790625*^9, 3.415445478078125*^9}, {3.415445515921875*^9, 
   3.415445550078125*^9}, {3.415445688421875*^9, 3.41544574753125*^9}, {
   3.415445815640625*^9, 3.41544582459375*^9}, 3.41615048359375*^9, {
   3.416150638109375*^9, 3.41615065103125*^9}, 3.4161506939375*^9, 
   3.41615074778125*^9, {3.41615079484375*^9, 3.416150848203125*^9}, {
   3.416150907203125*^9, 3.41615091521875*^9}, {3.41615097675*^9, 
   3.41615098175*^9}, {3.41615106675*^9, 3.416151175515625*^9}, {
   3.416151254734375*^9, 3.4161512686875*^9}, 3.4408426154873133`*^9}],

Cell[BoxData[
 RowBox[{"CartesianVectors", " ", "/:", " ", 
  RowBox[{"Dimensions", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"Dimensions", "[", 
   RowBox[{"Components", "[", "v", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411140995484375*^9, 3.411141001984375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Dot", "[", 
    RowBox[{"u_CartesianVectors", ",", "v_CartesianVectors"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "u", "]"}], "===", "1"}]}], ":=", 
  RowBox[{"Plus", "@@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Components", "[", "u", "]"}], "*", 
     RowBox[{"Components", "[", "v", "]"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.412003868546875*^9, 3.4120038854375*^9}, {
   3.4120039710625*^9, 3.4120039776875*^9}, {3.4120041046875*^9, 
   3.4120041075625*^9}, 3.412004846703125*^9, {3.412004925078125*^9, 
   3.41200493965625*^9}, {3.41200498359375*^9, 3.412004994875*^9}, {
   3.414315589265625*^9, 3.414315639953125*^9}, {3.414315683625*^9, 
   3.41431568940625*^9}, {3.414315760640625*^9, 3.414315766515625*^9}, 
   3.4143158551875*^9, {3.4143160109375*^9, 3.41431602365625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Dot", "[", 
   RowBox[{"u_CartesianVectors", ",", "v_CartesianVectors"}], "]"}], ":=", 
  RowBox[{"Plus", "@@@", 
   RowBox[{"Transpose", "[", 
    RowBox[{
     RowBox[{"Components", "[", "u", "]"}], "*", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.412003868546875*^9, 3.4120038854375*^9}, {
   3.4120039710625*^9, 3.4120039776875*^9}, {3.4120041046875*^9, 
   3.4120041075625*^9}, 3.412004846703125*^9, {3.412004925078125*^9, 
   3.41200493965625*^9}, {3.41200498359375*^9, 3.412004994875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Dot", "[", 
    RowBox[{"v_CartesianVectors", ",", "a_List"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "2"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"List", "/@", 
    RowBox[{"Thread", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Components", "[", "v", "]"}], ",", "a"}], "]"}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410794679796875*^9, 3.41079469334375*^9}, {
   3.410794851234375*^9, 3.4107948558125*^9}, {3.41079504146875*^9, 
   3.4107951005*^9}, {3.410795154046875*^9, 3.4107951955625*^9}, {
   3.41079530590625*^9, 3.410795320703125*^9}, {3.410795436140625*^9, 
   3.4107955135*^9}, {3.410795589875*^9, 3.4107955970625*^9}, {
   3.410795676421875*^9, 3.410795689203125*^9}, {3.410795724921875*^9, 
   3.410795760046875*^9}, {3.41079592678125*^9, 3.410795933421875*^9}, {
   3.414324226203125*^9, 3.4143242388125*^9}, {3.4143243856875*^9, 
   3.414324386875*^9}, {3.414324494296875*^9, 3.41432450940625*^9}, {
   3.414324542859375*^9, 3.41432455953125*^9}, 3.4143246089375*^9, {
   3.4143247460625*^9, 3.414324823703125*^9}, {3.414324876203125*^9, 
   3.414324901296875*^9}, 3.414324982171875*^9, {3.414325556078125*^9, 
   3.414325564234375*^9}, {3.414325641328125*^9, 3.41432564228125*^9}, {
   3.414325708453125*^9, 3.414325710625*^9}, {3.414325786578125*^9, 
   3.41432580509375*^9}, {3.414325872046875*^9, 3.41432588734375*^9}, {
   3.4143310868125*^9, 3.41433109115625*^9}, {3.414331240671875*^9, 
   3.414331257828125*^9}, {3.414331450734375*^9, 3.414331457265625*^9}, {
   3.414331536328125*^9, 3.414331539671875*^9}, {3.4143317461875*^9, 
   3.4143317516875*^9}, {3.414331904515625*^9, 3.41433191484375*^9}, {
   3.414332023078125*^9, 3.414332029796875*^9}, {3.415533234890625*^9, 
   3.415533240765625*^9}, {3.415533741265625*^9, 3.4155338290625*^9}, {
   3.415534100375*^9, 3.41553410509375*^9}, {3.415534155234375*^9, 
   3.415534173484375*^9}, {3.4155342330625*^9, 3.415534238078125*^9}, {
   3.415534279265625*^9, 3.415534282859375*^9}, {3.417773231421875*^9, 
   3.417773249125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Dot", "[", 
    RowBox[{"v_CartesianVectors", ",", "a_List"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "3"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Thread", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Components", "[", "v", "]"}], ",", "a"}], "]"}], "]"}], "]"}],
    "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410794679796875*^9, 3.41079469334375*^9}, {
   3.410794851234375*^9, 3.4107948558125*^9}, {3.41079504146875*^9, 
   3.4107951005*^9}, {3.410795154046875*^9, 3.4107951955625*^9}, {
   3.41079530590625*^9, 3.410795320703125*^9}, {3.410795436140625*^9, 
   3.4107955135*^9}, {3.410795589875*^9, 3.4107955970625*^9}, {
   3.410795676421875*^9, 3.410795689203125*^9}, {3.410795724921875*^9, 
   3.410795760046875*^9}, {3.41079592678125*^9, 3.410795933421875*^9}, {
   3.414324226203125*^9, 3.4143242388125*^9}, {3.4143243856875*^9, 
   3.414324386875*^9}, {3.414324494296875*^9, 3.41432450940625*^9}, {
   3.414324542859375*^9, 3.41432455953125*^9}, 3.4143246089375*^9, {
   3.4143247460625*^9, 3.414324823703125*^9}, {3.414324876203125*^9, 
   3.414324901296875*^9}, 3.414324982171875*^9, {3.414325556078125*^9, 
   3.414325564234375*^9}, {3.414325641328125*^9, 3.41432564228125*^9}, {
   3.414325708453125*^9, 3.414325710625*^9}, {3.414325786578125*^9, 
   3.41432580509375*^9}, {3.414325872046875*^9, 3.41432588734375*^9}, {
   3.4143310868125*^9, 3.41433109115625*^9}, {3.414331240671875*^9, 
   3.414331257828125*^9}, {3.414331450734375*^9, 3.414331457265625*^9}, {
   3.414331536328125*^9, 3.414331539671875*^9}, {3.4143317461875*^9, 
   3.4143317516875*^9}, {3.414331904515625*^9, 3.41433191484375*^9}, {
   3.414332023078125*^9, 3.414332029796875*^9}, {3.415533234890625*^9, 
   3.415533240765625*^9}, {3.415533741265625*^9, 3.4155337914375*^9}, {
   3.417773271140625*^9, 3.41777328228125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Drop", "[", 
   RowBox[{"v_CartesianVectors", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "n"}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4112111255625*^9, 3.41121113525*^9}, {
  3.417773316953125*^9, 3.4177733255*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Drop", "[", 
   RowBox[{"v_CartesianVectors", ",", 
    RowBox[{"{", "n__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", "n", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411212397171875*^9, 3.411212414296875*^9}, {
  3.417773350953125*^9, 3.4177733596875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"First", "[", "v_CartesianVectors", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "2"}]}], ":=", 
  RowBox[{"First", "/@", 
   RowBox[{"Components", "[", "v", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411143129484375*^9, 3.41114318903125*^9}, {
   3.41114324590625*^9, 3.411143253609375*^9}, 3.41114409453125*^9, {
   3.411145378984375*^9, 3.41114540375*^9}, {3.411145510796875*^9, 
   3.411145528375*^9}, {3.41561088084375*^9, 3.415610902671875*^9}, {
   3.41562765434375*^9, 3.4156276624375*^9}, 3.41562772753125*^9}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"First", "[", "v_CartesianVectors", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "3"}]}], ":=", 
  RowBox[{"CartesianVectors", "@@", 
   RowBox[{"First", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411143129484375*^9, 3.41114318903125*^9}, {
   3.41114324590625*^9, 3.411143253609375*^9}, 3.41114409453125*^9, {
   3.411145378984375*^9, 3.41114540375*^9}, {3.411145488125*^9, 
   3.411145488890625*^9}, {3.41114553409375*^9, 3.411145554921875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Flatten", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{"Flatten", ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41078387715625*^9, 3.410783884015625*^9}, {
  3.4107842461875*^9, 3.4107842490625*^9}, {3.4111219554375*^9, 
  3.41112195840625*^9}, {3.411122032046875*^9, 3.4111220395625*^9}, {
  3.417773384984375*^9, 3.41777339584375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"u_CartesianVectors", ",", "elem_List", ",", "pos_Integer"}], 
    "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Dimensions", "[", "u", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
    RowBox[{"Length", "[", "elem", "]"}]}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"Components", "[", "u", "]"}], ",", "elem", ",", "pos"}], 
      "]"}], "]"}], "/.", 
    RowBox[{"f", "\[Rule]", "Insert"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41112661540625*^9, 3.411126657421875*^9}, {
   3.41112750790625*^9, 3.4111275159375*^9}, {3.411127630125*^9, 
   3.4111276371875*^9}, 3.411127688125*^9, {3.411127804859375*^9, 
   3.4111278183125*^9}, {3.411128354921875*^9, 3.411128394140625*^9}, {
   3.41112842521875*^9, 3.411128471875*^9}, {3.411128529015625*^9, 
   3.41112852921875*^9}, {3.411128569703125*^9, 3.411128604765625*^9}, {
   3.411128654390625*^9, 3.411128681703125*^9}, {3.41112886578125*^9, 
   3.4111288701875*^9}, {3.41112890678125*^9, 3.411128927078125*^9}, 
   3.411129048734375*^9, {3.41112911603125*^9, 3.4111291261875*^9}, {
   3.41112918015625*^9, 3.411129264046875*^9}, {3.411129325875*^9, 
   3.411129343875*^9}, {3.411129503734375*^9, 3.41112955409375*^9}, {
   3.411129632109375*^9, 3.4111296396875*^9}, {3.4177730455*^9, 
   3.417773057921875*^9}, {3.434362558037629*^9, 3.4343625784069185`*^9}, {
   3.434362697768552*^9, 3.4343627219132705`*^9}, {3.4343627737077475`*^9, 
   3.434362775149821*^9}, {3.4343652666023536`*^9, 3.434365294873005*^9}, {
   3.4343654453694077`*^9, 3.434365453711403*^9}, {3.4343657168497777`*^9, 
   3.434365720234645*^9}, {3.4343658090623727`*^9, 3.43436581319832*^9}, {
   3.4343658888170547`*^9, 3.4343658926725984`*^9}, {3.434366001318824*^9, 
   3.4343660065363264`*^9}, {3.4343661048677197`*^9, 3.4343661231339855`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Join", "[", 
   RowBox[{"u_CartesianVectors", ",", "v_CartesianVectors"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"MapThread", "[", 
    RowBox[{"Join", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Components", "[", "u", "]"}], ",", 
       RowBox[{"Components", "[", "v", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41554355659375*^9, 3.41554356046875*^9}, {
  3.415543638265625*^9, 3.415543650203125*^9}, {3.415543700953125*^9, 
  3.415543713390625*^9}, {3.41554413965625*^9, 3.41554415521875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Last", "[", "v_CartesianVectors", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "2"}]}], ":=", 
  RowBox[{"Last", "/@", 
   RowBox[{"Components", "[", "v", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411143129484375*^9, 3.41114318903125*^9}, {
   3.41114324590625*^9, 3.411143253609375*^9}, {3.411143334546875*^9, 
   3.4111433450625*^9}, 3.411144376640625*^9, {3.411145664875*^9, 
   3.41114571671875*^9}, {3.415610294421875*^9, 3.415610298984375*^9}, {
   3.415610407203125*^9, 3.415610419359375*^9}, {3.415627809171875*^9, 
   3.415627811609375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Last", "[", "v_CartesianVectors", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "3"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Last", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411143129484375*^9, 3.41114318903125*^9}, {
   3.41114324590625*^9, 3.411143253609375*^9}, {3.411143334546875*^9, 
   3.4111433450625*^9}, 3.411144376640625*^9, {3.411145664875*^9, 
   3.41114574215625*^9}, {3.417773426703125*^9, 3.417773434875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Length", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"Length", "[", 
   RowBox[{"Components", "[", "v", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41561235946875*^9, 3.415612364546875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"r_CartesianVectors", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Components", "[", "r", "]"}], "]"}], ",", "opts"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41554355659375*^9, 3.41554356046875*^9}, {
   3.415543638265625*^9, 3.415543650203125*^9}, {3.415543700953125*^9, 
   3.415543713390625*^9}, {3.41554413965625*^9, 3.41554415521875*^9}, {
   3.4183746116727886`*^9, 3.418374630409731*^9}, 3.4183746905261745`*^9, {
   3.418374749621149*^9, 3.4183747779619007`*^9}, {3.418374834703491*^9, 
   3.418374837377336*^9}, {3.4183750903010225`*^9, 3.4183750964899216`*^9}, 
   3.4183752660737715`*^9, {3.4183753630832644`*^9, 3.4183753967516766`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"ListVectorPlot", "[", 
   RowBox[{"r_CartesianVectors", ",", "v_CartesianVectors", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"ListVectorPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Components", "[", "r", "]"}], "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Components", "[", "v", "]"}], "]"}]}], "}"}], "]"}], ",", 
    "opts"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41554355659375*^9, 3.41554356046875*^9}, {
   3.415543638265625*^9, 3.415543650203125*^9}, {3.415543700953125*^9, 
   3.415543713390625*^9}, {3.41554413965625*^9, 3.41554415521875*^9}, {
   3.4183746116727886`*^9, 3.418374630409731*^9}, 3.4183746905261745`*^9, {
   3.418374749621149*^9, 3.4183747779619007`*^9}, {3.418374834703491*^9, 
   3.418374837377336*^9}, {3.4183750903010225`*^9, 3.4183750964899216`*^9}, 
   3.4183752660737715`*^9, {3.4183753630832644`*^9, 3.4183753967516766`*^9}, {
   3.4183759866699376`*^9, 3.418376003083539*^9}, {3.4183760464258623`*^9, 
   3.418376064541912*^9}, {3.4183761442164783`*^9, 3.4183762151284447`*^9}, {
   3.4408457105678205`*^9, 3.44084572618027*^9}}],

Cell["\<\
It is necessary to replace the head instead of using constructor in following \
overload.\
\>", "Text",
 CellChangeTimes->{{3.4179484362003345`*^9, 3.4179485220537853`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"MatrixForm", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"CartesianVectors", "@@", 
   RowBox[{"Map", "[", 
    RowBox[{"MatrixForm", ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410776868234375*^9, 3.410776872703125*^9}, {
   3.410777069890625*^9, 3.410777077078125*^9}, {3.41561262409375*^9, 
   3.4156126510625*^9}, {3.4156127243125*^9, 3.415612733453125*^9}, 
   3.415612795703125*^9, {3.417773561015625*^9, 3.417773570171875*^9}, {
   3.4179485264100494`*^9, 3.4179485417821536`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Most", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Most", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411209189921875*^9, 3.411209193203125*^9}, {
  3.411209442296875*^9, 3.4112094609375*^9}, {3.417773601046875*^9, 
  3.417773609578125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Normalize", "[", "v_CartesianVectors", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "2"}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Normalize", "/@", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Components", "[", "v", "]"}], "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.420195155063363*^9, 3.420195190284008*^9}, {
   3.420195360889326*^9, 3.4201953806677666`*^9}, {3.4201955920216784`*^9, 
   3.420195600123328*^9}, {3.4201956652770147`*^9, 3.4201956737992687`*^9}, {
   3.4201957395638337`*^9, 3.4201957468543167`*^9}, {3.4201958077518835`*^9, 
   3.420195821311381*^9}, 3.420196070429595*^9, {3.4201968524040194`*^9, 
   3.4201968530649695`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", " ", "/:", 
  RowBox[{"Outer", "[", 
   RowBox[{"f_", ",", "u_CartesianVectors", ",", "v_CartesianVectors"}], 
   "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"f", ",", 
       RowBox[{
        RowBox[{"Components", "[", "u", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Components", "[", "v", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "u", "]"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Part", "[", 
    RowBox[{"v_CartesianVectors", ",", "i_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "2"}]}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Part", "[", 
      RowBox[{"#", ",", "i"}], "]"}], "&"}], ",", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4002522665625*^9, 3.40025236015625*^9}, {
   3.40025343415625*^9, 3.400253435921875*^9}, {3.400253647234375*^9, 
   3.40025369284375*^9}, {3.40025377365625*^9, 3.40025381440625*^9}, 
   3.40025384759375*^9, 3.40025754834375*^9, {3.4002576726875*^9, 
   3.400257687578125*^9}, {3.410700215046875*^9, 3.41070021984375*^9}, {
   3.4107002960625*^9, 3.410700317390625*^9}, 3.4107003613125*^9, {
   3.410705928171875*^9, 3.410705930140625*^9}, {3.41070596034375*^9, 
   3.410705963046875*^9}, {3.41070608971875*^9, 3.410706098421875*^9}, {
   3.410706147015625*^9, 3.41070615165625*^9}, {3.410706379578125*^9, 
   3.4107063975625*^9}, {3.4107064606875*^9, 3.410706467359375*^9}, {
   3.4107066840625*^9, 3.41070670215625*^9}, {3.410707043734375*^9, 
   3.41070705109375*^9}, {3.410707323484375*^9, 3.41070733565625*^9}, {
   3.410707425125*^9, 3.410707428765625*^9}, {3.410707544671875*^9, 
   3.41070755275*^9}, {3.410707600640625*^9, 3.410707611140625*^9}, {
   3.410707739234375*^9, 3.4107077426875*^9}, {3.410707845640625*^9, 
   3.410707851359375*^9}, {3.4107079041875*^9, 3.4107079091875*^9}, {
   3.410707954328125*^9, 3.410707966609375*^9}, {3.411124214390625*^9, 
   3.411124224375*^9}, {3.411124307078125*^9, 3.411124316828125*^9}, {
   3.41112444921875*^9, 3.41112445121875*^9}, 3.41415027553125*^9, 
   3.414150596046875*^9, 3.414150873265625*^9, {3.414150977125*^9, 
   3.414151004015625*^9}, 3.414151037359375*^9, {3.414151103953125*^9, 
   3.414151161671875*^9}, {3.414151281265625*^9, 3.414151291703125*^9}, {
   3.415611717328125*^9, 3.41561176084375*^9}, 3.415611931046875*^9, {
   3.4156280456875*^9, 3.41562805934375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Part", "[", 
    RowBox[{"v_CartesianVectors", ",", "i_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Dimensions", "[", "v", "]"}], "]"}], "===", "3"}]}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Part", "[", 
       RowBox[{"#", ",", "i"}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4002522665625*^9, 3.40025236015625*^9}, {
   3.40025343415625*^9, 3.400253435921875*^9}, {3.400253647234375*^9, 
   3.40025369284375*^9}, {3.40025377365625*^9, 3.40025381440625*^9}, 
   3.40025384759375*^9, 3.40025754834375*^9, {3.4002576726875*^9, 
   3.400257687578125*^9}, {3.410700215046875*^9, 3.41070021984375*^9}, {
   3.4107002960625*^9, 3.410700317390625*^9}, 3.4107003613125*^9, {
   3.410705928171875*^9, 3.410705930140625*^9}, {3.41070596034375*^9, 
   3.410705963046875*^9}, {3.41070608971875*^9, 3.410706098421875*^9}, {
   3.410706147015625*^9, 3.41070615165625*^9}, {3.410706379578125*^9, 
   3.4107063975625*^9}, {3.4107064606875*^9, 3.410706467359375*^9}, {
   3.4107066840625*^9, 3.41070670215625*^9}, {3.410707043734375*^9, 
   3.41070705109375*^9}, {3.410707323484375*^9, 3.41070733565625*^9}, {
   3.410707425125*^9, 3.410707428765625*^9}, {3.410707544671875*^9, 
   3.41070755275*^9}, {3.410707600640625*^9, 3.410707611140625*^9}, {
   3.410707739234375*^9, 3.4107077426875*^9}, {3.410707845640625*^9, 
   3.410707851359375*^9}, {3.4107079041875*^9, 3.4107079091875*^9}, {
   3.410707954328125*^9, 3.410707966609375*^9}, {3.411124214390625*^9, 
   3.411124224375*^9}, {3.411124307078125*^9, 3.411124316828125*^9}, {
   3.41112444921875*^9, 3.41112445121875*^9}, 3.41415027553125*^9, 
   3.414150596046875*^9, 3.414150873265625*^9, {3.414150977125*^9, 
   3.414151004015625*^9}, 3.414151037359375*^9, {3.414151103953125*^9, 
   3.414151161671875*^9}, {3.414151281265625*^9, 3.414151291703125*^9}, {
   3.415611717328125*^9, 3.41561176084375*^9}, {3.415611931046875*^9, 
   3.415611953453125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Part", "[", 
   RowBox[{"v_CartesianVectors", ",", "i_Integer", ",", "j_Integer"}], "]"}], 
  ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"[", "i", "]"}], "]"}], "[", 
   RowBox[{"[", "j", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4002522665625*^9, 3.40025236015625*^9}, {
   3.40025343415625*^9, 3.400253435921875*^9}, {3.400253647234375*^9, 
   3.40025369284375*^9}, {3.40025377365625*^9, 3.40025381440625*^9}, 
   3.40025384759375*^9, 3.40025754834375*^9, {3.4002576726875*^9, 
   3.400257687578125*^9}, {3.410700215046875*^9, 3.41070021984375*^9}, {
   3.4107002960625*^9, 3.410700317390625*^9}, 3.4107003613125*^9, {
   3.410705928171875*^9, 3.410705930140625*^9}, {3.41070596034375*^9, 
   3.410705963046875*^9}, {3.41070608971875*^9, 3.410706098421875*^9}, {
   3.410706147015625*^9, 3.41070615165625*^9}, {3.410706379578125*^9, 
   3.4107063975625*^9}, {3.4107064606875*^9, 3.410706467359375*^9}, {
   3.4107066840625*^9, 3.41070670215625*^9}, {3.410707043734375*^9, 
   3.41070705109375*^9}, {3.410707323484375*^9, 3.41070733565625*^9}, {
   3.410707425125*^9, 3.410707428765625*^9}, {3.410707544671875*^9, 
   3.41070755275*^9}, {3.410707600640625*^9, 3.410707611140625*^9}, {
   3.410707739234375*^9, 3.4107077426875*^9}, {3.410707845640625*^9, 
   3.410707851359375*^9}, {3.4107079041875*^9, 3.4107079091875*^9}, {
   3.410707954328125*^9, 3.410707966609375*^9}, {3.411124214390625*^9, 
   3.411124224375*^9}, {3.411124307078125*^9, 3.411124316828125*^9}, {
   3.41112444921875*^9, 3.41112445121875*^9}, 3.41415027553125*^9, 
   3.414150596046875*^9, 3.414150873265625*^9, {3.414150977125*^9, 
   3.414150993828125*^9}, {3.414163162921875*^9, 3.414163168265625*^9}, {
   3.4141632688125*^9, 3.414163271765625*^9}, {3.41416331628125*^9, 
   3.4141633496875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Part", "[", 
   RowBox[{"v_CartesianVectors", ",", 
    RowBox[{"{", "i__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"List", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Part", "[", 
        RowBox[{"#", ",", 
         RowBox[{"{", "i", "}"}]}], "]"}], "&"}], ",", 
      RowBox[{"Components", "[", "v", "]"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.410705815046875*^9, 3.410705825125*^9}, {
  3.41112476184375*^9, 3.411124784171875*^9}, {3.411124861578125*^9, 
  3.41112487753125*^9}, {3.41561388575*^9, 3.4156139025625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{"u_CartesianVectors", ",", "elem_List"}], "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Dimensions", "[", "u", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
    RowBox[{"Length", "[", "elem", "]"}]}]}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"List", "@@", 
    RowBox[{"MapThread", "[", 
     RowBox[{"Prepend", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Components", "[", "u", "]"}], ",", "elem"}], "}"}]}], 
     "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41112661540625*^9, 3.411126657421875*^9}, {
   3.41112750790625*^9, 3.4111275159375*^9}, {3.411127630125*^9, 
   3.4111276371875*^9}, 3.411127688125*^9, {3.411127804859375*^9, 
   3.4111278183125*^9}, {3.411128354921875*^9, 3.411128394140625*^9}, {
   3.41112842521875*^9, 3.411128471875*^9}, {3.411128529015625*^9, 
   3.41112852921875*^9}, {3.411128569703125*^9, 3.411128604765625*^9}, {
   3.411128654390625*^9, 3.411128681703125*^9}, {3.41112886578125*^9, 
   3.4111288701875*^9}, {3.41112890678125*^9, 3.411128927078125*^9}, 
   3.411129048734375*^9, {3.41112911603125*^9, 3.4111291261875*^9}, {
   3.41112918015625*^9, 3.411129264046875*^9}, {3.411129325875*^9, 
   3.411129343875*^9}, {3.411129503734375*^9, 3.41112955409375*^9}, {
   3.411129632109375*^9, 3.4111296396875*^9}, {3.411141637359375*^9, 
   3.41114165953125*^9}, {3.4156139104375*^9, 3.4156139299375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{"u_CartesianVectors", ",", 
    RowBox[{"n_Integer", "\[Rule]", 
     RowBox[{"elem_", "?", "VectorQ"}]}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"MapThread", "[", 
    RowBox[{"ReplacePart", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Components", "[", "u", "]"}], ",", 
       RowBox[{"Thread", "[", 
        RowBox[{"n", "\[Rule]", "elem"}], "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4531265989772*^9, 3.453126624686*^9}, {
  3.4531266761504*^9, 3.4531267330592003`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{"u_CartesianVectors", ",", 
    RowBox[{"{", "rule__Rule", "}"}]}], "]"}], ":=", 
  RowBox[{"Fold", "[", 
   RowBox[{"ReplacePart", ",", "u", ",", 
    RowBox[{"{", "rule", "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4531265989772*^9, 3.453126624686*^9}, {
  3.4531267540256*^9, 3.4531267931191998`*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Rest", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"List", "@@", 
    RowBox[{"Rest", "/@", 
     RowBox[{"Components", "[", "v", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411209866734375*^9, 3.41120989584375*^9}, {
  3.415615249984375*^9, 3.415615272203125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Reverse", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{"Reverse", ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41561612240625*^9, 3.415616131*^9}, {
  3.415616197890625*^9, 3.4156162118125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"RotateLeft", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"RotateLeft", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41414277146875*^9, 3.414142775359375*^9}, {
   3.414142918890625*^9, 3.4141429280625*^9}, {3.414143763578125*^9, 
   3.41414379040625*^9}, 3.414143827125*^9, {3.415617180609375*^9, 
   3.41561719321875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"RotateLeft", "[", 
   RowBox[{"v_CartesianVectors", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"RotateLeft", "[", 
       RowBox[{"#", ",", "n"}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41414277146875*^9, 3.414142775359375*^9}, {
  3.414142918890625*^9, 3.4141429280625*^9}, {3.41414325025*^9, 
  3.414143286453125*^9}, {3.414143435359375*^9, 3.414143453421875*^9}, {
  3.414143594734375*^9, 3.414143601640625*^9}, {3.4156172033125*^9, 
  3.415617209828125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"RotateLeft", "[", 
   RowBox[{"v_CartesianVectors", ",", 
    RowBox[{"{", "n__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"RotateLeft", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", "n", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414143210609375*^9, 3.41414321515625*^9}, {
  3.414144208671875*^9, 3.414144216421875*^9}, {3.414420921453125*^9, 
  3.414420925953125*^9}, {3.41561721953125*^9, 3.415617227828125*^9}, {
  3.415617384078125*^9, 3.41561739540625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"RotateRight", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"RotateRight", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.41414294153125*^9, {3.414143726546875*^9, 3.4141437284375*^9}, {
   3.414143851515625*^9, 3.414143872984375*^9}, {3.415618617*^9, 
   3.415618636140625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"RotateRight", "[", 
   RowBox[{"v_CartesianVectors", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"RotateRight", "[", 
       RowBox[{"#", ",", "n"}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41414277146875*^9, 3.414142775359375*^9}, {
  3.414142918890625*^9, 3.4141429280625*^9}, {3.41414325025*^9, 
  3.414143286453125*^9}, {3.414143435359375*^9, 3.414143453421875*^9}, {
  3.414143594734375*^9, 3.414143601640625*^9}, {3.414144161875*^9, 
  3.41414417371875*^9}, {3.4156186689375*^9, 3.4156186816875*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"CartesianVectors", "/:", 
   RowBox[{"RotateRight", "[", 
    RowBox[{"v_CartesianVectors", ",", 
     RowBox[{"{", "n__Integer", "}"}]}], "]"}], ":=", 
   RowBox[{"MakeCartesianVectors", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RotateRight", "[", 
        RowBox[{"#", ",", 
         RowBox[{"{", "n", "}"}]}], "]"}], "&"}], ",", 
      RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414143223671875*^9, 3.41414322734375*^9}, {
  3.414144219890625*^9, 3.414144227265625*^9}, {3.415618584375*^9, 
  3.41561858834375*^9}, {3.41561865025*^9, 3.415618651703125*^9}, {
  3.415618695640625*^9, 3.415618700578125*^9}}],

Cell["\<\
Scale is restricted to vectors whose components are simple lists.\
\>", "Text",
 CellChangeTimes->{{3.415619901875*^9, 3.41561992728125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Scale", "[", 
   RowBox[{"v_CartesianVectors", ",", 
    RowBox[{"{", 
     RowBox[{"sx_", ",", "sy__"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "ts"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Components", "[", "v", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ts", "=", 
      RowBox[{"ScalingTransform", "[", 
       RowBox[{"{", 
        RowBox[{"sx", ",", "sy"}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"Transpose", "[", 
       RowBox[{"ts", "[", "p", "]"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399717395109375*^9, 3.399717490046875*^9}, {
   3.399719875640625*^9, 3.39971987659375*^9}, {3.399883908*^9, 
   3.399883908234375*^9}, 3.39988394690625*^9, 3.399883980984375*^9, {
   3.39988414009375*^9, 3.399884166125*^9}, {3.399884216296875*^9, 
   3.399884238484375*^9}, {3.3998843659375*^9, 3.39988439528125*^9}, {
   3.399884429484375*^9, 3.39988452128125*^9}, 3.39988455221875*^9, 
   3.39988516103125*^9, {3.3998852676875*^9, 3.399885303375*^9}, 
   3.39988548025*^9, {3.399886753765625*^9, 3.3998867586875*^9}, {
   3.39988682284375*^9, 3.3998868305*^9}, 3.399886884703125*^9, 
   3.3998877748125*^9, {3.399887941234375*^9, 3.399887943640625*^9}, {
   3.399887988484375*^9, 3.399888010359375*^9}, {3.3998880593125*^9, 
   3.399888084203125*^9}, {3.3998882464375*^9, 3.39988825071875*^9}, {
   3.399889984421875*^9, 3.39988998646875*^9}, {3.399890111921875*^9, 
   3.399890136515625*^9}, {3.3998905119375*^9, 3.3998905140625*^9}, 
   3.40083657225*^9}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Simplify", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{"Simplify", ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41562026096875*^9, 3.41562026728125*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Take", "[", 
   RowBox[{"v_CartesianVectors", ",", "i__Integer"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Take", "[", 
       RowBox[{"#", ",", "i"}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.415621184296875*^9, 3.415621188859375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Take", "[", 
   RowBox[{"v_CartesianVectors", ",", 
    RowBox[{"{", "i__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Take", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", "i", "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"Components", "[", "v", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41562119540625*^9, 3.415621202234375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Translate", "[", 
   RowBox[{
    RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y__"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "tt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Components", "[", "v", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tt", "=", 
      RowBox[{"TranslationTransform", "[", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"Transpose", "[", 
       RowBox[{"tt", "[", "p", "]"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399717395109375*^9, 3.399717490046875*^9}, {
   3.399719875640625*^9, 3.39971987659375*^9}, {3.399883908*^9, 
   3.399883908234375*^9}, 3.39988394690625*^9, 3.399883980984375*^9, {
   3.39988414009375*^9, 3.399884166125*^9}, {3.399884216296875*^9, 
   3.399884238484375*^9}, {3.3998843659375*^9, 3.39988439528125*^9}, {
   3.399884429484375*^9, 3.39988452128125*^9}, 3.39988455221875*^9, 
   3.39988516103125*^9, {3.3998852676875*^9, 3.399885303375*^9}, 
   3.39988548025*^9, {3.399886753765625*^9, 3.3998867586875*^9}, {
   3.39988682284375*^9, 3.3998868305*^9}, 3.399886884703125*^9, 
   3.3998877748125*^9, {3.399887941234375*^9, 3.399887943640625*^9}, {
   3.399887988484375*^9, 3.399888010359375*^9}, {3.3998880593125*^9, 
   3.399888084203125*^9}, {3.3998882464375*^9, 3.39988825071875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Transpose", "[", "v_CartesianVectors", "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"Transpose", "/@", 
    RowBox[{"Components", "[", "v", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414321116875*^9, 3.41432112334375*^9}, {
  3.41432119525*^9, 3.41432124784375*^9}, {3.4177736810625*^9, 
  3.417773691171875*^9}}],

Cell["The following overloads are restricted to two dimensions.", "Text",
 CellChangeTimes->{{3.417776418390625*^9, 3.4177764726875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"ArcTan", "[", 
   RowBox[{"r_CartesianVectors", "?", "TwoDimQ"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "=", 
      RowBox[{"Components", "[", "r", "]"}]}], ";", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399884108*^9, 3.3998841339375*^9}, {
  3.400236789640625*^9, 3.40023679371875*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Rotate", "[", 
   RowBox[{
    RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], ",", "\[Theta]_"}], "]"}],
   ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "tr"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Components", "[", "v", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tr", "=", 
      RowBox[{"RotationTransform", "[", "\[Theta]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"CartesianVectors", "@@", 
      RowBox[{"Transpose", "[", 
       RowBox[{"tr", "[", "p", "]"}], "]"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414317755453125*^9, 3.41431780053125*^9}, {
   3.414318025359375*^9, 3.41431804596875*^9}, {3.41431811815625*^9, 
   3.4143181284375*^9}, 3.414318197296875*^9}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Rotate", "[", 
   RowBox[{
    RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], ",", "\[Theta]_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "z_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Translate", "[", 
   RowBox[{
    RowBox[{"Rotate", "[", 
     RowBox[{
      RowBox[{"Translate", "[", 
       RowBox[{"v", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "x"}], ",", 
          RowBox[{"-", "z"}]}], "}"}]}], "]"}], ",", "\[Theta]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399717395109375*^9, 3.399717490046875*^9}, {
   3.399719875640625*^9, 3.39971987659375*^9}, {3.399883908*^9, 
   3.399883908234375*^9}, 3.39988394690625*^9, 3.399883980984375*^9, {
   3.39988414009375*^9, 3.399884166125*^9}, {3.399884216296875*^9, 
   3.399884238484375*^9}, {3.3998843659375*^9, 3.39988439528125*^9}, {
   3.399884429484375*^9, 3.39988452128125*^9}, 3.39988455221875*^9, 
   3.39988516103125*^9, {3.3998852676875*^9, 3.399885303375*^9}, 
   3.39988548025*^9, {3.399886753765625*^9, 3.3998867586875*^9}, {
   3.39988682284375*^9, 3.3998868305*^9}, 3.399886884703125*^9, {
   3.399888920328125*^9, 3.399889019609375*^9}, {3.399889230375*^9, 
   3.3998892501875*^9}, {3.3998893010625*^9, 3.399889318359375*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Rotate", "[", 
   RowBox[{
    RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], ",", "\[Theta]_List"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cn", ",", "sn", ",", "vx", ",", "vz"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cn", ",", "sn"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"vx", ",", "vz"}], "}"}], "=", 
      RowBox[{"Components", "[", "v", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CartesianVectors", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"cn", "*", "vx"}], "-", 
         RowBox[{"sn", "*", "vz"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"+", "sn"}], "*", "vx"}], "+", 
         RowBox[{"cn", "*", "vz"}]}]}], "}"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40023670121875*^9, 3.400236777421875*^9}, {
   3.400236815390625*^9, 3.400236822078125*^9}, {3.40023686796875*^9, 
   3.40023716921875*^9}, {3.400237967828125*^9, 3.4002380240625*^9}, {
   3.400238273140625*^9, 3.400238336359375*^9}, {3.40023851275*^9, 
   3.400238586265625*^9}, {3.400238738984375*^9, 3.400238808*^9}, {
   3.400240376640625*^9, 3.400240382484375*^9}, {3.400318139796875*^9, 
   3.400318167859375*^9}, 3.400318521453125*^9, {3.40032399409375*^9, 
   3.400324001015625*^9}, {3.400324091125*^9, 3.400324116171875*^9}, {
   3.400324229046875*^9, 3.4003242453125*^9}, 3.400324287078125*^9, {
   3.400324392015625*^9, 3.400324399515625*^9}, 3.400325901375*^9, {
   3.410515466328125*^9, 3.41051549771875*^9}, {3.41051565190625*^9, 
   3.41051565559375*^9}, {3.410515860234375*^9, 3.410515866109375*^9}, {
   3.410516049578125*^9, 3.4105160536875*^9}, 3.41051691328125*^9, {
   3.4141459115*^9, 3.4141459664375*^9}}],

Cell["Allow single scaling factor for both axes.", "Text",
 CellChangeTimes->{{3.417773965109375*^9, 3.417773979140625*^9}}],

Cell[BoxData[
 RowBox[{"CartesianVectors", "/:", 
  RowBox[{"Scale", "[", 
   RowBox[{
    RowBox[{"v_CartesianVectors", "?", "TwoDimQ"}], ",", "s_"}], "]"}], ":=", 
  RowBox[{"Scale", "[", 
   RowBox[{"v", ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "s"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400836596890625*^9, 3.400836670109375*^9}, 
   3.40083676996875*^9, {3.415619647546875*^9, 3.415619652921875*^9}, {
   3.41777385546875*^9, 3.417773857765625*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Format", "Subsubsection"],

Cell["Define a format for displaying CartesianVectors.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Format", "[", "v_CartesianVectors", "]"}], "=", 
   RowBox[{"Infix", "[", 
    RowBox[{"v", ",", "\"\<\[UpArrow]\>\""}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411210268765625*^9, 3.41121027790625*^9}, {
  3.411226900671875*^9, 3.4112269036875*^9}, {3.41122700446875*^9, 
  3.41122701275*^9}, {3.412525786046875*^9, 3.412525790109375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" End private context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Epilogue", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "CartesianVectors", ",", "ComplexToCartesianVectors", ",", "Components", 
    ",", "ExtendXyToXyz", ",", "ExtendXzToXyz", ",", "MakeCartesianVectors", 
    ",", "MirrorXAxis", ",", "MultiplyByList", ",", "NumberOfVectors", ",", 
    "ReplicateVector", ",", "ThreeDimQ", ",", "TwoDimQ"}], "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.397310076125*^9, 3.397310079984375*^9}, 
   3.3973130833125*^9, {3.39789586596875*^9, 3.397895866359375*^9}, {
   3.397901325890625*^9, 3.3979013261875*^9}, 3.3979024798125*^9, 
   3.397920363296875*^9, {3.398068210515625*^9, 3.398068210828125*^9}, 
   3.399883766484375*^9, {3.399894132765625*^9, 3.39989415503125*^9}, {
   3.4002335794375*^9, 3.400233584578125*^9}, 3.40083355646875*^9, {
   3.4008338150625*^9, 3.400833817421875*^9}, 3.417339030859375*^9, 
   3.417770949390625*^9, 3.4177745135*^9, 3.418375802725438*^9, 
   3.4183765426193533`*^9, 3.4408427865232515`*^9}],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{653, 950},
WindowMargins->{{Automatic, 294}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellTags->True,
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 124, 1, 71, "Section"],
Cell[694, 25, 267, 5, 47, "Text"],
Cell[964, 32, 365, 4, 29, "Text"],
Cell[1332, 38, 673, 12, 47, "Text"],
Cell[CellGroupData[{
Cell[2030, 54, 31, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[2086, 58, 32, 0, 27, "Subsubsection"],
Cell[2121, 60, 508, 9, 65, "Text"],
Cell[2632, 71, 605, 13, 83, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3274, 89, 35, 0, 21, "Subsubsection"],
Cell[3312, 91, 203, 8, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3552, 104, 37, 0, 21, "Subsubsection"],
Cell[3592, 106, 954, 19, 155, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4583, 130, 35, 0, 21, "Subsubsection"],
Cell[4621, 132, 1710, 50, 119, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6380, 188, 45, 0, 36, "Subsection"],
Cell[6428, 190, 264, 7, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[6729, 202, 32, 0, 28, "Subsection"],
Cell[CellGroupData[{
Cell[6786, 206, 105, 1, 27, "Subsubsection"],
Cell[6894, 209, 539, 10, 112, "Input",
 InitializationCell->True],
Cell[7436, 221, 518, 10, 92, "Input",
 InitializationCell->True],
Cell[7957, 233, 440, 10, 72, "Input",
 InitializationCell->True],
Cell[8400, 245, 420, 9, 92, "Input",
 InitializationCell->True],
Cell[8823, 256, 418, 9, 92, "Input",
 InitializationCell->True],
Cell[9244, 267, 1527, 25, 132, "Input",
 InitializationCell->True],
Cell[10774, 294, 472, 10, 72, "Input",
 InitializationCell->True],
Cell[11249, 306, 335, 8, 52, "Input",
 InitializationCell->True],
Cell[11587, 316, 348, 8, 72, "Input",
 InitializationCell->True],
Cell[11938, 326, 687, 13, 112, "Input",
 InitializationCell->True],
Cell[12628, 341, 487, 10, 72, "Input",
 InitializationCell->True],
Cell[13118, 353, 433, 10, 72, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[13588, 368, 67, 0, 21, "Subsubsection"],
Cell[13658, 370, 504, 10, 72, "Input",
 InitializationCell->True],
Cell[14165, 382, 217, 6, 52, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14431, 394, 37, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[14493, 398, 47, 0, 27, "Subsubsection"],
Cell[14543, 400, 154, 5, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[14734, 410, 76, 0, 21, "Subsubsection"],
Cell[14813, 412, 987, 18, 72, "Input",
 InitializationCell->True],
Cell[15803, 432, 839, 15, 92, "Input",
 InitializationCell->True],
Cell[16645, 449, 288, 8, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[16970, 462, 50, 0, 21, "Subsubsection"],
Cell[17023, 464, 612, 10, 65, "Text"],
Cell[17638, 476, 1029, 29, 32, "Text"],
Cell[18670, 507, 423, 11, 47, "Text"],
Cell[19096, 520, 1211, 35, 92, "Input",
 InitializationCell->True],
Cell[20310, 557, 1058, 28, 92, "Input",
 InitializationCell->True],
Cell[21371, 587, 199, 4, 29, "Text"],
Cell[21573, 593, 837, 16, 52, "Input",
 InitializationCell->True],
Cell[22413, 611, 160, 3, 29, "Text"],
Cell[22576, 616, 726, 15, 52, "Input",
 InitializationCell->True],
Cell[23305, 633, 54, 0, 29, "Text"],
Cell[23362, 635, 444, 11, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[23843, 651, 117, 1, 21, "Subsubsection"],
Cell[23963, 654, 385, 11, 47, "Text"],
Cell[24351, 667, 560, 12, 47, "Text"],
Cell[24914, 681, 268, 5, 47, "Text"],
Cell[25185, 688, 1425, 26, 52, "Input",
 InitializationCell->True],
Cell[26613, 716, 228, 4, 47, "Text"],
Cell[26844, 722, 908, 21, 72, "Input",
 InitializationCell->True],
Cell[27755, 745, 571, 11, 31, "Input",
 InitializationCell->True],
Cell[28329, 758, 60, 0, 29, "Text"],
Cell[28392, 760, 300, 9, 31, "Input",
 InitializationCell->True],
Cell[28695, 771, 75, 0, 29, "Text"],
Cell[28773, 773, 641, 18, 52, "Input",
 InitializationCell->True],
Cell[29417, 793, 520, 14, 52, "Input",
 InitializationCell->True],
Cell[29940, 809, 377, 10, 52, "Input",
 InitializationCell->True],
Cell[30320, 821, 226, 5, 29, "Text"],
Cell[30549, 828, 163, 5, 29, "Text"],
Cell[30715, 835, 194, 5, 31, "Input",
 InitializationCell->True],
Cell[30912, 842, 158, 5, 29, "Text"],
Cell[31073, 849, 600, 13, 31, "Input",
 InitializationCell->True],
Cell[31676, 864, 144, 3, 47, "Text"],
Cell[31823, 869, 717, 19, 92, "Input",
 InitializationCell->True],
Cell[32543, 890, 145, 3, 47, "Text"],
Cell[32691, 895, 718, 19, 92, "Input",
 InitializationCell->True],
Cell[33412, 916, 306, 6, 47, "Text"],
Cell[33721, 924, 772, 22, 72, "Input",
 InitializationCell->True],
Cell[34496, 948, 161, 5, 29, "Text"],
Cell[34660, 955, 192, 5, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[34889, 965, 53, 0, 21, "Subsubsection"],
Cell[34945, 967, 560, 10, 83, "Text"],
Cell[35508, 979, 645, 13, 52, "Input",
 InitializationCell->True],
Cell[36156, 994, 528, 11, 52, "Input",
 InitializationCell->True],
Cell[36687, 1007, 1085, 21, 52, "Input",
 InitializationCell->True],
Cell[37775, 1030, 1445, 30, 72, "Input",
 InitializationCell->True],
Cell[39223, 1062, 1097, 22, 52, "Input",
 InitializationCell->True],
Cell[40323, 1086, 3049, 51, 92, "Input",
 InitializationCell->True],
Cell[43375, 1139, 3989, 74, 152, "Input",
 InitializationCell->True],
Cell[47367, 1215, 4038, 72, 132, "Input",
 InitializationCell->True],
Cell[51408, 1289, 308, 6, 52, "Input",
 InitializationCell->True],
Cell[51719, 1297, 921, 19, 52, "Input",
 InitializationCell->True],
Cell[52643, 1318, 630, 13, 52, "Input",
 InitializationCell->True],
Cell[53276, 1333, 2231, 40, 72, "Input",
 InitializationCell->True],
Cell[55510, 1375, 2052, 37, 72, "Input",
 InitializationCell->True],
Cell[57565, 1414, 514, 13, 52, "Input",
 InitializationCell->True],
Cell[58082, 1429, 578, 15, 52, "Input",
 InitializationCell->True],
Cell[58663, 1446, 685, 14, 52, "Input",
 InitializationCell->True],
Cell[59351, 1462, 658, 14, 52, "Input",
 InitializationCell->True],
Cell[60012, 1478, 551, 11, 52, "Input",
 InitializationCell->True],
Cell[60566, 1491, 2026, 38, 72, "Input",
 InitializationCell->True],
Cell[62595, 1531, 651, 15, 52, "Input",
 InitializationCell->True],
Cell[63249, 1548, 718, 15, 52, "Input",
 InitializationCell->True],
Cell[63970, 1565, 664, 14, 52, "Input",
 InitializationCell->True],
Cell[64637, 1581, 289, 6, 31, "Input",
 InitializationCell->True],
Cell[64929, 1589, 874, 17, 52, "Input",
 InitializationCell->True],
Cell[65806, 1608, 1300, 25, 92, "Input",
 InitializationCell->True],
Cell[67109, 1635, 183, 4, 29, "Text"],
Cell[67295, 1641, 634, 12, 52, "Input",
 InitializationCell->True],
Cell[67932, 1655, 427, 9, 52, "Input",
 InitializationCell->True],
Cell[68362, 1666, 882, 18, 72, "Input",
 InitializationCell->True],
Cell[69247, 1686, 701, 19, 92, "Input",
 InitializationCell->True],
Cell[69951, 1707, 2170, 39, 72, "Input",
 InitializationCell->True],
Cell[72124, 1748, 2204, 40, 72, "Input",
 InitializationCell->True],
Cell[74331, 1790, 1898, 32, 52, "Input",
 InitializationCell->True],
Cell[76232, 1824, 699, 17, 52, "Input",
 InitializationCell->True],
Cell[76934, 1843, 1528, 31, 72, "Input",
 InitializationCell->True],
Cell[78465, 1876, 661, 17, 92, "Input",
 InitializationCell->True],
Cell[79129, 1895, 429, 10, 52, "Input",
 InitializationCell->True],
Cell[79561, 1907, 409, 9, 52, "Input",
 InitializationCell->True],
Cell[79973, 1918, 409, 9, 52, "Input",
 InitializationCell->True],
Cell[80385, 1929, 507, 10, 52, "Input",
 InitializationCell->True],
Cell[80895, 1941, 721, 16, 52, "Input",
 InitializationCell->True],
Cell[81619, 1959, 733, 17, 52, "Input",
 InitializationCell->True],
Cell[82355, 1978, 461, 10, 52, "Input",
 InitializationCell->True],
Cell[82819, 1990, 763, 16, 52, "Input",
 InitializationCell->True],
Cell[83585, 2008, 758, 18, 52, "Input",
 InitializationCell->True],
Cell[84346, 2028, 151, 3, 29, "Text"],
Cell[84500, 2033, 1825, 38, 112, "Input",
 InitializationCell->True],
Cell[86328, 2073, 369, 8, 52, "Input",
 InitializationCell->True],
Cell[86700, 2083, 477, 12, 52, "Input",
 InitializationCell->True],
Cell[87180, 2097, 530, 14, 52, "Input",
 InitializationCell->True],
Cell[87713, 2113, 1694, 35, 112, "Input",
 InitializationCell->True],
Cell[89410, 2150, 428, 9, 52, "Input",
 InitializationCell->True],
Cell[89841, 2161, 137, 1, 29, "Text"],
Cell[89981, 2164, 607, 17, 52, "Input",
 InitializationCell->True],
Cell[90591, 2183, 956, 24, 112, "Input",
 InitializationCell->True],
Cell[91550, 2209, 1408, 30, 52, "Input",
 InitializationCell->True],
Cell[92961, 2241, 2079, 48, 112, "Input",
 InitializationCell->True],
Cell[95043, 2291, 124, 1, 29, "Text"],
Cell[95170, 2294, 501, 12, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[95708, 2311, 32, 0, 21, "Subsubsection"],
Cell[95743, 2313, 64, 0, 29, "Text"],
Cell[95810, 2315, 422, 9, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[96269, 2329, 45, 0, 21, "Subsubsection"],
Cell[96317, 2331, 96, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96462, 2340, 30, 0, 36, "Subsection"],
Cell[96495, 2342, 1006, 18, 72, "Input",
 InitializationCell->True],
Cell[97504, 2362, 85, 2, 31, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
