(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10188,        349]
NotebookOptionsPosition[      6913,        249]
NotebookOutlinePosition[      8152,        281]
CellTagsIndexPosition[      8109,        278]
WindowTitle->CartesianVectors - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "GuideColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[CellGroupData[{

Cell["CartesianVectors", "GuideTitle",
 CellID->942062912],

Cell[TextData[{
 "CartesianVectors is the name of the data type defined to describe \
collections of vectors in the  ",
 StyleBox["Aerodynamics ",
  FontSlant->"Italic"],
 "software.  You should be able to use the computational tools in the other \
packages without being familiar with this package. "
}], "GuideAbstract",
 CellID->2001916300],

Cell["\<\
The primary reasons for introducing the data type CartesianVectors are \
convenience of pattern matching for input arguments for functions defined in \
the other packages, and for simplifying vector algebra in those function \
definitions. An understanding of the data type will be helpful for reading or \
altering function definitions in other packages.  \
\>", "GuideAbstract",
 CellID->767589011],

Cell[TextData[{
 "Most properties of the data type are defined by overloading ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions.  The use of the data type with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions is illustrated in a tutorial."
}], "GuideAbstract",
 CellID->247703532],

Cell[CellGroupData[{

Cell["Constructor and Selector", "GuideFunctionsSubsection",
 CellID->64787135],

Cell[TextData[{
 Cell[TextData[ButtonBox["MakeCartesianVectors",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/MakeCartesianVectors"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " constructs data type CartesianVectors from list of components"
}], "GuideText",
 CellID->305513954],

Cell[TextData[{
 Cell[TextData[ButtonBox["Components",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/Components"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " selects the list of components from the data type CartesianVectors"
}], "GuideText",
 CellID->1463276848],

Cell["\t", "GuideDelimiterSubsection",
 CellID->130491264]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exported Functions, General", "GuideFunctionsSubsection",
 CellID->792128480],

Cell[TextData[{
 Cell[TextData[ButtonBox["MultiplyByList",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/MultiplyByList"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " multiplies collection of vectors by a list"
}], "GuideText",
 CellID->638282084],

Cell[TextData[{
 Cell[TextData[ButtonBox["NumberOfVectors",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/NumberOfVectors"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " counts number of vectors in collection"
}], "GuideText",
 CellID->177633201],

Cell[TextData[{
 Cell[TextData[ButtonBox["ReplicateVector",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ReplicateVector"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " makes collection of vectors consisting of copies of input vector"
}], "GuideText",
 CellID->108018996],

Cell["\t", "GuideDelimiterSubsection",
 CellID->669805398]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exported Functions, 3-D Vectors", "GuideFunctionsSubsection",
 CellID->280113763],

Cell[TextData[{
 Cell[TextData[ButtonBox["ThreeDimQ",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ThreeDimQ"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " tests collection of vectors for being three dimensional"
}], "GuideText",
 CellID->422546481],

Cell["\t", "GuideDelimiterSubsection",
 CellID->150899699]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exported Functions, 2-D Vectors", "GuideFunctionsSubsection",
 CellID->431151480],

Cell[TextData[{
 Cell[TextData[ButtonBox["ComplexToCartesianVectors",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ComplexToCartesianVectors"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " converts list of complex numbers to collection of vectors"
}], "GuideText",
 CellID->564851738],

Cell[TextData[{
 Cell[TextData[ButtonBox["ExtendXyToXyz",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ExtendXyToXyz"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extends 2-D vectors to 3-D vectors by padding ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"]
}], "GuideText",
 CellID->434658853],

Cell[TextData[{
 Cell[TextData[ButtonBox["ExtendXzToXyz",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ExtendXzToXyz"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extends 2-D vectors to 3-D vectors by padding ",
 Cell[BoxData[
  StyleBox["y", "TI"]], "InlineFormula"]
}], "GuideText",
 CellID->66601704],

Cell[TextData[{
 Cell[TextData[ButtonBox["MirrorXAxis",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/MirrorXAxis"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " constructs mirror image through x axis of collection of vectors"
}], "GuideText",
 CellID->201642374],

Cell[TextData[{
 Cell[TextData[ButtonBox["TwoDimQ",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/TwoDimQ"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " tests collection of vectors for being two dimensional"
}], "GuideText",
 CellID->22123132]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIALS", "GuideTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["A1 CartesianVectors",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/CartesianVectors"]], "GuideTutorial",
 CellID->137824362],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "GuideTutorial",
 CellID->362382436]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "GuideMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["Aerodynamics",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"]], "GuideMoreAbout",
 CellID->422375765]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"CartesianVectors - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 55, 32.6262000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Guide", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "CartesianVectors is the name of the data type defined to describe \
collections of vectors in the Aerodynamics software. You should be able to \
use the computational tools in the other packages without being familiar with \
this package. ", "synonyms" -> {}, "title" -> "CartesianVectors", "type" -> 
    "Guide", "uri" -> "Aerodynamics/guide/CartesianVectors"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[597, 21, 75, 1, 70, "GuideColorBar"],
Cell[675, 24, 191, 5, 70, "LinkTrail"],
Cell[CellGroupData[{
Cell[891, 33, 58, 1, 70, "GuideTitle",
 CellID->942062912],
Cell[952, 36, 343, 8, 70, "GuideAbstract",
 CellID->2001916300],
Cell[1298, 46, 410, 7, 70, "GuideAbstract",
 CellID->767589011],
Cell[1711, 55, 311, 9, 70, "GuideAbstract",
 CellID->247703532],
Cell[CellGroupData[{
Cell[2047, 68, 79, 1, 70, "GuideFunctionsSubsection",
 CellID->64787135],
Cell[2129, 71, 325, 9, 70, "GuideText",
 CellID->305513954],
Cell[2457, 82, 308, 8, 70, "GuideText",
 CellID->1463276848],
Cell[2768, 92, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->130491264]
}, Open  ]],
Cell[CellGroupData[{
Cell[2863, 98, 83, 1, 70, "GuideFunctionsSubsection",
 CellID->792128480],
Cell[2949, 101, 294, 9, 70, "GuideText",
 CellID->638282084],
Cell[3246, 112, 292, 9, 70, "GuideText",
 CellID->177633201],
Cell[3541, 123, 318, 9, 70, "GuideText",
 CellID->108018996],
Cell[3862, 134, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->669805398]
}, Open  ]],
Cell[CellGroupData[{
Cell[3957, 140, 87, 1, 70, "GuideFunctionsSubsection",
 CellID->280113763],
Cell[4047, 143, 294, 8, 70, "GuideText",
 CellID->422546481],
Cell[4344, 153, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->150899699]
}, Open  ]],
Cell[CellGroupData[{
Cell[4439, 159, 87, 1, 70, "GuideFunctionsSubsection",
 CellID->431151480],
Cell[4529, 162, 331, 9, 70, "GuideText",
 CellID->564851738],
Cell[4863, 173, 350, 10, 70, "GuideText",
 CellID->434658853],
Cell[5216, 185, 349, 10, 70, "GuideText",
 CellID->66601704],
Cell[5568, 197, 306, 8, 70, "GuideText",
 CellID->201642374],
Cell[5877, 207, 287, 8, 70, "GuideText",
 CellID->22123132]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6213, 221, 62, 1, 70, "GuideTutorialsSection",
 CellID->415694126],
Cell[6278, 224, 170, 4, 70, "GuideTutorial",
 CellID->137824362],
Cell[6451, 230, 164, 3, 70, "GuideTutorial",
 CellID->362382436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6652, 238, 62, 1, 70, "GuideMoreAboutSection",
 CellID->23220180],
Cell[6717, 241, 154, 3, 70, "GuideMoreAbout",
 CellID->422375765]
}, Open  ]],
Cell[6886, 247, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

