(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8118,        281]
NotebookOptionsPosition[      5556,        205]
NotebookOutlinePosition[      6814,        237]
CellTagsIndexPosition[      6771,        234]
WindowTitle->Influence Coefficients - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "GuideColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[CellGroupData[{

Cell["Influence Coefficients", "GuideTitle",
 CellID->942062912],

Cell["\<\
This package contains functions for the commonly used influence coefficients \
for two-dimensional potential flow.  For each singularity, functions for \
velocity, velocity-potential and  stream-function influence coefficients are \
defined.\
\>", "GuideAbstract",
 CellID->2001916300],

Cell[TextData[{
 Cell[TextData[ButtonBox["DisplacementVectors",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/DisplacementVectors"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " displacement vectors from singularities to field points "
}], "GuideText",
 CellID->461542648],

Cell[TextData[{
 Cell[TextData[ButtonBox["UniformFlow",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/UniformFlow"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " velocity, velocity potential and stream function for uniform flow"
}], "GuideText",
 CellID->411125827],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICSourcePoint",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICSourcePoint"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " point sources"
}], "GuideText",
 CellID->133394187],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICVortexPoint",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICVortexPoint"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " point vortices"
}], "GuideText",
 CellID->254624606],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICDoubletPoint",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICDoubletPoint"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " point doublets"
}], "GuideText",
 CellID->18652149],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICSourceConstant",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICSourceConstant"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " source panels of constant strength"
}], "GuideText",
 CellID->13136292],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICVortexConstant",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICVortexConstant"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " vortex panels of constant strength"
}], "GuideText",
 CellID->175155773],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICDoubletConstant",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICDoubletConstant"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " doublet panels of constant strength"
}], "GuideText",
 CellID->353611842],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICSourceLinear",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICSourceLinear"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " source panels of linearly varying strength"
}], "GuideText",
 CellID->383210361],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICVortexLinear",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICVortexLinear"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " vortex panels of linearly varying strength"
}], "GuideText",
 CellID->632449638],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICDoubletLinear",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICDoubletLinear"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " doublet panels of linearly varying strength"
}], "GuideText",
 CellID->126639774],

Cell[TextData[{
 Cell[TextData[ButtonBox["ICDoubletQuadratic",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICDoubletQuadratic"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " doublet panels of quadratically varying strength"
}], "GuideText",
 CellID->1463276848]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIALS", "GuideTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["2.1 Introduction to Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"]], \
"GuideTutorial",
 CellID->806871991],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "GuideTutorial",
 CellID->1885805579]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "GuideMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["Aerodynamics",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"]], "GuideMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Influence Coefficients - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 55, 36.1674000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Guide", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "This package contains functions for the commonly used influence \
coefficients for two-dimensional potential flow. For each singularity, \
functions for velocity, velocity-potential and stream-function influence \
coefficients are defined.", "synonyms" -> {}, "title" -> 
    "Influence Coefficients", "type" -> "Guide", "uri" -> 
    "Aerodynamics/guide/InfluenceCoefficients"}, "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[603, 21, 75, 1, 70, "GuideColorBar"],
Cell[681, 24, 191, 5, 70, "LinkTrail"],
Cell[CellGroupData[{
Cell[897, 33, 64, 1, 70, "GuideTitle",
 CellID->942062912],
Cell[964, 36, 295, 6, 70, "GuideAbstract",
 CellID->2001916300],
Cell[1262, 44, 318, 9, 70, "GuideText",
 CellID->461542648],
Cell[1583, 55, 308, 8, 70, "GuideText",
 CellID->411125827],
Cell[1894, 65, 260, 8, 70, "GuideText",
 CellID->133394187],
Cell[2157, 75, 261, 8, 70, "GuideText",
 CellID->254624606],
Cell[2421, 85, 265, 9, 70, "GuideText",
 CellID->18652149],
Cell[2689, 96, 289, 9, 70, "GuideText",
 CellID->13136292],
Cell[2981, 107, 290, 9, 70, "GuideText",
 CellID->175155773],
Cell[3274, 118, 293, 9, 70, "GuideText",
 CellID->353611842],
Cell[3570, 129, 294, 9, 70, "GuideText",
 CellID->383210361],
Cell[3867, 140, 294, 9, 70, "GuideText",
 CellID->632449638],
Cell[4164, 151, 297, 9, 70, "GuideText",
 CellID->126639774],
Cell[4464, 162, 309, 9, 70, "GuideText",
 CellID->1463276848]
}, Open  ]],
Cell[CellGroupData[{
Cell[4810, 176, 62, 1, 70, "GuideTutorialsSection",
 CellID->415694126],
Cell[4875, 179, 214, 5, 70, "GuideTutorial",
 CellID->806871991],
Cell[5092, 186, 165, 3, 70, "GuideTutorial",
 CellID->1885805579]
}, Open  ]],
Cell[CellGroupData[{
Cell[5294, 194, 62, 1, 70, "GuideMoreAboutSection",
 CellID->23220180],
Cell[5359, 197, 155, 3, 70, "GuideMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[5529, 203, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

