(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     74112,       1941]
NotebookOptionsPosition[     66671,       1688]
NotebookOutlinePosition[     68201,       1729]
CellTagsIndexPosition[     68115,       1724]
WindowTitle->AirfoilFromDataFile - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.2 Airfoils From Data Files\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilSurfacePoints\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/AirfoilSurfacePoints"], "\<\"FitAirfoil\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/FitAirfoil"], "\<\"NumberingConvention\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/NumberingConvention"], "\<\"PlotAirfoil\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/ref/PlotAirfoil"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Airfoil Geometry\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/AirfoilGeometry"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/AirfoilFromDataFile\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/AirfoilFromDataFile"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
AirfoilFromDataFile.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/AirfoilFromDataFile", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["AirfoilFromDataFile", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["AirfoilFromDataFile",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"], "[", 
       "\"\<\!\(\*
StyleBox[\"file\", \"TI\"]\)\>\"", "]"}]], "InlineFormula"],
     " \[LineSeparator]returns a collection of vectors locating points on the \
airfoil contour (surface) as specified by the data in ",
     Cell[BoxData[
      StyleBox["file", "TI"]], "InlineFormula"],
     ".  The order of points in the collection of vectors returned by the \
function uses the clockwise numbering convention for airfoils with thickness."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->151295086],

Cell[TextData[{
 "Collections of vectors are of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->88103432],

Cell["\<\
AirfoilFromDataFile has an option to specify the order in which the data in \
the file is listed:\
\>", "Notes",
 CellID->196814693],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["NumberingConvention",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/NumberingConvention"], 
    ButtonBox["Counterclockwise",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/Counterclockwise"], Cell[
    "convention used for ordering data", "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True}}}},
 CellID->38199289],

Cell["\<\
Clockwise and counterclockwise numbering conventions start and stop at the \
trailing edge of the airfoil.  ForeToAft numbering convention traverses upper \
surface first, then lower surface.\
\>", "Notes",
 CellID->113042594],

Cell[TextData[{
 "Some files have been downloaded from the ",
 ButtonBox["UIUC Airfoil Data Site",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}],
 " for use in documentation examples, and files may be imported directly from \
the data site if you are connected to the Internet."
}], "Notes",
 CellID->162465969],

Cell["\<\
The UIUC Airfoil Data Site contains data files from various sources, and \
there are some files in the collection that need modifying before using in \
AirfoilFromDataFile.  Always check data file for expected format.\
\>", "Notes",
 CellID->85533099]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->19904936],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->377525862],

Cell["Load the Aerodynamics packages.", "ExampleText",
 CellID->701079788],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->18639833],

Cell["\<\
Here are the names of the data files in the folder Airfoil Data.  Repetitive \
parts have been stripped away from path names.\
\>", "ExampleText",
 CellID->411631528],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"StringTake", "[", 
     RowBox[{"#", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"StringPosition", "[", 
         RowBox[{"#", ",", "\"\<Airfoil Data\\\\\>\""}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"StringLength", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FileNames", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\*\>\"", ",", "$Path"}], 
    "]"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->161538214],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"clarky.dat\"\>", ",", "\<\"e205.dat\"\>", 
   ",", "\<\"e374.dat\"\>", ",", "\<\"l7769.dat\"\>", 
   ",", "\<\"naca23012.dat\"\>", ",", "\<\"naca4412.dat\"\>", 
   ",", "\<\"naca4412m.dat\"\>", ",", "\<\"naca642415.dat\"\>", 
   ",", "\<\"naca747a315.dat\"\>", ",", "\<\"s1223.dat\"\>", 
   ",", "\<\"sd7003.dat\"\>", ",", "\<\"usa35b.dat\"\>"}], "}"}]], "Output",
 ImageSize->{572, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->212560998]
}, Open  ]],

Cell[TextData[{
 "Use AirfoilFromDataFile to import data from the file for the Eppler-205 \
airfoil and rearrange the data to the form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  This data file uses the counterclockwise numbering convention, which is \
the default value for the option NumberingConvention."
}], "ExampleText",
 CellID->158695459],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rD", "=", 
  RowBox[{
  "AirfoilFromDataFile", "[", 
   "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->317289154],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1.`", ",", "0.99651`", ",", "0.98635`", ",", "0.97017`", ",", "0.9486`", 
     ",", "0.92195`", ",", "0.89034`", ",", "0.854`", ",", "0.81343`", ",", 
     "0.76911`", ",", "0.7216`", ",", "0.67149`", ",", "0.61938`", ",", 
     "0.56591`", ",", "0.51174`", ",", "0.45751`", ",", "0.40388`", ",", 
     "0.35149`", ",", "0.30097`", ",", "0.2529`", ",", "0.20783`", ",", 
     "0.16627`", ",", "0.12864`", ",", "0.09534`", ",", "0.06669`", ",", 
     "0.04291`", ",", "0.02419`", ",", "0.01065`", ",", "0.00233`", ",", 
     "0.00002`", ",", "0.00331`", ",", "0.01097`", ",", "0.02292`", ",", 
     "0.03909`", ",", "0.05937`", ",", "0.0836`", ",", "0.11157`", ",", 
     "0.14302`", ",", "0.17764`", ",", "0.21508`", ",", "0.25496`", ",", 
     "0.29699`", ",", "0.34101`", ",", "0.3868`", ",", "0.4341`", ",", 
     "0.48265`", ",", "0.53217`", ",", "0.58218`", ",", "0.63204`", ",", 
     "0.68108`", ",", "0.72866`", ",", "0.77412`", ",", "0.81684`", ",", 
     "0.85624`", ",", "0.89175`", ",", "0.92285`", ",", "0.94916`", ",", 
     "0.97049`", ",", "0.98649`", ",", "0.99655`", ",", "1.`"}], "}"}], 
   "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.00003`"}], ",", 
     RowBox[{"-", "0.00036`"}], ",", 
     RowBox[{"-", "0.00125`"}], ",", 
     RowBox[{"-", "0.00252`"}], ",", 
     RowBox[{"-", "0.0038`"}], ",", 
     RowBox[{"-", "0.00497`"}], ",", 
     RowBox[{"-", "0.00614`"}], ",", 
     RowBox[{"-", "0.0074`"}], ",", 
     RowBox[{"-", "0.00876`"}], ",", 
     RowBox[{"-", "0.01023`"}], ",", 
     RowBox[{"-", "0.0118`"}], ",", 
     RowBox[{"-", "0.01345`"}], ",", 
     RowBox[{"-", "0.01516`"}], ",", 
     RowBox[{"-", "0.01689`"}], ",", 
     RowBox[{"-", "0.01859`"}], ",", 
     RowBox[{"-", "0.02021`"}], ",", 
     RowBox[{"-", "0.02168`"}], ",", 
     RowBox[{"-", "0.02292`"}], ",", 
     RowBox[{"-", "0.02384`"}], ",", 
     RowBox[{"-", "0.02435`"}], ",", 
     RowBox[{"-", "0.02436`"}], ",", 
     RowBox[{"-", "0.02378`"}], ",", 
     RowBox[{"-", "0.02252`"}], ",", 
     RowBox[{"-", "0.02053`"}], ",", 
     RowBox[{"-", "0.01776`"}], ",", 
     RowBox[{"-", "0.0142`"}], ",", 
     RowBox[{"-", "0.00988`"}], ",", 
     RowBox[{"-", "0.00506`"}], ",", "0.00055`", ",", "0.00766`", ",", 
     "0.01589`", ",", "0.02461`", ",", "0.03344`", ",", "0.04211`", ",", 
     "0.0504`", ",", "0.05811`", ",", "0.06507`", ",", "0.07111`", ",", 
     "0.07606`", ",", "0.0797`", ",", "0.08177`", ",", "0.08214`", ",", 
     "0.08081`", ",", "0.07785`", ",", "0.07342`", ",", "0.06782`", ",", 
     "0.06147`", ",", "0.0547`", ",", "0.04777`", ",", "0.04088`", ",", 
     "0.03419`", ",", "0.02786`", ",", "0.02199`", ",", "0.01668`", ",", 
     "0.01196`", ",", "0.00778`", ",", "0.00427`", ",", "0.00174`", ",", 
     "0.00039`", ",", "0.`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[CompressedData["
1:eJwB9QEK/iFib1JlAQAAAD0AAAAAAAAAAADwP/phhPBo4+8/cRsN4C2Q7z8k
7rH0oQvvPwmKH2PuWu4/qoJRSZ2A7T+vQspPqn3sP4cW2c73U+s/nbryWZ4H
6j+U2SCTjJzoPyxlGeJYF+c/zemymNh85T/EfHkB9tHjP+tWz0nvG+I/48KB
kCxg4D8O8+UF2EfdP/CK4H8r2dk/H7+36c9+1j+J78SsF0PTPzojSnuDL9A/
0VeQZiyayj9jKCfaVUjFP2WNeohGd8A/8SkAxjNouD+mYfiImBKxP3+8V61M
+KU/E5uPa0PFmD/kg57Nqs+FP4P6ljldFmM/8WjjiLX49D6vCP63kh1rPyyf
5Xlwd4Y/8YCyKVd4lz8WhzO/mgOkP0sfuqC+Za4/1xLyQc9mtT/k9zb92Y+8
PwNDVrd6TsI/dxA7U+i8xj/yBwPPvYfLPzdxcr9DUdA/bkxPWOIB0z8z+Wab
G9PVP2/whclUwdg/8WPMXUvI2z+IhVrTvOPeP7oxPWGJB+E/N1SM8zeh4j9h
cTjzqznkP7O1vkhoy+U/U+i8xi5R5z+hvmVOl8XoP4gRwqONI+o/g92wbVFm
6z/wp8ZLN4nsP5yiI7n8h+0/yHvVyoRf7j+RCmMLQQ7vP+GX+nlTke8/iIVa
07zj7z8AAAAAAADwP7Ee+1o=
    "], CompressedData["
1:eJwB9QEK/iFib1JlAQAAAD0AAAAAAAAAAAAAAGkdVU0Qdf++D9b/OcyXN797
FK5H4XpUv03bv7LSpGS/xY8xdy0hb79dv2A3bFt0v9i2KLNBJnm/rK3YX3ZP
fr/GihpMw/CBvxYwgVt384S/7Q2+MJkqiL+WsgxxrIuLv1ysqME0DI+/64uE
tpxLkb9hbCHIQQmTv25pNSTusZS/F7zoK0gzlr/xgLIpV3iXvyi4WFGDaZi/
5WGh1jTvmL9SflLt0/GYv5kNMsnIWZi/5A8GnnsPl78S91j60AWVvwE1tWyt
L5K/hlrTvOMUjb9AahMn9zuEv7a+SGjLuXS/L26jAbwFQj8AOsyXF2B/P0xx
Vdl3RZA/+kSeJF0zmT+sqME0DB+hP3NLqyFxj6U/INJvXwfOqT9xICQLmMCt
P2Ni83FtqLA/wCZr1EM0sj9/pIgMq3izP0i/fR04Z7Q/Vz7L8+DutD9JhbGF
IAe1Px2UMNP2r7Q/klz+Q/rtsz9dUN8yp8uyP7HEA8qmXLE/DMhe7/54rz/E
sS5uowGsPxO4dTdPdag/PPceLjnupD+oUrMHWoGhP4Fbd/NUh5w/TS1b64uE
lj/4Nv3ZjxSRP5Gb4QZ8fog/dY4B2evdfz8FqKlla31xP6ciFcYWglw/5SfV
Ph2POT8AAAAAAAAAAPf66Iw=
    "]], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{580, 237},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->283978495]
}, Open  ]],

Cell[TextData[{
 "Look at the list of ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 " components to verify that the lower surface is being traversed first, from \
trailing edge forward, indicative of the clockwise numbering convention for \
panels.  Note that the head of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["d", "TI"]]], "InlineFormula"],
 " identifies the collection of vectors as the data type CartesianVectors."
}], "ExampleText",
 CellID->604996005],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "rD", "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->693433935],

Cell[BoxData["CartesianVectors"], "Output",
 ImageSize->{116, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->676398026]
}, Open  ]],

Cell["Plot the points specified in the data file.", "ExampleText",
 CellID->235318411],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gData", "=", 
  RowBox[{"PlotAirfoil", "[", 
   RowBox[{"rD", ",", 
    RowBox[{"Joined", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->109742180],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3b3O49QWBuAcTg8UiBJBS0MLXwMSxdCBRkKiQhqKTIVo6SgoKMldcANH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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->543095592]
}, Open  ]],

Cell["\<\
Data in the file can be used to specify panel endpoints for a discretized \
airfoil, or a B-spline can be fit to the data using FitAirfoil, and a \
user-specified discretization can be based on this fit using \
AirfoilSurfacePoints.  \
\>", "ExampleText",
 CellID->457083155]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell[TextData[{
 "Data can be downloaded directly from the ",
 ButtonBox["UIUC Airfoil Data Site",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}],
 ".  From this site, select the Airfoil Coordinates Database link and choose \
the airfoil you wish to use, for example, the Eppler-1214.  Note the address \
that displays at the bottom of the screen when you place the cursor over the \
link to the data file.    "
}], "ExampleText",
 CellID->99156681],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"url", "=", "\"\<www.ae.uiuc.edu/m-selig/ads/coord/e1214.dat\>\""}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rE1214", "=", 
   RowBox[{"AirfoilFromDataFile", "[", 
    RowBox[{"\"\<http://\>\"", "<>", "url"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gE1214", "=", 
  RowBox[{"PlotAirfoil", "[", 
   RowBox[{"rE1214", ",", 
    RowBox[{"Joined", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->906552818],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3b2O+2QWB+BZbQ8U1Ii9CzQNSBTQgVZCooUiVGhbOgoKSnIX3MAqXEwa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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->722680064]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Options",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "NumberingConvention",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->1757724783],

Cell[TextData[{
 "Data for airfoils listed on the UIUC Airfoil Data Site use two numbering \
conventions, both different from the convention used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  Inspect the data before using it in AirfoilFromDataFile so that you can \
identify the appropriate value for the option NumberingConvention."
}], "ExampleText",
 CellID->563083506],

Cell["Look at the files for the Eppler-205 and Clark-Y airfoils.", \
"ExampleText",
 CellID->982447825],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
   "Import", "[", "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}], 
   ",", "4"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->555832],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"E205\"\>", ",", "\<\"(10.48%)\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.99655`", ",", "0.00039`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.98649`", ",", "0.00174`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.97049`", ",", "0.00427`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.94916`", ",", "0.00778`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "51", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9486`", ",", 
      RowBox[{"-", "0.00252`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.97017`", ",", 
      RowBox[{"-", "0.00125`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.98635`", ",", 
      RowBox[{"-", "0.00036`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.99651`", ",", 
      RowBox[{"-", "0.00003`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "0.`"}], "}"}]}], "}"}],
  Short[#, 4]& ]], "Output",
 ImageSize->{498, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]//Short=",
 CellID->1450946]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
   "Import", "[", "\"\<Aerodynamics\\\\Airfoil Data\\\\clarky.dat\>\"", "]"}],
    ",", "4"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->88900868],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"CLARK\"\>", ",", "\<\"Y\"\>", ",", "\<\"AIRFOIL\"\>"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"61.`", ",", "61.`"}], "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0005`", ",", "0.002339`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.001`", ",", "0.0037271`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "115", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.96`", ",", 
      RowBox[{"-", "0.0020683`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.97`", ",", 
      RowBox[{"-", "0.0017011`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.98`", ",", 
      RowBox[{"-", "0.0013339`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.99`", ",", 
      RowBox[{"-", "0.0009666`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", 
      RowBox[{"-", "0.0005993`"}]}], "}"}]}], "}"}],
  Short[#, 4]& ]], "Output",
 ImageSize->{472, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]//Short=",
 CellID->552774952]
}, Open  ]],

Cell["\<\
Note the structure of each file.  For the Eppler-205 airfoil, numerical data \
starts with pairs of numbers locating points on the airfoil surface.  For the \
Clark-Y airfoil, numerical data starts with a pair of numbers specifying the \
number of points in the data file followed by an empty list, followed by the \
geometric data.  The ordering of points in the two data files is also \
different.  For the Eppler-205 airfoil, the first and last data points locate \
the trailing edge of the airfoil, and the data points are ordered so that the \
airfoil is traversed in a counterclockwise direction.  For the Clark-Y \
airfoil, the first airfoil data point locates the leading edge of the \
airfoil; data points are ordered so that the upper surface is traversed from \
fore to aft, and then the lower surface from fore to aft.  You may wish to \
look at more of the data to verify this.\
\>", "ExampleText",
 CellID->42341199],

Cell["\<\
The default setting for the option NumberingConvention is Counterclockwise, \
so when importing data for the Clark-Y airfoil the value of the option must \
be changed to ForeToAft.  \
\>", "ExampleText",
 CellID->298376845],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{"AirfoilFromDataFile", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\clarky.dat\>\"", ",", 
     RowBox[{"NumberingConvention", "\[Rule]", "ForeToAft"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gData", "=", 
  RowBox[{"PlotAirfoil", "[", "rD", "]"}]}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->294412045],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rFOkWx/Fc7l9y/43AMAtxIS7ECyGLkI0XGt3MbHSjm2SjmwQa3RiQ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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->121014389]
}, Open  ]],

Cell["\<\
An inappropriate value for NumberingConvention is apparent if the data points \
are joined.  In the following plot, the default value of Counterclockwise is \
used for the Clary-Y airfoil.  There are two extraneous \"panels\", one drawn \
from the trailing edge to the leading edge, and one drawn at a angle of 45\
\[Degree] extending off the graph because the pair of numbers (61. ,61.) was \
not removed from the data used to plot the airfoil.\
\>", "ExampleText",
 CellID->79017753],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{
  "AirfoilFromDataFile", "[", 
   "\"\<Aerodynamics\\\\Airfoil Data\\\\clarky.dat\>\"", "]"}], 
  "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->213824485],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rFFsax/EM85fMvxEYZiEuxIU4IFmEbBQa3czd6EY3yUY3CTS6UZBx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->58447030]
}, Open  ]],

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->110266141]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(3)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell["\<\
There are some data files that deviate from the format assumed for input to \
the function AirfoilFromDataFile.  Such files must be modified.  As an \
example, consider the data file for the NACA-4412 airfoil.  In this example, \
there are no error messages generated, but routine checking of results shows \
clearly that there is a problem.\
\>", "ExampleText",
 CellID->307170278],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
   "Import", "[", "\"\<Aerodynamics\\\\Airfoil Data\\\\naca4412.dat\>\"", 
    "]"}], ",", "4"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->150414795],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NACA\"\>", ",", "4412"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "\<\"......\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "\<\"(0.0013)\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.95`", ",", "0.0147`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9`", ",", "0.0271`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.8`", ",", "0.0489`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.7`", ",", "0.0669`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "25", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.7`", ",", 
      RowBox[{"-", "0.0065`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.8`", ",", 
      RowBox[{"-", "0.0039`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9`", ",", 
      RowBox[{"-", "0.0022`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.95`", ",", 
      RowBox[{"-", "0.0016`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "\<\"(-0.0013)\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10000", ",", "0.`"}], "}"}]}], "}"}],
  Short[#, 4]& ]], "Output",
 ImageSize->{502, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]//Short=",
 CellID->764571404]
}, Open  ]],

Cell[TextData[{
 "Note that the ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 "-values for the trailing edge are enclosed in parentheses.  Also, a data \
point far downstream is added to specify a trailing-edge panel used in some \
numerical models.  Use AirfoilFromDataFile to import this file and plot the \
results."
}], "ExampleText",
 CellID->219797083],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\naca4412.dat\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gData", "=", 
  RowBox[{"PlotAirfoil", "[", 
   RowBox[{"rD", ",", 
    RowBox[{"Joined", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->330733392],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3T2S6lYaBmCmZiWzjY4cOp7IsQPSSZ05dGh24Q1M4cWwCIeejKGB5qe7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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->686461684]
}, Open  ]],

Cell[TextData[{
 "Note that the trailing-edge points are not plotted.  The data file can be \
opened in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " or a text editor and modified to remove the wake panel and to remove the \
parentheses for the trailing-edge ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 "-values.  This was done and the result saved as naca4412m.dat."
}], "ExampleText",
 CellID->248958358],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
   "Import", "[", "\"\<Aerodynamics\\\\Airfoil Data\\\\naca4412m.dat\>\"", 
    "]"}], ",", "4"}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->31207036],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NACA\"\>", ",", "4412"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "\<\"......\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "0.0013`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.95`", ",", "0.0147`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9`", ",", "0.0271`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.8`", ",", "0.0489`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.7`", ",", "0.0669`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "24", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.6`", ",", 
      RowBox[{"-", "0.01`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.7`", ",", 
      RowBox[{"-", "0.0065`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.8`", ",", 
      RowBox[{"-", "0.0039`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9`", ",", 
      RowBox[{"-", "0.0022`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.95`", ",", 
      RowBox[{"-", "0.0016`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", 
      RowBox[{"-", "0.0013`"}]}], "}"}]}], "}"}],
  Short[#, 4]& ]], "Output",
 ImageSize->{488, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]//Short=",
 CellID->15606801]
}, Open  ]],

Cell["\<\
 Use AirfoilFromDataFile to import this modified file and plot the results.\
\>", "ExampleText",
 CellID->351383497],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\naca4412m.dat\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gData", "=", 
  RowBox[{"PlotAirfoil", "[", 
   RowBox[{"rD", ",", 
    RowBox[{"Joined", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->429283093],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3T2y68QWBlBTjISElCI9CYTERMQETl9KRkhAgGfBBCgzGA+CEDI///+c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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->708734816]
}, Open  ]],

Cell[TextData[{
 "This modified file results in a collection of vectors suitable for use in \
the panel methods implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 "."
}], "ExampleText",
 CellID->126530141],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->350152876],

Cell["\<\
Some airfoils are specified with a small gap at the trailing edge.  This can \
cause problems in some implementations of panel methods and are discussed in \
documentation pages for panel-method functions.\
\>", "ExampleText",
 CellID->176711659]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->61572870],

Cell[TextData[{
 "Non-fatal surprises may also be encountered in airfoil data files.  ",
 "My expectation is that airfoils are specified in an airfoil-fixed \
coordinate system with the chord being along the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis.   Import and plot the data for the USA-35B airfoil, joining data \
points.  This airfoil is specified using the fore-to-aft numbering convention."
}], "ExampleText",
 CellID->347091],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{"AirfoilFromDataFile", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\usa35b.dat\>\"", ",", 
     RowBox[{"NumberingConvention", "\[Rule]", "ForeToAft"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gData", "=", 
  RowBox[{"PlotAirfoil", "[", 
   RowBox[{"rD", ",", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->135857809],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rFNkax/G+3L9k/o3A5S6GWYgL8YK4CNkk0Ohm3Ogm2ehGNwk0ulEY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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->7110669]
}, Open  ]],

Cell["Obviously, my expectation was not met for this data file.", \
"ExampleText",
 CellID->374433390],

Cell["\<\
In summary, for a collection of data from several sources, there may be \
inconsistencies in form.  There may be good reasons to arrange the data in a \
given form.  It is the users responsibility to examine the data in a file in \
enough detail to determine if it deviates from expectations.\
\>", "ExampleText",
 CellID->39125373]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["AirfoilSurfacePoints",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["FitAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/FitAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " .  ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["NumberingConvention",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/NumberingConvention"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PlotAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PlotAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " "
}], "SeeAlso",
 CellID->812431431]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["1.2 Airfoils From Data Files",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]], "Tutorials",
 CellID->341631938]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "MoreAbout",
 CellID->390763483]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["RELATED LINKS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "RelatedLinksSection",
 CellID->1584193535],

Cell[TextData[ButtonBox["UIUC Airfoil Data Site",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}]], "RelatedLinks",
 CellID->1038487239]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"AirfoilFromDataFile - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 55, 42.4542000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "AirfoilFromDataFile[\"file\"] returns a collection of vectors locating \
points on the airfoil contour (surface) as specified by the data in file. The \
order of points in the collection of vectors returned by the function uses \
the clockwise numbering convention for airfoils with thickness.", 
    "synonyms" -> {}, "title" -> "AirfoilFromDataFile", "type" -> "Symbol", 
    "uri" -> "Aerodynamics/ref/AirfoilFromDataFile"}, "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[7867, 223, 460, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->19904936]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 67973, 1717}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[600, 21, 76, 1, 70, "SymbolColorBar"],
Cell[679, 24, 191, 5, 70, "LinkTrail"],
Cell[873, 31, 3418, 77, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4316, 112, 62, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4381, 115, 965, 23, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[5383, 143, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->151295086],
Cell[5966, 162, 249, 8, 70, "Notes",
 CellID->88103432],
Cell[6218, 172, 142, 4, 70, "Notes",
 CellID->196814693],
Cell[6363, 178, 595, 15, 70, "3ColumnTableMod",
 CellID->38199289],
Cell[6961, 195, 236, 5, 70, "Notes",
 CellID->113042594],
Cell[7200, 202, 366, 9, 70, "Notes",
 CellID->162465969],
Cell[7569, 213, 261, 5, 70, "Notes",
 CellID->85533099]
}, Closed]],
Cell[CellGroupData[{
Cell[7867, 223, 460, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->19904936],
Cell[CellGroupData[{
Cell[8352, 240, 148, 5, 70, "ExampleSection",
 CellID->377525862],
Cell[8503, 247, 74, 1, 70, "ExampleText",
 CellID->701079788],
Cell[8580, 250, 99, 3, 70, "Input",
 CellID->18639833],
Cell[8682, 255, 176, 4, 70, "ExampleText",
 CellID->411631528],
Cell[CellGroupData[{
Cell[8883, 263, 607, 18, 70, "Input",
 CellID->161538214],
Cell[9493, 283, 539, 12, 54, "Output",
 CellID->212560998]
}, Open  ]],
Cell[10047, 298, 368, 8, 70, "ExampleText",
 CellID->158695459],
Cell[CellGroupData[{
Cell[10440, 310, 193, 6, 70, "Input",
 CellID->317289154],
Cell[10636, 318, 4579, 92, 258, "Output",
 CellID->283978495]
}, Open  ]],
Cell[15230, 413, 504, 13, 70, "ExampleText",
 CellID->604996005],
Cell[CellGroupData[{
Cell[15759, 430, 101, 3, 70, "Input",
 CellID->693433935],
Cell[15863, 435, 174, 5, 36, "Output",
 CellID->676398026]
}, Open  ]],
Cell[16052, 443, 86, 1, 70, "ExampleText",
 CellID->235318411],
Cell[CellGroupData[{
Cell[16163, 448, 354, 11, 28, "Input",
 CellID->109742180],
Cell[16520, 461, 4001, 73, 201, "Output",
 CellID->543095592]
}, Open  ]],
Cell[20536, 537, 285, 6, 70, "ExampleText",
 CellID->457083155]
}, Open  ]],
Cell[CellGroupData[{
Cell[20858, 548, 221, 7, 70, "ExampleSection",
 CellID->1293636265],
Cell[21082, 557, 503, 11, 70, "ExampleText",
 CellID->99156681],
Cell[CellGroupData[{
Cell[21610, 572, 649, 19, 70, "Input",
 CellID->906552818],
Cell[22262, 593, 3989, 73, 70, "Output",
 CellID->722680064]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[26300, 672, 223, 7, 70, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[26548, 683, 241, 7, 70, "ExampleSubsection",
 CellID->1757724783],
Cell[26792, 692, 387, 8, 70, "ExampleText",
 CellID->563083506],
Cell[27182, 702, 103, 2, 70, "ExampleText",
 CellID->982447825],
Cell[CellGroupData[{
Cell[27310, 708, 210, 7, 70, "Input",
 CellID->555832],
Cell[27523, 717, 1187, 36, 71, "Output",
 CellID->1450946]
}, Open  ]],
Cell[CellGroupData[{
Cell[28747, 758, 214, 7, 70, "Input",
 CellID->88900868],
Cell[28964, 767, 1187, 37, 71, "Output",
 CellID->552774952]
}, Open  ]],
Cell[30166, 807, 940, 14, 70, "ExampleText",
 CellID->42341199],
Cell[31109, 823, 233, 5, 70, "ExampleText",
 CellID->298376845],
Cell[CellGroupData[{
Cell[31367, 832, 388, 10, 70, "Input",
 CellID->294412045],
Cell[31758, 844, 5180, 92, 70, "Output",
 CellID->121014389]
}, Open  ]],
Cell[36953, 939, 495, 8, 70, "ExampleText",
 CellID->79017753],
Cell[CellGroupData[{
Cell[37473, 951, 212, 7, 70, "Input",
 CellID->213824485],
Cell[37688, 960, 5436, 97, 70, "Output",
 CellID->58447030]
}, Open  ]],
Cell[43139, 1060, 125, 3, 70, "ExampleDelimiter",
 CellID->110266141]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[43313, 1069, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[43547, 1078, 392, 7, 70, "ExampleText",
 CellID->307170278],
Cell[CellGroupData[{
Cell[43964, 1089, 218, 7, 70, "Input",
 CellID->150414795],
Cell[44185, 1098, 1310, 40, 71, "Output",
 CellID->764571404]
}, Open  ]],
Cell[45510, 1141, 373, 9, 70, "ExampleText",
 CellID->219797083],
Cell[CellGroupData[{
Cell[45908, 1154, 535, 17, 70, "Input",
 CellID->330733392],
Cell[46446, 1173, 3456, 64, 70, "Output",
 CellID->686461684]
}, Open  ]],
Cell[49917, 1240, 432, 11, 70, "ExampleText",
 CellID->248958358],
Cell[CellGroupData[{
Cell[50374, 1255, 218, 7, 70, "Input",
 CellID->31207036],
Cell[50595, 1264, 1335, 42, 71, "Output",
 CellID->15606801]
}, Open  ]],
Cell[51945, 1309, 126, 3, 70, "ExampleText",
 CellID->351383497],
Cell[CellGroupData[{
Cell[52096, 1316, 536, 17, 70, "Input",
 CellID->429283093],
Cell[52635, 1335, 3513, 65, 70, "Output",
 CellID->708734816]
}, Open  ]],
Cell[56163, 1403, 223, 7, 70, "ExampleText",
 CellID->126530141],
Cell[CellGroupData[{
Cell[56411, 1414, 125, 3, 70, "ExampleDelimiter",
 CellID->350152876],
Cell[56539, 1419, 256, 5, 70, "ExampleText",
 CellID->176711659]
}, Open  ]],
Cell[CellGroupData[{
Cell[56832, 1429, 124, 3, 70, "ExampleDelimiter",
 CellID->61572870],
Cell[56959, 1434, 459, 9, 70, "ExampleText",
 CellID->347091],
Cell[CellGroupData[{
Cell[57443, 1447, 449, 12, 70, "Input",
 CellID->135857809],
Cell[57895, 1461, 5052, 90, 70, "Output",
 CellID->7110669]
}, Open  ]],
Cell[62962, 1554, 102, 2, 70, "ExampleText",
 CellID->374433390],
Cell[63067, 1558, 342, 6, 70, "ExampleText",
 CellID->39125373]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63470, 1571, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[63890, 1585, 832, 30, 70, "SeeAlso",
 CellID->812431431]
}, Open  ]],
Cell[CellGroupData[{
Cell[64759, 1620, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[65181, 1634, 180, 4, 70, "Tutorials",
 CellID->341631938]
}, Open  ]],
Cell[CellGroupData[{
Cell[65398, 1643, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[65820, 1657, 156, 3, 70, "MoreAbout",
 CellID->390763483]
}, Open  ]],
Cell[CellGroupData[{
Cell[66013, 1665, 427, 12, 70, "RelatedLinksSection",
 CellID->1584193535],
Cell[66443, 1679, 186, 4, 70, "RelatedLinks",
 CellID->1038487239]
}, Open  ]],
Cell[66644, 1686, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

