(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     71246,       1737]
NotebookOptionsPosition[     65470,       1552]
NotebookOutlinePosition[     67347,       1597]
CellTagsIndexPosition[     67261,       1592]
WindowTitle->AirfoilSurfacePoints - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.2 AirfoilsFromDataFiles\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"], "\<\"1.3 \
Airfoils From Thickness And Camber Properties\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/\
AirfoilsFromThicknessAndCamberProperties"], "\<\"1.4 Airfoils From Conformal \
Mapping\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilFromDataFile\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/AirfoilFromDataFile"], "\<\"FitAirfoil\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/FitAirfoil"], "\<\"NACA4DigitAirfoil\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/NACA4DigitAirfoil"], "\<\"PlotAirfoil\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/ref/PlotAirfoil"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Airfoil Geometry\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/AirfoilGeometry"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/ref/AirfoilSurfacePoints\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/AirfoilSurfacePoints"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
AirfoilSurfacePoints.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/AirfoilSurfacePoints", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["AirfoilSurfacePoints", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["AirfoilSurfacePoints",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"], "[", 
       RowBox[{
        StyleBox["spline", "TI"], ",", 
        StyleBox["x", "TI"]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]returns a collection of vectors on the surface of an \
airfoil, where the airfoil is described by a B-",
     Cell[BoxData[
      StyleBox["spline", "TI"]], "InlineFormula"],
     ".  Locations of points on the surface of the airfoil are determined \
from a list of ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     "-values.  "
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["AirfoilSurfacePoints",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"], "[", 
       StyleBox["properties", "TI"], "]"}]], "InlineFormula"],
     "\[LineSeparator]returns a collection of vectors on the surface of an \
airfoil specified by lists of thickness and camber ",
     Cell[BoxData[
      StyleBox["properties", "TI"]], "InlineFormula"],
     "."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["AirfoilSurfacePoints",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"], "[", 
       RowBox[{
        StyleBox["t", "TI"], ",", 
        StyleBox["\[Tau]", "TR"], ",", 
        StyleBox["\[Theta]", "TR"]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]returns a collection of vectors on the surface of a van \
de Vooren airfoil of thickness parameter ",
     Cell[BoxData[
      StyleBox["t", "TI"]], "InlineFormula"],
     " and trailing-edge angle ",
     Cell[BoxData[
      StyleBox["\[Tau]", "TR"]], "InlineFormula"],
     " corresponding to a list of ",
     Cell[BoxData[
      StyleBox["\[Theta]", "TR"]], "InlineFormula"],
     " values in the range 0 to \[Pi]."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{"Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], 
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], {
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->630736251],

Cell[TextData[{
 "Collections of vectors are of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/guide/CartesianVectors"]], 
  "InlineFormula"],
 "."
}], "Notes",
 CellID->380359041],

Cell[TextData[{
 "AirfoilSurfacePoints is used to rediscretize an airfoil specified by data \
files to a user-specified discretization.  The function AirfoilFromDataFile \
is used to import the file and arrange the data as a collection of vectors \
locating the points in the order used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  The function FitAirfoil generates a b-spline function fitting the data.  \
AirfoilSurfacePoints uses the B-spline function to compute a collection of \
vectors locating points on the surface of the airfoil at specified ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values.  The primary source for airfoil data is from the data base \
maintained by Michael Selig at University of Illinois (",
 ButtonBox["UIUC Airfoil Data Site)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}],
 "."
}], "Notes",
 CellID->100603792],

Cell[TextData[{
 "For airfoils specified by equations for thickness and camber properties, \
AirfoilSurfacePoints computes a collection of vectors locating points on the \
surface of the airfoil from lists of these properties at specified ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values.  The example used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " for this type of specification is the family of NACA four-digit airfoils."
}], "Notes",
 CellID->588903450],

Cell["\<\
The van de Vooren airfoil is used as an example of an airfoil specified by \
conformal mapping.  The last definition of AirfoilSurfacePoints is specific \
to this family of symmetric airfoils. \
\>", "Notes",
 CellID->168477564]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->251452875],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->14671045],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->251463159],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->492977788],

Cell["\<\
Here are the names of the data files in the folder Airfoil Data.  Repetitive \
parts have been stripped away from path names.\
\>", "ExampleText",
 CellID->411631528],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"StringTake", "[", 
     RowBox[{"#", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"StringPosition", "[", 
         RowBox[{"#", ",", "\"\<Data\\\\\>\""}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"StringLength", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FileNames", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\*\>\"", ",", "$Path"}], 
    "]"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->161538214],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"clarky.dat\"\>", ",", "\<\"e205.dat\"\>", 
   ",", "\<\"e374.dat\"\>", ",", "\<\"l7769.dat\"\>", 
   ",", "\<\"naca23012.dat\"\>", ",", "\<\"naca4412.dat\"\>", 
   ",", "\<\"naca4412m.dat\"\>", ",", "\<\"naca642415.dat\"\>", 
   ",", "\<\"naca747a315.dat\"\>", ",", "\<\"s1223.dat\"\>", 
   ",", "\<\"sd7003.dat\"\>", ",", "\<\"usa35b.dat\"\>"}], "}"}]], "Output",
 ImageSize->{572, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->543149132]
}, Open  ]],

Cell[TextData[{
 "Choose the Eppler 205 airfoil for this example.  Use AirfoilFromDataFile to \
read the data and arrange it in the form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  Use FitAirfoil to fit a B-spline to the data, and the resulting spline \
function to compute a collection of vectors locating points on the surface of \
the airfoil.  Plot both the data and the spline fit to the data."
}], "ExampleText",
 CellID->193925074],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", "\"\<Aerodynamics\\Airfoil Data\\e205.dat\>\"",
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"spline", "=", 
   RowBox[{"FitAirfoil", "[", "rD", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSpline", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"spline", "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gD", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->435709841],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PFPUdx/Fr+pf037hEueMOFAk9D4vYWmrhZAtt1Wo0MagRalsIQrrx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->96932933]
}, Open  ]],

Cell["\<\
The following discretization is based on the spline fit to the data.  A plot \
of the user-specified discretization is shown below. \
\>", "ExampleText",
 CellID->105478441],

Cell[CellGroupData[{

Cell["PlotAirfoil[AirfoilSurfacePoints[spline,Range[0.,1.,0.05]]]", "Input",
 CellLabel->"In[4]:=",
 CellID->78161919],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c2rG9cZx3GV/iX9Ny6ULkIWIYuQQsjCeGODsDfNJtm0G3uTbFoQyeZe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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->350128323]
}, Open  ]],

Cell["\<\
Next, consider at the NACA 4415 airfoil defined by equations for thickness \
and camber properties that are computed by the function NACA4DigitAirfoil.  \
Note that functions can be nested.\
\>", "ExampleText",
 CellID->656638239],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"NACA4DigitAirfoil", "[", 
    RowBox[{"4415", ",", 
     RowBox[{"Range", "[", 
      RowBox[{"0.", ",", "1.", ",", "0.1"}], "]"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->52317584],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQvWGdZJn3v/f2zdsO14lMidxf8Y37fO6eN/aPvkpJ
dMwu358tL+tzsfGlPd/ZKQcaE1r3t36+U1Do+8ze1cOo7JfQhP0hKUt3F8s9
ti+JXuB7+ePU/VNzzDpfPr9vv0te5v2GN7P3z5oJAjftv6Z2Pzy6YsF+cdvJ
e6YUXLaf+evSikOai/cb+Ym0FTafsk9Ykfl3su7S/Vc/bhNYfmm3/akjV5fM
XrtkPwMaiHesUepJ2G4fxX08cYLPZnump3JrD64/Yd+TXP7l06ed9oGal1de
/HrJvmHDnHaRE3vsYfaXHS+2cDm/x37ryRRrbp4H9k1uG85nPdllL8J0cNUn
98f2uy8z+ZzesN3e8+b76Oj6Z/Y5iv6Tnydstj8pLPY8ceNL+4j5z9p6JNfY
Ky3uPaV99429VuPt1zfezbNfofHZ5RbDB1j42QMAAsKt8g==
    "]]},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->{{{-1.2, 
      FormBox[
       RowBox[{"-", "1.2`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.7999999999999999, 
      FormBox[
       RowBox[{"-", "0.7999999999999999`"}], 
       TraditionalForm]}, {-0.5999999999999999, 
      FormBox[
       RowBox[{"-", "0.5999999999999999`"}], 
       TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {1.0000000000000002`, 
      FormBox["1.0000000000000002`", TraditionalForm]}, {1.2000000000000004`, 
      FormBox["1.2000000000000004`", TraditionalForm]}, {1.4000000000000001`, 
      FormBox["1.4000000000000001`", TraditionalForm]}, {1.6, 
      FormBox["1.6`", TraditionalForm]}}, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}, None, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}},
  ImageSize->{504., 180.},
  PlotRange->{{-0.05, 1.05}, {-0.1, 0.201}},
  PlotRangeClipping->True,
  RotateLabel->False]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->24904285]
}, Open  ]],

Cell[TextData[{
 "Finally, consider an airfoil defined by a mapping function.  The example \
used is a member of  the van de Vooren family of symmetric airfoils.  The \
list of ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 "-values locates points on a circle that are mapped to the airfoil using the \
van de Vooren transformation.  The range of ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 " is ",
 Cell[BoxData["0"], "InlineFormula"],
 " to ",
 Cell[BoxData[
  StyleBox["\[Pi]", "TR"]], "InlineFormula"],
 " to generate points on the upper surface of the airfoil, and mirror \
symmetry is used to generate points on the lower surface.  The thickness \
parameter, ",
 Cell[BoxData[
  StyleBox["t", "TI"]], "InlineFormula"],
 ", and the trailing-edge angle, ",
 Cell[BoxData[
  StyleBox["\[Tau]", "TR"]], "InlineFormula"],
 ", are parameters in the transformation.  Plot a member of this family of \
airfoils."
}], "ExampleText",
 CellID->179618537],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"0.12", ",", 
    RowBox[{"9.81", " ", "Degree"}], ",", 
    RowBox[{"N", "[", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "\[Pi]", ",", 
       RowBox[{"\[Pi]", "/", "30"}]}], "]"}], "]"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->4154308],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c+LFHcax/Fe9i/Zf2Ng2UPIIeQQsiAeQi4uNMllc0kuekkuekmg0UuE
sB6iQnQPhl1KBAOiIA6EFWQFSQdkhGX2kEZwGNgBYfaZfmae+U51V03/qOp+
nm+9X1SI9Gj3U9NVn/rWt75V3z+c++zP537f6/X+Kf/973e93sGf9wEAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAcKPo98TGYDjt5cnXAQBLWXXqyhv3i/H/
T7z3cDAoDn9M0gNAc1aeusPBxvgDJz7yuCJyHgAas/rUPTqwVL110T/88aEe
AGAhi6Xu8uqPLEfnESdyvtkCAKALLDznTd0GVPQUaTHjl4pB8gNyHgAWcBye
c6ZuI05e+T2s4PC671h6DkHOA8AC0vCcK3VXj5wHgAUECs9ApQKAH4HCM1Cp
AOBHoPAMVCoA+BEoPAOVCgB+BArPQKUCgB+BwjNQqQDgR6DwDFQqAPgRKDwD
lQoAfgQKz0ClAoAfgcIzUKkA4Eeg8AxUKgD4ESg8A5UKAH4ECs9ApQKAH4HC
M1CpAOBHoPAMVCoA+BEoPAOVCgB+BArPQKUCgB+BwjNQqQDgR6DwDFQqAPgR
KDwDlQoAfgQKz0ClAoAfgcIzUKkA4Eeg8AxUKgD4ESg8A5UKAH4ECs9ApQKA
H4HCM1CpAOBHoPAMVCoA+BEoPAOVCgB+BArPQKUCgB+BwjNQqQDgR6DwDFQq
APgRKDwDlQoAfqw3PIu+fH5vYzA8+fJwsCEv94uTr5LzALCANDznSt0GyOeN
37XoT3zmwYeS8wDQgOPwnDN1l3f8plM+kpwHgGZYeM6buss7OrCQ8wDQIgvP
eVN3eQu0503TtQBAbiYzc/XtefrnAWAF1tg/v1++8pueUvQmLwmT8wCwgOrx
Nqek7uqR8wCwgEDhGahUAPAjUHgGKhUA/AgUnoFKBQA/AoVnoFIBwI9A4Rmo
VADwI1B4BioVAPwIFJ6BSgUAPwKFZ6BSAcCPQOEZqFQA8CNQeAYqFQD8CBSe
gUoFAD8ChWegUgHAj0DhGahUb7a2Xj/9139s+fHO82t/+3lyufrt5md//ccq
lwvn702tRJe7xYu0bF12dvbW/esEggkUnoFKbdtotKuh99P9XzUSv/n6UZqf
77937U9/vGrLxx/9kP5U/vLUXL1x/elkrra6PHr4sibnL118MHloKK2aLKW/
8MXnRel95FPsE+VXt+5vD1i1psJTJwtv9fHF3cl5jXHLQMtwiWtNtg8/+F5f
+erL+/p3pIne2UZv6dix+eRVKeflrMGOAvKrswPE2TM37XX7TZaOd8Nfflv3
+gHLaiznhwfpPhz023tIfX45LxlivSjadtUk1xi3Pg3L8K2t1+suOSvb228s
z+3MqNR/9Zdzf7fjgvx5srvJThY4IsCtJsNz2kxUDQqd89pEl4ai5vm773xn
uaG9KNoXTZJ7psflUneTnSzUHxFu33rG4QDr0lx4Fv3x9FPDoqDfZmdnT/Zo
2bW1y0VSXZvo0lDUPN/be7vuGtGiySPClcuPS4eD99+7xrEAq9FUeFr3fK+V
iWQPeM55yW3ZPWVX1QuFugvLrq1dLqQ6JmljYMZjgV0633zySv7J83//d93l
IxLP4VnirdTRaPen+7/KvvnpJ3ekxS47o+yGXbsGilbZscCGwn7xeSFbmmxy
pUvJsh2mV5DpAETKW3jW8FDq9vYb2eMuXXwg+9eHH3z/1Zf35VybxhXWxS4l
y3aYXkG2oVlyREhHE+npAEeBrvEQnjNaY6myX0hLSc6mJd7lDPpu8UL2r3UV
A8xOGiHpaCI9HeAo0DXkfI3hL79JA0l2ClnkD1wdQ2ZmOQropQG7RszFpojI
+UnSVpdUl6a7NOClGU/zBt2kRwG9NGDXiHVIsN5hbSOF9ESAk1y3yPmUtNjl
HFYSXuKdjRaook9MspFCeiIgO046RkgaS/IjOVlgpOjakfNKtlgdzyabZXuf
AmTPxghJY0lyXhpO6UjRdJiojjpmGMMKkPMS7HISKmegssm18f4ATDpMVO8i
tDGiehPxpYsP0ssB6643E13O+dFoV843pb1BDzywdnoT8d3iRXo5ID0EcBaw
sM7mvGxO0ozffPKqwfcE0Ib0iX+ls4B0UJA98W/d9brTwZzf3n4j24acHnLj
KhBdOijInuBNR1BJ13J+NNqVkOekD8jeqR1B3TkEdCrn9/beSsgzxAvouK5d
C+hUzl84f+/Rw5dN1AIgT6deC4h4FuAz54v+lBkIlyz16rebN64/Xa4uAN2l
1wJqzgLsSUHeJiNOw3Nquq6B1DF+iH1pfqolc/7smZvc4gqgDXoWYE8KSicj
thuE9Uc609CK+4KOw7MiXVdvONg4nKvkZCnL5PzW1uuPP/ph6dIAYD52g7Dm
vM4cWro7zJ4UpI+JaLw7yMKzKl1X7+iAMyXnzbzvefvWMznPaq5GAGiAngjY
k4L0MRHWHWTnAhJfC4T/ZGZWpevqtdGeJ+cBeDMa7aZNfevz1w4fexyQtvaX
aeQ7bM+30T+/vf3m7Jmby5cGAHNJr97ahF/SUJcYlzxPu+5tDE/jF3Ad9s/v
tzPehuuwANpQ6oEvPaIzHY1pE/iu+GZ8j+NtKiyZ8/oVNFUMgE7RPpbNJ69q
HrmfXkt1dT+mz/HzUy1fqhxnebw8gCpTw1x7y7WPRV6JOIVWp3J+b++tfE1R
bmED0IZSN8uF8/fqw9zP7U4L61TO74+/4k8/ucPjiIHsTU5rNbWb5dHDl3mE
eY2u5fz+0fQiPJcYyED6XGK9Bak0R2E6TW2UbpbGdTDnFfOMACHs7b1NW+al
ME/nGdFHCri6AOpEZ3N+n3kDATem9plLS0yS/N13vktb5oT5Arqc80rnAZfA
p20PtGpqmNf0mdMAawo5ryTkJeol8KW1IOeJ7X0QkLd5w7yzfearRM6npP1w
6eID2SblDJG2BFAlvZe//jG8hLkH5Pyk0Wj3xvWn0raXwL9y+TE9geggSeb0
jqGae/kdTquBEnK+hmzqt289k21bGirffP2IDnzkRJO89Fx0eyKuNHLSO4Yc
3suP2ZHzs5CGyo93nss2L+ek0rCR8GeDh3+zJHlpniPuFs8SOT+XnZ09adhc
ufxYGvk63EtPWrl0i9WzgeXWT64XPW2uIpIcykN4zshbqbqX6UUoyXzZuST/
Hz18yQVcNEVj2SYbsga5bG/pwHLrJ9eLniueexT+eQvPGs5LlZ3r9q1n0qDS
mzsk9nXydwYbYCrNcOtUsVEr1q9Smk4obZBz/oi5OA/PVKBS98exr5O/2+Bh
vTtbJxqgzZ8xmwzOBqvUZLh1qtioFfpV0LhA4Rmo1Kn0aUs6cZi2+fUhqNpa
0ynDuLzrmQ4aT/vDbRo4mwkunQzOBquQ4VivQOEZqNQZacNPe191CmAdn6x3
mtjZuhwdNCI4C2iQXcTURY6zlsly2mXpbSPGbdB42h9u08CtfiY4YHaBwjNQ
qUvSO8ft6pvFjp4FpC1GvQSQHgs6lTnWQ2KLPp82XXRKIF20A00Xu4ipixxn
7Z+kv0zOsJCBQOEZqNS2Wb7pJYBSEzTtQ9BFDhDpT/UhrlVLKTlbWtL28+SS
VmuLDRe0xY53NaumUwLpwgVxdFOg8AxUqjdbW6/rG72nZmzjS9p+nvFYw3BB
YDGBwjNQqQDgR6DwDFQqAPgRKDwDlQoAfgQKz0ClAoAfgcIzUKkA4Eeg8AxU
KgD4ESg8A5UKAH4ECs9ApQKAH4HCM1CpAOBHoPAMVCoA+BEoPAOVCgB+rDc8
i758fm9jMDz58nCwIS/3i5OvkvMAsIBTw3OuKJ6PvPX4DYr+xNsfvH+TOd/N
Y0QH15pV7oIOrvJ+qwE4ZxTP5fjfT3l3cr4BHVxrVrkLOrjK+20G4LxRPJej
Ywg535YOrjWr3AUdXOX9NgNw3iiue6PU+L0WaM8DABbQYBTPp81OIQDATFqO
4pMXedOzh176AwBAe4hiAAAAAOtSMf4/QxVrmvOJV92Xm+kVnppV1nta8vui
a2/hyXGFjzVxm1IX1F1fyEvFmg4Hg+Lwx9n9Buq+3HE25Ld/VK+yJEJ2X/BY
1SofHcePu5LzlGl7pVG144Wycuqa5vcLqFnlot8vctw/Klf5qG2b37Gt+ls+
DPiD73o9pa1Gjttx02rH/2fltDXNcG+oXGVd1xz3j6pVtsZ8fqdtdRt2pidt
J+W4HTeN9vzRTwf5bSoVq3zctM2v77bqW854O69rz2tzPrcvuYScn0Hn++f3
jxt7xSCzX0H9l5vl/lG1ykdpl+FK16zy+PVsL0wcyvArbUNXx9tY7+Vx4za/
zaXq5o4Dme4fp9zP0qFVthO3HNf5yMnRcrlfcwYAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAIBOHT03sDw7+z8MEASBHB1EvOZ/hVC4AgEPZz2oEAF2m
sz8wBwQAZGl42C+v/fQ06gEAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
SPwfBwfpSw==
    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->533707948]
}, Open  ]],

Cell[TextData[{
 "Although the list of ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 "-values can be used for discretization, a function XToTheta is defined to \
provide user-specified discretization consistent with the other sources of \
information for airfoils.  This function uses on the van de Vooren \
transformation to provide an interpolating function for ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 " as a function of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->88818872],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"0.12", ",", 
    RowBox[{"9.81", " ", "Degree"}], ",", 
    RowBox[{"XToTheta", "[", 
     RowBox[{"0.12", ",", 
      RowBox[{"9.81", " ", "Degree"}], ",", 
      RowBox[{"Range", "[", 
       RowBox[{"0.", ",", "1.", ",", "0.1"}], "]"}]}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->261648493],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3cGL3OYZx/Ep/Uv6byyUHkoPIQfjQsih9LKGIbk0F/uye0kuySWBwb7E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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->208291264]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell[TextData[{
 "A list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values controls the layout of the discretized airfoil used in numerical \
models.  The function NDiscretizeUnitSegment generates such a list and \
provides some flexibility for layout.  This is illustrated using the NACA \
3415 airfoil."
}], "ExampleText",
 CellID->148587983],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"NACA4DigitAirfoil", "[", 
    RowBox[{"3415", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Layout", "\[Rule]", "ConstantSpacing"}]}], "]"}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->562629873],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQzf2tImz7v/f276WO99itjdz/osBBufbAG/u3Ulsq
mDWb9i9m3tu6u/2lfZVch05I/oT931QNOVcFP7NncKmdsvrM9P1vV5Y9XKj8
2N57vdS5AqH5+1dy8i1/9/a+/ZYv+65N/7ho/6yZIHDTXuR1mXHd8aX7NW8m
nXRKvGz/5ulisTe/l+9X0OaUivU8Zb8t9U3cR4mV+7fqXiwqddttv8NtDe81
/uX7GdBAPWvSgb1vttuLOEV/snHYZC/CoSV57eUJ+0S5E+nTBXfY2/cyz1Vm
vWwfE7mjMCZllz3M/mcsdfwv7HfZ6/yuWMPB+cDeI9Pv1q70HfbVe963HHF6
bF+58xfv3eyt9jeWzT6sVPnMvsWmcK5nxUb7ifpla8tXv7T3VQhV3+2x0n6T
RmSZzM039jYLdr6oujXb/lfL4ZAlDB9g4WcPAJfCo1Y=
    "]]},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->{{{-1.2, 
      FormBox[
       RowBox[{"-", "1.2`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.7999999999999999, 
      FormBox[
       RowBox[{"-", "0.7999999999999999`"}], 
       TraditionalForm]}, {-0.5999999999999999, 
      FormBox[
       RowBox[{"-", "0.5999999999999999`"}], 
       TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {1.0000000000000002`, 
      FormBox["1.0000000000000002`", TraditionalForm]}, {1.2000000000000004`, 
      FormBox["1.2000000000000004`", TraditionalForm]}, {1.4000000000000001`, 
      FormBox["1.4000000000000001`", TraditionalForm]}, {1.6, 
      FormBox["1.6`", TraditionalForm]}}, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}, None, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}},
  ImageSize->{504., 180.},
  PlotRange->{{-0.05, 1.05}, {-0.1, 0.201}},
  PlotRangeClipping->True,
  RotateLabel->False]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->409406008]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"NACA4DigitAirfoil", "[", 
    RowBox[{"3415", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Layout", "\[Rule]", "CosineSpacing"}]}], "]"}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->15423508],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3cFrFFsWx/EM85fMvxF4vIW4CFmIA+JC3ERodPPeRje60Y1uEmh0Y0Am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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->597902934]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"AirfoilSurfacePoints", "[", 
   RowBox[{"NACA4DigitAirfoil", "[", 
    RowBox[{"3415", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Layout", "\[Rule]", "HalfCosineSpacing"}]}], "]"}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->466370447],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3cFrFNkWx/F+vL9k/o3AMIthFuJCfBCyEDcJNLrRjbPRjW50k0CjGwPD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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->324093728]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell[TextData[{
 "For some airfoils defined by data files, numerical problems may be \
encountered for fine discretization.  Tests performed on the airfoils \
specified by data files in the folder Airfoil Data showed no problems were \
encountered for discretizations of 200 panels or less.  No problems were \
encountered for 1000 panels when the value for the Layout option was set to \
ConstantSpacing.  The problem occurs near the leading edge and causes the \
list of spline parameters for discretization to be out of order.  This \
symptom is used to provide a warning message.  Since the intent of \
CosineSpacing and HalfCosineSpacing is to improve results of panel methods \
for coarse discretizations, this problem should not be a serious handicap.  \
After the next major release of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", I will revisit this problem."
}], "ExampleText",
 CellID->373231908]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["AirfoilFromDataFile",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["FitAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/FitAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["NACA4DigitAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/NACA4DigitAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PlotAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PlotAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->50156180]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["1.2 AirfoilsFromDataFiles",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["1.3 Airfoils From Thickness And Camber Properties",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromThicknessAndCamberProperties"]], \
"Tutorials",
 CellID->333185244],

Cell[TextData[ButtonBox["1.4 Airfoils From Conformal Mapping",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"]], "Tutorials",
 CellID->113142828]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "MoreAbout",
 CellID->4867765]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["RELATED LINKS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "RelatedLinksSection",
 CellID->1584193535],

Cell[TextData[ButtonBox["UIUC Airfoil Data Site",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}]], "RelatedLinks",
 CellID->1038487239]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"AirfoilSurfacePoints - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 55, 51.9234000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "AirfoilSurfacePoints[spline, x] returns a collection of vectors on the \
surface of an airfoil, where the airfoil is described by a B-spline. \
Locations of points on the surface of the airfoil are determined from a list \
of x-values. AirfoilSurfacePoints[properties] returns a collection of vectors \
on the surface of an airfoil specified by lists of thickness and camber \
properties. AirfoilSurfacePoints[t, \\[Tau], \\[Theta]] returns a collection \
of vectors on the surface of a van de Vooren airfoil of thickness parameter t \
and trailing-edge angle \\[Tau] corresponding to a list of \\[Theta] values \
in the range 0 to \\[Pi].", "synonyms" -> {}, "title" -> 
    "AirfoilSurfacePoints", "type" -> "Symbol", "uri" -> 
    "Aerodynamics/ref/AirfoilSurfacePoints"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[9857, 268, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->251452875]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 67118, 1585}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[601, 21, 76, 1, 70, "SymbolColorBar"],
Cell[680, 24, 191, 5, 70, "LinkTrail"],
Cell[874, 31, 3739, 83, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4638, 118, 63, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4704, 121, 2566, 67, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[7307, 193, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->630736251],
Cell[7890, 212, 255, 9, 70, "Notes",
 CellID->380359041],
Cell[8148, 223, 934, 20, 70, "Notes",
 CellID->100603792],
Cell[9085, 245, 494, 11, 70, "Notes",
 CellID->588903450],
Cell[9582, 258, 238, 5, 70, "Notes",
 CellID->168477564]
}, Closed]],
Cell[CellGroupData[{
Cell[9857, 268, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->251452875],
Cell[CellGroupData[{
Cell[10343, 285, 147, 5, 70, "ExampleSection",
 CellID->14671045],
Cell[10493, 292, 132, 6, 70, "ExampleText",
 CellID->251463159],
Cell[10628, 300, 100, 3, 70, "Input",
 CellID->492977788],
Cell[10731, 305, 176, 4, 70, "ExampleText",
 CellID->411631528],
Cell[CellGroupData[{
Cell[10932, 313, 599, 18, 70, "Input",
 CellID->161538214],
Cell[11534, 333, 539, 12, 54, "Output",
 CellID->543149132]
}, Open  ]],
Cell[12088, 348, 460, 9, 70, "ExampleText",
 CellID->193925074],
Cell[CellGroupData[{
Cell[12573, 361, 833, 26, 101, "Input",
 CellID->435709841],
Cell[13409, 389, 5842, 103, 201, "Output",
 CellID->96932933]
}, Open  ]],
Cell[19266, 495, 183, 4, 70, "ExampleText",
 CellID->105478441],
Cell[CellGroupData[{
Cell[19474, 503, 118, 2, 28, "Input",
 CellID->78161919],
Cell[19595, 507, 4831, 87, 201, "Output",
 CellID->350128323]
}, Open  ]],
Cell[24441, 597, 240, 5, 70, "ExampleText",
 CellID->656638239],
Cell[CellGroupData[{
Cell[24706, 606, 305, 9, 70, "Input",
 CellID->52317584],
Cell[25014, 617, 5428, 124, 201, "Output",
 CellID->24904285]
}, Open  ]],
Cell[30457, 744, 994, 26, 70, "ExampleText",
 CellID->179618537],
Cell[CellGroupData[{
Cell[31476, 774, 361, 10, 28, "Input",
 CellID->4154308],
Cell[31840, 786, 5079, 91, 201, "Output",
 CellID->533707948]
}, Open  ]],
Cell[36934, 880, 575, 15, 70, "ExampleText",
 CellID->88818872],
Cell[CellGroupData[{
Cell[37534, 899, 416, 12, 47, "Input",
 CellID->261648493],
Cell[37953, 913, 4823, 87, 201, "Output",
 CellID->208291264]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42825, 1006, 221, 7, 70, "ExampleSection",
 CellID->1293636265],
Cell[43049, 1015, 367, 9, 70, "ExampleText",
 CellID->148587983],
Cell[CellGroupData[{
Cell[43441, 1028, 364, 10, 70, "Input",
 CellID->562629873],
Cell[43808, 1040, 5425, 124, 201, "Output",
 CellID->409406008]
}, Open  ]],
Cell[CellGroupData[{
Cell[49270, 1169, 361, 10, 70, "Input",
 CellID->15423508],
Cell[49634, 1181, 5339, 95, 70, "Output",
 CellID->597902934]
}, Open  ]],
Cell[CellGroupData[{
Cell[55010, 1281, 366, 10, 70, "Input",
 CellID->466370447],
Cell[55379, 1293, 5237, 93, 70, "Output",
 CellID->324093728]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[60665, 1392, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[60899, 1401, 918, 16, 70, "ExampleText",
 CellID->373231908]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61866, 1423, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[62286, 1437, 818, 29, 70, "SeeAlso",
 CellID->50156180]
}, Open  ]],
Cell[CellGroupData[{
Cell[63141, 1471, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[63563, 1485, 177, 4, 70, "Tutorials",
 CellID->341631938],
Cell[63743, 1491, 222, 5, 70, "Tutorials",
 CellID->333185244],
Cell[63968, 1498, 194, 4, 70, "Tutorials",
 CellID->113142828]
}, Open  ]],
Cell[CellGroupData[{
Cell[64199, 1507, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[64621, 1521, 154, 3, 70, "MoreAbout",
 CellID->4867765]
}, Open  ]],
Cell[CellGroupData[{
Cell[64812, 1529, 427, 12, 70, "RelatedLinksSection",
 CellID->1584193535],
Cell[65242, 1543, 186, 4, 70, "RelatedLinks",
 CellID->1038487239]
}, Open  ]],
Cell[65443, 1550, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

