(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12744,        411]
NotebookOptionsPosition[     10001,        321]
NotebookOutlinePosition[     11297,        359]
CellTagsIndexPosition[     11212,        354]
WindowTitle->Clockwise - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.2 Airfoils From Data Files\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"NumberingConvention\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/NumberingConvention"], \
"\<\"AirfoilFromDataFile\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/AirfoilFromDataFile"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilGeometry\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/AirfoilGeometry"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/Clockwise\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/Clockwise"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
Clockwise.html"], StandardForm]], "Input", TextClipboardType -> "PlainText"]},
             Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/Clockwise", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Clockwise", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      ButtonBox["Clockwise",
       BaseStyle->"Link",
       ButtonData->"paclet:Aerodynamics/ref/Clockwise"]], "InlineFormula"],
     " \[LineSeparator]is a value for the option NumberingConvention for the \
function AirfoilFromDataFile."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->292883001],

Cell[TextData[{
 "The clockwise numbering convention starts numbering points (or panels) on \
the airfoil surface at the trailing edge and proceeds clockwise around the \
airfoil, traversing the lower surface forward to the leading edge and \
continuing aft along the upper surface, ending at the trailing edge.  This \
convention is used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ", but not in the data files of the ",
 ButtonBox["UIUC Airfoil Data Site",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}],
 "."
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "The other two values for the option ",
 ButtonBox["NumberingConvention",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/NumberingConvention"],
 " are ",
 ButtonBox["Counterclockwise",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/Counterclockwise"],
 " and ",
 ButtonBox["ForeToAft",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ForeToAft"],
 "."
}], "Notes",
 CellID->295403640]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->64605462],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->553891813],

Cell["See AirfoilFromDataFile for examples.", "ExampleText",
 CellID->20039398]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["NumberingConvention",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/NumberingConvention"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["AirfoilFromDataFile",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->468638561]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["1.2 Airfoils From Data Files",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]], "Tutorials",
 CellID->341631938]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["AirfoilGeometry",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "MoreAbout",
 CellID->1665078683]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["RELATED LINKS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "RelatedLinksSection",
 CellID->1584193535],

Cell[TextData[ButtonBox["UIUC Airfoil Data Site",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www.ae.uiuc.edu/m-selig/ads.html"], None}]], "RelatedLinks",
 CellID->1038487239]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Clockwise - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 55, 58.1790000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "Clockwise is a value for the option NumberingConvention for the function \
AirfoilFromDataFile.", "synonyms" -> {}, "title" -> "Clockwise", "type" -> 
    "Symbol", "uri" -> "Aerodynamics/ref/Clockwise"}, "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[6419, 188, 460, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->64605462]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 11070, 347}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[590, 21, 76, 1, 70, "SymbolColorBar"],
Cell[669, 24, 191, 5, 70, "LinkTrail"],
Cell[863, 31, 3155, 73, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4043, 108, 52, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4098, 111, 610, 16, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4745, 132, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->292883001],
Cell[5328, 151, 612, 15, 70, "Notes",
 CellID->1067943069],
Cell[5943, 168, 439, 15, 70, "Notes",
 CellID->295403640]
}, Closed]],
Cell[CellGroupData[{
Cell[6419, 188, 460, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->64605462],
Cell[CellGroupData[{
Cell[6904, 205, 148, 5, 70, "ExampleSection",
 CellID->553891813],
Cell[7055, 212, 79, 1, 70, "ExampleText",
 CellID->20039398]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7183, 219, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[7603, 233, 449, 15, 70, "SeeAlso",
 CellID->468638561]
}, Open  ]],
Cell[CellGroupData[{
Cell[8089, 253, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[8511, 267, 180, 4, 70, "Tutorials",
 CellID->341631938]
}, Open  ]],
Cell[CellGroupData[{
Cell[8728, 276, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[9150, 290, 156, 3, 70, "MoreAbout",
 CellID->1665078683]
}, Open  ]],
Cell[CellGroupData[{
Cell[9343, 298, 427, 12, 70, "RelatedLinksSection",
 CellID->1584193535],
Cell[9773, 312, 186, 4, 70, "RelatedLinks",
 CellID->1038487239]
}, Open  ]],
Cell[9974, 319, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

