(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     39116,       1270]
NotebookOptionsPosition[     33010,       1062]
NotebookOutlinePosition[     34522,       1102]
CellTagsIndexPosition[     34436,       1097]
WindowTitle->ForceAndMoment - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.6 Aerodynamic Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PMVortexLinearNeumann\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMVortexLinearNeumann"], \
"\<\"PMDoubletConstantDirichlet\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"], \
"\<\"PMDoubletQuadraticDirichlet\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/ForceAndMoment\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/ForceAndMoment"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
ForceAndMoment.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/ForceAndMoment", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["ForceAndMoment", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["ForceAndMoment",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"], "[", 
       RowBox[{
        StyleBox["singularity", "TI"], ",", 
        StyleBox["strength", "TI"], ",", 
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]], ",", 
        StyleBox["\[Alpha]", "TR"], ",", 
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["c", "TI"]]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]computes measures of lift and pitching moment given \
the name of the ",
     Cell[BoxData[
      StyleBox["singularity", "TI"]], "InlineFormula"],
     ", values for ",
     Cell[BoxData[
      StyleBox["strength", "TI"]], "InlineFormula"],
     " parameters, angle(s) of attack ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     ", and collections of vectors locating panel endpoints ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     ", and collocation points ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["c", "TI"]]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1015850645],

Cell[TextData[{
 "Collections of vectors are of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->967930315],

Cell["The singularity used is identified by \"Doublet\" or \"Vortex\".", \
"Notes",
 CellID->457944686],

Cell["\<\
There may be multiple lists of strength parameters, depending on the \
distribution of singularity density.\
\>", "Notes",
 CellID->155271063],

Cell[TextData[{
 "Measures of lift and pitching moment computed depend on the input used for \
the angle of attack.\t\t\t\t\t\t\t\t\t\t\t\t\t                       If a \
single value of ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " is input, the function returns the list ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["l", "TI"]], ",", 
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["m", "TI"]], ",", 
    SubscriptBox[
     StyleBox[
      StyleBox[
       RowBox[{
        StyleBox["\[CapitalDelta]",
         FontSlant->"Plain"], "c"}]], "TI"], 
     StyleBox["l", "TI"]], ",", 
    SubscriptBox[
     StyleBox[
      StyleBox[
       RowBox[{
        StyleBox["\[CapitalDelta]",
         FontSlant->"Plain"], "c"}]], "TI"], 
     StyleBox["m", "TI"]]}], "}"}]], "InlineFormula"],
 ", where ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["l", "TI"]]], "InlineFormula"],
 " denotes lift coefficient, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["m", "TI"]]], "InlineFormula"],
 ", pitching-moment coefficient about the origin of the coordinate system, \
and ",
 Cell[BoxData[
  StyleBox["\[CapitalDelta]", "TR"]], "InlineFormula"],
 " preceding these symbols denotes lists of panel contributions to the \
coefficient.\t\t\t\t\t\t\t\t\t                                                \
                                                             \t\t\t\t\t\t\t\tI\
f a list of angles of attack is input, a straight line is fit to the \
resulting lift and moment coefficients, and the function returns the list ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["l\[Alpha]", "TI"]], ",", 
    SubscriptBox[
     StyleBox["\[Alpha]", "TR"], 
     StyleBox["0", "TR"]], ",", 
    SubscriptBox[
     StyleBox["x", "TI"], 
     StyleBox["ac", "TI"]], ",", 
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["m0", "TI"]]}], "}"}]], "InlineFormula"],
 ", where ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["l\[Alpha]", "TI"]]], "InlineFormula"],
 " is the slope of the lift curve, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["\[Alpha]", "TR"], 
   StyleBox["0", "TR"]]], "InlineFormula"],
 " is the angle of attack at zero lift, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["x", "TI"], 
   StyleBox["ac", "TI"]]], "InlineFormula"],
 " locates the aerodynamic center and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["m0", "TI"]]], "InlineFormula"],
 " is the moment coefficient at zero lift (couple).  In the range of ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " where ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["l", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["m", "TI"]]], "InlineFormula"],
 " vary linearly, the lift and moment coefficients can be written as ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["l", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["l\[Alpha]", "TI"]], 
    RowBox[{"(", 
     RowBox[{
      StyleBox["\[Alpha]", "TR"], "-", 
      SubscriptBox[
       StyleBox["\[Alpha]", "TR"], 
       StyleBox["0", "TR"]]}], ")"}]}]}]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["m", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["m0", "TI"]], "-", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["l", "TI"]], " ", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["ac", "TI"]]}]}]}]], "InlineFormula"],
 "."
}], "Notes",
 CellID->61049260]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->54417649],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->675184996],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->218104157],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->326492779],

Cell[TextData[{
 "Use AirfoilFromDataFile to import data from the file for the Eppler-205 \
airfoil located in the folder Airfoil Data, and rearrange the data to the \
form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  The data file for this airfoil uses the counterclockwise numbering \
convention, which is the default value for the option NumberingConvention.  \
Also, display the number of panels specifying the discretized airfoil. "
}], "ExampleText",
 CellID->158695459],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"nP", "=", 
  RowBox[{"Length", "[", 
   RowBox[{"PanelLengths", "[", "rD", "]"}], "]"}]}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->317289154],

Cell[BoxData["60"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->13207542]
}, Open  ]],

Cell["Plot the discretized airfoil specified by the data.", "ExampleText",
 CellID->235318411],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", "rD", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->109742180],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c+LG+cdx3GV/iX9NxZKD8aHkINxwfhgfNkFkVyai31JLu2lvdggkosN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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->32713399]
}, Open  ]],

Cell["\<\
For a specified airfoil and angle of attack, PMVortexLinearNeumann returns \
strength parameters for the vortex panels, locations of collocation points \
and surface speeds at collocation points.  The function ForceAndMoment \
computes lift and pitching moment characteristics of the airfoil.  In this \
example, panel distributions of lift and pitching moment are ignored, and \
only the integrated airfoil lift coefficient and pitching-moment coefficient \
are displayed.  The pitching-moment coefficient is about the leading edge of \
the airfoil.\
\>", "ExampleText",
 CellID->40832064],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"3.", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rD", ",", "\[Alpha]", ",", 
     "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->462013216],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.635922933431754`", ",", 
   RowBox[{"-", "0.21167313112807118`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->393177655]
}, Open  ]],

Cell[TextData[{
 "If a list of angles of attack is input to the model function, lists of \
strength parameters are output and ForceAndMoment computes aerodynamic \
characteristics of the airfoil in terms of slope of lift curve, angle of \
attach at zero lift, aerodynamic center and pitching moment at zero lift.  \
These computations are based on fits of straight lines to the lift and \
pitching moment coefficients, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["l", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["l\[Alpha]", "TI"]], 
    RowBox[{"(", 
     RowBox[{
      StyleBox["\[Alpha]", "TR"], "-", 
      SubscriptBox[
       StyleBox["\[Alpha]", "TR"], 
       StyleBox["0", "TR"]]}], ")"}]}]}]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["m", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["m0", "TI"]], "-", 
    RowBox[{
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["ac", "TI"]], " ", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["l", "TI"]]}]}]}]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->39200997],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]L", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "4."}], ",", "0.", ",", "4."}], "}"}], "Degree"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aL", ",", "bL", ",", "rC", ",", "un"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rD", ",", "\[Alpha]L"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Vortex\>\"", ",", "aL", ",", "bL", ",", "rD", ",", "\[Alpha]L", ",", 
    "rC"}], "]"}]}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->110914806],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.787617175665627`", ",", 
   RowBox[{"-", "0.04129970570828699`"}], ",", "0.2597457840434449`", ",", 
   RowBox[{"-", "0.046417359166542146`"}]}], "}"}]], "Output",
 ImageSize->{298, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->588446796]
}, Open  ]],

Cell["Display the angle of attack at zero lift in degrees.", "ExampleText",
 CellID->42722081],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]0", "/", "Degree"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->595815551],

Cell[BoxData[
 RowBox[{"-", "2.3662988322171987`"}]], "Output",
 ImageSize->{54, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->206186900]
}, Open  ]],

Cell[TextData[{
 "Compute the lift and moment coefficients at ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " using the linear characteristics computed from the list of two angles of \
attack."
}], "ExampleText",
 CellID->195026435],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}]}]}], 
  "}"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->4822966],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6357253960563551`", ",", 
   RowBox[{"-", "0.21154435060152965`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->62906341]
}, Open  ]],

Cell["\<\
These values can be compared to those above for a specific angle of attack.\
\>", "ExampleText",
 CellID->84929584]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell["\<\
Repeat the computation of the basic example for the model \
PMDoubletConstantDirichlet for the same input.\
\>", "ExampleText",
 CellID->794166201],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "aW", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMDoubletConstantDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "a", ",", "rD", ",", "\[Alpha]", ",", "rC"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->443450959],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6481580536096048`", ",", 
   RowBox[{"-", "0.2171192731411692`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->161796]
}, Open  ]],

Cell["For the list of angles of attack.", "ExampleText",
 CellID->62876428],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aL", ",", "aW", ",", "rC", ",", "un"}], "}"}], "=", 
   RowBox[{"PMDoubletConstantDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]L"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Doublet\>\"", ",", "aL", ",", "rD", ",", "\[Alpha]L", ",", "rC"}], 
   "]"}]}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->38785546],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.721155160180188`", ",", 
   RowBox[{"-", "0.04404583670833849`"}], ",", "0.2569757757790824`", ",", 
   RowBox[{"-", "0.05047908533013451`"}]}], "}"}]], "Output",
 ImageSize->{298, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->233549193]
}, Open  ]],

Cell["Display the angle of attack at zero lift in degrees.", "ExampleText",
 CellID->139609124],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]0", "/", "Degree"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->327670291],

Cell[BoxData[
 RowBox[{"-", "2.5236405485101896`"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->112382152]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}]}]}], 
  "}"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->789288613],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6479577639243567`", ",", 
   RowBox[{"-", "0.21698853438667562`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->275639798]
}, Open  ]],

Cell["\<\
Repeat the computation of the basic for the model PMDoubletQuadraticDirichlet \
or the same input.\
\>", "ExampleText",
 CellID->781746724],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "a", ",", "b", ",", "c", ",", "rD", ",", 
     "\[Alpha]", ",", "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->161130905],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6359972898610773`", ",", 
   RowBox[{"-", "0.21880037336874703`"}]}], "}"}]], "Output",
 ImageSize->{135, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->24558261]
}, Open  ]],

Cell["For the list of angles of attack.", "ExampleText",
 CellID->9097697],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aL", ",", "bL", ",", "cL", ",", "aW", ",", "rC", ",", "un"}], 
    "}"}], "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]L"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Doublet\>\"", ",", "aL", ",", "bL", ",", "cL", ",", "rD", ",", 
    "\[Alpha]L", ",", "rC"}], "]"}]}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->85011794],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.7882366327189105`", ",", 
   RowBox[{"-", "0.04130210930293226`"}], ",", "0.2601955124584506`", ",", 
   RowBox[{"-", "0.05324000902038542`"}]}], "}"}]], "Output",
 ImageSize->{284, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->345283582]
}, Open  ]],

Cell["Display the angle of attack at zero lift in degrees.", "ExampleText",
 CellID->702932761],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]0", "/", "Degree"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->612261436],

Cell[BoxData[
 RowBox[{"-", "2.3664365480460328`"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->7729705]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}]}]}], 
  "}"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->359264607],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6357997303150393`", ",", 
   RowBox[{"-", "0.21867224567065177`"}]}], "}"}]], "Output",
 ImageSize->{135, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->96020350]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMVortexLinearNeumann",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMDoubletConstantDirichlet",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMDoubletQuadraticDirichlet",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . "
}], "SeeAlso",
 CellID->469214351]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["3.6 Aerodynamic Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"]], "Tutorials",
 CellID->65261378],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "Tutorials",
 CellID->194407723]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "MoreAbout",
 CellID->640103481]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"ForceAndMoment - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 56, 25.2762000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "ForceAndMoment[singularity, strength, r_p, \\[Alpha], r_c] computes \
measures of lift and pitching moment given the name of the singularity, \
values for strength parameters, angle(s) of attack \\[Alpha], and collections \
of vectors locating panel endpoints r_p, and collocation points r_c.", 
    "synonyms" -> {}, "title" -> "ForceAndMoment", "type" -> "Symbol", "uri" -> 
    "Aerodynamics/ref/ForceAndMoment"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[10991, 342, 460, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->54417649]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 34293, 1090}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[595, 21, 76, 1, 70, "SymbolColorBar"],
Cell[674, 24, 191, 5, 70, "LinkTrail"],
Cell[868, 31, 3434, 77, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4327, 112, 57, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4387, 115, 1578, 46, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6002, 166, 581, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1015850645],
Cell[6586, 185, 250, 8, 70, "Notes",
 CellID->967930315],
Cell[6839, 195, 103, 2, 70, "Notes",
 CellID->457944686],
Cell[6945, 199, 152, 4, 70, "Notes",
 CellID->155271063],
Cell[7100, 205, 3854, 132, 70, "Notes",
 CellID->61049260]
}, Closed]],
Cell[CellGroupData[{
Cell[10991, 342, 460, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->54417649],
Cell[CellGroupData[{
Cell[11476, 359, 148, 5, 70, "ExampleSection",
 CellID->675184996],
Cell[11627, 366, 132, 6, 70, "ExampleText",
 CellID->218104157],
Cell[11762, 374, 100, 3, 70, "Input",
 CellID->326492779],
Cell[11865, 379, 497, 10, 70, "ExampleText",
 CellID->158695459],
Cell[CellGroupData[{
Cell[12387, 393, 344, 11, 70, "Input",
 CellID->317289154],
Cell[12734, 406, 158, 5, 36, "Output",
 CellID->13207542]
}, Open  ]],
Cell[12907, 414, 94, 1, 70, "ExampleText",
 CellID->235318411],
Cell[CellGroupData[{
Cell[13026, 419, 108, 3, 28, "Input",
 CellID->109742180],
Cell[13137, 424, 5000, 89, 201, "Output",
 CellID->32713399]
}, Open  ]],
Cell[18152, 516, 600, 10, 70, "ExampleText",
 CellID->40832064],
Cell[CellGroupData[{
Cell[18777, 530, 761, 23, 70, "Input",
 CellID->462013216],
Cell[19541, 555, 259, 8, 36, "Output",
 CellID->393177655]
}, Open  ]],
Cell[19815, 566, 1244, 41, 70, "ExampleText",
 CellID->39200997],
Cell[CellGroupData[{
Cell[21084, 611, 737, 23, 70, "Input",
 CellID->110914806],
Cell[21824, 636, 336, 9, 36, "Output",
 CellID->588446796]
}, Open  ]],
Cell[22175, 648, 94, 1, 70, "ExampleText",
 CellID->42722081],
Cell[CellGroupData[{
Cell[22294, 653, 105, 3, 70, "Input",
 CellID->595815551],
Cell[22402, 658, 193, 6, 36, "Output",
 CellID->206186900]
}, Open  ]],
Cell[22610, 667, 254, 7, 70, "ExampleText",
 CellID->195026435],
Cell[CellGroupData[{
Cell[22889, 678, 355, 12, 70, "Input",
 CellID->4822966],
Cell[23247, 692, 259, 8, 36, "Output",
 CellID->62906341]
}, Open  ]],
Cell[23521, 703, 125, 3, 70, "ExampleText",
 CellID->84929584]
}, Open  ]],
Cell[CellGroupData[{
Cell[23683, 711, 221, 7, 70, "ExampleSection",
 CellID->1293636265],
Cell[23907, 720, 157, 4, 70, "ExampleText",
 CellID->794166201],
Cell[CellGroupData[{
Cell[24089, 728, 657, 20, 70, "Input",
 CellID->443450959],
Cell[24749, 750, 256, 8, 36, "Output",
 CellID->161796]
}, Open  ]],
Cell[25020, 761, 75, 1, 70, "ExampleText",
 CellID->62876428],
Cell[CellGroupData[{
Cell[25120, 766, 541, 16, 70, "Input",
 CellID->38785546],
Cell[25664, 784, 335, 9, 36, "Output",
 CellID->233549193]
}, Open  ]],
Cell[26014, 796, 95, 1, 70, "ExampleText",
 CellID->139609124],
Cell[CellGroupData[{
Cell[26134, 801, 105, 3, 70, "Input",
 CellID->327670291],
Cell[26242, 806, 193, 6, 36, "Output",
 CellID->112382152]
}, Open  ]],
Cell[CellGroupData[{
Cell[26472, 817, 357, 12, 70, "Input",
 CellID->789288613],
Cell[26832, 831, 260, 8, 36, "Output",
 CellID->275639798]
}, Open  ]],
Cell[27107, 842, 149, 4, 70, "ExampleText",
 CellID->781746724],
Cell[CellGroupData[{
Cell[27281, 850, 703, 21, 70, "Input",
 CellID->161130905],
Cell[27987, 873, 259, 8, 36, "Output",
 CellID->24558261]
}, Open  ]],
Cell[28261, 884, 74, 1, 70, "ExampleText",
 CellID->9097697],
Cell[CellGroupData[{
Cell[28360, 889, 592, 17, 70, "Input",
 CellID->85011794],
Cell[28955, 908, 336, 9, 36, "Output",
 CellID->345283582]
}, Open  ]],
Cell[29306, 920, 95, 1, 70, "ExampleText",
 CellID->702932761],
Cell[CellGroupData[{
Cell[29426, 925, 105, 3, 70, "Input",
 CellID->612261436],
Cell[29534, 930, 191, 6, 36, "Output",
 CellID->7729705]
}, Open  ]],
Cell[CellGroupData[{
Cell[29762, 941, 357, 12, 70, "Input",
 CellID->359264607],
Cell[30122, 955, 259, 8, 36, "Output",
 CellID->96020350]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30442, 970, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[30862, 984, 695, 23, 70, "SeeAlso",
 CellID->469214351]
}, Open  ]],
Cell[CellGroupData[{
Cell[31594, 1012, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[32016, 1026, 181, 4, 70, "Tutorials",
 CellID->65261378],
Cell[32200, 1032, 160, 3, 70, "Tutorials",
 CellID->194407723]
}, Open  ]],
Cell[CellGroupData[{
Cell[32397, 1040, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[32819, 1054, 149, 3, 70, "MoreAbout",
 CellID->640103481]
}, Open  ]],
Cell[32983, 1060, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

