(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    291408,       6350]
NotebookOptionsPosition[    283127,       6081]
NotebookOutlinePosition[    284982,       6126]
CellTagsIndexPosition[    284895,       6121]
WindowTitle->ICDoubletQuadratic - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"2.1 Introduction to Influence Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"], "\
\<\"2.3 Isolated Panel\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IsolatedPanel"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"ICDoubletPoint\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ICDoubletPoint"], "\<\"ICDoubletConstant\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ICDoubletConstant"], \
"\<\"ICDoubletLinear\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ICDoubletLinear"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Influence Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/guide/InfluenceCoefficients"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/ICDoubletQuadratic\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/ICDoubletQuadratic"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
ICDoubletQuadratic.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/ICDoubletQuadratic", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["ICDoubletQuadratic", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["ICDoubletQuadratic",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/ICDoubletQuadratic"], "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["f", "TI"]], ",", 
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]computes velocity influence coefficients at field \
points ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["f", "TI"]]], "InlineFormula"],
     ", due to connected doublet panels of quadratically varying strength \
whose endpoints are located by ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     "."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"IC\[Phi]DoubletQuadratic", "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["f", "TI"]], ",", 
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]computes velocity-potential influence coefficients at \
field points ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["f", "TI"]]], "InlineFormula"],
     " due to connected doublet panels of quadratically varying strength \
whose endpoints are located by ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     "."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["f", "TI"]], ",", 
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]computes stream-function influence coefficients at \
field points ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["f", "TI"]]], "InlineFormula"],
     " due to connected doublet panels of quadratically varying strength \
whose endpoints are located by ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{"Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], 
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], {
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->918915790],

Cell[TextData[{
 "Input arguments are collections of vectors of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "The doublet density for the panel of quadratically varying strength is \
written as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Mu]", "TR"], 
    RowBox[{"(", 
     StyleBox["x", "TI"], ")"}]}], "=", 
   RowBox[{
    StyleBox["a", "TI"], "+", 
    RowBox[{
     StyleBox["b", "TI"], " ", 
     StyleBox["x", "TI"]}], 
    StyleBox["+", "TI"], 
    StyleBox[" ", "TI"], 
    RowBox[{
     StyleBox["c", "TI"], 
     StyleBox[" ", "TI"], 
     SuperscriptBox[
      StyleBox["x", "TI"], "2"]}]}]}]], "InlineFormula"],
 ", where ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " is the distance from the beginning of the panel, constants ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 " are the strength parameters for the panel.  For collections of panels, the \
strength parameters are written in three lists, one for the constant term, \
one for the linear term and one for the quadratic term in the equation for \
doublet density.  Within each list strength parameters are ordered according \
to the clockwise numbering convention for panels. "
}], "Notes",
 CellID->105355403],

Cell[TextData[{
 "Output for velocity influence coefficients are three collections of vectors \
one grouping influence coefficients for the ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " parameters, one grouping terms the ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " parameters and one grouping terms for the ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 " parameters.  Influence coefficients for velocity potential and stream \
function are three lists of scalar influence coefficients."
}], "Notes",
 CellID->396753093],

Cell[TextData[{
 "The velocity, velocity potential or stream function for a panel are written \
as the sum of three terms, each term being the product of a geometric \
influence coefficient and the appropriate strength parameter.\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["v", "TI"], "=", 
   RowBox[{
    RowBox[{
     StyleBox["a", "TI"], " ", 
     StyleBox["ica", "TI"]}], "+", 
    RowBox[{
     StyleBox["b", "TI"], " ", 
     StyleBox["icb", "TI"]}], "+", 
    RowBox[{
     StyleBox["c", "TI"], " ", 
     StyleBox["icc", "TI"]}]}]}]], "InlineFormula"],
 "\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Phi]", "TR"], "=", 
   RowBox[{
    RowBox[{
     StyleBox["a", "TI"], " ", 
     StyleBox["ic\[Phi]a", "TI"]}], "+", 
    RowBox[{
     StyleBox["b", "TI"], " ", 
     StyleBox["ic\[Phi]b", "TI"]}], "+", 
    RowBox[{
     StyleBox["c", "TI"], " ", 
     StyleBox["ic\[Phi]c", "TI"]}]}]}]], "InlineFormula"],
 "\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Psi]", "TR"], "=", 
   RowBox[{
    RowBox[{
     StyleBox["a", "TI"], " ", 
     StyleBox["ic\[Psi]a", "TI"]}], "+", " ", 
    RowBox[{
     StyleBox["b", "TI"], " ", 
     StyleBox["ic\[Psi]b", "TI"]}], "+", 
    RowBox[{
     StyleBox["c", "TI"], " ", 
     StyleBox["ic\[Psi]c", "TI"]}]}]}]], "InlineFormula"]
}], "Notes",
 CellID->1369051]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->132597713],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->278572386],

Cell["Load the package.", "ExampleText",
 CellID->513831186],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->66474307],

Cell[TextData[{
 "This example demonstrates some properties of a single panel.  Algebraic \
equations for influence coefficients are simplest in a local coordinate \
system where the panel extends from the origin along the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " axis to ",
 Cell[BoxData[
  StyleBox["\[Delta]", "TR"]], "InlineFormula"],
 ", the length of the panel.  ",
 "Because this example deals with a single panel, unwanted list brackets are \
eliminated using Flatten."
}], "ExampleText",
 CellID->659456463],

Cell["\<\
Specify an arbitrary field point and the two panel endpoints.\
\>", "ExampleText",
 CellID->562424937],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rF", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "x", "}"}], ",", 
     RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->64953589],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "x", "}"}], "\[UpArrow]", 
   RowBox[{"{", "z", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{$CellContext`x}, \
{$CellContext`z}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->278074213]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rP", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "\[Delta]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->47353595],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "\[Delta]"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{
    0, $CellContext`\[Delta]}, {0, 0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{91, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->460607572]
}, Open  ]],

Cell["\<\
Compute the velocity influence coefficients.  There are separate influence \
coefficients for the constant, linear and quadratic terms in the function \
describing doublet distribution.\
\>", "ExampleText",
 CellID->326501090],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ica", ",", "icb", ",", "icc"}], "}"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"ICDoubletQuadratic", "[", 
      RowBox[{"rF", ",", "rP"}], "]"}], ",", 
     RowBox[{"\[Delta]", ">", "0"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->560964283],

Cell[TextData[{
 "Display the algebraic expressions for components of the velocity influence \
coefficient associated with strength parameter ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->120984796],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"icax", ",", "icaz"}], "}"}], "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Components", "[", "ica", "]"}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->176773044],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"z", " ", "\[Delta]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "x"}], "+", "\[Delta]"}], ")"}]}], 
     RowBox[{"2", " ", "\[Pi]", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"], "-", 
        RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
        SuperscriptBox["\[Delta]", "2"]}], ")"}]}]]}], ",", 
   FractionBox[
    RowBox[{"\[Delta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], "+", 
       SuperscriptBox["z", "2"], "+", 
       RowBox[{"x", " ", "\[Delta]"}]}], ")"}]}], 
    RowBox[{"2", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
       SuperscriptBox["\[Delta]", "2"]}], ")"}]}]]}], "}"}]], "Output",
 ImageSize->{436, 41},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->65382208]
}, Open  ]],

Cell[TextData[{
 "Display the algebraic equations for components of the velocity influence \
coefficient associated with strength parameter ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->118713566],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icbx", ",", "icbz"}], "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Components", "[", "icb", "]"}], "]"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"icbx", ",", "icbz"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", "\[Theta]1"}], ",", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"x", "-", "\[Delta]"}], ",", "z"}], "]"}], "\[Rule]", 
       "\[Theta]2"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->25568170],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", "\[Delta]"}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
       SuperscriptBox["\[Delta]", "2"]}]], "+", "\[Theta]1", "-", 
     "\[Theta]2"}], 
    RowBox[{"2", " ", "\[Pi]"}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[Delta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "x"}], "+", "\[Delta]"}], ")"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
       SuperscriptBox["\[Delta]", "2"]}]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"], "-", 
         RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
         SuperscriptBox["\[Delta]", "2"]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}]], "]"}]}]}], 
    RowBox[{"2", " ", "\[Pi]"}]]}], "}"}]], "Output",
 ImageSize->{367, 46},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->795787059]
}, Open  ]],

Cell[TextData[{
 "Display the algebraic equations for components of the velocity influence \
coefficient associated with strength parameter ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->64639684],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"iccx", ",", "iccz"}], "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Components", "[", "icc", "]"}], "]"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"iccx", ",", "iccz"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", "\[Theta]1"}], ",", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"x", "-", "\[Delta]"}], ",", "z"}], "]"}], "\[Rule]", 
       "\[Theta]2"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[7]:=",
 CellID->263173446],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", 
       SuperscriptBox["\[Delta]", "2"]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
       SuperscriptBox["\[Delta]", "2"]}]], "+", 
     RowBox[{"2", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{"\[Theta]1", "-", "\[Theta]2"}], ")"}]}], "-", 
     RowBox[{"z", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"], "-", 
         RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
         SuperscriptBox["\[Delta]", "2"]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}]], "]"}]}]}], 
    RowBox[{"2", " ", "\[Pi]"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "\[Delta]"}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Delta]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "x"}], "+", "\[Delta]"}], ")"}]}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"], "-", 
        RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
        SuperscriptBox["\[Delta]", "2"]}]], "+", 
      RowBox[{"2", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"\[Theta]1", "-", "\[Theta]2"}], ")"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"], "-", 
          RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
          SuperscriptBox["\[Delta]", "2"]}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"]}]], "]"}]}]}], 
     RowBox[{"2", " ", "\[Pi]"}]]}]}], "}"}]], "Output",
 ImageSize->{350, 94},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->27415657]
}, Open  ]],

Cell[TextData[{
 "Compute velocity-potential influence coefficients associated with the \
strength parameters ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ",  ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->44302699],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Phi]a", ",", "ic\[Phi]b", ",", "ic\[Phi]c"}], "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"IC\[Phi]DoubletQuadratic", "[", 
       RowBox[{"rF", ",", "rP"}], "]"}], ",", 
      RowBox[{"\[Delta]", ">", "0"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Phi]a", ",", "ic\[Phi]b", ",", "ic\[Phi]c"}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", "\[Theta]1"}], ",", 
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"x", "-", "\[Delta]"}], ",", "z"}], "]"}], "\[Rule]", 
      "\[Theta]2"}]}], "}"}]}], "]"}]}], "Input",
 CellLabel->"In[8]:=",
 CellID->575890672],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"\[Theta]1", "-", "\[Theta]2"}], 
    RowBox[{"2", " ", "\[Pi]"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Theta]1"}], "+", "\[Theta]2"}], ")"}]}], "+", 
      RowBox[{"z", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"], "-", 
          RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
          SuperscriptBox["\[Delta]", "2"]}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"]}]], "]"}]}]}], 
     RowBox[{"4", " ", "\[Pi]"}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"z", " ", "\[Delta]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["z", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Theta]1", "-", "\[Theta]2"}], ")"}]}], "+", 
      RowBox[{"x", " ", "z", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"], "-", 
          RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
          SuperscriptBox["\[Delta]", "2"]}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"]}]], "]"}]}]}], 
     RowBox[{"2", " ", "\[Pi]"}]]}]}], "}"}]], "Output",
 ImageSize->{319, 94},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->144118160]
}, Open  ]],

Cell[TextData[{
 "Compute stream-function influence coefficients associated with the strength \
parameters ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ",  ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->14511646],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]a", ",", "ic\[Psi]b", ",", "ic\[Psi]c"}], "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
       RowBox[{"rF", ",", "rP"}], "]"}], ",", 
      RowBox[{"\[Delta]", ">", "0"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]a", ",", "ic\[Psi]b", ",", "ic\[Psi]c"}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", "\[Theta]1"}], ",", 
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"x", "-", "\[Delta]"}], ",", "z"}], "]"}], "\[Rule]", 
      "\[Theta]2"}]}], "}"}]}], "]"}]}], "Input",
 CellLabel->"In[9]:=",
 CellID->8664355],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
       SuperscriptBox["\[Delta]", "2"]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["z", "2"]}]], "]"}], 
    RowBox[{"4", " ", "\[Pi]"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "\[Delta]"}], "+", 
     RowBox[{"2", " ", "z", " ", "\[Theta]1"}], "-", 
     RowBox[{"2", " ", "z", " ", "\[Theta]2"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"], "-", 
         RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
         SuperscriptBox["\[Delta]", "2"]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}]], "]"}]}]}], 
    RowBox[{"4", " ", "\[Pi]"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "\[Delta]"}], ")"}]}], "+", 
     RowBox[{"2", " ", "x", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{"\[Theta]1", "-", "\[Theta]2"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["z", "2"]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"], "-", 
         RowBox[{"2", " ", "x", " ", "\[Delta]"}], "+", 
         SuperscriptBox["\[Delta]", "2"]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}]], "]"}]}]}], 
    RowBox[{"2", " ", "\[Pi]"}]]}], "}"}]], "Output",
 ImageSize->{384, 94},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->689982562]
}, Open  ]],

Cell["\<\
Write the velocity components, velocity potential and stream function in \
terms of geometric influence coefficients and strength parameters.\
\>", "ExampleText",
 CellID->9427774],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "w"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "icax"}], "+", 
      RowBox[{"b", " ", "icbx"}], "+", 
      RowBox[{"c", " ", "iccx"}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "icaz"}], "+", 
      RowBox[{"b", " ", "icbz"}], "+", 
      RowBox[{"c", " ", "iccz"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "\[Psi]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "ic\[Phi]a"}], "+", 
      RowBox[{"b", " ", "ic\[Phi]b"}], "+", 
      RowBox[{"c", " ", "ic\[Phi]c"}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "ic\[Psi]a"}], "+", 
      RowBox[{"b", " ", "ic\[Psi]b"}], "+", 
      RowBox[{"c", " ", "ic\[Psi]c"}]}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[10]:=",
 CellID->258291294],

Cell[TextData[{
 "Verify that the relations between velocity, velocity potential and stream \
function are satisfied.\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["u", "TI"], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", 
      StyleBox["\[Phi]", "TR"]}], 
     RowBox[{"\[PartialD]", 
      StyleBox["x", "TI"]}]], "=", 
    FractionBox[
     RowBox[{"\[PartialD]", 
      StyleBox["\[Psi]", "TR"]}], 
     RowBox[{"\[PartialD]", 
      StyleBox["z", "TI"]}]]}]}]], "InlineFormula"],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["w", "TI"], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", 
      StyleBox["\[Phi]", "TR"]}], 
     RowBox[{"\[PartialD]", 
      StyleBox["z", "TI"]}]], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[PartialD]", 
       StyleBox["\[Psi]", "TR"]}], 
      RowBox[{"\[PartialD]", 
       StyleBox["x", "TI"]}]]}]}]}]], "InlineFormula"],
 "\t\t\t\t\t"
}], "ExampleText",
 CellID->78226744],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Equal]", 
     RowBox[{"D", "[", 
      RowBox[{"\[Phi]", ",", "x"}], "]"}]}], ",", 
    RowBox[{"u", "\[Equal]", 
     RowBox[{"D", "[", 
      RowBox[{"\[Psi]", ",", "z"}], "]"}]}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->13857323],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->95143627]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"w", "\[Equal]", 
     RowBox[{"D", "[", 
      RowBox[{"\[Phi]", ",", "z"}], "]"}]}], ",", 
    RowBox[{"w", "\[Equal]", 
     RowBox[{"-", 
      RowBox[{"D", "[", 
       RowBox[{"\[Psi]", ",", "x"}], "]"}]}]}]}], "}"}], "//", 
  "Simplify"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->499128776],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->104089847]
}, Open  ]],

Cell[TextData[{
 "Flow visualization provides a plausibility check on the computed flow \
field.  Since the contributions of the ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " and b parameters are illustrated in ICDoubletConstant and ICDoubletLinear, \
set ",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{
    StyleBox["b", "TI"], "=", "0"}]}]], "InlineFormula"],
 ".  Set ",
 Cell[BoxData[
  RowBox[{
   StyleBox["c", "TI"], "=", "3"}]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[Delta]", "TR"], "=", "1"}]], "InlineFormula"],
 " to provide unit integrated panel strength,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     StyleBox["\[Delta]", "TR"]], 
    RowBox[{"\[Mu]", 
     RowBox[{"(", 
      StyleBox["x", "TI"], ")"}], 
     RowBox[{"\[DifferentialD]", 
      StyleBox["x", "TI"]}]}]}], "=", "1"}]], "InlineFormula"],
 ".  Circular regions near the edges of the panel are excluded from the \
vector plot to avoid showing vectors of very large magnitude.  Also, \
nonlinear scaling is used for magnitudes of vectors to enhance visibility in \
the far field."
}], "ExampleText",
 CellID->78531558],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xMin", ",", "xMax", ",", "zMin", ",", "zMax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2", ",", 
     RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"uPlot", ",", "wPlot"}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "w"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", "0"}], ",", 
      RowBox[{"b", "\[Rule]", "0"}], ",", 
      RowBox[{"c", "\[Rule]", "3"}], ",", 
      RowBox[{"\[Delta]", "\[Rule]", "1"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Phi]Plot", ",", "\[Psi]Plot"}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Phi]", ",", "\[Psi]"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", "0"}], ",", 
      RowBox[{"b", "\[Rule]", "0"}], ",", 
      RowBox[{"c", "\[Rule]", "3"}], ",", 
      RowBox[{"\[Delta]", "\[Rule]", "1"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gV", "=", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uPlot", ",", "wPlot"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "z"}], "}"}], ",", 
        RowBox[{
         RowBox[{"0.01", "<", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"z", "^", "2"}]}]}], " ", "&&", " ", 
         RowBox[{"0.01", "<", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "1"}], ")"}], "^", "2"}], "+", 
           RowBox[{"z", "^", "2"}]}]}]}]}], "]"}]}], ",", 
     RowBox[{"VectorColorFunction", "->", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"VectorPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"20", ",", "20"}], "}"}]}], ",", 
     RowBox[{"VectorScale", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Large", ",", "Automatic", ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "#5", "]"}], "&"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g\[Phi]", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Phi]Plot", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "13"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g\[Psi]", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]Plot", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "7"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gPanel", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
      RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Components", "[", 
         RowBox[{"rP", "/.", 
          RowBox[{"\[Delta]", "\[Rule]", "1.0"}]}], "]"}], "]"}], "]"}]}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gV", ",", "g\[Phi]", ",", "g\[Psi]", ",", "gPanel", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "1.0"}], ",", "2.0", ",", "0.25"}], "]"}], "]"}], ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "1.2"}], ",", "1.2", ",", "0.2"}], "]"}], "]"}], ",", 
      "None", ",", "None"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", " ", "72"}]}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellLabel->"In[13]:=",
 CellID->1746043248],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.005155568657073443, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.016435228364837, -1.1941437715951384`}, \
{-0.983564771635163, -1.2058562284048615`}}]}}, 
      {Arrowheads[{{0.005337564925081218, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0163216064618916`, -1.0659454314777506`}, \
{-0.9836783935381083, -1.0814229895748808`}}]}}, 
      {Arrowheads[{{0.005518029585552964, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0159157410271928`, -0.9376006577429147}, \
{-0.984084258972807, -0.9571361843623486}}]}}, 
      {Arrowheads[{{0.005693456486451876, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0151551205044205`, -0.8091544169596092}, \
{-0.9848448794955795, -0.8329508461982857}}]}}, 
      {Arrowheads[{{0.0058595236094239, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0139821761424253`, -0.6806756616806191}, \
{-0.9860178238575749, -0.7087980225299074}}]}}, 
      {Arrowheads[{{0.0060111346627143795`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0123541403433705`, -0.5522592150771991}, \
{-0.9876458596566297, -0.5845828901859592}}]}}, 
      {Arrowheads[{{0.006142606229628945, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0102554493854063`, -0.4240233518794248}, \
{-0.9897445506145938, -0.4601871744363651}}]}}, 
      {Arrowheads[{{0.00624805614867746, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0077105741934005`, -0.2961008762596747}, \
{-0.9922894258065995, -0.3354780711087467}}]}}, 
      {Arrowheads[{{0.006322013031793323, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0047932543936122`, -0.1686226534878483}, \
{-0.9952067456063878, -0.21032471493320473`}}]}}, 
      {Arrowheads[{{0.006360181369152893, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-1.0016269867499912`, -0.04169542819260318}, \
{-0.9983730132500089, -0.08462036128108141}}]}}, 
      {Arrowheads[{{0.0063601813691528935`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9983730132500088, 
         0.08462036128108102}, {-1.0016269867499912`, 
         0.041695428192602794`}}]}}, 
      {Arrowheads[{{0.0063220130317933184`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9952067456063878, 
         0.21032471493320434`}, {-1.0047932543936122`, 
         0.16862265348784794`}}]}}, 
      {Arrowheads[{{0.006248056148677467, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9922894258065995, 
         0.3354780711087464}, {-1.0077105741934005`, 0.2961008762596743}}]}}, 
      {Arrowheads[{{0.006142606229628936, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9897445506145938, 
         0.46018717443636475`}, {-1.0102554493854061`, 
         0.4240233518794244}}]}}, 
      {Arrowheads[{{0.0060111346627143795`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9876458596566297, 
         0.5845828901859588}, {-1.0123541403433705`, 0.5522592150771987}}]}}, 
      {Arrowheads[{{0.005859523609423913, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9860178238575747, 
         0.708798022529907}, {-1.0139821761424253`, 0.6806756616806187}}]}}, 
      {Arrowheads[{{0.005693456486451876, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9848448794955795, 
         0.8329508461982853}, {-1.0151551205044205`, 0.8091544169596088}}]}}, 
      {Arrowheads[{{0.005518029585552949, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9840842589728072, 
         0.9571361843623482}, {-1.0159157410271928`, 0.9376006577429142}}]}}, 
      {Arrowheads[{{0.005337564925081277, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.9836783935381082, 
         1.0814229895748806`}, {-1.0163216064618918`, 
         1.0659454314777501`}}]}}, 
      {Arrowheads[{{0.005155568657073443, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.983564771635163, 
         1.205856228404861}, {-1.016435228364837, 1.194143771595138}}]}}, 
      {Arrowheads[{{0.005481469528874633, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8600859462699757, -1.1954382654446745`}, \
{-0.8241245800458137, -1.2045617345553252`}}]}}, 
      {Arrowheads[{{0.00570222354819718, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8602218437111739, -1.0670374894681416`}, \
{-0.8239886826046154, -1.08033093158449}}]}}, 
      {Arrowheads[{{0.005924723529115604, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8600417599787229, -0.9384074154770758}, \
{-0.8241687663370665, -0.9563294266281873}}]}}, 
      {Arrowheads[{{0.006144838641255308, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8594543945782305, -0.8095873992634518}, \
{-0.8247561317375589, -0.8325178638944432}}]}}, 
      {Arrowheads[{{0.006357110099760108, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8583662071593641, -0.680650716552287}, \
{-0.8258443191564253, -0.7088229676582397}}]}}, 
      {Arrowheads[{{0.006554646060806515, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8566947131966518, -0.5517119003776433}, \
{-0.8275158131191376, -0.585130204885515}}]}}, 
      {Arrowheads[{{0.006729217674269135, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8543883947927011, -0.42292894438750356`}, \
{-0.8298221315230883, -0.4612815819282864}}]}}, 
      {Arrowheads[{{0.006871716059246735, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8514513883135016, -0.2944950349329208}, \
{-0.8327591380022878, -0.3370839124355007}}]}}, 
      {Arrowheads[{{0.006973119672277365, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8479663871647031, -0.16661478943848282`}, \
{-0.8362441391510863, -0.2123325789825702}}]}}, 
      {Arrowheads[{{0.00702596382437212, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8441040057734146, -0.039464873581130835`}, \
{-0.8401065205423749, -0.08685091589255377}}]}}, 
      {Arrowheads[{{0.007025963824372117, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8401065205423748, 
         0.08685091589255337}, {-0.8441040057734146, 
         0.039464873581130454`}}]}}, 
      {Arrowheads[{{0.006973119672277373, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8362441391510862, 
         0.21233257898256985`}, {-0.8479663871647031, 
         0.16661478943848243`}}]}}, 
      {Arrowheads[{{0.00687171605924675, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8327591380022877, 
         0.3370839124355003}, {-0.8514513883135016, 0.29449503493292034`}}]}}, 
      {Arrowheads[{{0.006729217674269144, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8298221315230881, 
         0.46128158192828594`}, {-0.8543883947927011, 0.4229289443875031}}]}}, 
      {Arrowheads[{{0.006554646060806528, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8275158131191377, 
         0.5851302048855147}, {-0.8566947131966518, 0.5517119003776427}}]}}, 
      {Arrowheads[{{0.006357110099760121, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8258443191564252, 
         0.7088229676582392}, {-0.8583662071593642, 0.6806507165522866}}]}}, 
      {Arrowheads[{{0.0061448386412552986`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8247561317375589, 
         0.8325178638944427}, {-0.8594543945782305, 0.8095873992634515}}]}}, 
      {Arrowheads[{{0.005924723529115604, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8241687663370665, 
         0.956329426628187}, {-0.8600417599787229, 0.9384074154770755}}]}}, 
      {Arrowheads[{{0.00570222354819718, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8239886826046154, 
         1.0803309315844896`}, {-0.8602218437111739, 1.0670374894681411`}}]}}, 
      {Arrowheads[{{0.005481469528874649, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.8241245800458136, 
         1.2045617345553248`}, {-0.8600859462699757, 1.195438265444674}}]}}, 
      {Arrowheads[{{0.00583436617425174, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.703755948170193, -1.1972026312677133`}, \
{-0.6646651044613857, -1.2027973687322866`}}]}}, 
      {Arrowheads[{{0.006103049170266898, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.7042365099404515, -1.0686302998291657`}, \
{-0.6641845426911271, -1.0787381212234657`}}]}}, 
      {Arrowheads[{{0.006379036267671291, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.7043980667525499, -0.9397199785092355}, \
{-0.664022985879029, -0.9550168635960277}}]}}, 
      {Arrowheads[{{0.006657852795802533, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.7041138390134142, -0.8104921809888297}, \
{-0.6643072136181647, -0.8316130821690653}}]}}, 
      {Arrowheads[{{0.006932998862668398, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.7032395348139023, -0.6810113577056636}, \
{-0.6651815178176765, -0.7084623265048631}}]}}, 
      {Arrowheads[{{0.007195490218502729, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.7016280060045429, -0.5514034989217109}, \
{-0.6667930466270359, -0.5854386063414475}}]}}, 
      {Arrowheads[{{0.0074335669272738575`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6991576668878867, -0.42187072081007443`}, \
{-0.669263385743692, -0.4623398055057154}}]}}, 
      {Arrowheads[{{0.0076329200119090775`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6957768461748857, -0.29269244359435165`}, \
{-0.672644206456693, -0.3388865037740698}}]}}, 
      {Arrowheads[{{0.007777987632462348, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6915573800442982, -0.16419760308228273`}, \
{-0.6768636725872804, -0.2147497653387703}}]}}, 
      {Arrowheads[{{0.007854779065077505, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6867334631432458, -0.036695848447717325`}, \
{-0.6816875894883331, -0.08961994102596728}}]}}, 
      {Arrowheads[{{0.007854779065077507, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.681687589488333, 
         0.08961994102596689}, {-0.6867334631432458, 
         0.036695848447716936`}}]}}, 
      {Arrowheads[{{0.007777987632462343, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6768636725872805, 
         0.2147497653387699}, {-0.6915573800442982, 0.16419760308228235`}}]}}, 
      {Arrowheads[{{0.0076329200119090775`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6726442064566931, 
         0.3388865037740695}, {-0.6957768461748857, 0.29269244359435126`}}]}}, 
      {Arrowheads[{{0.007433566927273886, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.669263385743692, 
         0.46233980550571513`}, {-0.6991576668878868, 0.421870720810074}}]}}, 
      {Arrowheads[{{0.007195490218502716, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.666793046627036, 
         0.5854386063414471}, {-0.7016280060045428, 0.5514034989217104}}]}}, 
      {Arrowheads[{{0.00693299886266841, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6651815178176764, 
         0.7084623265048626}, {-0.7032395348139023, 0.6810113577056631}}]}}, 
      {Arrowheads[{{0.006657852795802555, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6643072136181646, 
         0.8316130821690649}, {-0.7041138390134142, 0.8104921809888292}}]}}, 
      {Arrowheads[{{0.006379036267671264, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.664022985879029, 
         0.9550168635960272}, {-0.7043980667525498, 0.9397199785092353}}]}}, 
      {Arrowheads[{{0.006103049170266867, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6641845426911273, 
         1.0787381212234652`}, {-0.7042365099404515, 1.0686302998291657`}}]}}, 
      {Arrowheads[{{0.00583436617425174, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.6646651044613857, 
         1.2027973687322862`}, {-0.703755948170193, 1.1972026312677129`}}]}}, 
      {Arrowheads[{{0.006212545397016835, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.547335263240092, -1.1995440582546855`}, \
{-0.5052963157072762, -1.2004559417453144`}}]}}, 
      {Arrowheads[{{0.00653983801494661, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.54826876673738, -1.0708746047173519`}, \
{-0.5043628122099881, -1.0764938163352795`}}]}}, 
      {Arrowheads[{{0.006883330797900776, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5489189680051524, -0.9417355532813274}, \
{-0.5037126109422158, -0.953001288823936}}]}}, 
      {Arrowheads[{{0.007238973895964525, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5491223105857995, -0.8121074213543309}, \
{-0.5035092683615685, -0.8299978418035641}}]}}, 
      {Arrowheads[{{0.007599942938685306, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5486710892480084, -0.6820191371681916}, \
{-0.5039604896993598, -0.707454547042335}}]}}, 
      {Arrowheads[{{0.007955527085213803, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5473219678202039, -0.5515809775560082}, \
{-0.5053096111271642, -0.58526112770715}}]}}, 
      {Arrowheads[{{0.008289825224937288, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5448265196269795, -0.4210245164567109}, \
{-0.5078050593203887, -0.46318600985907904`}}]}}, 
      {Arrowheads[{{0.008580691174724491, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5409989892407251, -0.29073657264936265`}, \
{-0.511632589706643, -0.3408423747190588}}]}}, 
      {Arrowheads[{{0.008800290081025218, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5358306754272775, -0.16125269166891384`}, \
{-0.5168009035200907, -0.2176946767521392}}]}}, 
      {Arrowheads[{{0.008919832714627738, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5296207185755537, -0.03315297278444923}, \
{-0.5230108603718144, -0.09316281668923537}}]}}, 
      {Arrowheads[{{0.008919832714627738, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5230108603718145, 
         0.093162816689235}, {-0.5296207185755536, 0.03315297278444883}}]}}, 
      {Arrowheads[{{0.008800290081025225, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5168009035200907, 
         0.21769467675213883`}, {-0.5358306754272775, 
         0.16125269166891343`}}]}}, 
      {Arrowheads[{{0.008580691174724491, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.511632589706643, 
         0.3408423747190584}, {-0.5409989892407251, 0.29073657264936226`}}]}}, 
      {Arrowheads[{{0.00828982522493729, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5078050593203887, 
         0.46318600985907865`}, {-0.5448265196269794, 0.4210245164567104}}]}}, 
      {Arrowheads[{{0.007955527085213802, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5053096111271643, 
         0.5852611277071497}, {-0.5473219678202039, 0.5515809775560078}}]}}, 
      {Arrowheads[{{0.007599942938685298, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5039604896993598, 
         0.7074545470423347}, {-0.5486710892480083, 0.6820191371681912}}]}}, 
      {Arrowheads[{{0.007238973895964502, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5035092683615686, 
         0.8299978418035636}, {-0.5491223105857995, 0.8121074213543306}}]}}, 
      {Arrowheads[{{0.006883330797900799, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5037126109422156, 
         0.9530012888239355}, {-0.5489189680051524, 0.9417355532813267}}]}}, 
      {Arrowheads[{{0.006539838014946618, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5043628122099881, 
         1.0764938163352795`}, {-0.54826876673738, 1.0708746047173514`}}]}}, 
      {Arrowheads[{{0.006212545397016819, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.5052963157072762, 
         1.200455941745314}, {-0.5473352632400919, 1.199544058254685}}]}}, 
      {Arrowheads[{{0.006611534497216907, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3906489932437724, -1.2025582430825534`}, \
{-0.3461931120193853, -1.1974417569174465`}}]}}, 
      {Arrowheads[{{0.007009128887101085, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3921399968953426, -1.0739288691169093`}, \
{-0.34470210836781506`, -1.073439551935722}}]}}, 
      {Arrowheads[{{0.007436352065130849, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3934441796329056, -0.9446905221760761}, \
{-0.34339792563025195`, -0.9500463199291872}}]}}, 
      {Arrowheads[{{0.00789111692859063, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.39437324139536306`, -0.8147564475491046}, \
{-0.3424688638677945, -0.8273488156087903}}]}}, 
      {Arrowheads[{{0.008368194577991364, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3946577466316364, -0.6840770023739706}, \
{-0.34218435863152125`, -0.705396681836556}}]}}, 
      {Arrowheads[{{0.008857312745186221, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.39393449223320876`, -0.5526872217365506}, \
{-0.3429076130299489, -0.5841548835266078}}]}}, 
      {Arrowheads[{{0.009340129760500354, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3917548324429338, -0.42078279159551096`}, \
{-0.3450872728202239, -0.4634277347202789}}]}}, 
      {Arrowheads[{{0.009785607431633645, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3876489026126323, -0.288826886803409}, \
{-0.34919320265052534`, -0.34275206056501245`}}]}}, 
      {Arrowheads[{{0.010144658937362421`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3813144198841, -0.15765532480412997`}, \
{-0.35552768537905766`, -0.221292043616923}}]}}, 
      {Arrowheads[{{0.010351745943640087`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.37299679876041, -0.028425762640078053`}, \
{-0.36384530650274766`, -0.09789002683360655}}]}}, 
      {Arrowheads[{{0.010351745943640087`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3638453065027477, 
         0.09789002683360618}, {-0.3729967987604099, 0.02842576264007765}}]}}, 
      {Arrowheads[{{0.010144658937362425`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3555276853790576, 
         0.22129204361692265`}, {-0.38131441988410003`, 
         0.1576553248041296}}]}}, 
      {Arrowheads[{{0.00978560743163365, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3491932026505253, 
         0.34275206056501206`}, {-0.3876489026126323, 0.2888268868034086}}]}}, 
      {Arrowheads[{{0.009340129760500353, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3450872728202239, 
         0.46342773472027854`}, {-0.39175483244293374`, 
         0.4207827915955105}}]}}, 
      {Arrowheads[{{0.008857312745186205, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.34290761302994893`, 
         0.5841548835266073}, {-0.3939344922332087, 0.55268722173655}}]}}, 
      {Arrowheads[{{0.008368194577991355, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3421843586315213, 
         0.7053966818365556}, {-0.39465774663163633`, 0.6840770023739701}}]}}, 
      {Arrowheads[{{0.007891116928590642, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.3424688638677945, 
         0.8273488156087899}, {-0.3943732413953631, 0.8147564475491041}}]}}, 
      {Arrowheads[{{0.007436352065130847, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.34339792563025195`, 
         0.9500463199291868}, {-0.3934441796329056, 0.9446905221760757}}]}}, 
      {Arrowheads[{{0.007009128887101085, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.344702108367815, 
         1.0734395519357216`}, {-0.39213999689534257`, 1.073928869116909}}]}}, 
      {Arrowheads[{{0.006611534497216907, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.34619311201938524`, 
         1.197441756917446}, {-0.39064899324377234`, 1.202558243082553}}]}}, 
      {Arrowheads[{{0.007023105846498765, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.23344498179960357`, -1.206295166625255}, \
{-0.18760764977934355`, -1.1937048333747446`}}]}}, 
      {Arrowheads[{{0.007502607200308162, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.23556070124729345`, -1.0779201616141634`}, \
{-0.18549193033165368`, -1.0694482594384684`}}]}}, 
      {Arrowheads[{{0.008030718437914175, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.23766482154798768`, -0.9488229490476537}, \
{-0.18338781003095944`, -0.9459138930576095}}]}}, 
      {Arrowheads[{{0.00860975890123382, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.23957813193241892`, -0.818825758082597}, \
{-0.18147449964652818`, -0.823279505075298}}]}}, 
      {Arrowheads[{{0.009239672858052808, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.24100458552504841`, -0.6877502844927471}, \
{-0.18004804605389874`, -0.7017233997177794}}]}}, 
      {Arrowheads[{{0.009915974019413644, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.241481763787722, -0.5554647011510122}, \
{-0.17957086779122514`, -0.581377404112146}}]}}, 
      {Arrowheads[{{0.010625824878016851`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.24032668275157973`, -0.42197955472758886`}, \
{-0.1807259488273674, -0.462230971588201}}]}}, 
      {Arrowheads[{{0.011339384586558018`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.23660092452788511`, -0.28763410228019576`}, \
{-0.184451707051062, -0.3439448450882257}}]}}, 
      {Arrowheads[{{0.011988336923594358`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.229197187493334, -0.15345442974731355`}, \
{-0.1918554440856131, -0.22549293867373948`}}]}}, 
      {Arrowheads[{{0.012420948130576131`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.21750873520703742`, -0.02170706066454276}, \
{-0.2035438963719097, -0.10460872880914185`}}]}}, 
      {Arrowheads[{{0.01242094813057613, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.20354389637190973`, 
         0.10460872880914146`}, {-0.21750873520703737`, 
         0.021707060664542366`}}]}}, 
      {Arrowheads[{{0.011988336923594356`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.19185544408561314`, 
         0.2254929386737391}, {-0.22919718749333398`, 
         0.15345442974731316`}}]}}, 
      {Arrowheads[{{0.011339384586558022`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.184451707051062, 
         0.34394484508822537`}, {-0.23660092452788511`, 
         0.28763410228019537`}}]}}, 
      {Arrowheads[{{0.01062582487801685, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.18072594882736742`, 
         0.46223097158820065`}, {-0.2403266827515797, 
         0.42197955472758847`}}]}}, 
      {Arrowheads[{{0.009915974019413649, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.1795708677912251, 
         0.5813774041121456}, {-0.24148176378772201`, 0.5554647011510118}}]}}, 
      {Arrowheads[{{0.009239672858052824, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.18004804605389868`, 
         0.7017233997177791}, {-0.24100458552504844`, 0.6877502844927467}}]}}, 
      {Arrowheads[{{0.008609758901233826, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.18147449964652818`, 
         0.8232795050752976}, {-0.23957813193241895`, 0.8188257580825966}}]}}, 
      {Arrowheads[{{0.008030718437914173, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.18338781003095944`, 
         0.9459138930576091}, {-0.23766482154798768`, 0.9488229490476532}}]}}, 
      {Arrowheads[{{0.007502607200308162, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.18549193033165368`, 
         1.0694482594384678`}, {-0.23556070124729345`, 
         1.0779201616141627`}}]}}, 
      {Arrowheads[{{0.007023105846498765, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.1876076497793435, 
         1.1937048333747446`}, {-0.23344498179960363`, 
         1.2062951666252546`}}]}}, 
      {Arrowheads[{{0.007434464818334193, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.0753986238966478, -1.2107083272271368`}, \
{-0.029864533998088815`, -1.189291672772863}}]}}, 
      {Arrowheads[{{0.008005620618476223, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.07811768155485527, -1.0828746000968008`}, \
{-0.02714547633988134, -1.0644938209558308`}}]}}, 
      {Arrowheads[{{0.008650302950458752, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08107709722404902, -0.954284634685544}, \
{-0.024186060670687598`, -0.9404522074197192}}]}}, 
      {Arrowheads[{{0.009378328187662755, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08416300697542016, -0.8246680150673253}, \
{-0.021100150919316454`, -0.8174372480905696}}]}}, 
      {Arrowheads[{{0.010199634264080309`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08713318805882114, -0.6936904187847879}, \
{-0.01812996983591548, -0.6957832654257388}}]}}, 
      {Arrowheads[{{0.011123596995124824`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08953189153267893, -0.5609736994665441}, \
{-0.015731266362057676`, -0.5758684057966141}}]}}, 
      {Arrowheads[{{0.01215822839551004, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.0905625124907463, -0.4261611456165619}, \
{-0.014700645403990312`, -0.458049380699228}}]}}, 
      {Arrowheads[{{0.01330902644807863, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08889068981764611, -0.28907056412141674`}, \
{-0.016372468077090502`, -0.3425083832470047}}]}}, 
      {Arrowheads[{{0.014572445811391185`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.08225930749145427, -0.15004964916329802`}, \
{-0.023003850403282337`, -0.228897719257755}}]}}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.014572445811391187`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.023003850403282372`, 
         0.22889771925775465`}, {-0.08225930749145424, 
         0.1500496491632976}}]}}, 
      {Arrowheads[{{0.013309026448078638`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.016372468077090502`, 
         0.3425083832470044}, {-0.08889068981764611, 0.2890705641214163}}]}}, 
      {Arrowheads[{{0.01215822839551005, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.014700645403990312`, 
         0.4580493806992277}, {-0.0905625124907463, 0.4261611456165614}}]}}, 
      {Arrowheads[{{0.011123596995124831`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.015731266362057676`, 
         0.5758684057966139}, {-0.08953189153267893, 0.5609736994665436}}]}}, 
      {Arrowheads[{{0.010199634264080314`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.018129969835915458`, 
         0.6957832654257384}, {-0.08713318805882116, 0.6936904187847874}}]}}, 
      {Arrowheads[{{0.009378328187662759, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.02110015091931644, 
         0.8174372480905692}, {-0.08416300697542017, 0.8246680150673249}}]}}, 
      {Arrowheads[{{0.008650302950458747, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.024186060670687588`, 
         0.9404522074197189}, {-0.08107709722404903, 0.9542846346855435}}]}}, 
      {Arrowheads[{{0.008005620618476218, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.027145476339881323`, 
         1.0644938209558303`}, {-0.0781176815548553, 1.0828746000968001`}}]}}, 
      {Arrowheads[{{0.007434464818334211, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{-0.029864533998088805`, 
         1.1892916727728626`}, {-0.07539862389664781, 
         1.2107083272271366`}}]}}, 
      {Arrowheads[{{0.007827956894342868, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.08384941597531184, -1.2155961286674968`}, {
         0.12667689981416205`, -1.184403871332503}}]}}, 
      {Arrowheads[{{0.008496366368826587, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.08069512326291725, -1.0886228762076913`}, {
         0.12983119252655664`, -1.0587455448449403`}}]}}, 
      {Arrowheads[{{0.009268519994507765, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.07701226473099065, -0.960997017984385}, {
         0.13351405105848324`, -0.9337398241208783}}]}}, 
      {Arrowheads[{{0.010164890614474347`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.07278698707137923, -0.8323950794939073}, {
         0.13773932871809466`, -0.8097101836639875}}]}}, 
      {Arrowheads[{{0.011210115607991698`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.06809982470087911, -0.7023600104704696}, {
         0.1424264910885948, -0.6871136737400572}}]}}, 
      {Arrowheads[{{0.012434427179463074`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.0632236103645912, -0.5702755713306751}, {
         0.1473027054248827, -0.5665665339324832}}]}}, 
      {Arrowheads[{{0.013877933212329252`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.05878267562652761, -0.43537283874578425`}, {
         0.15174364016294628`, -0.44883768757000564`}}]}}, 
      {Arrowheads[{{0.015605179495860346`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.05598187689171969, -0.296806810473922}, {
         0.1545444388977542, -0.3347721368944995}}]}}, 
      {Arrowheads[{{0.01775886730127861, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.05688084678652841, -0.1538214451480669}, {
         0.15364546900294548`, -0.22512592327298614`}}]}}, 
      {Arrowheads[{{0.020790552825352082`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.06434660579976681, -0.005919422858368752}, {
         0.14617970998970709`, -0.12039636661531586`}}]}}, 
      {Arrowheads[{{0.020790552825352096`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.14617970998970703`, 0.12039636661531555`}, {
         0.06434660579976687, 0.00591942285836828}}]}}, 
      {Arrowheads[{{0.017758867301278628`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.15364546900294548`, 0.22512592327298583`}, {
         0.05688084678652842, 0.15382144514806642`}}]}}, 
      {Arrowheads[{{0.015605179495860351`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.1545444388977542, 0.33477213689449914`}, {
         0.05598187689171968, 0.29680681047392155`}}]}}, 
      {Arrowheads[{{0.013877933212329259`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.1517436401629463, 0.4488376875700053}, {
         0.058782675626527586`, 0.43537283874578386`}}]}}, 
      {Arrowheads[{{0.012434427179463083`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.14730270542488272`, 0.5665665339324829}, {
         0.06322361036459118, 0.5702755713306746}}]}}, 
      {Arrowheads[{{0.01121011560799171, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.14242649108859481`, 0.6871136737400566}, {
         0.06809982470087908, 0.7023600104704691}}]}}, 
      {Arrowheads[{{0.010164890614474347`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.13773932871809466`, 0.8097101836639871}, {
         0.07278698707137923, 0.8323950794939069}}]}}, 
      {Arrowheads[{{0.009268519994507758, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.1335140510584832, 0.9337398241208779}, {
         0.07701226473099067, 0.9609970179843845}}]}}, 
      {Arrowheads[{{0.008496366368826577, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.12983119252655667`, 1.0587455448449399`}, {
         0.08069512326291722, 1.0886228762076906`}}]}}, 
      {Arrowheads[{{0.007827956894342868, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.12667689981416205`, 1.1844038713325027`}, {
         0.08384941597531184, 1.2155961286674966`}}]}}, 
      {Arrowheads[{{0.008181597072381742, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2446111163010508, -1.2205583456233953`}, {
         0.28170467317263354`, -1.1794416543766046`}}]}}, 
      {Arrowheads[{{0.008946228728081042, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.24137496964127805`, -1.0947109338687417`}, {
         0.2849408198324063, -1.0526574871838899`}}]}}, 
      {Arrowheads[{{0.009848347266437279, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2373731712119374, -0.9684858821013735}, {
         0.288942618261747, -0.9262509600038896}}]}}, 
      {Arrowheads[{{0.010921960804201599`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.23242855012026722`, -0.8415926916626298}, {
         0.2938872393534172, -0.800512571495265}}]}}, 
      {Arrowheads[{{0.012210485001849878`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.22637302931967296`, -0.7135631131203433}, {
         0.29994276015401145`, -0.6759105710901833}}]}}, 
      {Arrowheads[{{0.01376925714554404, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2191258086803941, -0.5836698378182602}, {
         0.3071899807932903, -0.5531722674448982}}]}}, 
      {Arrowheads[{{0.01566966649642805, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.210856226486814, -0.45085853420248767`}, {
         0.3154595629868704, -0.43335199211330216`}}]}}, 
      {Arrowheads[{{0.018008929286586726`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2022450780562443, -0.313790970232543}, {
         0.3240707114174401, -0.31778797713587853`}}]}}, 
      {Arrowheads[{{0.020934507045933182`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.1947082864633499, -0.17120215446893502`}, {
         0.3316075030103345, -0.207745213952118}}]}}, 
      {Arrowheads[{{0.024673931237484497`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.1900500395054851, -0.022813213163567804`}, {
         0.33626574996819925`, -0.1035025763101168}}]}}, 
      {Arrowheads[{{0.02467393123748451, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3362657499681993, 0.10350257631011646`}, {
         0.1900500395054851, 0.022813213163567367`}}]}}, 
      {Arrowheads[{{0.020934507045933182`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3316075030103345, 0.20774521395211767`}, {
         0.1947082864633499, 0.17120215446893455`}}]}}, 
      {Arrowheads[{{0.018008929286586726`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3240707114174401, 0.31778797713587814`}, {
         0.2022450780562443, 0.3137909702325426}}]}}, 
      {Arrowheads[{{0.015669666496428068`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.31545956298687045`, 0.43335199211330183`}, {
         0.21085622648681396`, 0.4508585342024873}}]}}, 
      {Arrowheads[{{0.013769257145544056`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.30718998079329035`, 0.5531722674448977}, {
         0.21912580868039405`, 0.5836698378182597}}]}}, 
      {Arrowheads[{{0.01221048500184988, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.29994276015401145`, 0.6759105710901829}, {
         0.22637302931967293`, 0.7135631131203429}}]}}, 
      {Arrowheads[{{0.010921960804201589`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.29388723935341715`, 0.8005125714952647}, {
         0.23242855012026725`, 0.8415926916626295}}]}}, 
      {Arrowheads[{{0.009848347266437288, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.288942618261747, 0.9262509600038892}, {
         0.2373731712119374, 0.9684858821013732}}]}}, 
      {Arrowheads[{{0.00894622872808107, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2849408198324064, 1.0526574871838894`}, {
         0.24137496964127805`, 1.0947109338687415`}}]}}, 
      {Arrowheads[{{0.008181597072381726, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.2817046731726336, 1.1794416543766042`}, {
         0.24461111630105078`, 1.2205583456233946`}}]}}, 
      {Arrowheads[{{0.00847062041806756, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.40703015179917196`, -1.2250023841118847`}, {
         0.4350751113587229, -1.1749976158881152`}}]}}, 
      {Arrowheads[{{0.009321481523242973, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.40423254602198605`, -1.1003715141925912`}, {
         0.43787271713590886`, -1.0469969068600404`}}]}}, 
      {Arrowheads[{{0.010344061412344617`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4006018472156385, -0.975779729680204}, {
         0.44150341594225634`, -0.9189571124250593}}]}}, 
      {Arrowheads[{{0.011588470188319723`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3958288834566333, -0.8510822700082038}, {
         0.4462763797012616, -0.7910229931496912}}]}}, 
      {Arrowheads[{{0.013121708775341452`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.38949441980084115`, -0.7259778523658142}, {
         0.45261084335705376`, -0.6634958318447123}}]}}, 
      {Arrowheads[{{0.01503153205527724, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.38107273843563266`, -0.5998744536092351}, {
         0.46103252472226225`, -0.5369676516539232}}]}}, 
      {Arrowheads[{{0.017426956616073346`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.37002986382638675`, -0.4716832299619112}, {
         0.47207539933150816`, -0.4125272963538787}}]}}, 
      {Arrowheads[{{0.020428223369590156`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3561549880217966, -0.3396150664815608}, {
         0.4859502751360983, -0.29196388088686065`}}]}}, 
      {Arrowheads[{{0.024134869462993497`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.3402399879247574, -0.20132426588219351`}, {
         0.5018652752331375, -0.17762310253885952`}}]}}, 
      {Arrowheads[{{0.028565245493166545`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.324724693891747, -0.05503106032824854}, {
         0.517380569266148, -0.07128472914543607}}]}}, 
      {Arrowheads[{{0.028565245493166552`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.517380569266148, 0.07128472914543575}, {
         0.32472469389174696`, 0.05503106032824808}}]}}, 
      {Arrowheads[{{0.024134869462993494`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5018652752331375, 0.17762310253885918`}, {
         0.3402399879247574, 0.20132426588219307`}}]}}, 
      {Arrowheads[{{0.020428223369590163`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.48595027513609834`, 0.2919638808868603}, {
         0.35615498802179657`, 0.33961506648156037`}}]}}, 
      {Arrowheads[{{0.017426956616073352`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4720753993315082, 0.4125272963538783}, {
         0.37002986382638675`, 0.4716832299619108}}]}}, 
      {Arrowheads[{{0.015031532055277252`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4610325247222623, 0.5369676516539228}, {
         0.3810727384356326, 0.5998744536092346}}]}}, 
      {Arrowheads[{{0.013121708775341445`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4526108433570538, 0.663495831844712}, {
         0.38949441980084115`, 0.7259778523658138}}]}}, 
      {Arrowheads[{{0.011588470188319723`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4462763797012616, 0.7910229931496907}, {
         0.3958288834566333, 0.8510822700082034}}]}}, 
      {Arrowheads[{{0.010344061412344617`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.4415034159422564, 0.9189571124250588}, {
         0.4006018472156386, 0.9757797296802035}}]}}, 
      {Arrowheads[{{0.009321481523242997, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.43787271713590886`, 1.04699690686004}, {
         0.4042325460219861, 1.100371514192591}}]}}, 
      {Arrowheads[{{0.008470620418067565, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.43507511135872295`, 1.1749976158881148`}, {
         0.40703015179917196`, 1.2250023841118842`}}]}}, 
      {Arrowheads[{{0.008670200928259628, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5709560766985396, -1.228232390601533}, {
         0.5869386601435655, -1.1717676093984666`}}]}}, 
      {Arrowheads[{{0.009586594657709216, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5691779058476365, -1.104621163156976}, {
         0.5887168309944688, -1.0427472578956554`}}]}}, 
      {Arrowheads[{{0.010704666994549522`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.566768129621284, -0.9814863440745671}, {
         0.5911266072208212, -0.913250498030696}}]}}, 
      {Arrowheads[{{0.012091966751051337`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5634132156377917, -0.8589110229973966}, {
         0.5944815212043135, -0.7831942401604983}}]}}, 
      {Arrowheads[{{0.013844603546165084`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5586037837745005, -0.7369424959010142}, {
         0.5992909530676049, -0.6525311883095124}}]}}, 
      {Arrowheads[{{0.016098286495793698`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.551503844271346, -0.6154835843288781}, {
         0.6063908925707593, -0.5213585209342803}}]}}, 
      {Arrowheads[{{0.019035696088171277`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.540776075374096, -0.4939987663170142}, {
         0.6171186614680092, -0.39021175999877566`}}]}}, 
      {Arrowheads[{{0.022866806199116036`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5245348192565027, -0.3708149149108219}, {
         0.6333599175856026, -0.26076403245759955`}}]}}, 
      {Arrowheads[{{0.02772186690922486, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5011768492477664, -0.24194450577562493`}, {
         0.6567178875943389, -0.1370028626454281}}]}}, 
      {Arrowheads[{{0.03340857627691852, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.47242363196125947`, -0.10104532299371247`}, {
         0.6854711048808458, -0.025270466479972144`}}]}}, 
      {Arrowheads[{{0.03340857627691853, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.685471104880846, 0.025270466479971818`}, {
         0.4724236319612594, 0.10104532299371201`}}]}}, 
      {Arrowheads[{{0.027721866909224888`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.656717887594339, 0.13700286264542771`}, {
         0.5011768492477663, 0.24194450577562454`}}]}}, 
      {Arrowheads[{{0.02286680619911606, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.6333599175856027, 0.26076403245759916`}, {
         0.5245348192565026, 0.3708149149108215}}]}}, 
      {Arrowheads[{{0.019035696088171287`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.6171186614680093, 0.3902117599987753}, {
         0.540776075374096, 0.49399876631701384`}}]}}, 
      {Arrowheads[{{0.016098286495793715`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.6063908925707594, 0.5213585209342798}, {
         0.5515038442713459, 0.6154835843288776}}]}}, 
      {Arrowheads[{{0.013844603546165098`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5992909530676048, 0.652531188309512}, {
         0.5586037837745004, 0.7369424959010139}}]}}, 
      {Arrowheads[{{0.012091966751051373`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5944815212043136, 0.7831942401604978}, {
         0.5634132156377917, 0.8589110229973963}}]}}, 
      {Arrowheads[{{0.010704666994549538`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5911266072208213, 0.9132504980306957}, {
         0.5667681296212841, 0.9814863440745669}}]}}, 
      {Arrowheads[{{0.009586594657709216, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5887168309944688, 1.0427472578956551`}, {
         0.5691779058476365, 1.1046211631569758`}}]}}, 
      {Arrowheads[{{0.008670200928259628, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.5869386601435655, 1.1717676093984664`}, {
         0.5709560766985396, 1.2282323906015329`}}]}}, 
      {Arrowheads[{{0.008759409542573126, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7358772935172421, -1.2296277787704892`}, {
         0.737806917009074, -1.1703722212295107`}}]}}, 
      {Arrowheads[{{0.009709731097130503, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7355689897338304, -1.1065190885337703`}, {
         0.7381152207924855, -1.0408493325188612`}}]}}, 
      {Arrowheads[{{0.010880724978264306`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7350970885969978, -0.9841494625463979}, {
         0.7385871219293181, -0.9105873795588654}}]}}, 
      {Arrowheads[{{0.012354531946518652`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7343357259168382, -0.862787491255169}, {
         0.7393484846094779, -0.779317771902726}}]}}, 
      {Arrowheads[{{0.014256391578444707`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7330283241198564, -0.7428321712339814}, {
         0.7406558864064594, -0.6466415129765453}}]}}, 
      {Arrowheads[{{0.016783215328147263`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7306131225369761, -0.6248760000820159}, {
         0.7430710879893399, -0.5119661051811424}}]}}, 
      {Arrowheads[{{0.020250673096589903`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7257670598865751, -0.5097365319159858}, {
         0.747917150639741, -0.3744739943998041}}]}}, 
      {Arrowheads[{{0.025149388527886393`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7152047293133326, -0.3981033715961769}, {
         0.7584794812129835, -0.23347557577224456`}}]}}, 
      {Arrowheads[{{0.03206616166523211, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.6911871937198676, -0.28792044194963573`}, {
         0.7824970168064483, -0.09102692647141733}}]}}, 
      {Arrowheads[{{0.040787940112482435`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.6432099801133949, -0.1645798845476215}, {
         0.8304742304129209, 0.03826409507393691}}]}}, 
      {Arrowheads[{{0.04078794011248245, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8304742304129211, -0.03826409507393724}, {
         0.6432099801133948, 0.16457988454762107`}}]}}, 
      {Arrowheads[{{0.03206616166523212, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7824970168064485, 0.09102692647141693}, {
         0.6911871937198675, 0.28792044194963534`}}]}}, 
      {Arrowheads[{{0.02514938852788641, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7584794812129835, 0.23347557577224415`}, {
         0.7152047293133325, 0.3981033715961766}}]}}, 
      {Arrowheads[{{0.020250673096589924`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7479171506397408, 0.37447399439980367`}, {
         0.725767059886575, 0.5097365319159854}}]}}, 
      {Arrowheads[{{0.016783215328147267`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7430710879893399, 0.5119661051811419}, {
         0.730613122536976, 0.6248760000820155}}]}}, 
      {Arrowheads[{{0.014256391578444707`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7406558864064595, 0.6466415129765448}, {
         0.7330283241198565, 0.7428321712339809}}]}}, 
      {Arrowheads[{{0.012354531946518652`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7393484846094778, 0.7793177719027256}, {
         0.7343357259168382, 0.8627874912551685}}]}}, 
      {Arrowheads[{{0.010880724978264306`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7385871219293181, 0.9105873795588649}, {
         0.7350970885969978, 0.9841494625463975}}]}}, 
      {Arrowheads[{{0.009709731097130503, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.7381152207924855, 1.0408493325188608`}, {
         0.7355689897338303, 1.10651908853377}}]}}, 
      {Arrowheads[{{0.008759409542573126, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.737806917009074, 1.1703722212295102`}, {
         0.7358772935172421, 1.2296277787704888`}}]}}, 
      {Arrowheads[{{0.008725984077590001, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9009830993879314, -1.2288622032541092`}, {
         0.888490584822595, -1.1711377967458907`}}]}}, 
      {Arrowheads[{{0.009670556627875138, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9022619354129515, -1.1055342961780028`}, {
         0.8872117487975751, -1.0418341248746286`}}]}}, 
      {Arrowheads[{{0.010836949482203982`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9039460653734179, -0.982867606611435}, {
         0.8855276188371087, -0.9118692354938283}}]}}, 
      {Arrowheads[{{0.012311804070786008`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9062096623161897, -0.8611073985827301}, {
         0.8832640218943368, -0.780997864575165}}]}}, 
      {Arrowheads[{{0.01423345429999928, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9093180921322641, -0.7406455410316476}, {
         0.8801555920782625, -0.648828143178879}}]}}, 
      {Arrowheads[{{0.016837908480970408`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9136738170886057, -0.6221650019144516}, {
         0.8757998671219208, -0.5146771033487068}}]}}, 
      {Arrowheads[{{0.020565589424586705`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9198416106626187, -0.5070175556261436}, {
         0.8696320735479077, -0.37719297068964636`}}]}}, 
      {Arrowheads[{{0.026346601996145472`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9282402738583675, -0.39841727627983714`}, {
         0.861233410352159, -0.23316167108858435`}}]}}, 
      {Arrowheads[{{0.036479271290814484`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9355152390966606, -0.30599702762596026`}, {
         0.853958445113866, -0.0729503407950928}}]}}, 
      {Arrowheads[{{0.0561992370313836, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8928867307945075, -0.2533376487006134}, {
         0.8965869534160189, 0.12702185922692882`}}]}}, 
      {Arrowheads[{{0.05619923703138367, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8965869534160193, -0.12702185922692946`}, {
         0.8928867307945071, 0.25333764870061326`}}]}}, 
      {Arrowheads[{{0.03647927129081452, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.853958445113866, 0.07295034079509227}, {
         0.9355152390966606, 0.30599702762596}}]}}, 
      {Arrowheads[{{0.026346601996145483`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.861233410352159, 0.23316167108858388`}, {
         0.9282402738583675, 0.39841727627983675`}}]}}, 
      {Arrowheads[{{0.020565589424586722`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8696320735479077, 0.3771929706896459}, {
         0.9198416106626188, 0.5070175556261433}}]}}, 
      {Arrowheads[{{0.016837908480970408`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8757998671219208, 0.5146771033487063}, {
         0.9136738170886057, 0.6221650019144511}}]}}, 
      {Arrowheads[{{0.014233454299999301`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8801555920782624, 0.6488281431788786}, {
         0.9093180921322641, 0.7406455410316473}}]}}, 
      {Arrowheads[{{0.012311804070786022`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8832640218943368, 0.7809978645751644}, {
         0.9062096623161897, 0.8611073985827297}}]}}, 
      {Arrowheads[{{0.010836949482203987`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8855276188371086, 0.9118692354938278}, {
         0.9039460653734179, 0.9828676066114346}}]}}, 
      {Arrowheads[{{0.009670556627875129, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8872117487975751, 1.0418341248746281`}, {
         0.9022619354129513, 1.1055342961780024`}}]}}, 
      {Arrowheads[{{0.00872598407759, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.8884905848225951, 1.1711377967458902`}, {
         0.9009830993879314, 1.2288622032541088`}}]}}, 
      {Arrowheads[{{0.008570412017547973, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0653754808342748`, -1.2260541372482952`}, {
         1.0398876770604621`, -1.1739458627517048`}}]}}, 
      {Arrowheads[{{0.009468107215066243, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0679423130155994`, -1.101831351614836}, {
         1.037320844879138, -1.0455370694377957`}}]}}, 
      {Arrowheads[{{0.010568056314896645`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0713190986686159`, -0.977862036578652}, {
         1.0339440592261213`, -0.9168748055266112}}]}}, 
      {Arrowheads[{{0.01194624483664233, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0758671513147007`, -0.8541367395025652}, {
         1.0293960065800365`, -0.7879685236553298}}]}}, 
      {Arrowheads[{{0.013723018485038305`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0821683273808822`, -0.7305749750330077}, {
         1.023094830513855, -0.6588987091775189}}]}}, 
      {Arrowheads[{{0.016102877868818945`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0912121805093133`, -0.6069081848709396}, {
         1.0140509773854238`, -0.5299339203922188}}]}}, 
      {Arrowheads[{{0.0194695747685998, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1048138970065018`, -0.48233367650427}, {
         1.0004492608882354`, -0.40187684981151983`}}]}}, 
      {Arrowheads[{{0.024658546835800325`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1266838799565546`, -0.3542604561261493}, {
         0.9785792779381826, -0.27731849124227215`}}]}}, 
      {Arrowheads[{{0.03398506393394715, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.165454074919264, -0.21180762143310547`}, {
         0.9398090829754733, -0.1671397469879476}}]}}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.03398506393394721, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.939809082975473, 0.16713974698794729`}, {
         1.1654540749192641`, 0.21180762143310497`}}]}}, 
      {Arrowheads[{{0.024658546835800373`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{0.9785792779381824, 0.27731849124227176`}, {
         1.1266838799565548`, 0.354260456126149}}]}}, 
      {Arrowheads[{{0.019469574768599805`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0004492608882354`, 0.40187684981151944`}, {
         1.1048138970065018`, 0.48233367650426967`}}]}}, 
      {Arrowheads[{{0.016102877868818945`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0140509773854238`, 0.5299339203922183}, {
         1.0912121805093133`, 0.6069081848709391}}]}}, 
      {Arrowheads[{{0.013723018485038305`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.023094830513855, 0.6588987091775185}, {
         1.0821683273808822`, 0.7305749750330073}}]}}, 
      {Arrowheads[{{0.011946244836642363`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0293960065800365`, 0.7879685236553293}, {
         1.075867151314701, 0.8541367395025649}}]}}, 
      {Arrowheads[{{0.01056805631489663, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0339440592261213`, 0.9168748055266107}, {
         1.0713190986686159`, 0.9778620365786515}}]}}, 
      {Arrowheads[{{0.009468107215066243, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.037320844879138, 1.0455370694377952`}, {
         1.0679423130155994`, 1.1018313516148355`}}]}}, 
      {Arrowheads[{{0.008570412017547973, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.0398876770604621`, 1.1739458627517043`}, {
         1.0653754808342748`, 1.2260541372482947`}}]}}, 
      {Arrowheads[{{0.008307067544407248, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2283481103815503`, -1.2217418045192945`}, {
         1.1927045211973974`, -1.1782581954807052`}}]}}, 
      {Arrowheads[{{0.00912383454908741, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2316084733607104`, -1.0962434067980669`}, {
         1.1894441582182371`, -1.0511250142545645`}}]}}, 
      {Arrowheads[{{0.010106992142457813`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2357473171188076`, -0.9704727864104741}, {
         1.1853053144601402`, -0.9242640556947893}}]}}, 
      {Arrowheads[{{0.011310197382560975`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2410593989830654`, -0.844134439273474}, {
         1.1799932325958824`, -0.797970823884421}}]}}, 
      {Arrowheads[{{0.012811707850850387`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2479306936296086`, -0.7166631078425298}, {
         1.1731219379493392`, -0.6728105763679967}}]}}, 
      {Arrowheads[{{0.014728698058218284`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2568024868544663`, -0.5869415179594627}, {
         1.1642501447244815`, -0.5499005873036955}}]}}, 
      {Arrowheads[{{0.017238183716530898`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2678977226866213`, -0.4526767262876669}, {
         1.1531549088923265`, -0.431533800028123}}]}}, 
      {Arrowheads[{{0.020587364847654718`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2798761005953276`, -0.3091017599414065}, {
         1.1411765309836202`, -0.3224771874270149}}]}}, 
      {Arrowheads[{{0.024934525559980974`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2839636046959328`, -0.14791079678317176`}, {
         1.137089026883015, -0.23103657163788127`}}]}}, 
      {Arrowheads[{{0.029169379759340735`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.2495318623330343`, 0.02752368703087088}, {
         1.1715207692459133`, -0.15383947650455548`}}]}}, 
      {Arrowheads[{{0.029169379759340735`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1715207692459138`, 0.1538394765045552}, {
         1.2495318623330343`, -0.02752368703087138}}]}}, 
      {Arrowheads[{{0.024934525559980998`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.137089026883015, 0.23103657163788105`}, {
         1.2839636046959328`, 0.1479107967831712}}]}}, 
      {Arrowheads[{{0.020587364847654718`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1411765309836202`, 0.3224771874270146}, {
         1.2798761005953276`, 0.3091017599414061}}]}}, 
      {Arrowheads[{{0.01723818371653093, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1531549088923265`, 0.4315338000281227}, {
         1.2678977226866215`, 0.4526767262876665}}]}}, 
      {Arrowheads[{{0.01472869805821828, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1642501447244815`, 0.5499005873036952}, {
         1.2568024868544663`, 0.5869415179594623}}]}}, 
      {Arrowheads[{{0.012811707850850416`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1731219379493392`, 0.6728105763679963}, {
         1.2479306936296088`, 0.7166631078425295}}]}}, 
      {Arrowheads[{{0.011310197382560975`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1799932325958824`, 0.7979708238844205}, {
         1.2410593989830654`, 0.8441344392734735}}]}}, 
      {Arrowheads[{{0.0101069921424578, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1853053144601402`, 0.9242640556947888}, {
         1.2357473171188074`, 0.9704727864104736}}]}}, 
      {Arrowheads[{{0.009123834549087387, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1894441582182373`, 1.0511250142545643`}, {
         1.2316084733607104`, 1.0962434067980666`}}]}}, 
      {Arrowheads[{{0.008307067544407227, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.1927045211973974`, 1.1782581954807048`}, {
         1.2283481103815501`, 1.221741804519294}}]}}, 
      {Arrowheads[{{0.007961098648167133, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.389579035504534, -1.2166794199892101`}, {
         1.3472630697586243`, -1.1833205800107898`}}]}}, 
      {Arrowheads[{{0.008676309231235262, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.392896286387071, -1.0899047240789232`}, {
         1.343945818876087, -1.0574636969737083`}}]}}, 
      {Arrowheads[{{0.009515524565579612, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3968682564704535`, -0.9624596745928325}, {
         1.3399738487927046`, -0.9322771675124307}}]}}, 
      {Arrowheads[{{0.010508249879209083`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4015688958398866`, -0.833931619373298}, {
         1.3352732094232718`, -0.808173643784597}}]}}, 
      {Arrowheads[{{0.011690259443246665`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4069637226339717`, -0.7036596642462017}, {
         1.3298783826291865`, -0.6858140199643249}}]}}, 
      {Arrowheads[{{0.01310025261514262, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4127006220513985`, -0.5706114003015734}, {
         1.3241414832117602`, -0.566230704961585}}]}}, 
      {Arrowheads[{{0.014764631511390779`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4176082404646455`, -0.4333160787358147}, {
         1.319233864798513, -0.45089444757997527`}}]}}, 
      {Arrowheads[{{0.016647654580844558`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4186640693329962`, -0.29030030284637737`}, {
         1.3181780359301623`, -0.34127864452204415`}}]}}, 
      {Arrowheads[{{0.018524995042637497`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4098731926840404`, -0.1424416318721012}, {
         1.326968912579118, -0.23650573654895182`}}]}}, 
      {Arrowheads[{{0.019816983348156944`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3853148064563228`, 0.0017438233347990273`}, {
         1.3515272988068356`, -0.12805961280848363`}}]}}, 
      {Arrowheads[{{0.01981698334815695, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3515272988068356`, 0.1280596128084833}, {
         1.3853148064563225`, -0.0017438233347994714`}}]}}, 
      {Arrowheads[{{0.018524995042637504`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.326968912579118, 0.23650573654895155`}, {
         1.4098731926840402`, 0.1424416318721007}}]}}, 
      {Arrowheads[{{0.016647654580844568`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3181780359301623`, 0.3412786445220438}, {
         1.4186640693329962`, 0.29030030284637687`}}]}}, 
      {Arrowheads[{{0.014764631511390814`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3192338647985127`, 0.45089444757997493`}, {
         1.4176082404646455`, 0.43331607873581424`}}]}}, 
      {Arrowheads[{{0.013100252615142654`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.32414148321176, 0.5662307049615846}, {
         1.4127006220513985`, 0.570611400301573}}]}}, 
      {Arrowheads[{{0.011690259443246665`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3298783826291867`, 0.6858140199643245}, {
         1.406963722633972, 0.7036596642462013}}]}}, 
      {Arrowheads[{{0.010508249879209083`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3352732094232718`, 0.8081736437845966}, {
         1.4015688958398866`, 0.8339316193732975}}]}}, 
      {Arrowheads[{{0.009515524565579612, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3399738487927049`, 0.9322771675124303}, {
         1.3968682564704538`, 0.9624596745928321}}]}}, 
      {Arrowheads[{{0.008676309231235234, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.3439458188760873`, 1.057463696973708}, {
         1.392896286387071, 1.0899047240789228`}}]}}, 
      {Arrowheads[{{0.007961098648167157, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.347263069758624, 1.1833205800107893`}, {
         1.389579035504534, 1.2166794199892097`}}]}}, 
      {Arrowheads[{{0.0075622571654610365`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.549138634412954, -1.2115789946714275`}, {
         1.503492944534415, -1.1884210053285724`}}]}}, 
      {Arrowheads[{{0.008169933914116608, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.552046097183868, -1.083803285358984}, {
         1.500585481763501, -1.0635651356936475`}}]}}, 
      {Arrowheads[{{0.008862141060322215, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5552680795755671`, -0.9551936221289787}, {
         1.4973634993718021`, -0.9395432199762844}}]}}, 
      {Arrowheads[{{0.009650125418119104, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.558683284839826, -0.8253976660171906}, {
         1.493948294107543, -0.8167075971407043}}]}}, 
      {Arrowheads[{{0.010541922317266614`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5619830657293161`, -0.6939551430708821}, {
         1.4906485132180531`, -0.6955185411396446}}]}}, 
      {Arrowheads[{{0.011535458640827117`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5645091171285108`, -0.5603434773463539}, {
         1.488122461818858, -0.5764986279168045}}]}}, 
      {Arrowheads[{{0.01260440625271292, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.565025860145179, -0.4241877602324174}, {
         1.48760571880219, -0.4600227660833725}}]}}, 
      {Arrowheads[{{0.013673743941945342`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5615809440999713`, -0.2858278416377059}, {
         1.4910506348473977`, -0.34575110573071555`}}]}}, 
      {Arrowheads[{{0.014592348701844097`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5520113484985996`, -0.1473020945372499}, {
         1.5006202304487697`, -0.23164527388380307`}}]}}, 
      {Arrowheads[{{0.015142205794284398`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.535881808118166, -0.012814620433295038`}, {
         1.5167497708292028`, -0.11350116904038957`}}]}}, 
      {Arrowheads[{{0.015142205794284396`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.516749770829203, 0.11350116904038919`}, {
         1.535881808118166, 0.012814620433294635`}}]}}, 
      {Arrowheads[{{0.014592348701844103`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.5006202304487697`, 0.23164527388380274`}, {
         1.5520113484985996`, 0.14730209453724952`}}]}}, 
      {Arrowheads[{{0.013673743941945347`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4910506348473977`, 0.3457511057307152}, {
         1.5615809440999713`, 0.2858278416377055}}]}}, 
      {Arrowheads[{{0.012604406252712929`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.48760571880219, 0.46002276608337217`}, {
         1.565025860145179, 0.42418776023241694`}}]}}, 
      {Arrowheads[{{0.011535458640827117`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.4881224618188582`, 0.576498627916804}, {
         1.564509117128511, 0.5603434773463534}}]}}, 
      {Arrowheads[{{0.010541922317266614`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.490648513218053, 0.6955185411396441}, {1.561983065729316,
          0.6939551430708816}}]}}, 
      {Arrowheads[{{0.009650125418119104, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.493948294107543, 0.8167075971407038}, {1.558683284839826,
          0.8253976660171901}}]}}, 
      {Arrowheads[{{0.008862141060322215, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.497363499371802, 0.939543219976284}, {1.555268079575567, 
         0.9551936221289783}}]}}, 
      {Arrowheads[{{0.008169933914116608, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.500585481763501, 1.063565135693647}, {1.552046097183868, 
         1.0838032853589836`}}]}}, 
      {Arrowheads[{{0.007562257165461067, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.503492944534415, 1.188421005328572}, {
         1.5491386344129543`, 1.211578994671427}}]}}, 
      {Arrowheads[{{0.007138626591663842, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7073507048584797`, -1.2069399474125195`}, {
         1.6610703477730997`, -1.1930600525874804`}}]}}, 
      {Arrowheads[{{0.007644179863439153, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7096207059274628`, -1.0785365707297265`}, {
         1.6588003467041168`, -1.068831850322905}}]}}, 
      {Arrowheads[{{0.008202869729679894, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7119011011281267`, -0.9493311684880227}, {
         1.6565199515034528`, -0.9454056736172406}}]}}, 
      {Arrowheads[{{0.008815360047730557, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7139796641545517`, -0.8191042397950559}, {
         1.654441388477028, -0.8230010233628392}}]}}, 
      {Arrowheads[{{0.009476710395045098, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7154868091500386`, -0.6876417105833197}, {
         1.6529342434815413`, -0.701831973627207}}]}}, 
      {Arrowheads[{{0.010171682143683134`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7158343163477299`, -0.5548243431217018}, {
         1.6525867362838498`, -0.5820177621414566}}]}}, 
      {Arrowheads[{{0.010868098680127383`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7141956671674212`, -0.4208065208299345}, {
         1.6542253854641584`, -0.46340400548585536`}}]}}, 
      {Arrowheads[{{0.011510089810264695`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.709640038777577, -0.2862831745146326}, {
         1.658781013854003, -0.3452957728537889}}]}}, 
      {Arrowheads[{{0.012017489939844412`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.7015698223865712`, -0.1526951839290157}, {
         1.6668512302450085`, -0.22625218449203732`}}]}}, 
      {Arrowheads[{{0.0123017998314298, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6904161823249093`, -0.021991407475090506`}, {
         1.6780048703066703`, -0.10432438199859409`}}]}}, 
      {Arrowheads[{{0.012301799831429802`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6780048703066703`, 0.10432438199859373`}, {
         1.690416182324909, 0.021991407475090097`}}]}}, 
      {Arrowheads[{{0.012017489939844412`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6668512302450085`, 0.22625218449203693`}, {
         1.7015698223865712`, 0.15269518392901532`}}]}}, 
      {Arrowheads[{{0.011510089810264695`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6587810138540027`, 0.3452957728537885}, {
         1.7096400387775768`, 0.2862831745146322}}]}}, 
      {Arrowheads[{{0.010868098680127405`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6542253854641584`, 0.4634040054858551}, {
         1.7141956671674212`, 0.42080652082993397`}}]}}, 
      {Arrowheads[{{0.010171682143683134`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6525867362838498`, 0.5820177621414561}, {
         1.7158343163477299`, 0.5548243431217013}}]}}, 
      {Arrowheads[{{0.009476710395045098, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.652934243481541, 0.7018319736272065}, {
         1.7154868091500384`, 0.6876417105833192}}]}}, 
      {Arrowheads[{{0.008815360047730557, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.654441388477028, 0.8230010233628388}, {
         1.7139796641545517`, 0.8191042397950554}}]}}, 
      {Arrowheads[{{0.008202869729679894, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.656519951503453, 0.9454056736172401}, {
         1.7119011011281269`, 0.9493311684880222}}]}}, 
      {Arrowheads[{{0.0076441798634391215`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.658800346704117, 1.0688318503229046`}, {
         1.7096207059274628`, 1.078536570729726}}]}}, 
      {Arrowheads[{{0.007138626591663842, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.6610703477730997`, 1.19306005258748}, {
         1.7073507048584797`, 1.206939947412519}}]}}, 
      {Arrowheads[{{0.0067126323987369224`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8646212802552573`, -1.2030136796045416`}, {
         1.8195892460605327`, -1.1969863203954583`}}]}}, 
      {Arrowheads[{{0.007127936203894935, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8662191702570805`, -1.0743194303023567`}, {
         1.8179913560587095`, -1.073048990750275}}]}}, 
      {Arrowheads[{{0.007573976360972087, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8676234246408832`, -0.9449579566013234}, {
         1.8165871016749073`, -0.94977888550394}}]}}, 
      {Arrowheads[{{0.008046651298981185, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8686163645013534`, -0.8148309465324607}, {
         1.8155941618144367`, -0.8272743166254343}}]}}, 
      {Arrowheads[{{0.008536996234019595, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.868884422182408, -0.683894577140141}, {
         1.8153261041333824`, -0.7055791070703856}}]}}, 
      {Arrowheads[{{0.009028921501320192, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8680167677983082`, -0.552227339358185}, {
         1.816193758517482, -0.5846147659049733}}]}}, 
      {Arrowheads[{{0.009497038810619357, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8655513289164303`, -0.42012240285047375`}, {
         1.81865919739936, -0.4640881234653162}}]}}, 
      {Arrowheads[{{0.009905998658562653, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8611054426366134`, -0.28816999827750023`}, {
         1.8231050836791767`, -0.3434089490909212}}]}}, 
      {Arrowheads[{{0.01021367060712193, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8545985314669549`, -0.15724550076763671`}, {
         1.8296119948488354`, -0.22170186765341632`}}]}}, 
      {Arrowheads[{{0.010380026906675579`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8464760576359565`, -0.028302916515030432`}, {
         1.8377344686798336`, -0.09801287295865417}}]}}, 
      {Arrowheads[{{0.010380026906675575`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8377344686798338`, 0.09801287295865377}, {
         1.8464760576359567`, 0.028302916515030065`}}]}}, 
      {Arrowheads[{{0.010213670607121922`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8296119948488354`, 0.2217018676534159}, {
         1.8545985314669549`, 0.15724550076763635`}}]}}, 
      {Arrowheads[{{0.00990599865856267, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.823105083679177, 0.3434089490909209}, {
         1.8611054426366136`, 0.2881699982774998}}]}}, 
      {Arrowheads[{{0.009497038810619368, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.81865919739936, 0.4640881234653158}, {
         1.8655513289164303`, 0.42012240285047325`}}]}}, 
      {Arrowheads[{{0.009028921501320192, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.816193758517482, 0.5846147659049729}, {
         1.8680167677983082`, 0.5522273393581846}}]}}, 
      {Arrowheads[{{0.008536996234019571, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8153261041333824`, 0.7055791070703853}, {
         1.8688844221824077`, 0.6838945771401406}}]}}, 
      {Arrowheads[{{0.008046651298981189, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.815594161814437, 0.8272743166254338}, {
         1.8686163645013536`, 0.8148309465324601}}]}}, 
      {Arrowheads[{{0.007573976360972087, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8165871016749071`, 0.9497788855039394}, {
         1.867623424640883, 0.9449579566013229}}]}}, 
      {Arrowheads[{{0.0071279362038949344`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.8179913560587098`, 1.0730489907502747`}, {
         1.8662191702570807`, 1.0743194303023562`}}]}}, 
      {Arrowheads[{{0.0067126323987369224`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.819589246060533, 1.1969863203954578`}, {
         1.8646212802552575`, 1.2030136796045412`}}]}}, 
      {Arrowheads[{{0.006299830186599165, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.021319333892669, -1.1998580766121776`}, {
         1.978680666107332, -1.2001419233878223`}}]}}, 
      {Arrowheads[{{0.006639007146740669, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.0223204813010685`, -1.0711168826131603`}, {
         1.9776795186989324`, -1.0762515384394715`}}]}}, 
      {Arrowheads[{{0.006994101763563625, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.023021860113319, -0.9418700436004788}, {
         1.9769781398866815`, -0.9528667985047845}}]}}, 
      {Arrowheads[{{0.007359596684486189, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.0232415485133077`, -0.812099869476136}, {
         1.9767584514866932`, -0.8300053936817589}}]}}, 
      {Arrowheads[{{0.007726555010065077, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.022751885580051, -0.6818498181345923}, {
         1.9772481144199496`, -0.7076238660759342}}]}}, 
      {Arrowheads[{{0.008081778962973667, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.021298173251883, -0.5512622571230908}, {
         1.9787018267481182`, -0.5855798481400675}}]}}, 
      {Arrowheads[{{0.008407444332789489, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.018646180414447, -0.420614400450869}, {
         1.9813538195855542`, -0.4635961258649209}}]}}, 
      {Arrowheads[{{0.008681858951650127, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.0146636713784787`, -0.2903292666130577}, {
         1.9853363286215222`, -0.3412496807553637}}]}}, 
      {Arrowheads[{{0.008882004852615494, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.0094198072094716`, -0.16092945883010032`}, {
         1.9905801927905293`, -0.2180179095909527}}]}}, 
      {Arrowheads[{{0.008987946674919001, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{2.0032534544365355`, -0.03291549702403106}, {
         1.9967465455634654`, -0.09340029244965355}}]}}, 
      {Arrowheads[{{0.00898794667491901, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9967465455634652`, 0.09340029244965314}, {
         2.003253454436536, 0.032915497024030675`}}]}}, 
      {Arrowheads[{{0.008882004852615456, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9905801927905296`, 0.2180179095909523}, {
         2.009419807209471, 0.16092945883009996`}}]}}, 
      {Arrowheads[{{0.008681858951650127, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9853363286215222`, 0.3412496807553634}, {
         2.0146636713784787`, 0.29032926661305736`}}]}}, 
      {Arrowheads[{{0.008407444332789511, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.981353819585554, 0.4635961258649205}, {2.018646180414447,
          0.4206144004508686}}]}}, 
      {Arrowheads[{{0.008081778962973714, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.978701826748118, 0.5855798481400671}, {2.021298173251883,
          0.5512622571230903}}]}}, 
      {Arrowheads[{{0.007726555010065143, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9772481144199496`, 0.7076238660759339}, {
         2.0227518855800515`, 0.6818498181345919}}]}}, 
      {Arrowheads[{{0.0073595966844862, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9767584514866932`, 0.8300053936817585}, {
         2.0232415485133077`, 0.8120998694761354}}]}}, 
      {Arrowheads[{{0.0069941017635635925`, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9769781398866817`, 0.9528667985047841}, {
         2.023021860113319, 0.9418700436004783}}]}}, 
      {Arrowheads[{{0.006639007146740669, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9776795186989324`, 1.0762515384394709`}, {
         2.0223204813010685`, 1.0711168826131596`}}]}}, 
      {Arrowheads[{{0.006299830186599198, 1.}}], 
       {RGBColor[0, 1, 0], 
        ArrowBox[{{1.9786806661073317`, 1.2001419233878217`}, {
         2.021319333892669, 1.1998580766121771`}}]}}}}}, 
   GraphicsComplexBox[CompressedData["
1:eJx0vXdgVMUX970UgR8gvSsSqiKINEEQmEXpAlIUkbp0EOkdBJYqqHSkKgRR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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl009Mz3Ecx/E3a8Moq/Qr/flVI7O5mCEX0yU245JhEYWfYjPNHGS2jl0S
tmYzFjkoIRvGoYM6cVJJszmIFhtGJ5v5k3l85/Dc8/36/P99Pr9v5eHWupPz
ImICDcUR43kR+3mM95VG7FkWUc+7+Rxf5kxJxJH8iAF+xH18G/2YyI24y/dw
B/cxiIxx2UUROSgrjFjKaS5HypqLrZ2NJThu74vLI47xJZ7jdmeasfZ3Y/tx
0LwmHEI2DqABV63bpz9H3YbV5n5KRXzGgPb5BfbXdj3Zn1ut36M+amyh/l3q
nzxlfJqrjW/R90YeSUcUO19Jct6KiAJ1PmqM6cSJsojGckYdOnAWz7UPJUY3
BtGb9GlP8xrkohabkj7tP+yVpR7nL3iLRu3T2mYxiYXO8JuHtJ/Sv0POcLe8
nbfIe3la3szr5LVcJ/9BkbxIHlSv4Co5xR3yQz4tD/OkfIub5StcK7dzvdzJ
s/Iv77PAO7/ib3iPcL817m0nvnr/DL/jZ+4vy5wpdb67HZZT8gg/RZs7Pc9n
uIv/GjOH195/G2/FTVzwdi326OIn8gf+iMfqHu0z6hvqXlSgEs3WGOaN3rka
GzDuHOv5Ja80pwqrMOb3jOJB8r/CNRSjBKV4YY96v3M0+Va4IO//N/QPOz17
aQ==
          "]]},
        "0.43799999999999994`"],
       Annotation[#, 0.43799999999999994`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1FtMj2EcwPHHYaSLooPyT1KymdlihpHDhWaoC2VLVrKVkjLMxszmxuGm
zCbMhcwNi81NURRzUSQ5jRo2Ie5aurKZw4bPOxffvs/v8Bze5/++ZVftL9k3
IYQw0Z/HSSE8wejsEPr546wQmnAaHekhdKI3I4SHWCm3CvlonxnCyIwQ1hiv
Rp/6I5RZ55BaorWK5bdgckoIP9S+cVBP4HL5CuzAYf3lySFU6angao6ZH683
RW8cJ/M0Pqr3i323poWQKldr/m7UYUgtw7wa4wH1V9GzcYlnSDA3EXvU6tGA
a/pv2+uOPefouctZPGTeGW6y/k7zG/msuc3o0t+Nc8bX5RdnhnBJ7wXx+WgP
/a+t02ntQd6eGsIf67XoqVKrRp7cXPE+Z8jmXXLzORcjesfM/cwfeLneWvU6
vBG/Q8y+8XPdjf2SsE5PIxqcpTKLUYxTOII++a7IaMZNXIlq8pm8ENNRgBVR
Tf77nBAmGb/kUQyjUn5EbhyDmOoMv7hL/oB6obiam8WbeK24lEfEq3mJOI+L
xb+RJo4T3zTO4VxxKp8St/FB8QMeFF/lGvFFLhAf4zJxI4+Lf8ZCmOJ3ec1f
8Ql/vSfr3FcRxqL3intQhmr3u4CX4q37zOQknDSnNbpL7kG+e1+FNL/NTNyw
TqE7L8JGbMYmbLDecfOXOcsJ3qvvnv77qLfOImvGIybOwCxkYjZa9aZH3xrf
8gwd3MbteIJ+rI++R+u+UHsufskD/AxPcVmtBfP05UTvVfSN6tni2Xqdr8IZ
uvHeeBjb3E+fM5fG/v8P+Adyn5XE
          "]]},
        "0.365`"],
       Annotation[#, 0.365, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1F1MjmEYwPGLjWZshFREaFNhxLB8NVuM6YBSQ8mm4cDQYuPEiYmtM3Vg
UzSfsTnwZigbpk2nPko1Y+LMRxsO8jXM752Df//7+riv537v51mzamrLDo6I
iBR/miZHlKVHFGVGvEuN+D0l4g8uZkVcwgUk9Fzm25MijnCDOFd/PvKSnh6R
rvZF7btZn7l5YsRbtRa+JbdHfYJ8KvbLH0CWWptn3Z0W0YE7uKevk3+p1WVE
LPSsevtP4hSu6b+ORfKH1Av4MK/h43wuLeI8vomHsc26z6zZajnYYMZGLJGf
Ix5UGzIvR2+hXKXcUs6W75MfQKbamJkRGZzp/EXqDdjnd1dnMzajHkfRLd+Z
NBpxA63JmnwW52M8irEsWZMfnhEx0voJv8crVMsPyg2hB6Od4Sd3yteqbxTX
cKN4A68WV/CgeCUXiBfwZvEvTBGniG9Yz+Ic8WSuFye4TvyAe8SXebf4DBeL
j/FWcQMPiX9MjRjlPT3nT3iDv76fIvdVgo/eYw13YStq3GcuL0a/e8ziVJyw
p81ddrv3dt6j1s33sSn5DfEH5JnXz+s9swgrsBLLsRqr8Fr/E+/2FT/l+b6x
PvPXWb/gtVyMLjzCXn3nuBXnkeYMrc7Uq3eevXORMPcmXjpXM7fgLNqcp1lv
C9qtr8gl+CpX2X8Pu6y3y401t5LHcaGZpZ61RbwjOVsugQ79leJS+e1cxlXc
5IzP7OnBc2zR9yL5u9CLAfSjXP6hb7PEOcvtrbZ3J9rNvoUK9Q6u5sf6yvSV
ohETvc/T/BVf0JTx///CPwHpoB4=
          "]]},
        "0.292`"],
       Annotation[#, 0.292, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1FtMj2EcwPEnc7ZZVERUYmFjZdMmY+ofnYSNJFTkcIHJ4cKGzYUwFy4Y
NoYLmRs3bGylnGZtOZTTlotMznO+KsMwPu9cfPu+v9PzPv/nfd/GrdmyuC4u
hJDpT8+YEOYmhPAmMYQYN4qLh4VwdVQI+4aH0MQtaEaJ/HW+gWvYr36TS+Wb
zM0zf0DuRXII5eKlWIYKbBoRQqF6eYoYS3FI70u9r/AaC61Tp6+Cb5ops6dt
4q3Yjl1yR+V28jG+IncZefYwB23W7HCPKWNDWCyOt/4SzhDfc105OoR8cQzJ
+gbqH4xBaFdvGxnCfb7DvfyUx5t94rrabA3a5d66/31+xyPUTtj7ScQlOVQM
Uau3v83qdfii9hXP5Lqwx543un9MLSbO43zO52zrZVtjGpr1lFhrPsqQK1eB
U/pO46w1z6EBE8zX8CqsRDWqkG69YjOlGKungJPNzuaD2OD3VaUxFqEeO9Aq
3xgZh3EBZ6KafApPwlDEkBPV5HtTnYHrDn6PLlTJd8t9xmP0Sw/hBzfK16mX
iGv5sLiIZ4nLuVs8k7PEU3mR+CeSxP3FF1ync4Y4gevFF3mr+Bo/FjfwWvFx
jol3c4X4IH8Wf/c8+3r2j/gTnuOPd2+251OKj86/lm9F7yRqnWUmT0Ons0zh
eOw1c95ZtjrvS7xOrZVbsDD6HvgDJlqvkwuj95R7zKW4zkAisjEZlWaCdQcg
y8wPvQOj9wt/vQeBf3Oq2i9O40LPtAgF0XcYfdPIs06635mrPy06T56BR+7x
1EwfuWbxevu4p/8u7iDXmjNwBZexWr0FOa6n4xIuYkX03eO931tpvdtml4sT
7bfSPR74zh6iHUfspYPL9H3Tt4DfmpvPLVFsbri5goT//5P+AQBJqOI=
          "]]},
        "0.21899999999999997`"],
       Annotation[#, 0.21899999999999997`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1F1MlmUYwPFbUZsHTfALA005UMs1PytLTCNFRAMR5mhzxatNwwPzQCkR
PBAznM3h/MI2stzckrbI0tCylh9b5scUBYwarylqJtWBNrOZW/7udfDn/1zX
fV3XfT8Pz/tkLV5R/GaPEMJKfyYOCGFOZggvYy5SB4UwLS2ExsdC+AT7sLp/
CPOtFaMIz+r5Qs0L2G+9ynrrkBDakG3tztAQpnCaWTPUHBRPE3cNDOFL8Uwc
0rdeX6eeJC4jT75ZbY7aTda+V/Men+Q5cqe5TnyKt/AZLpJP8o44i3dywhlL
5Q+YeRBN6SG8Lz+BJ2ISDsuX2W/14BAqsUx9qlx5PDenO/ta+UNokxusp50v
mt3BF/hHXue89e5rm56dfAApw0L4ydolNT9zK7ejDTftucrsP7gpQz0a8S0O
I9c5G3gPNqMeW1Gp/ra+R+xzj8ea28fZ/nNdqucJs8dhALKQgTt6zlrPjXvz
KD03+TIK9HzNJ/C6M38Wr83ey+v09TM7I967tfE8Egk9C/i7eI3fzMvnqXig
p9M5b+E8Uuz5N3d7FrWP6xsRwhrOEW/nxeI93CI+wivETVwj7s9Z4uHcKO7N
A8X/uC7EU+Kx4uc5KS7hbPEsrhMneLZ4OTeL7w0PoZe4hbuRxML4P7L+K84i
yP3FDfJPu87BoxiNDFTIN3Aj6nACzdHyFVyDQpTH2dHxvj3LqUj3jrzEQz3L
Ts/qhud43fuUL7eME577SGtVriu8w2Os/6nuSa6UK1X3IP4G1b0iniLuir8P
Nff1/YtU/4uP7bMPNfG3hXdwX00tv4sNKLRegFpzejtjH/QUp6CfOT34NXVl
aNF7AWnyRfZO5V7Wh9i/yv/2rjOs4bWoRqu4jBchEe2d+AZVZiT1VXOm/Y6b
M8j+S70jS/C5tf3osudVdMT3Ufyqe/pU3S5zf5Gvj++f3FFrpeb+7kzduIVt
1jrUzJO/Ib6Oa9gs/4P8XPmv9OXp3yh3VK6Wj/F0uRLnKI/fAeTH75TaXD1v
iF+M3zBcMq8d1fqe03NbzWReqiZPT1/3NpufkSu2VoL5mCW3RE1RvE9z5vE5
c9425yP7T1I/Jr53/JbcbrkK/pCz1X/Aq+J3gVfG75i68bhq7hUUZP7/HX8I
xwDfmg==
          "]]},
        "0.146`"],
       Annotation[#, 0.146, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV1G1MllUYwPGjvXww1yYk+lAZmuYH50trq0Ra6LTQCSaabzVJZJGPom4y
NVOBPrS1NbayfIlSEkxMgYmi07RNFP2gC1+2RLDWpiDYerEVfmiTfufDn/+5
rnNd55z7PvfDyMI1+asHhBA+8GfykBC2JUL4HJ9hO75AzpMh7ORd2IEqfImZ
8rW8DzXYj2+RJz8HDcbvp4RQz5u4kSenhnCEt4qbuIxfibmnQphm/2NyH8p1
DA+hE8fkXkMyLYTZfFLdrCdCKBGvQo7ef+RmcqW+bj130IN89WvULOIzanL1
lYrXIc940NPOyQv0zufHxPN4g/llcvf1FPJX1n1xWAgvYbiaBNJRZN0T9lnB
l9Qu1rsIZcbl2Iyt2IIuNcvTQ/jJWoV8nYv4a3O7sQe11lrv+Z8398AZ+jHQ
nkVDQ3jbugXRKLVWMSdxSX4tlyBT32Yuw8/OvZHX4Tf19fZqQh1O4Timq6/i
anyC7fgUG9X/pe9R5+nj8dZ6xFkeGC/QM9bdTkAKMpDAPT0XzU83vsZj9HTH
c2C2nhPcgkLnbYhja9dwub7HrZ3ANXMTeTQK9MznH+IYd6yXw1Pwn55O5+zB
jxhoz3+51518NEJfhu+Os8XbeJm4mtvEJ3m1uJ4rxEM4QzyC68QPc6r4vnEu
xonHi1/mm+J8zhTP4EpxAb8uXsXN4r5nQnhI3Ma9uIkl8u3mu3AR/fgbVfIv
mM/GYDyHBErlq7gOlWhBc7R8KVcgF8Vx7ej43N7lFKT5jqZyp/fUgdve4y3f
UPD+fuX++Hvz7v8UbxL/wRfU/c5X4x1gn3tYbG4J3sJg3JWv1tdgbg83cqvc
uXgn4ix0qRtgnSSPsk/SndziYl6B9+J37+7edL52/sVZv1f/nTUOYKTatb7/
ErkSd3remhfQYr2zqIm/Qc+aVLfXeCXXcp36FHUreZT4WYxGwj7pKI7PaK/l
9jyNXmd/V+58/H2L09QUiPvE73CP+aXcKl5qfmicd54OZ+vEjfg/0t5z1JxW
M1dNt54u5MmdkntDLlXfQn3n1LeiBR/rO8vZ6pq5QnyUyzlLrinen94bnqcd
17HF3GE1r8ofwVW5KzgkdxBZcodxWa4Ne+W+QaZcIyZ5FxNxCAcxSM3/cirp
4w==
          "]]},
        "0.073`"],
       Annotation[#, 0.073, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV00lIVlEYBuDz22A2aqOVptGwCBuoRdQim8hFbSoapJAsMEvLyEVBkDZY
NkFEZbkJ2kj2twgiikah0chFmyCDBkotLRvU5uG5i8f3ft8959zruecfvbZk
yeZYCGGmP+tTQmgaHkIzH1PVI0O4qVcoW/Te0a6/QX1Lf6N8r9fKJ/0i9W39
Ytmm94HP+qvSQqjTXy3LhoZQzorBITxSF+rvUhfL9mid6Nl8ieaySb9DdvKV
b3SxWf+6NYakh3BDXiNuvQuc4zy1lBjXc0gIidw1Jkn24o3+efVg8+OyltPG
V3OSU1SxxbjyEd6RMvawm8UDQ9gvK9nLPipoMr55mP2iiVbeMc34fM+NuV4n
V3leXpSUmlMgN/BIv0QWM8OcHXInzweFsE1u5b3xcc+6SA3XuMw846vlGQ5x
gqNsi/bWvB6+RafMslZ3e/7H9TJzxvteE0khg1Q+mVPv/jzXT+RYc95G78FC
c67IOvK974Xo2tpnZZl5/aydyhP3Jskx5JmzVN6IrmmyXo6cyU9znnnPZh4T
88wO2eLbVIwyLzOE7TJbfUyuUZ+RDeqrcpM6LsvVyTJDnS5r1N3kQHWX60VM
UGepp8tG9WI5Qz1fHlHnyQXqInlJ3ZkRQoK6QbbQSK7+U/ffUM9fPlOtP9X9
bPowjlRK9atlDUeo41KU+qWynEUURGtHGf3f9vIoOVRxnBZ7+NH5aec1H2gj
pp9t/2czi7nModYev7K/r9nrW7yUL6iw38vdX8EycllJpjGjnPkMRpJOGgnW
nygnkcUUJjPd+PX09b4Fcp91H8hh6ofyfnQ2PC/OHe9yj5h7d+V+Y3/4Hf/k
O7/5RaX+X/mPP8Scg8AB/W6yOwn0pAcH9XvJJBLpQ+/o/EfnUPanL8kM4LD+
f0PiwXY=
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV1H1M1VUYwPFjL1sDtFDsgsAFU3TNsEQlrEWJQppbKuHm3FhGYa+DLjOo
lvBHWK4gZTqVLcm2RjO1talJpYxya1lh4qbz7R+zZL3MLHTpltXn/PG93/M8
53nOOff8fvdOrGusbhgVQujw8XFmCEOoSIQwF/04iN1yR1GYE0IBlkwIYTF2
yP2APLlczJebh165HHE2EhgYG8ID8h/In8gLYdu4EA7Ilcp9wffyFrmZ3Ce+
h0swA2tzQ9h4ewir9D2NerRmhfAMv62ny9y71j0mfkV+t/4CfRNRiGb9G9TU
mX8ST6BZ3VP8mv4m4zH5IaS4U10jjxa/yOvEb2KD9QfVPyv3hrjM/FpekB3C
3/Hc4qu8UPwoblb3o/qxznJEXSafE78nP318CMXIcK4cPek8gUdzj7ps952D
PDW5qMFZ+892j6Vo9J0a8LvaEvseV7tavl9ujHUu2med3Mtys9Rctv8VzLT3
amcr4alqisydl29Sl4rrxuds7oLcz7hkrW94q1yruW7epD9N/pw4nf/kYets
dMbNqMJ6tKPe2ZYXMBahDU0YkN8TjQ70ojvOySd4MtJQjhlxTv5SMoTrOIzz
OIHl8qfND2MQowp9V94j/5z5SnEtd4jncZl4CZ8Wl/I08Z28SHwFmeIbxL3G
eZwU38pt4p38griPB8U9/Li4i8vFLVwtbudh8YhnETzP7/kCTuGaZzjHfVbF
+3V3tXwA1ah1h3dwMYbcc4Iz0KrnfXc54N538UpzA7wfj+g5wz9hkvWGuMKe
h/kPfQnjJG7DXShCjZ5/zN9o7Wl6LhvfZO2L3KxnvXNuwlvoQTcq9Ozjz+Pv
Gp9gJ35Rn4p9OGOtNfwqytQ/zw34Nv5O47uAJvUruBYr5Os4eH9WcomeFu/g
r+JD1v4KI8aDOGWuXnySJ7vbYnXTcTf2WWeH83/KH/Fe7sN+3K8+qX7IGvl8
jI9iRN1fOBTPj7Nqv4z/B+qzzNdzpfgWPfN5V/yPwFW/mRTnO2+XviPil8S/
qWnha/F/hZPmC9BqnHLna/hr9ZuR5Xt8aP1/7f8f2s1d1/c6F+mZgk7jNn0d
/J2ebZiibyrSfOd0ZGC7/HG9Xeo+s+as+Ix4Nm+Vm8MHxWXcz/dxZ1wXDxo/
hPL4fDEX78hX8cOoxEIsiO+DfDU/hqVYhpq4h/z/K3rjVw==
          "]]},
        RowBox[{"-", "0.073`"}]],
       Annotation[#, -0.073, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1F9M1lUcx/EDttRZKg/wWCrknyxCl62tdAtstryIMqdu0YWrrXmhUaRb
WC35o62VspBSFEOUpMc/4HQyJ3PaWOoFlqVOm4I3rhSdLmlh4gSz11kXbz7n
8/13zvk9Z0x854MFpWkhhDJ/Lo0PIS0rhE8zQxiwHsRdpBIhZI4NYQddLXdG
bHNGCLlie8TSHw1hCB5Ag/gU8f3iQ/lhGI5t4uf01eo/KPe0mnY6nW4UWzsu
hLzsEJ7CFr6ab6C/6GvGC+oKkG1WMs6Tu2/eVpqvZ5eaC/x2vtcdvtG/Huvw
NWoxVd0edXPNeR2v4rgzvEZbxbvjXfVvUptrj2NyRXLfi20Uq0OO+FHxZrEu
9S36NidD+I5/j19t7xK6itaLv2v9q5qldKzeH/U2qT3P7xTfpCZFs+QykUCH
mm/V/Bu/c9xbTaV5GTkhVNE6fkPcU98o9SPxMNr05TnvVvGzemv07hObJLaX
Tqafi42hu/lsuosmaaV4gjbzGXQ7Xea+H4ufeCSEnzBrTAiFKECTfDvtFP/K
frfpP7iFRn1bUKpmipon8CTO4SzO40Kc4y4rnbscFeh3pwI9G+QOyV11h1l8
Iu5Lj5j5g/Mcpkfos37PbvFPaDrfr6fM+prztLjDPqRwCAcwW209bcQarEcN
ytT/qW+Is/fRfLPSnWXAeqGex+Pbwaj4+yOJm3o65Wdbn6aT9PwRz4NX9Byk
HXjbmVrj2uwmWq5vhNlJnJabRidikZ759HBc47J5c+hM3Ilv2zmv4Gfcx9/o
8R4+y9U3IYQVtJCvpW/xjfQk305L+BZawY+kOfw4muLT6Gj+lnUR8vh8/jna
xc+jM/iXaDW/iL7ML6VtfN9j/nnwJ2kPulAs/pv87+jEIHpRL/6MfCGGYzKS
WC5eT1OoRgfaooovpxUowuI4O2q8t29Zgzl40Leqoz2+4V/eylzrErrEN8/z
jcutKzFN/qbvOZWu5Futj+m9TI/SefpuyPXxg/ruIUt8jXe4Fl+gQexLekLN
Km+2CpV4Mb5VVNnzI7OvW982q8v6DRQjx6znvZeZmIE78t3i/fQiHUp78aHf
dkV8l9jG3zVzAMe9g3VY6Jx19JQ9Sp3nfQzT/6ZzFKOJfyjx///z/wDXPeOH

          "]]},
        RowBox[{"-", "0.146`"}]],
       Annotation[#, -0.146, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1Ftoz2EYwPGXtSXFGHPY5rCDrf+G3czcKGTKDI0LN4uyIaRtOYQxzTBM
rIaURDEKETnELoYLrTa1G2US5XjjUJvjJpvPLxfffd/ned/n+b//5//7Lb28
akXlkBBCLPozNoTiiSEsRglGiP+mhjCIAXxLCmFXSgi9/CkthC/4jD/i6c5+
tM637hnnDGbKTZObwdk8zF7f+BD6cRlV4ktczY/0fYyHSBxjz+dVcyVX8QH9
KjlPn0L9YjyLcyOrL00OYTnGOLNUzyT+ycvkXo4OoXxCCBVYg3VYi2z1G3kT
1iNDr3Rk6leibgni9SniY6hHxaQQVk5hFKMW1WiTvxUZjWjB6WhPPpkzMAxz
kB/tyX+dbHZoxxs8w0r5bvsf0IlB9OKW/Ab7C6aGUMaN4vlcKF7G3eICjolz
uFj8DYniIG6xTuE08QiuFV/hTeJ73Ck+y6vETTxHvJ1LxfX8QdzjtxlAB97j
OX6Z7Wy/TRHemVUZt6IUZeY4lfPQZdbJPBx71Jw3yzYzv8qr7bXxXSxS84Lf
Il2/Lp7nGWjnL+qSrdMwErnIxAo1/faH6B1T02s9VO/P3IfX+r9CnfVmZy+6
dwsuIM75OLlufXqsn3Mvv+BrHHzvVrUHUeXZaOBqPqp/EQqjOTu3wPo7L+Tr
fE79Df4l/o0+HHf/+57JB5iLeXgi14wj7t6IOjVb1G7DVhyV284T3TUFE3DV
fVN5h7sk+vyd3KBuN+eLa7g5mjOPEtdyk/0T0fsjbuaY+tv6jPKeN+j/1B0O
RTOVz8No+cPiIzjp/Cncid5ze3d5RjQ/NTlmus+ZetThAPYjQX08bjqb5ewZ
Zzui76nPXvuNnKU2E03ums4F7pbBCeYSj5bo+RHXOPsj9f//p39pbKrn
          "]]},
        RowBox[{"-", "0.21899999999999997`"}]],
       Annotation[#, -0.21899999999999997`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1ElI1kEYgPERKpGkKC01NbVFbZPMdoOi/dBG4EXykEXRfsgo0w5WakZ4
iSII2r4OWVAe6tBiBJJlG0GQbbZ6qoySDI2230eHx2fed955Z5z/8GWVblu5
NSaEkOTPweQQtieGMC4phPGYgPqhITyUf4A8cW1CCDtTQ7gw2KKUEHYZ3x0U
QjmnDQshHTHyu8Wt8gfUVxjvQSUGWBexR0J6CGe5DDvwOC2EY+rv4Je9fuOc
/c4jX20DH5U7gnq1J6xZYp+l6K9nrPk6c9f5Bq7hDV5jmppcPXrV5XC7XDa/
4hW4Ld/CZc7aT+9YrLFmLVLMNbqDZC4Vr8Zge/dV80WuIHo31uXzfZ7EF9Vf
wgh1meqyOM9+O8xNNs6V+zgkhE/4K/6D48ad+o1RMxbLnGcT33Jno9SPUTOS
98p/1TtHvDVay+t5CzZjlB7xeg1EnPM0Dw+hDx8SV6HUOYoyGItRiW1okm+M
GnWI4Gh0Tj6RsxCLQuRF5+Q79f6JFrzFExTJt5nvwD38wTc0yq83PzczhGKu
E8/hKeKl3CYu4FxxNi8Wd2GA+C9HkCKfKo7nSvE53iC+wvfEx3mVuJ4LxWW8
XFzFHeKv3uZvtOIDnuKH9zbVfc7De/dUzFexHMXuMoPH4pF7TuQ4VFhzwl02
ue8GLjHXxJexyJpn/A6Z+j3i2b5hC7ehR223b/g9+jbVrnOGdh7tfBO9rXw8
13+Wb/2Cu9Q3o9e+Pbip50xzhZiGGZiOvnrs4/3RN4IaVKNb/Qv7v8JLtOt5
Up9TxqdxEhGcQYn6N/wW851jARbijPoINjpHknN/5k7c9/8f1q+WD6AG1dE3
qabKvonG5Qn/f1f+AZknqHY=
          "]]},
        RowBox[{"-", "0.292`"}]],
       Annotation[#, -0.292, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl1F1MzWEcwPGHzHu2RJL3C4vlhF7Y2sywOS5S1rDF5u3CbOlQyabYMjfh
9GbMy9xoUXfNy4ULN5qoxo1NdzK6ESZssibm85+Lb9//7/U85znntOLIibLE
pBBCij8580K4NT+ECwtCyJ0bwmhGCDFuEJ9HDVZlhpCNMn2nxbU4idT0EH7w
bTs6FodwF28XhTCEMbU0tU5zXahHkb467lF/igL9+ejXm9Q7wOvUM7iNW/S3
cDO38n1na9XXgmZsMFuIs2ons5wV1ajCDfWb2OW9/DZ3aWEIF9GIbfa1qW1U
G1Orl6vDGTxQu2fnVz7Ex/kAV/BBTurfq28PdmO2/IT3UuoMnXZW29kmX8Wn
9NeiCjWoRof5UvUSjJn7hX2eyzHPzAw7ZqLd3jtIlXtp5hVSxMVeZzLv5Otp
IUzRe5VXR58TmuSTmKZn3O6pHFuiV67V67dgSP+I2id8xB/3/ZkneMDr7HCW
OJJ6L+OFfK75Pl7L3byGY8hBHNtxDpuiO3P/lajAiPMX2F2I9chHHqbIp9nz
TM9z9EYzcg98xx7inXN3cZ2zTnem9OgO5FbzUpTrLeHH0TPe27WVC/HTzBv7
PqAPExjFsHtoWGpuuc+Di8RNvF98i/vFj/iYuJPrxbM4S5zJ7eK/SBV/5zhW
ymeL83hQXMwF4s3cKC7nLeKj3C3+tsx9ox/DGMRu+dfq79CLcXzBNfmYehGm
YjnSkZC/xu1oxBN0R5ZPcD3iOBztjix/xV322DndPc3xPAsJ35fK6Lec+f//
wD+RmJfT
          "]]},
        RowBox[{"-", "0.365`"}]],
       Annotation[#, -0.365, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl0ztI1lEYx/EnzEwzKM3MtEwIW1q8EElktTgkEaRBNEkQOVSSRppDQgV2
c+ieQZBDLtUL0RhlkpHQEEFCU6ZWhpWXcjDt9nlp+PI9v+ec8/zPe/7/t2hf
w67D8yLiLcayImpzI06siChYFbFAbjPORp/6c+zEdrkas9kRn/Ij5niUf/IH
/oghjGAYiYKIu9bfw0mUyBuXRZRyBe/W85h6M46jBemenWFu1v5FPMcL+dVy
5zE3Ym+6PGncvDJiils4l+vyIoqcv8v4s3UduGXtIGeovdTjj7NO6/mXp/gH
vmNwacQ3HsdXTGICTdbdtq8L9XqlOHM7n8EY7jtzAqdxCjnWn7XmHM4jX57h
DZ6fkhOxyZ4O+Y613Xggp6rPxxL1LXIfrifH9lzlaziCJr+vWG3UWdbxUbVG
FFpfq9dN7tQn0zMb5IPmFssT7uQGp6n3ro64aFynVlPIqEIrDuGReiJptKML
V5Jz6llciFRUYH1yTv2LnjPowzu8Ro36gPlh9OMXJpBQ329+65qIPdwuV3KZ
XM0DcgkXy2u5Sp5Epvw7+W6Rq54nZ3Cr3M0H5IfcL3fyXvkCV8iNvENu42F5
3PcyhxcYwhtMe//l7nUb3runZ1zA6e7xknu8jDL39sQ30aP+mJ9ypTtP03Mz
l3s/ZShFr7me/P//rX9TJoiF
          "]]},
        RowBox[{"-", "0.43799999999999994`"}]],
       Annotation[#, -0.43799999999999994`, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJx0vXdcFNf3/7+WxBZL1GjsvfceS3I2iVGT2HuMscbeu8a2sdcYNfZG1NgL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    "], {{{}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwl0rtLlmEYgPHbMc1DZtiW4rGjm1tfSfqq1OK32OAgmWsNLWoHCirImnQU
QyUCW7KgXBs8VjooQR7RNf8Az+DvpeHieu7T89zfofzew+yDnIgYQxREtBVF
7OMA/eJRzuEsH+IIb8XHvMRTxRHLPM2b+RG35Bvx7mxEEzcjwZ0zEbeRK19b
GDHJ/WYGzP7kPzzL85jDB3cl3IwmtKIFM/IF5g+dj3GEfHGVN6px0fk5Mvpe
8CPUyteg0LnSDlWowHd8w6zeT/ZZ0zPO67yK92rD+Kj+2zsL+IUVuy7yXy7X
n3XvBW7jMu7TX2furjva0YptuRvp5zGT4YSv6R/Wf5U3xM+cv+o7r/8LP013
kb+ivsZPxBPypeqf+bF4Vf6VeiK+LN/AL8WX0u8CM+qJeACDyMO+90/zAW/o
H9K3xT/s3OL8Dx3uvim343yde9P9zZSkeT7HGe5Fpzd6uF5uz525zrt8irvN
30cX3qS7yr9Of1Nv1buzB7tqexgp+v8fPAHC7FtZ
          "]]},
        "0.55`"],
       Annotation[#, 0.55, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwl081vTFEYx/FTlIq0nWltESqRoKU2rHSmiUgIGhWJDTFWVKcIbb2UTQXR
8bJgaobQSpCysMPKX+BloW26wUIrKghjoYOpz43FN9/z/J7znHN7e2dxqmN7
uiyEMIbJeAgpHKsJoROnq0L4rJ6qDGEfz6nVs67g8eoQ6jDXeil/xASa7Uvi
pPlT6LfOImeuPRZCGgkksUbWzGt5p3OWme9z54i5cR7mD5yVX8eYelI95LyH
eIRv8ozsnN4FnMc69SW+jIvIoA/P7X3qrh/WBXzHLFnS3c1YjwSa8Ma+af24
folrOMhHnN3g3m3qeh7EQnmL+hkPqEftmWk9X1bGtTyDh525kuuxAqvQgHL9
BeYWRWdFf5t9T2RD3O39dOElXiAjrzYTQyWWq6u4wA/M3sc9THiGUc+dk+fx
Tv1K/Z5f81uuM7dDbwm3co/7NmKPepe7tmC2s8oxz/5+czeQRV59xt4r5m5Z
52Q3Oc+PZS16JXPT+IO43t/ovcl/c0z9i4vR94Wt8qK5zZxyf6N1zp7VvFe9
ST5lvYF3R+8v+vb0C2Yr+Cdf46vuP6w3aM8RTuMQBtQdfBcHcUfdzvvRhtvq
A9wbfUPO+Ro9u7u+cImPy0+gSZ1Ao6wTvfZ2yc9yNxdlPdat0f/W+miE/FP8
/+/rH6GLfDo=
          "]]},
        "0.44`"],
       Annotation[#, 0.44, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV1HtszmcYxvGnTmGiVdV2VYcahiULYWY2s0Qxmzkt2JjRFqNdKcoyiWXL
Eu2MZbM/FsxaIVKUzWE6p23JlixIrKV1XCJUWBda00pIkO3z/HG93/u67+t+
fr/38Ht75xW9uSQhhLDCS2liCI1JIVTSvc4hlFE5fUf/0h0q7hLCarkt6ged
QmhIDuE+rtKbnBLCQPUyWueMD/Um6Q3gd/PL7C6nOjtNerXYiEvlXpXrqS6i
JfxXfBHe4gtxDJ8RZ1HOKKLT9hv4mbiUXyw3Vq6b3k7XW8R/yefjWr5Qf5Fc
Pp2wc4OfhgX8+1Qgd5K/qT8dC+OZcaZ/iv9bfwa2cWZbSnVmO6zFOkqjbD5d
7pw6E6vla+hP+od/Ur8qZvA8XaAMGqfX3fyiuheOj+8jfmaunYmv8Vn6l9SX
qQdtiTv4FxXLbeBXYItcjuvl0nL1M3RNZlB8vzL91B/LNeAneNd32UIVZs24
E7+VrTE75v0/VN921iP8iC/Rz+bHULN6jfzvZll27/LXZO7hVWzBrWZNrlWO
m+1soj/i78DsoN39/AG6rHdL75De6+qJ6gk4Ca84ewSm4jDzlc4bZecDPEUn
aYfzV5r/ph4p21f9Ml7HGViP03GeM+fTz/Z/ide19ytuNm+iRsqVy5PJw9v8
KziMH4VfuH6JfCltsHvG/CzVUDUtpGfl6jAba3E0Hndfg7EUS6iZ6u1XxM+c
ZtE7NJumOnsKDZJJdr1qe5/z62g9dZTpRAPMZsr0x1k4VG8IHXHuLrn6eB/u
e4f6CdrGd8ByvTL6VG4q7bOzn+ZSTrwfuW+cWYEHnPu2TD7/ffyd8Wvic0cF
ej/o9aCfaCNfhZ+ZzYnPKn+Y/9HOQcqLz7veUb1K1y92L8nYmXbTWvPc+D8g
c0Smys4hWqiXad5fLwOfxm74XnymsB+fhn0xHRfop2IfPgWfwq7xe9dv5f21
ppHOLXOdlzAh/r7wMP8iZsknyvfCJMyxF2TexcUyL8T7Mhse/1f42fr/qd+K
/zH88+p08wS7adgKt9M2emyWIjMUu+Bz+Ige0kT78/SGqJPs3ff5JOIevfbx
2YnfizP2uJe9VElt9FvT1/oP7L2hN4H+B9UJzTA=
          "]]},
        "0.33`"],
       Annotation[#, 0.33, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0ttPz3Ecx/FPJzcqqdY6iWQOf4DzXLjkgs0NKzRSkUNlksom3BgVnSyb
C0RmY3O6Ulo5GzfV2FwaYWZqQ5d4fC6ee37er+/78/58ft/ft3h37ZZDCSGE
X6hJC+FwVghD6SEsQ0lmCEt5EQ/yHS7GQhRhAebjNlIyQpiFdXNCqDdjn1nJ
6r18FsfmhtCIeXoLUSE7qm7AERSbnykvj3dQ16MORfI0eal8v7l31XlIkuVy
Mt/i+87K5qDOinfVey/2o199RX4VnWZ24aJ5BZ71co87N6PQjAI8lJ3gVhxA
u/4eWap1d7wH16AZTXggy+N8fHTWmHMmMI5JjJndpafBeRusX+mZlidY/+TA
U7F2TiIG4rvUU8UpfINL+TWX8Tce0vfBzBl7B60f4ZI8Qz3bOanYJNuMHOv1
8iXWi+Nvie+Ju/mCc0finczqtD/Juo+Xe37Gvgn5CutxXqVejZVo0beGG3mt
/kQu4Rx0xHeGNsw44x//RT+u4xpGMYLTZp83+7F7DGMovi97sj3LwmXParkO
uzCMAed2yE/Z284nuTX+p+hFn6w7/k604DjaZOn2nuNmdRPyzclDs/O+qv94
Nsm/+Uv8NuXveVr9jqfitynbaE+xdblsJ3bgh3o8ft+8nctQiu/qMc7lg9hm
vRVv8Sb+N/F7QpW51X57Nd/0LgdQpX6h5yWe4jmeoVJeqe+J9Wd7R/kT75F1
uFsF/wfN1IP7
          "]]},
        "0.22`"],
       Annotation[#, 0.22, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV00lsjVEYh/FjYahZsaGmorRFmlBDTYmFIYoqNc+hVlRCzEOomBamoBUL
ldRcxDw2FlZmVkpLa1gotSBIJKbfWTx9zvt/33O+0+/e22VBQe7SeiGEFH9G
NwthXusQipuHsKdFCBvVY3C+ZQgXMBtzcEz/gLkSvmgukY/joKyUC+2ZhIXq
E+q2KEOR+ixv1ZuCxepz6iRcwWWcTgzhFApahdCUm+Aktps/wUvljTkBx7FN
XspL5I24IS4655KzL3F71Je14wY80/xfd87jfDOZ1mf0etqfivH+vyG8SG+y
maHWubzDXK25Cmd8jPfVz9BL41QUmemnnmOuL8/lAc7qj+d6280sklVaZ8mq
eKcsXzbIfBbuyG/Jyvk2XqICtZjvuVMwFXnR7jCTZ2EaZmA6Hjj3M9fhE/6Z
+8K/43v2jL/cjv/Ed8MjzK/Dbvf4JTvHZXgoS9b/bv0Dt3BI/yaPk9/ge3EO
ufIEd2yMx+pHyJI94acoxknnPeNTfNT+ErRGW7RBnflWnIj37vsOP2RHvI/R
skH2Tbeehqnxs/GsSViB1eq1WINj5ibal2N/LiaiWjbSGaMwMH43ZXftu4Kr
uIzruIb7+in66c7ozmk81r1XOvuwXm8zfTBOliTL5g7cSNYQmzxjIzag3N7O
+jn66fYuxzv1cvV7LuUVPJQ38GBez0P4p9k31tXxd4jhzk6WLUOV+jVO46t6
mN6ueMd4V3u7yio8/yVeoBKv0E3+mt+gCjWoRvd4r/je8Rbf1B84hbOd19HZ
q5zdKX726h7yGute8V2ru1iv00+O3wV177jfOoPz1CnWm/VreQvvlxXyH/0J
7p6DVdaZ8btrpg779C+Y28v/AakepMM=
          "]]},
        "0.11`"],
       Annotation[#, 0.11, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwl00tIlGEUxvE3ioxwKnNRLaJsV5mi2QUSauEmMQ1dFESbqKCMpAu0cy5m
ZURGo4mQ06YWFWnlrRJ1ZqwgsU2QWxe1atGNVGjV76PFn+ec533Oeb+Zb6bk
REvj+SUhhFksXRVCJ44Vh1AdC+FXUQjL9CfpKZzGfv5vWsA/Q8+iGTX84+Z6
+Csxz1vAkzUhPEaBemB1CHVyTepG9K0N4T6qzJXK3OF14jZqZR/hIZJmLsvE
7H2j3mZmO7aiHofQ4CzhrE59zvxN+ULeU9of3Y1nOMxrkMnYW6uOOx82t0Kf
0af1D2gFuuS6kcY8/mC5XIk9m9HqmQ9Gz8SfoTd4Hfgkc1T/mj9NX9EP9D3/
o7s+m5tFNX8fapytM7ceaf4onZHbou7BPXThr9wGZ3fVY3aV6xdpWXQXbxp7
7NuL3YjJztEDzt/JXXOeszenztMO/XU0OZ+jvfxCM9/17fpB9RA2qbPybTSF
Sl4Fdsnl9W8xhXGZCTuG3TmCIeRlRqN3TMedtZu7ipx+kL+TXjB7EZewqP/K
jyOBVqSQxC3zR5DwjkbctTH6rmhS/8Vcd/T7oin9GL/cTKW+lJZhR3Qff4A+
Rz9e4gUm5LLoNTtJq+Ti9tXjCq8v2ue+DM3LT2ESOWTxTa4t+p3ILOCnz/ij
6P9/6h9KOX3w
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwl00tIFFAUgOFbGxfRzGiQrQLBHpQLX+WrIB0jq12o9HBSp8BpU7s26aIS
iYRy06YHldYiqKGlPaiFmYJprTIoo6B8LELbhNCm79Li57/nnnPuuXNnpiR7
7sjZNSGEaSwVhfA3EcI8L2IBj9eH0MVP+EFhCCPYr2avvSmeTYXQwhe4F33o
FG/dEEJ7MoRSbuMt3MMN+nNcJe7mcu7iCv5oRiXP8jN1oyiQ+2PWUd7s7AVn
7+F74vvIYpOeJi7mNGfUnMQH5xSpnba+KTfDk/ITyKPRuU3Yh2ak8V7PLj0z
PKAno+6QOC3uRc6denDb/kP5O/Hu8uXIy0/xO9Q7qw6NZs6JD/NbruFxnsQE
XupZccZvrMR3tXfJ+nKca85BNKgZMStl3S7fFvvEa+PnNKMTGRwTD6mdj++E
n/iBLMrkruG4vno1J+IM61fW1fKvuV/cYf8uNpq1qv663BDG5Uv4DdfKnVJT
w6e5zn4tPskNi1v1fRd/i+/iXlWoRAUu2nthTh5P9Q/ybvXVcrfiu8bfmHNa
xcP8hefwGb/UfeUxTsa7cH+8G6+L78Q74+/THa7Yb+Yd4pT1IK7GHnvL6hL2
Hzk/yeftP8c2Z2/HqHUOZ9ChtkxNi74b4gNcGL+7xP//yz+CF3Kl
          "]]},
        RowBox[{"-", "0.11`"}]],
       Annotation[#, -0.11, "Tooltip"]& ], {}, {}}}], 
   {GrayLevel[0], AbsoluteThickness[3], LineBox[{{0, 0}, {1., 0}}]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->{{{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.75, 
      FormBox[
       RowBox[{"-", "0.75`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.25, 
      FormBox[
       RowBox[{"-", "0.25`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.25, 
      FormBox["0.25`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.75, 
      FormBox["0.75`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}, {1.25, 
      FormBox["1.25`", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {1.75, 
      FormBox["1.75`", TraditionalForm]}, {2., 
      FormBox["2.`", TraditionalForm]}}, {{-1.2, 
      FormBox[
       RowBox[{"-", "1.2`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.7999999999999999, 
      FormBox[
       RowBox[{"-", "0.7999999999999999`"}], 
       TraditionalForm]}, {-0.5999999999999999, 
      FormBox[
       RowBox[{"-", "0.5999999999999999`"}], 
       TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {1.0000000000000002`, 
      FormBox["1.0000000000000002`", TraditionalForm]}, {1.2, 
      FormBox["1.2`", TraditionalForm]}}, None, None},
  ImageMargins->0.,
  ImageSize->504,
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-1.1920937271229854`, 
   2.1920937271229857`}, {-1.3920937271229854`, 1.3920937271229854`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 421},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->7675931]
}, Open  ]],

Cell["\<\
Arrows for velocity field are green, equipotential lines are red, streamlines \
are blue and panel is black.  Note orthogonality of equipotential lines and \
streamlines, and streamlines parallel to velocity field.\
\>", "ExampleText",
 CellID->680409942],

Cell["\<\
Potential-flow singularities may have discontinuities in velocity, velocity \
potential and stream function across the panel.  Such discontinuities are \
called jump conditions.\
\>", "ExampleText",
 CellID->61408839],

Cell["\<\
Compute the jump conditions for the tangent-component velocity across panel.\
\>", "ExampleText",
 CellID->584360219],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icaxMinus", ",", "icbxMinus", ",", "iccxMinus"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{"icax", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"icbx", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"iccx", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icaxPlus", ",", "icbxPlus", ",", "iccxPlus"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{"icax", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"icbx", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"iccx", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icaxJump", ",", "icbxJump", ",", "iccxJump"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"icaxPlus", "-", "icaxMinus"}], ",", 
     RowBox[{"icbxPlus", "-", "icbxMinus"}], ",", 
     RowBox[{"iccxPlus", "-", "iccxMinus"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"vxJump", "=", 
  RowBox[{
   RowBox[{"a", " ", "icaxJump"}], "+", 
   RowBox[{"b", " ", "icbxJump"}], "+", 
   RowBox[{"c", " ", "iccxJump"}]}]}]}], "Input",
 CellLabel->"In[14]:=",
 CellID->98488054],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "b"}], "-", 
  RowBox[{"2", " ", "c", " ", "x"}]}]], "Output",
 ImageSize->{59, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->372159202]
}, Open  ]],

Cell[TextData[{
 "The magnitude of the jump in tangent-component velocity across the panel \
depends on the strength parameters  ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->444029989],

Cell["\<\
Compute the jump conditions for the normal-component velocity across panel.\
\>", "ExampleText",
 CellID->134318740],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icazMinus", ",", "icbzMinus", ",", "icczMinus"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{"icaz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"icbz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"iccz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icazPlus", ",", "icbzPlus", ",", "icczPlus"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{"icaz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"icbz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}], ",", 
     RowBox[{"Limit", "[", 
      RowBox[{"iccz", ",", 
       RowBox[{"z", "\[Rule]", "0"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Delta]", ">", "0"}], ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
         "}"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icazJump", ",", "icbzJump", ",", "icczJump"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"icazPlus", "-", "icazMinus"}], ",", 
     RowBox[{"icbzPlus", "-", "icbzMinus"}], ",", 
     RowBox[{"icczPlus", "-", "icczMinus"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"vzJump", "=", 
  RowBox[{
   RowBox[{"a", " ", "icazJump"}], "+", 
   RowBox[{"b", " ", "icbzJump"}], "+", 
   RowBox[{"c", " ", "icczJump"}]}]}]}], "Input",
 CellLabel->"In[15]:=",
 CellID->186471492],

Cell[BoxData["0"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->530078970]
}, Open  ]],

Cell["Normal-component velocity is continuous across the panel.", \
"ExampleText",
 CellID->531709516],

Cell["\<\
Compute the jump conditions for the velocity potential across panel.\
\>", "ExampleText",
 CellID->211831706],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Phi]aJump", ",", "ic\[Phi]bJump", ",", "ic\[Phi]cJump"}], 
    "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]a", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}], "-", 
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]a", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]b", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}], "-", 
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]b", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]c", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}], "-", 
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Phi]c", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Phi]Jump", "=", 
  RowBox[{
   RowBox[{"a", " ", "ic\[Phi]aJump"}], "+", 
   RowBox[{"b", " ", "ic\[Phi]bJump"}], "+", 
   RowBox[{"c", " ", "ic\[Phi]cJump"}]}]}]}], "Input",
 CellLabel->"In[16]:=",
 CellID->189498322],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "a"}], "-", 
  RowBox[{"b", " ", "x"}], "-", 
  RowBox[{"c", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->512090308]
}, Open  ]],

Cell["\<\
There is a jump in velocity potential across the panel that it is consistent \
with that of the tangent-component velocity.\
\>", "ExampleText",
 CellID->56731244],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"\[Phi]Jump", ",", "x"}], "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->114820653],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "b"}], "-", 
  RowBox[{"2", " ", "c", " ", "x"}]}]], "Output",
 ImageSize->{59, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->185424934]
}, Open  ]],

Cell["Properties of the stream function across the panel.", "ExampleText",
 CellID->403496840],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]aJump", ",", "ic\[Psi]bJump"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Psi]a", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}], "-", 
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Psi]a", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Psi]b", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}], "-", 
      RowBox[{"Limit", "[", 
       RowBox[{"ic\[Psi]b", ",", 
        RowBox[{"z", "\[Rule]", "0"}], ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Delta]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "\[Delta]"}]}], 
          "}"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Psi]Jump", "=", 
  RowBox[{
   RowBox[{"a", " ", "ic\[Psi]aJump"}], "+", 
   RowBox[{"b", " ", "ic\[Psi]bJump"}]}]}]}], "Input",
 CellLabel->"In[18]:=",
 CellID->102020424],

Cell[BoxData["0"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->70261956]
}, Open  ]],

Cell["Stream function is continuous across the panel.", "ExampleText",
 CellID->325279064]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Properties & Relations",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2123667759],

Cell["\<\
There is a relation between doublet density and circulation density for \
two-dimensional line singularities.\
\>", "ExampleText",
 CellID->342911820],

Cell[TextData[{
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Gamma]", "TR"], 
    RowBox[{"(", 
     StyleBox["x", "TI"], ")"}]}], "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[DifferentialD]", 
      StyleBox["\[Mu]", "TR"]}], 
     RowBox[{"\[DifferentialD]", 
      StyleBox["x", "TI"]}]]}]}]], "InlineFormula"],
 "\t\t\t\t"
}], "ExampleText",
 CellID->315517505],

Cell["\<\
Write the equivalent circulation density for a doublet panel of quadratically \
varying strength.\
\>", "ExampleText",
 CellID->218711756],

Cell[TextData[{
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Gamma]", "TR"], 
    RowBox[{"(", 
     StyleBox["x", "TI"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[DifferentialD]", 
       StyleBox["\[Mu]", "TR"]}], 
      RowBox[{"\[DifferentialD]", 
       StyleBox["x", "TI"]}]]}], "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       FractionBox["\[DifferentialD]", 
        RowBox[{"\[DifferentialD]", 
         StyleBox["x", "TI"]}]], 
       RowBox[{"(", 
        RowBox[{
         StyleBox["a", "TI"], "+", 
         RowBox[{
          StyleBox["b", "TI"], " ", 
          StyleBox["x", "TI"]}], "+", 
         RowBox[{
          StyleBox["c", "TI"], " ", 
          SuperscriptBox[
           StyleBox["x", "TI"], "2"]}]}], ")"}]}]}], "=", 
     RowBox[{
      RowBox[{"-", 
       StyleBox["b", "TI"]}], "-", 
      RowBox[{"2", 
       StyleBox["c", "TI"], " ", 
       StyleBox["x", "TI"]}]}]}]}]}]], "InlineFormula"]
}], "ExampleText",
 CellID->1713688],

Cell[TextData[{
 "A doublet panel of quadratically varying strength is equivalent to the \
superposition of a vortex panel of linearly varying strength ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    StyleBox["b", "TI"]}], "-", 
   RowBox[{"2", 
    StyleBox["c", "TI"], " ", 
    StyleBox["x", "TI"]}]}]], "InlineFormula"],
 " and point vortices of strength ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"-", "a"}], "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "+", 
   RowBox[{
    StyleBox["b", "TI"], " ", 
    StyleBox["\[Delta]", "TR"]}], "+", 
   RowBox[{
    StyleBox["c", "TI"], " ", 
    SuperscriptBox[
     StyleBox["\[Delta]", "TR"], "2"]}]}]], "InlineFormula"],
 " at panel endpoints."
}], "ExampleText",
 CellID->26256628],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"a", "+", 
      RowBox[{"b", " ", "\[Delta]"}], "+", 
      RowBox[{"c", " ", 
       RowBox[{"\[Delta]", "^", "2"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vVortexPoints", "=", 
   RowBox[{
    RowBox[{"ICVortexPoint", "[", 
     RowBox[{"rF", ",", "rP"}], "]"}], ".", "\[CapitalGamma]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icVA", ",", "icVB"}], "}"}], "=", 
   RowBox[{"ICVortexLinear", "[", 
    RowBox[{"rF", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vVortexPanel", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "icVA"}], "-", 
    RowBox[{"2", "c", " ", "icVB"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vV", "=", 
   RowBox[{"vVortexPoints", "+", "vVortexPanel"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->345799449],

Cell["\<\
The velocity influence coefficients for a doublet panel of quadratically \
varying strength was computed earlier and named ica, icb and icc.  Compute \
the velocity field for the doublet panel.\
\>", "ExampleText",
 CellID->24035249],

Cell[BoxData[
 RowBox[{
  RowBox[{"vD", "=", 
   RowBox[{
    RowBox[{"a", " ", "ica"}], "+", 
    RowBox[{"b", " ", "icb"}], "+", 
    RowBox[{"c", " ", "icc"}]}]}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->252617228],

Cell["Subtract the two velocity fields.", "ExampleText",
 CellID->366544510],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"vV", "-", "vD"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Element", "[", 
       RowBox[{"x", ",", "Reals"}], "]"}], ",", " ", 
      RowBox[{"Element", "[", 
       RowBox[{"z", ",", "Reals"}], "]"}], ",", 
      RowBox[{"\[Delta]", ">", "0"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->549191169],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "0", "}"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"{", "0", "}"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{{0}}, {{0}}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{83, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->523870384]
}, Open  ]],

Cell["\<\
Both components of the resulting velocity field are zero, showing that the \
two fields are the same.\
\>", "ExampleText",
 CellID->54964601],

Cell[TextData[{
 "Look again at the jump conditions for tangent-component velocity component \
across the doublet panel.  Note that the jump is equal to the value of the \
equivalent circulation density at the location ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " on the panel."
}], "ExampleText",
 CellID->156863266]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["ICDoubletPoint",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/ICDoubletPoint"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ICDoubletConstant",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/ICDoubletConstant"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ICDoubletLinear",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/ICDoubletLinear"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " ."
}], "SeeAlso",
 CellID->146837549]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["2.1 Introduction to Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"]], \
"Tutorials",
 CellID->513276270],

Cell[TextData[ButtonBox["2.3 Isolated Panel",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/IsolatedPanel"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "Tutorials",
 CellID->6436142]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/InfluenceCoefficients"]], "MoreAbout",
 CellID->326582296]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"ICDoubletQuadratic - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 56, 52.8102000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "ICDoubletQuadratic[r_f, r_p] computes velocity influence coefficients at \
field points r_f, due to connected doublet panels of quadratically varying \
strength whose endpoints are located by r_p. IC\\[Phi]DoubletQuadratic[r_f, \
r_p] computes velocity-potential influence coefficients at field points r_f \
due to connected doublet panels of quadratically varying strength whose \
endpoints are located by r_p. IC\\[Psi]DoubletQuadratic[r_f, r_p] computes \
stream-function influence coefficients at field points r_f due to connected \
doublet panels of quadratically varying strength whose endpoints are located \
by r_p.", "synonyms" -> {}, "title" -> "ICDoubletQuadratic", "type" -> 
    "Symbol", "uri" -> "Aerodynamics/ref/ICDoubletQuadratic"}, 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[11601, 350, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->132597713]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 284751, 6114}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[599, 21, 76, 1, 70, "SymbolColorBar"],
Cell[678, 24, 191, 5, 70, "LinkTrail"],
Cell[872, 31, 3575, 81, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4472, 116, 61, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4536, 119, 2955, 88, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[7528, 212, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->918915790],
Cell[8111, 231, 267, 8, 70, "Notes",
 CellID->1067943069],
Cell[8381, 241, 1267, 39, 70, "Notes",
 CellID->105355403],
Cell[9651, 282, 570, 14, 70, "Notes",
 CellID->396753093],
Cell[10224, 298, 1340, 47, 70, "Notes",
 CellID->1369051]
}, Closed]],
Cell[CellGroupData[{
Cell[11601, 350, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->132597713],
Cell[CellGroupData[{
Cell[12087, 367, 148, 5, 70, "ExampleSection",
 CellID->278572386],
Cell[12238, 374, 60, 1, 70, "ExampleText",
 CellID->513831186],
Cell[12301, 377, 99, 3, 70, "Input",
 CellID->66474307],
Cell[12403, 382, 538, 13, 70, "ExampleText",
 CellID->659456463],
Cell[12944, 397, 112, 3, 70, "ExampleText",
 CellID->562424937],
Cell[CellGroupData[{
Cell[13081, 404, 240, 8, 70, "Input",
 CellID->64953589],
Cell[13324, 414, 391, 13, 36, "Output",
 CellID->278074213]
}, Open  ]],
Cell[CellGroupData[{
Cell[13752, 432, 301, 10, 70, "Input",
 CellID->47353595],
Cell[14056, 444, 451, 15, 36, "Output",
 CellID->460607572]
}, Open  ]],
Cell[14522, 462, 236, 5, 70, "ExampleText",
 CellID->326501090],
Cell[14761, 469, 346, 11, 70, "Input",
 CellID->560964283],
Cell[15110, 482, 245, 7, 70, "ExampleText",
 CellID->120984796],
Cell[CellGroupData[{
Cell[15380, 493, 219, 7, 70, "Input",
 CellID->176773044],
Cell[15602, 502, 1393, 44, 62, "Output",
 CellID->65382208]
}, Open  ]],
Cell[17010, 549, 243, 7, 70, "ExampleText",
 CellID->118713566],
Cell[CellGroupData[{
Cell[17278, 560, 674, 22, 70, "Input",
 CellID->25568170],
Cell[17955, 584, 1363, 43, 67, "Output",
 CellID->795787059]
}, Open  ]],
Cell[19333, 630, 242, 7, 70, "ExampleText",
 CellID->64639684],
Cell[CellGroupData[{
Cell[19600, 641, 675, 22, 70, "Input",
 CellID->263173446],
Cell[20278, 665, 2061, 62, 115, "Output",
 CellID->27415657]
}, Open  ]],
Cell[22354, 730, 344, 13, 70, "ExampleText",
 CellID->44302699],
Cell[CellGroupData[{
Cell[22723, 747, 886, 27, 70, "Input",
 CellID->575890672],
Cell[23612, 776, 1704, 53, 115, "Output",
 CellID->144118160]
}, Open  ]],
Cell[25331, 832, 341, 13, 70, "ExampleText",
 CellID->14511646],
Cell[CellGroupData[{
Cell[25697, 849, 884, 27, 70, "Input",
 CellID->8664355],
Cell[26584, 878, 2003, 61, 115, "Output",
 CellID->689982562]
}, Open  ]],
Cell[28602, 942, 190, 4, 70, "ExampleText",
 CellID->9427774],
Cell[28795, 948, 921, 30, 70, "Input",
 CellID->258291294],
Cell[29719, 980, 967, 35, 70, "ExampleText",
 CellID->78226744],
Cell[CellGroupData[{
Cell[30711, 1019, 340, 12, 70, "Input",
 CellID->13857323],
Cell[31054, 1033, 209, 7, 36, "Output",
 CellID->95143627]
}, Open  ]],
Cell[CellGroupData[{
Cell[31300, 1045, 364, 13, 70, "Input",
 CellID->499128776],
Cell[31667, 1060, 210, 7, 36, "Output",
 CellID->104089847]
}, Open  ]],
Cell[31892, 1070, 1210, 36, 70, "ExampleText",
 CellID->78531558],
Cell[CellGroupData[{
Cell[33127, 1110, 4912, 140, 70, "Input",
 CellID->1746043248],
Cell[38042, 1252, 221729, 4050, 70, "Output",
 CellID->7675931]
}, Open  ]],
Cell[259786, 5305, 265, 5, 70, "ExampleText",
 CellID->680409942],
Cell[260054, 5312, 227, 5, 70, "ExampleText",
 CellID->61408839],
Cell[260284, 5319, 127, 3, 70, "ExampleText",
 CellID->584360219],
Cell[CellGroupData[{
Cell[260436, 5326, 3345, 94, 70, "Input",
 CellID->98488054],
Cell[263784, 5422, 232, 8, 36, "Output",
 CellID->372159202]
}, Open  ]],
Cell[264031, 5433, 299, 10, 70, "ExampleText",
 CellID->444029989],
Cell[264333, 5445, 126, 3, 70, "ExampleText",
 CellID->134318740],
Cell[CellGroupData[{
Cell[264484, 5452, 3346, 94, 70, "Input",
 CellID->186471492],
Cell[267833, 5548, 159, 5, 36, "Output",
 CellID->530078970]
}, Open  ]],
Cell[268007, 5556, 102, 2, 70, "ExampleText",
 CellID->531709516],
Cell[268112, 5560, 119, 3, 70, "ExampleText",
 CellID->211831706],
Cell[CellGroupData[{
Cell[268256, 5567, 3010, 81, 70, "Input",
 CellID->189498322],
Cell[271269, 5650, 280, 10, 36, "Output",
 CellID->512090308]
}, Open  ]],
Cell[271564, 5663, 173, 4, 70, "ExampleText",
 CellID->56731244],
Cell[CellGroupData[{
Cell[271762, 5671, 130, 4, 70, "Input",
 CellID->114820653],
Cell[271895, 5677, 232, 8, 36, "Output",
 CellID->185424934]
}, Open  ]],
Cell[272142, 5688, 94, 1, 70, "ExampleText",
 CellID->403496840],
Cell[CellGroupData[{
Cell[272261, 5693, 2082, 57, 70, "Input",
 CellID->102020424],
Cell[274346, 5752, 158, 5, 36, "Output",
 CellID->70261956]
}, Open  ]],
Cell[274519, 5760, 90, 1, 70, "ExampleText",
 CellID->325279064]
}, Open  ]],
Cell[CellGroupData[{
Cell[274646, 5766, 238, 7, 70, "ExampleSection",
 CellID->2123667759],
Cell[274887, 5775, 160, 4, 70, "ExampleText",
 CellID->342911820],
Cell[275050, 5781, 394, 16, 70, "ExampleText",
 CellID->315517505],
Cell[275447, 5799, 148, 4, 70, "ExampleText",
 CellID->218711756],
Cell[275598, 5805, 1029, 38, 70, "ExampleText",
 CellID->1713688],
Cell[276630, 5845, 775, 27, 70, "ExampleText",
 CellID->26256628],
Cell[277408, 5874, 1015, 33, 70, "Input",
 CellID->345799449],
Cell[278426, 5909, 243, 5, 70, "ExampleText",
 CellID->24035249],
Cell[278672, 5916, 226, 8, 70, "Input",
 CellID->252617228],
Cell[278901, 5926, 76, 1, 70, "ExampleText",
 CellID->366544510],
Cell[CellGroupData[{
Cell[279002, 5931, 433, 13, 70, "Input",
 CellID->549191169],
Cell[279438, 5946, 417, 14, 36, "Output",
 CellID->523870384]
}, Open  ]],
Cell[279870, 5963, 151, 4, 70, "ExampleText",
 CellID->54964601],
Cell[280024, 5969, 335, 8, 70, "ExampleText",
 CellID->156863266]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[280408, 5983, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[280828, 5997, 638, 23, 70, "SeeAlso",
 CellID->146837549]
}, Open  ]],
Cell[CellGroupData[{
Cell[281503, 6025, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[281925, 6039, 210, 5, 70, "Tutorials",
 CellID->513276270],
Cell[282138, 6046, 159, 3, 70, "Tutorials",
 CellID->341631938],
Cell[282300, 6051, 158, 3, 70, "Tutorials",
 CellID->6436142]
}, Open  ]],
Cell[CellGroupData[{
Cell[282495, 6059, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[282917, 6073, 168, 3, 70, "MoreAbout",
 CellID->326582296]
}, Open  ]],
Cell[283100, 6079, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

