(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23386,        672]
NotebookOptionsPosition[     20074,        565]
NotebookOutlinePosition[     21486,        604]
CellTagsIndexPosition[     21401,        599]
WindowTitle->NACA4DigitAirfoil - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.1 Introduction To Airfoil Geometry\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToAirfoilGeometry"], \
"\<\"1.3 Airfoils From Thickness and Camber Properties\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/\
AirfoilsFromThicknessAndCamberProperties"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilSurfacePoints\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/AirfoilSurfacePoints"], "\<\"PlotAirfoil\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/ref/PlotAirfoil"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Airfoil Geometry\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/AirfoilGeometry"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/NACA4DigitAirfoil\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/NACA4DigitAirfoil"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
NACA4DigitAirfoil.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/NACA4DigitAirfoil", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["NACA4DigitAirfoil", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["NACA4DigitAirfoil",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/NACA4DigitAirfoil"], "[", 
       RowBox[{
        StyleBox["id", "TI"], ",", 
        StyleBox["x", "TI"]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]computes a nested list of thickness and camber \
properties at a list of ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " values for the NACA airfoil identified by the four-digit \
identification number ",
     Cell[BoxData[
      StyleBox["id", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->410500287],

Cell[TextData[{
 "If the four-digit identification is written as ",
 Cell[BoxData[
  RowBox[{
   StyleBox["id", "TI"], "=", 
   StyleBox["ijkl", "TI"]}]], "InlineFormula"],
 ", then ",
 Cell[BoxData[
  StyleBox["i", "TI"]], "InlineFormula"],
 " specifies maximum camber in percent chord, ",
 Cell[BoxData[
  StyleBox["j", "TI"]], "InlineFormula"],
 " specifies location of maximum camber in tenths chord and ",
 Cell[BoxData[
  StyleBox["kl", "TI"]], "InlineFormula"],
 " specifies maximum thickness in percent chord. "
}], "Notes",
 CellID->213659944],

Cell[TextData[{
 "Output is the list ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    StyleBox["x", "TI"], ",", 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["t", "TI"]], ",", 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["t", "TI"]], ",", 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["c", "TI"]], ",", 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["c", "TI"]]}], "}"}]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    StyleBox["x", "TI"], Cell[TextData[{
     "input argument, list of ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " values"
    }], "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["t", "TI"]], Cell["list of thickness values", "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["t", "TI"]], Cell[TextData[{
     "list of angles that thickness line makes with ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " axis"
    }], "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["c", "TI"]], Cell["list of camber values", "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["c", "TI"]], Cell[TextData[{
     "list of angles that camber line makes with ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " axis"
    }], "TableText"]}
  }]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True, True, True, True, True}}}},
 CellID->401597287]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->505806668],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->113120906],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->467046585],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->145894596],

Cell[TextData[{
 "Compute nested list of thickness and camber properties for a NACA-4412 \
airfoil at the list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " values specified."
}], "ExampleText",
 CellID->63338921],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"x", ",", "zT", ",", "\[Theta]T", ",", "zC", ",", "\[Theta]C"}], 
   "}"}], "=", 
  RowBox[{"NACA4DigitAirfoil", "[", 
   RowBox[{"4412", ",", 
    RowBox[{"Range", "[", 
     RowBox[{"0", ",", "1", ",", "0.1"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->684504875],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.1`", ",", "0.2`", ",", "0.30000000000000004`", ",", "0.4`",
      ",", "0.5`", ",", "0.6000000000000001`", ",", "0.7000000000000001`", 
     ",", "0.8`", ",", "0.9`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.04682770423823951`", ",", "0.05737542990236251`", ",", 
     "0.060017266393970294`", ",", "0.05803010847647902`", ",", 
     "0.05294025200057157`", ",", "0.045633690658677804`", ",", 
     "0.036639067126780174`", ",", "0.026231179804725006`", ",", 
     "0.014477172714718477`", ",", "0.001259999999999961`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.5707963267948966`", ",", "0.16717100260042894`", ",", 
     "0.057639457820609204`", ",", 
     RowBox[{"-", "0.00007777267655939293`"}], ",", 
     RowBox[{"-", "0.037230752653313264`"}], ",", 
     RowBox[{"-", "0.06302740734581672`"}], ",", 
     RowBox[{"-", "0.08197024037979789`"}], ",", 
     RowBox[{"-", "0.09698198462109772`"}], ",", 
     RowBox[{"-", "0.11031266314794418`"}], ",", 
     RowBox[{"-", "0.12387740424635431`"}], ",", 
     RowBox[{"-", "0.13939996933185547`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.017499999999999998`", ",", "0.030000000000000002`", ",", 
     "0.0375`", ",", "0.04`", ",", "0.03888888888888888`", ",", 
     "0.03555555555555555`", ",", "0.02999999999999999`", ",", 
     "0.022222222222222216`", ",", "0.01222222222222222`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.19739555984988075`", ",", "0.14888994760949725`", ",", 
     "0.09966865249116202`", ",", "0.049958395721942744`", ",", "0.`", ",", 
     RowBox[{"-", "0.022218565326719054`"}], ",", 
     RowBox[{"-", "0.044415215246910854`"}], ",", 
     RowBox[{"-", "0.06656816377582382`"}], ",", 
     RowBox[{"-", "0.08865588186743747`"}], ",", 
     RowBox[{"-", "0.11065722117389563`"}], ",", 
     RowBox[{"-", "0.13255153229667402`"}]}], "}"}]}], "}"}]], "Output",
 ImageSize->{500, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->361744914]
}, Open  ]],

Cell["\<\
Thickness and camber properties are used as input to the function \
AirfoilSurfacePoints used to compute endpoints for straight-line panels \
specifying the discretized airfoil.\
\>", "ExampleText",
 CellID->15047424],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "zT", ",", "\[Theta]T", ",", "zC", ",", "\[Theta]C"}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotAirfoil", "[", "rP", "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->171426102],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c9rG3cax3Et+5fsv2EoPYQcSg/GCyGHspcURHJpLvYludiX5JKAsC8N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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->908817]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["AirfoilSurfacePoints",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PlotAirfoil",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PlotAirfoil"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->297243925]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->19724],

Cell[TextData[ButtonBox["1.1 Introduction To Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToAirfoilGeometry"]], "Tutorials",
 CellID->775622],

Cell[TextData[ButtonBox["1.3 Airfoils From Thickness and Camber Properties",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromThicknessAndCamberProperties"]], \
"Tutorials",
 CellID->322803794]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "MoreAbout",
 CellID->237447581]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"NACA4DigitAirfoil - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 57, 43.7754000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "NACA4DigitAirfoil[id, x] computes a nested list of thickness and camber \
properties at a list of x values for the NACA airfoil identified by the \
four-digit identification number id.", "synonyms" -> {}, "title" -> 
    "NACA4DigitAirfoil", "type" -> "Symbol", "uri" -> 
    "Aerodynamics/ref/NACA4DigitAirfoil"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[8400, 251, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->505806668]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 21258, 592}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[598, 21, 76, 1, 70, "SymbolColorBar"],
Cell[677, 24, 191, 5, 70, "LinkTrail"],
Cell[871, 31, 3370, 76, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4266, 111, 60, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4329, 114, 960, 27, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[5326, 146, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->410500287],
Cell[5909, 165, 552, 17, 70, "Notes",
 CellID->213659944],
Cell[6464, 184, 500, 20, 70, "Notes",
 CellID->1067943069],
Cell[6967, 206, 1396, 40, 70, "2ColumnTableMod",
 CellID->401597287]
}, Closed]],
Cell[CellGroupData[{
Cell[8400, 251, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->505806668],
Cell[CellGroupData[{
Cell[8886, 268, 148, 5, 70, "ExampleSection",
 CellID->113120906],
Cell[9037, 275, 132, 6, 70, "ExampleText",
 CellID->467046585],
Cell[9172, 283, 100, 3, 70, "Input",
 CellID->145894596],
Cell[9275, 288, 233, 7, 70, "ExampleText",
 CellID->63338921],
Cell[CellGroupData[{
Cell[9533, 299, 334, 10, 70, "Input",
 CellID->684504875],
Cell[9870, 311, 2153, 48, 156, "Output",
 CellID->361744914]
}, Open  ]],
Cell[12038, 362, 227, 5, 70, "ExampleText",
 CellID->15047424],
Cell[CellGroupData[{
Cell[12290, 371, 332, 9, 47, "Input",
 CellID->171426102],
Cell[12625, 382, 5003, 90, 201, "Output",
 CellID->908817]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17689, 479, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[18109, 493, 435, 15, 70, "SeeAlso",
 CellID->297243925]
}, Open  ]],
Cell[CellGroupData[{
Cell[18581, 513, 415, 12, 70, "TutorialsSection",
 CellID->19724],
Cell[18999, 527, 193, 4, 70, "Tutorials",
 CellID->775622],
Cell[19195, 533, 222, 5, 70, "Tutorials",
 CellID->322803794]
}, Open  ]],
Cell[CellGroupData[{
Cell[19454, 543, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[19876, 557, 156, 3, 70, "MoreAbout",
 CellID->237447581]
}, Open  ]],
Cell[20047, 563, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

