(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12408,        392]
NotebookOptionsPosition[      9663,        304]
NotebookOutlinePosition[     11019,        342]
CellTagsIndexPosition[     10934,        337]
WindowTitle->NumberingConvention - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.2 Airfoils From Data Files\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilFromDataFile\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/AirfoilFromDataFile"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Airfoil Geometry\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/AirfoilGeometry"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/NumberingConvention\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/NumberingConvention"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
NumberingConvention.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/NumberingConvention", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["NumberingConvention", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      ButtonBox["NumberingConvention",
       BaseStyle->"Link",
       ButtonData->"paclet:Aerodynamics/ref/NumberingConvention"]], 
      "InlineFormula"],
     " \[LineSeparator]is an option of AirfoilFromDataFile specifying the \
convention used for ordering the data in the file."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->120846788],

Cell[TextData[{
 "There are three values for the option NumberingConvention for ordering \
panels on a discretized airfoil: ",
 Cell[BoxData[
  ButtonBox["Clockwise",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/Clockwise"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["Counterclockwise",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/Counterclockwise"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["ForeToAft",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/ForeToAft"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "Clockwise numbering of panels begins at the lower-surface trailing edge and \
proceeds in a clockwise direction around the airfoil, ending at the \
upper-surface trailing edge.  This convention is used in the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " software."
}], "Notes",
 CellID->679077563],

Cell["\<\
Counterclockwise numbering of panels begins at the upper-surface trailing \
edge and proceeds in a counterclockwise direction around the airfoil, ending \
at the lower-surface trailing edge.  This convention is used for most of the \
data files available on the UIUC Airfoil Data Site.\
\>", "Notes",
 CellID->465652593],

Cell["\<\
ForeToAft numbering convention of panels begins at the upper-surface leading \
edge and proceeds aft to the trailing edge, and then lower-surface leading \
edge to trailing edge.\
\>", "Notes",
 CellID->686998075]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->63945120],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->193715005],

Cell["\<\
Examples illustrating the option NumberingConvention are in the documentation \
for the function AirfoilFromDataFile.\
\>", "ExampleText",
 CellID->321855659]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[Cell[BoxData[
 StyleBox[
  ButtonBox["AirfoilFromDataFile",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"],
  FontFamily->"Verdana"]], "InlineFormula"]], "SeeAlso",
 CellID->83182365]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["1.2 Airfoils From Data Files",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]], "Tutorials",
 CellID->341631938]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "MoreAbout",
 CellID->1665078683]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"NumberingConvention - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 57, 49.2510000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "NumberingConvention is an option of AirfoilFromDataFile specifying the \
convention used for ordering the data in the file.", "synonyms" -> {}, 
    "title" -> "NumberingConvention", "type" -> "Symbol", "uri" -> 
    "Aerodynamics/ref/NumberingConvention"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[6859, 200, 460, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->63945120]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 10792, 330}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[600, 21, 76, 1, 70, "SymbolColorBar"],
Cell[679, 24, 191, 5, 70, "LinkTrail"],
Cell[873, 31, 3098, 72, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3996, 107, 62, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4061, 110, 655, 17, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4753, 132, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->120846788],
Cell[5336, 151, 598, 19, 70, "Notes",
 CellID->1067943069],
Cell[5937, 172, 326, 8, 70, "Notes",
 CellID->679077563],
Cell[6266, 182, 330, 6, 70, "Notes",
 CellID->465652593],
Cell[6599, 190, 223, 5, 70, "Notes",
 CellID->686998075]
}, Closed]],
Cell[CellGroupData[{
Cell[6859, 200, 460, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->63945120],
Cell[CellGroupData[{
Cell[7344, 217, 148, 5, 70, "ExampleSection",
 CellID->193715005],
Cell[7495, 224, 168, 4, 70, "ExampleText",
 CellID->321855659]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7712, 234, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[8132, 248, 234, 6, 70, "SeeAlso",
 CellID->83182365]
}, Open  ]],
Cell[CellGroupData[{
Cell[8403, 259, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[8825, 273, 180, 4, 70, "Tutorials",
 CellID->341631938]
}, Open  ]],
Cell[CellGroupData[{
Cell[9042, 282, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[9464, 296, 157, 3, 70, "MoreAbout",
 CellID->1665078683]
}, Open  ]],
Cell[9636, 302, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

