(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    377394,       7670]
NotebookOptionsPosition[    365526,       7276]
NotebookOutlinePosition[    367323,       7320]
CellTagsIndexPosition[    367236,       7315]
WindowTitle->PMDoubletQuadraticDirichlet - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.1 Introduction To Panel Methods\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"], "\<\"3.2 \
Validation Example\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ValidationExample"], "\<\"3.3 \
Implementation\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/Implementation"], "\<\"3.5 Convergence \
and Timing\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ConvergenceAndTiming"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PMVortexLinearNeumann\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMVortexLinearNeumann"], \
"\<\"PMDoubletConstantDirichlet\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"], \
"\<\"ForceAndMoment\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ForceAndMoment"], \
"\<\"PlotSurfacePressureCoefficient\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PlotSurfacePressureCoefficient"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/ref/PMDoubletQuadraticDirichlet\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/PMDoubletQuadraticDirichlet"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
PMDoubletQuadraticDirichlet.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/PMDoubletQuadraticDirichlet", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["PMDoubletQuadraticDirichlet", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["PMDoubletQuadraticDirichlet",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"], 
       "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]], ",", 
        StyleBox["\[Alpha]", "TR"]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]implements a panel method for uniform flow over an \
airfoil using doublet panels of quadratically varying strength and internal \
Dirichlet boundary conditions.  Panel endpoints describing the discretized \
airfoil are located at ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     ", and the angle of attack is ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     ".  The function returns strength parameters for the doublet density \
function, the strength parameter for the wake panel, locations of collocation \
points and a list of surface speeds associated with collocation points."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->295041469],

Cell[TextData[{
 "Collections of vectors are of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "The discretized airfoil is specified by ",
 Cell[BoxData[
  StyleBox["N", "TI"]], "InlineFormula"],
 " straight-line panels, where the doublet density on each panel varies \
quadratically with distance from the beginning of each panel (use the \
clockwise numbering convention to identify the beginning of a panel).\t\t\t\t\
\t\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Mu]", "TR"], 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], ")"}]}], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["i", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SuperscriptBox[
      SubscriptBox[
       StyleBox["x", "TI"], 
       StyleBox["i", "TI"]], "2"], " "}]}]}]], "InlineFormula"],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["i", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   StyleBox["N", "TI"]}]], "InlineFormula"],
 "\t\t\t\t\tStrength parameters are denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["b", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", and the panel-local coordinate is denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["x", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 "."
}], "Notes",
 CellID->275911084],

Cell[TextData[{
 "There are three unknown strength parameters for each airfoil panel.  \
Strength parameters for the discretized airfoil are grouped as lists.\t\t\t\t\
\t\t\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["3", "TR"]], ",", "...", ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["3", "TR"]], ",", "...", ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   StyleBox["c", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["3", "TR"]], ",", "...", ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"]
}], "Notes",
 CellID->884219735],

Cell[TextData[{
 "Additionally, a constant-strength doublet panel of unknown strength ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 " extends from the trailing edge of the airfoil to a point far downstream on \
the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis.  This panel is used to satisfy the Kutta condition.  There are ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"3", 
    StyleBox["N", "TI"]}], "+", "1"}]], "InlineFormula"],
 " unknowns in this model."
}], "Notes",
 CellID->252999978],

Cell[TextData[{
 "Boundary conditions at collocation points provide ",
 Cell[BoxData[
  StyleBox["N", "TI"]], "InlineFormula"],
 " equations, continuity of the value and slope of the doublet density \
between panels (except at trailing edge) provide ",
 Cell[BoxData[
  RowBox[{"2", 
   RowBox[{"(", 
    RowBox[{
     StyleBox["N", "TI"], "-", "1"}], ")"}]}]], "InlineFormula"],
 " equations, and the Kutta condition provides 2 equations (zero circulation \
and zero circulation density at trailing edge).  The additional equation \
needed is generated by adding a point interior to the airfoil near the \
trailing edge where the boundary condition is applied.  The system of linear \
algebraic equations is solved by the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Notes",
 CellID->631099542],

Cell[TextData[{
 "Output of PMDoubletQuadraticDirichlet is 3 lists of strength parameters, ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 ", strength of the wake panel, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 ", a collection of vectors locating collocation points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 ", and a list of surface speeds just outside the airfoil near collocation \
points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1720708],

Cell[TextData[{
 "If a list of angles of attack is input instead of a single angle of attack, \
nested lists of ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " are returned."
}], "Notes",
 CellID->119343517],

Cell[TextData[{
 "The same example airfoils and computations are used in the documentation \
for ",
 ButtonBox["PMDoubletConstantDirichlet",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"],
 " and ",
 ButtonBox["PMVortexLinearNeumann",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"],
 ", providing a convenient way to compare results among the three \
panel-method functions in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 "."
}], "Notes",
 CellID->509195412],

Cell["The following option can be given:", "Notes",
 CellID->75751524],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["Epsilon",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/Epsilon"], 
    SuperscriptBox["10.", 
     RowBox[{"-", "10"}]], Cell[
    "offset collocation points to inside airfoil", "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["InterpolationOrder",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/InterpolationOrder"], "1", Cell[
    "degree of polynomial used for interpolation", "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["xWake",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/XWake"], 
    SuperscriptBox["10.", "10"], Cell[
    "large number used to locate endpoint of wake panel", "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True, True, True}}}},
 CellID->14117100]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->59031018],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->165605336],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->77267041],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->326492779],

Cell[TextData[{
 "This example uses the Eppler-205 airfoil specified by a data file located \
in the folder Airfoil Geometry.  Use ",
 Cell[BoxData[
  ButtonBox["AirfoilFromDataFile",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"]], 
  "InlineFormula"],
 " to import the data and arrange it in the form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 "."
}], "ExampleText",
 CellID->301361980],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"NumberOfVectors", "[", "rD", "]"}], ",", 
   RowBox[{"Head", "[", "rD", "]"}]}], "}"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->317289154],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61", ",", "CartesianVectors"}], "}"}]], "Output",
 ImageSize->{155, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->1561761]
}, Open  ]],

Cell["\<\
The collection of 61 vectors of the data type CartesianVectors locates \
endpoints of 60 connected panels. Generate graphics to plot the discretized \
airfoil.  This plot will be incorporated in a subsequent graphic.\
\>", "ExampleText",
 CellID->167522],

Cell[BoxData[
 RowBox[{
  RowBox[{"grD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->979024211],

Cell["Specify an angle of attack for the airfoil.", "ExampleText",
 CellID->20057380],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"6.", " ", "Degree"}]}], ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->233544807],

Cell[TextData[{
 "Solve the model.  Output consists of the lists of strength parameters ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 ", the strength of the wake panel, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 ", locations of collocation points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " and the fluid speed associated with collocation points, but just outside \
the airfoil ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 "."
}], "ExampleText",
 CellID->442126641],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->439469742],

Cell[TextData[{
 "Flow visualization provides a good plausibility check for model results.  \
The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ContourPlot can be used to plot streamlines for the flow field.  \
Specify an arbitrary field point and compute the steam function at the point \
as the superposition of the stream function for uniform flow and the stream \
function due to the collection of doublet panels describing the discretized \
airfoil and wake."
}], "ExampleText",
 CellID->10578989],

Cell["\<\
Although the strength of the wake panel is included in the output of \
PMDoubletQuadraticDirichlet, the location of the endpoint of the wake panel \
is the value of the option XWake for the function.  The default value was \
used above to solve the model.\
\>", "ExampleText",
 CellID->99130043],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xW", "=", 
  RowBox[{"XWake", "/.", 
   RowBox[{"Options", "[", 
    RowBox[{"PMDoubletQuadraticDirichlet", ",", "XWake"}], "]"}]}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->544103304],

Cell[BoxData["1.`*^10"], "Output",
 ImageSize->{54, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->402709323]
}, Open  ]],

Cell["\<\
Append the wake panel to the airfoil panels and the strength of the wake \
panel to the list of strength parameters for the airfoil panels.\
\>", "ExampleText",
 CellID->59684772],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rAll", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"{", 
      RowBox[{"xW", ",", "0."}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aAll", ",", "bAll", ",", "cAll"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{"a", ",", "aW"}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"b", ",", "0.0"}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"c", ",", "0.0"}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->509204874],

Cell[TextData[{
 "Compute the stream function at the location of an arbitrary field point ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 ".  Since the primary focus of this software is numerical computations, the \
standard form for output is a list of results.  In this case, the result is a \
list of one lengthy function of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 ".  Remove the extraneous list brackets to obtain the stream function. "
}], "ExampleText",
 CellID->342367202],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rF", "=", 
   RowBox[{"MakeCartesianVectors", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", 
      RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B", ",", "ic\[Psi]C"}], "}"}], "=", 
   RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
    RowBox[{"rF", ",", "rAll"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "aAll"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "bAll"}], "+", 
    RowBox[{"ic\[Psi]C", ".", "cAll"}]}]}], ";"}]}], "Input",
 CellLabel->"In[8]:=",
 CellID->555628545],

Cell["\<\
Generate the graphics for a streamline plot for flow over the airfoil.  Some \
experimentation with option values were made to obtain the plot below.  The \
number of contours plotted was used to avoid a streamline very near the \
airfoil, PerformanceGoal->\"Speed\" was used to obtain a contour plot in \
reasonable time, and MaxRecursion was set at a minimum value to avoid \
noticeable numerical artifacts in computed streamlines.\
\>", "ExampleText",
 CellID->260053747],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", ".5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "19"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "grD", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[9]:=",
 CellID->130177],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0nQmYztX7/79aRKpvZC3aKGUpRYXUyTftm6i0aJNIG0raKEpItKCNrFla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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{5206, 7668, 5207, 5133, 7209, 7210, 6546, 7714, 6545, 7715, 
          4953, 6868, 4952, 5768, 6149, 6148, 5519, 6090, 5520, 7685, 5521, 
          5131, 7207, 5132, 7208, 7468, 5011, 5477, 7683, 5478, 5414, 7645, 
          4944, 7054, 4945, 7712, 7713, 7646, 6525, 6523, 5117, 6524, 5832, 
          5833, 5118, 6343, 7043}]},
        RowBox[{"-", "1.44`"}]],
       Annotation[#, -1.44, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{6169, 6170, 5822, 5823, 5112, 6318, 6319, 6320, 6544, 6543, 
          4931, 5764, 5423, 7059, 7060, 7061, 7551, 7550, 4951, 7623, 5716, 
          7622, 5717, 7624, 5705, 6143, 5422, 6054, 5887, 5888, 5400, 6765, 
          5399, 7382, 4875, 6531, 6532, 6530, 6534, 6533, 5031, 6178, 6526, 
          6527, 6529, 6528, 5834, 5835, 5120, 6344, 7044}]},
        RowBox[{"-", "1.488`"}]],
       Annotation[#, -1.488, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{5896, 5794, 4940, 6452, 6453, 6451, 6536, 6535, 7195, 5119, 
          7194, 7197, 7196, 5033, 6261, 5032, 6407, 5121, 6537, 4876, 5756, 
          5401, 6340, 6341, 6342, 5891, 6822, 6823, 6447, 5081, 6258, 6259, 
          6744, 6745, 6327, 7037, 4933, 5886, 6326, 6325, 6324, 5391, 5825, 
          5824, 6505, 5111, 6504, 6507, 6506, 5025, 6400, 6402, 6401, 6508, 
          4870, 7378, 7379, 6741, 5389, 6742, 5380, 6041, 6321}]},
        RowBox[{"-", "1.536`"}]],
       Annotation[#, -1.536, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ctL1GEUxvFjCzU1L2OaeUujCwlCILWyv0DahIucERfunfEyo+NouirB
pRC0zTa1FUQCsUWrUklBkFrpP+BlETnmws8svjzvc855zvvy+3WPZl6lyyLi
PUaaIk7bI57RE/qcntHk7YgU9jsiviUifjdHbNE9fsXMzp2IbYw0RhyrFdVS
zkMyf/nXtFc/qXbE9+kvtkbM4b7zLO2mBfrYXK25hZaIN9jFDl6qzejnkUOX
+Wn6yPy8/hzq+K/uKrpjm19qi8iq3TM7STvpFH0oU9CfRRW/IXMh85N/JzOh
1mE2Q9vpOH0gk9efQTm/JvNP5gf/VmbA+6rvRtSgElW4iWXc0jv0HVvtSsu2
0Qr7yvGZ/4Kn5v6Yy9o3jZTaMDadF+xfRJn5G2iQT+rV0wN7v/sfGflxpDGG
LrnV0j7nHCYwhUlUqO/LVcsP2lNDr+z4j1W+wH8s/R/6ie6ZL7r/Ej3yT/BC
7YO39NNc6Tvj3HzON/mltm5XwhuuAfUYVGI=
          "]]},
        RowBox[{"-", "1.584`"}]],
       Annotation[#, -1.584, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TlPVGEUgOFDwrgEZsQBRFlM6ExsgE5JnIbgRIeGYNhFiLTYYUSwB3pU
WhiwcVRQwB8ADVsoKIh/QRoSlyAID8Wb96z3ft+99UMv2keKImIGv8ojem9F
/OY+3ub+mxEd4oO6iLN0xBNxqG/V6mMTu9jBWUVEtjqiqDKilYMf8uqNiDUk
5POel8cCjtUynjVaE7Eoz5l9jGHxc+zp3fW+vNo8Ts23qC3rLSHleZ3qY+qv
caz3yvw/HuM5rjc3Kq65HfHd+V+KN8zuO2/a/oD9ck5URRQja6fRTBNOnesE
P9Tu2E+KUyi2U3DXIzOfOCF/xN32v/A6f+Yuvmb+iv6y/DJ/5asX9+Re/RXe
4G/cw2XmS/XX5CWcQhI5+VP9AUw5bz/34aM7XddPowwVF/dBm/ln+oOYNv/B
/8u49wI/4EUu2L3P4/r3eIKbuYH/8x9+6zwzaBT/9M0m7R5yk/yd+nvM4q98
Wm8Kl3zzN/IV7+6WnwP41lVm
          "]]},
        RowBox[{"-", "1.6320000000000001`"}]],
       Annotation[#, -1.6320000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0DtPlFEUheGNiICxQkCuEqBVQqj4BZoh4SIkWDFxhsuMDNcOOrCBinBr
ycyAmqA9AQygQkdC+CtGgpJY+FC8WWfvvdY+5/ta07ODMyURsYaO6ohifcQe
dnH5NOK2MeIP2tVt6Nb7VRsx2BQxhLzeS7kCvTIrNEQs1ujTBfqXt9O8R12q
TtAH9Fq2hD8tN4oUxjGGHf2WuogR54bnEYdVEUnnJ80RK/Kr6EU/+tBl/xta
Ye8ALaeL7l24R+7OvmP7vuG1c17/FT1UH2ECL/gyNIt/99/B85H2P4v4RIvq
Jf/hxDzpjhHsu3fdd3yhv+UTNM9f7f4LmpMp0CLeevswDuRO7diQ28RXmRvZ
Sb0cWnlTPDV2vKO1NE2X3X1mviWzjTuZKfU0KryvTW6MbxyjyGACCbPvPD8w
g1lU6rXzvzefRBZTyKHH7CfPOeYwj8d6W+57iDKU4rPeI/rBu/4DElBPQg==

          "]]},
        RowBox[{"-", "1.68`"}]],
       Annotation[#, -1.68, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TlPlFEUxvEDlFLBsCsJFUaRhGBDgmInDQgIg1oIsYDQaALfgYDOlChU
yiZhbfgGBKNYWIAiCWolPSbsDMJvin+eszzn3Pvet+rFq46XORHxDksFEZ0l
EV0YLYropkk0JyJyyyPycFkWkUMDi/xvr5vFGCYwjmX+C77/OEMG51jgb7Ov
HSP2P6YdeMh/rH+CQyzJj2h+RcQ1VFdG/Cy0Q7xDa/XS4s/FEdvyeTt+0Fn1
j+h2hyTu2tNJu/Cb/w/SfKv8G85/ciPiGZ4ijzdtNoWB0ojvfHfE9eq39G9j
1/wvpPRa7djX/4c3yOX7Zi6l/8m9tnjmeDbpurxCb973r4mLxUVIoM5cod0J
FKDdvV5721Es6Pfb3Zd9E/SgF1Pq07hv9zDfjFo1buK5eg+a1B9gUjzkTg28
x87+IH+fndW7yP4nZ+7JV3j+0oz8TP2LNxtU2zdTI7/Hn6GN9Jxu6J/6nkfO
bEMrWpC046uzSvXLUIID+RVteV9o
          "]]},
        RowBox[{"-", "1.728`"}]],
       Annotation[#, -1.728, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0jtsjmEYxvEbPRto6/t6bkksiJ2KUoN2cGgr6hADrcmgNUkw0CqDKENr
oVWJGJSFtgy0X5XBKXFKVaoWCXFYisXg8PuGf67ncF/XfT9v3iUtbU0H50TE
G2wojHhQETGBcTzCQ9QnI/qLIvqwGJnqWosj8hIRR8oijuIYfqtbpb67POIc
1jqrQYb6Sr55tIUvl+8mfVEa8RKv8Qq17u/zj+IeUhhDndxL/BdRhbnq9vHv
xQ1UVUYM0m4ZZ7GUZ48eT/V+hue4xdfB98T6MarMV4mMRd5EM2l3ScRM2i+v
Xe0H6zZ6Xv98DMq4jiv8A/in54D7P/Qy/UvL5MzQ95hGgX2v3FP8p1Fjrln9
1tEf6W9Ef9Fa+pOup53mz1DbQU+gUK9++XXu67ERpXLfyZ/CWyyw79Gni++4
uavlTKbvrD/K2M8/Zd1Kk/ZFSKBJXbU3rcaw+wn7C3IS8r7xf0exuhKMmOMO
7qJMn170IEdNim8c0wUR2Wq3WGfRrTSHbqZ5dD5y0ZD+d8xyUs8udKIDX2Rt
cldIr8kakX+V5tsvxGd8wmHeXebcjWbsxA5Mqi03XwUa7behCcP2Q/jKO6v/
Cu9r9B2znGXjtj5DWO68wfkyutJ/cMZMzeY5pKYdbUi6T+AA1vhuKWdjGMV2
tX3p/xX/AaBwecI=
          "]]},
        RowBox[{"-", "1.776`"}]],
       Annotation[#, -1.776, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV09dvzWEcx/GnVozQQYdWSykq9ooGF221EiMkbf0BXKnRWgkiiJBYiUS0
hLaIWRdOJYTQGhEjaC/EFjT2TkisC+v1u3ifz/N89/M952TPqSypiAshpPuo
TwrhfEoInTNC6ISOGN4jhB9s3zGhewj9e4YwADkoTg+hCDd7hXBG7jwxG5ND
2JUaQl5WCDvpZPk3M0O4hRtoQTNmiG2gJxDDTPdq8afVSdI3Ky2EWrVrUKzG
Uf2KaD39Jna8WRppE6biHM4iTV4qNqqZ4F6n1l7sQ736FfIe8yfxHWE7imVs
X/mW0j3yarAbdajFSLGjkeJNo+gYpDqPjd4gp1WNGJ1iD5lmfOj+APeRxzYO
uc7v8QEHcQCL5RTzLaGH3Q9hmPtQbFe7Su9q3GG/i3u4bc59dpzPvp8W0At6
zmO/bneL5BWi3H0uZvOl2WFPpKIUJViHQvlx3jGJbjPDEH0TxQ+mCbSc7ZW4
XPVe0kH0Nd0hvkXtKtpBfjVtEl/JX4HffI3uI+hwbLDv9UiWm4JjzvXIj/bN
v9K7VmA5OqhV5k1X6ED35970ll4U+4Zeou/oKprgt5CIeGSr2weHzP5ETrM5
WvBL/Z94Ln4SXxHyUYgCxLP/oX/xG0Hvf3Sh+ac5T0eWfr2j71Tdp2o+pNnu
fVAudi4qxLcT2x5xaIs2GIRuiEdXJEa/S1SKP2neU9F+7SJHrVZ1n6n/jPZz
74tSsSW4bB+fxH7Ge3zEBySafzN/L3mbaCbdQq+Kf+nd12gX39F1mqJnzK4W
0eN0gbnnY6K4tdF/wBx58h/p+xhb2V7wzYrqRnvAWfZzWMN3gu+8cxMaUabH
FzVW88X4GlDKlh7NhwwcVP8/2/ui7g==
          "]]},
        RowBox[{"-", "1.824`"}]],
       Annotation[#, -1.824, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV02lMz3EcwPFvbg/QJNKh2YQH7q0aCvEAW8Y8yV3R5Z4nPGHSQw88dE5R
zLCp0ENHNUQ5ZmsrOTs2Q64wc8Tr/+Ddu8/3+7l+v35N3Lx79a6oEMJQP1Jj
QjgyLoQ0LkkIoRhfx4RwJzGEQ2NDKMNncWp8CF84jadw+fgQpvKIuBBGomJ0
CKO4kgfrMQgNqEep3t1m9KApNoS2pBA65b3Su4u7nW13thM70CXeyttQhBIU
o1Fus7uNfm/hTfyA8/kR5/JDzuPXclPMnoxee33CR+y3y3FzTyAbx3AUT/EI
FWrPoBzp4h92/o7D6mZ7J3MwEzGefRa3m5PgndwTx3MTJ/JdbuFO+zTzGy7U
s17+BPED90nczMl8nyv1q0IFzuIMXsg/Z4/nfp+kRwen8Dk7VWGlvQY66+EB
3M2l8pP5rft2ubf17+Cb/IxvcXTkedznqsk1+6K/Zx4/UfsYDeYO4VETfCc8
GMMRLR7GJepncqx4Fk/Dcc83I/I+eXrk3fKFyP6cIa7iTD7P87nQ/ALcMLeI
i7HK+XX3dajFNVxFkz5X7F1jz1pUY4+6BWoyI9+W+z7PtlfuN2501oBF+sXZ
MYtf2vmf7yHKM4fIuxUf9E2U4hAS9Tul70mUidM5LTLP3Da9lqtdhqVoNWOf
nr/MXaDXQsx3Pg9z0aL3Tz4rr1p9JddwgRmX9Czky7yF89TmI15+Apr1bNX7
gPzFWIIs9Mvtc/4VdfbJxgrkiHPs+1tdovgPrxWvwXsz3uG0+g/ci3XOM8z5
Ky9Jfj9vcLY+8n/i/iPK5f8HqvCkOA==
          "]]},
        RowBox[{"-", "1.872`"}]],
       Annotation[#, -1.872, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1FdszmEUx/FHSIzgQgetESS4log9orVCzCChhLSJmdSFETNxgZDUqhnq
SkWHKhUSW1EiEUVLeVUV0RqJNiVGzc//4tfvc875nXOe/v/v+/ZKXzEjs0UI
YaI/OZ1CKE4MoWf3EOYkhJCVHMJc3NnZme52DeEOlVFvnl50oEsI+2lMUgip
dEhPOQ2IC6FavUH/Z2qUG2f2ZxyLDTjQzEE0Ub3YzDN0lgbLTdF7UX4yXsKp
2GTmKmwUL+VbRstpN/8xd8ihr+Z+iQ9hj9wkvlpxkn3v1Up4z9Ertatq08y6
htMxXs8V53Y9QriMNTxr7XtLjepv8LD8IXqgdhCrzQ5mP8cXFKOufM/Vx+gZ
SyVyp3lXONdhJr7DVfpW0gXxdFzULYTFtMw9Wrrrckw3J4Pm8aRFz0FuLs88
nIPzMQ03q/W096+5Hd3/H/6iP9RB/Bsf2RHzfqt4r4tfm1tL6/Qlq1XaWUF1
4lZmDvYu3zsn0lb5en2nnDvId6Q+cnfMG+Jchjf9n7eolF6afxur8YMdO3i3
U424LHo/1EQFZk6yOz+aTYX0jWc9bqQNNNPOTTgL93p3e+iT+32kTXof8ndW
e2JPnnM+dRcXYgE9le8ifhTF+AxfmNfNOaZWLG7jGZ3B1XJ55q/BGvfNdp7t
fI9vpJ5R0T3dexdvEdar3fQOYvJJzpl8peJj7nYLj2AOHaUKzyjmvvt4+2I2
9sMveppoi/5aapB/hQlqce6ViM32vZFfENV5F2JfM9vZ0Qfb4g/8SfnuXECF
dIq3iCbob1YbH30usNJdas19TSVybe05Gz2X6F2ZXUSV9t3neyrfXr0Kc6m1
83F8zJvAd5DKeU/wPpYfbW8KpVIdTz1VyqfzVGAGJuupkk+NnqdcChZhvPt0
Mj8Oy81bFH0Hou8FZuBobOLbQsP1bMUR+F3+Fw71TprxuDiLPxfrfT5TMNu+
H3gDF5u/hH6Kh+npb+dJ55168vBD9FuG+3j307bo94b/vDuViv8DFsXdjQ==

          "]]},
        RowBox[{"-", "1.92`"}]],
       Annotation[#, -1.92, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0k1Mz3EcwPFvHDyOraInDjabqWRjhVM2G0KLsDng0MJBMQ7c6uThJPJU
UhtWDthCKclw8FBbyVIXWaj+PWmT2bgwr9/hvff38/D9fL+/7/+/rOh44bG4
EMIITi8KYXtSCA2JIUynhrAnOYS9SJNbnxbCOuwW16uPpYRwSn+Mb4t3yu9C
IVL15+jNRoH4lvqIvg36+8ztR598jXpRQghZ+g/q2b+EcQAl8j/kS3l4aQgL
F4dwEh/iQxjgHj7Bm1CBC6jDqNnpHOMMHuN65zZEZ5vTZd8n+W7uF9+V/+ic
Xhxx1ky1ezyDD3OPfK2eOixwx5tcg/fyh9Tj9F3hmFlX+Qx+qZ3lHLWf0Xfy
+Wim9Tm+IV5uXcbx4r/6E7hcvEK+3brP/VKidzO3UvwMU9ZtfEftEY+LH/NF
NGNC3MQv1Vv5u/gpX0ILJsVP+Ll6I4+JH3IFhvwWw/iCb/iKTn2v3aGDe/UW
Wa911zVIjM4Rv0CpuElPsfvno0R8FLlqGZyJffLpvBJtet/6Xd7hDTrRgUHv
OqGe7+wd0V3Exc7daJ2LAWf+41b5z/paeJb3qjT7MpKwJXoT+c3RW/BWnrZv
W/Tt4jxu5gH7H5h1H0NmJNs76A55atlqJe4+xV1y3ViNSbla/+MC/88s8YR4
FY/zK7lGM+bwXMzGfMxDtfN/O6OK/3C1GVWY9g7t6jH7M80Z5XJnluG6vmv4
DxvKl5A=
          "]]},
        RowBox[{"-", "1.968`"}]],
       Annotation[#, -1.968, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UtsjFEUwPFjJxGvdvqYPiSMLgg7VNHEou1OE4OEdlfqEUwTwopF1aOP
FVqJRkosa2dDZ9BF67FSWqFsCFOPpNqkxdpvFv/87z33nHPPd7+1bR3pzJKI
yKKrJOJoaUQ7Rssi/iUirvNuzicj7nFfVcRd7uFevMQLZCoj6ioi/jqr5T+8
nZPqm8sj9uCLHoPi3fKvYUjsgpyP1p8K/fToQ3NxxH11PdbdmHaWMtsd65PO
2u1P6HOEj/MWuU3OGtGAcbEhZ+d8x3kM2F+xv8VX+QZf5n6+xDe5iyfcMV4U
MVltTuvbyJovh0cYwWPk5eyQvxN1qMcuPDPbjPufcs2aiHLrJJ7InzZHjsvs
U777gT7DOODun2p/YQY/8L3wvWZodf836038lTdznvepOcj7OaFfCUrx3h0f
kBZfVL+Xj6lJm+ez/VL7TutXchc5occp69OotV9nv159wuw1nMIbZ28xiTnv
fFafrfK24bXYBJr813n1jVwsXoSHaqfwDofRhln1g/JWOV+N5ViJFVjwNlnO
m3Gk8BacK7wD/1ab8R393quDB/i5PnPunkeVeyuxUeyiOzZwi/ghzMo/Y+Yx
sWF9lnn7/x9Zc7E=
          "]]},
        RowBox[{"-", "2.016`"}]],
       Annotation[#, -2.016, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtPVGEQgOExJJoAmiByUxbdgCQCDeEWuRggIlctpKE2oaFACdBRAi0l
u4JG/AEqWIuEEIFSG6VEG0BdSYwS0IKH4s17ZuabOfOdk3z0+OHouYhII5Mf
0V4S0YkOrIubiiOaPbegDa04uBzxpjRiGa+xcyVihT/zVFHE0LWIV+Iv4rqy
iO/iDbN+8E8UmVGIarn9woikc/3O38cAPsjXJyLGCvTzE844V+Hcmvoev+P3
WMVv+3Sbd2LXfzjGghn/edj7UpwxZ1Mu4Vy7uAPnzSnXf4EreFG9VL7HmVv2
rkYVDuVruFe+krfEh+Zun30fcZn8nHhQ/FH/JyTQJ1+i/tZ+eer94gFcRxI3
UKvnl7vdtMMDO1Ryq/uGvhZ+oTdHPU+cy9mYdZdLPM0XeYZHzPmrv0vPH77H
R3yXm9QnuIHHuZGXzH3Jt/UvcTOf+HfHmLdDN7dxL6fPvjenuIez3OWr3RfE
u7zI3/gO96k/51V+xumrEU+RwqR3nwLMB1fV
          "]]},
        RowBox[{"-", "2.064`"}]],
       Annotation[#, -2.064, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0DtMlFEQxfGBQiJ2PNwVhIAk1MBuT6KIihRI6yuhoFRCJyKPWAny2MZk
Vy2FWFAQsIFOKA0JoOCjsARZhAaBwhB+W/xzvpl75sz9bn3P0+4nRRGRQaIi
InU1IknTdK88oqs64h4afNfrZWoiJjGFCdRdjpimO5UR+UTELp1T/6F99Ius
D+ZmMYNa9bsrEReTEaX4aD5bFvG/KmJFf8T5ZzpKL8krRd75gtmfeo18v+iu
uR08cLf7yMi6wFOCv+7aKmNCb1H9CQ95HuEx9szlcU3Omjvm5M+r39MB3ud4
hhcYxBjfurzXdEg9TptqI4pkFWOzsEtvg07ScncuQ5v9N3AdU/pfnfd7l290
Wn1TP2X+yN4K/n/0ll47tnm28Mb/fqc/cFs/zX/MV8l/QvcL71X4Zzqm9wot
/j/Lm8MddOCUN+GsWV4LmpBGqgB/r9y3fMOyRjCK33be1etE0uw4Duw5o4d0
lWcFy95wCS+94TmXW1qh
          "]]},
        RowBox[{"-", "2.112`"}]],
       Annotation[#, -2.112, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtI1mEUgPHj4BC4qHnXTxTM8rpoaoZTNigoOFSE4aVGS7HLmpkp6Neg
LU6uDgaiQYaXKRuCdHA071ugQ5pz/Roenvdc3nP+7/eV9A92PUuJiFmk5Ubc
yYmYvhqxxuu4i1bcltvPizjALvbwE3MZEecFERf4jUv8QW1mxLh7NfxE/Bhn
WREfsyMW8E5t2d0+51H5MfFbNNuzZe42fqAyP6ICXwojTtR69fdgVe+xeJRv
8Xe9E/xK3zi/5LpExJHzinOv/TfMORSX8wFf53T3m7y7EZtmvND7jT+IZ1Dl
+0f0vMG+O5/V9/jMt6fJnXK12VV4rjaMmqKIAW9qMefU/SlzkiiWfyD/Ve8m
lty/L07KF3vTFCd4HkNqi2Y/dH6tZ0W8Ze8g1/MVrjRz2Y6ndn7iSXGhNydQ
hBK7y8ws5U77OvDLOVV/hxnnap3cLXfPnkdcZ1cD/qo1cp9cmJuC93pumpvk
Hd92LHeCIxziGhL//3eewIbfdx3t9rbhH5fcW9c=
          "]]},
        RowBox[{"-", "2.16`"}]],
       Annotation[#, -2.16, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNz7kuhGEUh/HjCsjY10QjIcGYgsRacAVDNCpTaYwgllIsQUVIuAVboUOp
QUhwDQYFgsTSWX7Fk+d9z/c/5z1fbWYsnc2LiElsJSK+KiJGiiNyJRF3GKiM
6Ecau1URO2goi6jHaWFEojxiXc8a7uUfcFMUsSd3zfv8aO623KeeL3xgW+83
D5p7IHMrm6qJyDpPOY/xNB/pa+Xx0ogJzNltyBuHZk667zg/qY1XRzzzjNo0
6swv11uBMvza7wfhvT8+V5s394wX+ILbuFfvEh/zIifNbUEzRs2/lFtRb7d7
k1nNyJftcu9EB1Z9v5Lb9M4Gbpxv0e1bUv7V7gV63jjl3oJZ/zuDlHde/FOj
/TPqw8iZ16P3Xb5E3zJW0Cd3It/PR5zmY07q/Qf85Egv
          "]]},
        RowBox[{"-", "2.208`"}]],
       Annotation[#, -2.208, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz7kuBGAUhuHjAijs+z5CLINEQoVWKREFo9BpCEbMmIS4AUulUNONRIKY
SlyCtbNViNrUHsWb7yzfOf9/2hZXppdLImIOx+UR+eqIM7RWRkw1RrTQrqaI
VFVEd0XEq9obXvCBd/TqZXiy2MSvPFcTcW7fgl278i15FmP23dZF7NBVs9s0
2RyRqI94Fqf451HgfZJn6Cgd4SkTD9dG3JjPqRW9dSCfbYjoNP+o1k4faAct
5f/2hyGeQexjDwl3pPU2cM+b9487+sU7qfZJe+xM8ha8dY1D+5bccSVO8/bp
9WMA42YmsK5+ob9GL2nRzJFdJ+45xY93Z/7/Sv8A8rE25g==
          "]]},
        RowBox[{"-", "2.2560000000000002`"}]],
       Annotation[#, -2.2560000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{5476, 5472, 7682, 5473, 5471, 7464, 5475, 7463, 5474, 4995, 
          6882, 5665, 6881, 5666, 6088, 6087, 5516, 7684, 5517, 5418, 5741, 
          5740, 6139, 5417, 6053, 5200, 5928, 6352, 6351, 5416, 6782, 5415, 
          6592, 5245, 6196, 6197, 6198, 5954, 6955, 6954, 6195, 5244, 7469, 
          5483, 6905, 6907, 6906, 7726, 5241, 7280, 5242, 6590, 5239, 6589, 
          5240, 6586, 6588, 6587, 4760, 6903, 6904, 6419, 6421, 6420, 4903, 
          5862, 6068, 5482}]},
        RowBox[{"-", "2.3040000000000003`"}]],
       Annotation[#, -2.3040000000000003`, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdk30wG3YYx5lT61Adxm3OMK509dbSpdrVd5ptZah5K/Uy0izGKMtWi3dV
VFALahKltqxa6qWaeK3L/NRwipY2Y7KezVuuWpWE9Mpym0629Z89d889z5/P
53Pfx+pkUgDjJQ0NjcNbrZ7/lgIvNhUtTxG7IEecebDvzuTnvUwz/VmHUjkM
pp67jXEpxEYmeMrXlSPd+PrRubQgsr3Igi4Lk8H3ARHer/uUNJ7197p0ZgWD
nL0sB6sk0npkxK8x8wkiSTQlIfw0KTCR3F0PXMZ0p12bx65Ucqln7UStzmM0
t0xHfe2XRSoklhfO1yxhqOgNn58UOcSe8fp8qOlDmDjnhLOUeeTOIyFvOkOK
Ff1e56q32WQgI1Xz2b0FVAr1mM3FxWT5+LiX3GweEc0Nt1z1OGShP6fUPnoW
y8V5nTXeZWSHUqo9fXQGtASrYY/tF4iiaDZ7j0SCxLj9W2gVxIJ0PRrPmoKp
aGmPp0slKZQPNJtSxVg9I9wdksIlB60/Ss91moBdd6h/bhyP3AspjbG/OAIp
jT/lKucRup3tr8GegwjIClgRr/IIoySN/SGrD1X6+24Pn+CR1d0aQy6x3Vg0
2FabbsAlV2kbbJ6hAIbroaoJ7W9JtiikxWfjCjT3dyS0OJUTo2pOPHWQh3Nh
YtGCcQlZzK290ziej/c+N7JdP5RHclWVbpEmdHT2esaO3jxNVmMX2B0bT92d
Ei9rirSPoPXlza5y83hoHBzjmkZnw/47aeoXrHPwYQZLWB+UvuCC6v1am0iX
KpgUuJCLWnX4R58FH94WPd/3Mq7jK+8mKybnCn4xXPMYj+mA5f2kKJ2717C4
/s5fEo4ITEsbXV5fC7Sox7vSjvWDflLJPNVwA6ydhwKXREPo2xX/M9VViDUd
rfEfC0aRXcfWa0ppA4X5JaH6T8CTZJof+KwdiT5+ofOaYoS4jypnZe1w+SOm
2kw8Ca98Qb6lTgeSFPm3g25Nw7zCWfystR2r9LFI7+EHKI/YpKpW2sDOV4v6
DZEf/76vflSInr2HaYU6cxAMaI1cjRCAEnReSeHPQ2/4E/lmSitozAPKJrdF
DAgct4w1o61DLVIKo+5kil9yA9THO/o/xLvrbzq6yerA72Uc4w4uoSGgTScs
hw/2q/2XS6wfQ53OoIIa5M7cOOUfswxfh/CtyFVCUT/kTSl8gg21JuMy1Pxg
ffPPghWUVc9ty8hiYzh9ciQvSobkbzQlyzPZKHuFruuxQw7thmuM+Ewm5riq
1MAyOerfem3I5GzEf3xySG0n3c05bvj///4NQNjiEA==
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504,
  PlotRange->{{-0.5, 1.5}, {-0.4, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 224},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->22126918]
}, Open  ]],

Cell["\<\
Note in the streamline plot that the flow appears to leave the trailing edge \
smoothly, satisfying the Kutta condition.  There are no streamlines inside \
the airfoil indicating that the computed velocity there is zero, as it should \
be.\
\>", "ExampleText",
 CellID->259606597],

Cell["\<\
The function ForceAndMoment computes panel contributions to lift coefficient \
and pitching-moment coefficient (about the leading edge) and sums these \
contributions to obtain airfoil coefficients, which are displayed.\
\>", "ExampleText",
 CellID->139902411],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "a", ",", "b", ",", "c", ",", "rD", ",", 
     "\[Alpha]", ",", "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[10]:=",
 CellID->180266037],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9894268143363187`", ",", 
   RowBox[{"-", "0.3104568232290057`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->21026143]
}, Open  ]],

Cell["\<\
Note that the wake panel represents the starting vortex which should be equal \
and opposite to the circulation around the airfoil.  For the dimensionless \
formulation of the problem, lift coefficient is just twice the circulation.\
\>", "ExampleText",
 CellID->527976917],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"2", "aW"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->123809147],

Cell[BoxData[
 RowBox[{"-", "0.9895115971013265`"}]], "Output",
 ImageSize->{68, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->138380640]
}, Open  ]],

Cell["\<\
Surface pressure coefficient at collocation points is computed from surface \
speeds using Bernouilli's equation.\
\>", "ExampleText",
 CellID->753558053],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->435840926],

Cell["\<\
The function PlotSurfacePressureCoefficient provides the conventional plot of \
surface pressure coefficient versus the chordwise location on the airfoil.  \
It is also conventional to insert the airfoil shape in the graphic.\
\>", "ExampleText",
 CellID->139054009],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"gCp", "=", 
  RowBox[{"PlotSurfacePressureCoefficient", "[", 
   RowBox[{"xC", ",", "cp", ",", "rD", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}]}]}], "Input",
 CellLabel->"In[13]:=",
 CellID->671472236],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U+IJNd9B/AJufmSP6dcEuIEcgkkx+AJIQdjiCKQrICjQOJDVtBIxLGw
bF8kEiziSIfYSWOTsBuMF/THxtIe1rHcRmRlhAXGCyYLQgsiIzAKhNUhi0HG
IQLD5M28nVJt/5vqququfr/6fCjtamdnu6t6qr71+r3fe/3BC4/+yYWfPzg4
+OOfOzj4v/Tfyf8fAwAAADAKs8nBicPp0dB7AkD/jqbT2cnvKe0lPUBks4mc
BwhsNpnM6n8+AGAgHeP8rsc6a8Kf9d7clfOdnuj4+PoP/usP/+BS3l659lbH
RwMYie7xu+hoenia97NpreOm+xM9+blrVc5/9jOz8/8BAFvI+XoDv95z0/2J
Xnzh9Srnn3/uRsdHAxiJbbTnt/RE7733sxTvj37yW5cuXv/JT947Pu3JufzV
H+rDAVijoJyfo7seoIlyc153PUAT5ea87nqAJsrN+cXuegAWlZvzADQh5wFi
k/MAscl5gNiC5byZUwBzIuW8mVMAiyLlvJlTAIsi5byZUwCLIuW8mVMAiyLl
PACL5DxAbHIeIDY5DxCbnAeIbQw5b5IsMGbhc94kWWDkwue8SbLAyIXPeZNk
gZELn/MmyQIjFz7nAUZOzgPEJucBYpPzALHJeYDY5LzZskBsI895s2WB8Eae
82bLAuGNPOfNlgXCG3nOmy0LhDfynAcIr5ScVxUD0E4ROa8qBqC1InJ+2KoY
byWAohWR8wNWxXgrAZSuiJwfsCpGgT1QuiJyfkAK7IHSyfn1FNgDpZPzALHJ
eYDY5DxAbHK+L8rsgf0k53uhzB7YW3K+F8rsgb0l53uhzB7YW3K+F8rsgb0l
5wFik/O7pzIH2CU5v2Mqc4Adk/M7pjIH2DE5v2Mqc4Adk/M7pjIH2DE5DxCb
nN9zinOAjuT8PlOcA3Qn5/eZ4hygOzm/zxTnAN3J+X2mOAfoTs4HY9wWmCPn
IzFuCyyS85EYtwUWyflIjNsCi+R8JMZtgUVynmOjtxCanMfoLcQm5zF6C7HJ
eYzeQmxyHqO3EJucB4hNztOaKh0ogpynHVU6UAo5TzuqdKAUcp52VOlAKeQ8
7ajSgVLIeYDY5DxAbHIeIDY5z+4pvIddkvPsmMJ72LEtxO/R9DA96mSuolrO
kym8hx3bTvymqJfzLKfwHnZMzrNjCu9hx+Q8QGxd43c2Oag7nB6dfHV5ztd1
elIAGtOeB4htG/F7p41/p22/xScC4Fzq5wFik/OUxVxa2JScpyDm0kILcp6C
mEsLLch5CmIuLbQg5ymIubTQgpwHiE3OA8Qm5wFik/MAscl5gNjkPKNiOi0j
JOcZD9NpGSc5z3iYTss4yXnGw3RaxknOMx6m0zJOch4gNjkPEJucB4hNzgPE
JucBYpPzALHJeWjOsgmUSM5DQ5ZNoFByHhqybAKFkvPQkGUTKJSch4Ysm0Ch
5DxAbHIeIDY5DxCbnAeITc4DxCbnYWdMp2UQch52w3RahiLnYTdMp2Uoch52
w3RahiLnYTdMp2Uoch4gNjkPEJucB4hNzgPEJucBYpPzUArTaWlHzkMRTKel
NTkPRTCdltZq8TubHJw6nB7NptOj7T0RsDHTaWntTvweTQ9P8v347P8nvTcX
5Dx0YTotrZ3Gb0r2w1oD/mg66b05L+cBhnESv3Mxv70nAmDnTuJ3NtlCP82y
JwKGoyxztE7jNwX9+w36Wq/NycjsZDo9PDjo3t6X8zAgZZljVhuHPajKbaq/
PQn6kz/PJp0b/HIeBqQsc8zWxu9skkP/7PetPRHDu3Xr3Rv/8d/Vlpp86T3+
qu3LX/r+o5/81kZbyplVj/ba935Uf+q83XzjnaFfklCUZY7Zuvi904rvp/te
zu9eFd3puk5xeuni9XrwPnD/s9WFn7YHP/a1hrGcthQai8m8fltz43ji8ZcX
7wuPPHy12rePfPgr1ddTW7T6h+m43BcaUpY5ZmvitzZvartPRDtVjKfUzbmX
k/ChC1fmojtd2nOpmLbbt3869BE0lTKq2u08mJi3+p2rfl9It7D8xfS+I39n
/rdvv/3joQ8FBrA6fnvok2/2RJwjp9xr3/tR1WHy8T//Rj3G59Ls6D//Z+hd
Hli6hS29A+bXLW3pVpi/kv/2m1dv5u/X0CWkFfGb2/J9VtXL+SZuvvFOSpsq
mnIbNfdaPPH4y1WHiXZpR+lWmIM9v9Rf/MJrOfbvvedyesHTr/W7QHoHUdbb
ny1Rllku65gNKMV1bqV/9jOz3NRMwV7Fiz7noaRWff0ukH461XBG7hGqxgjy
LWAM7wKUZRZNzu9MTo/nn7vx9FOvpqxI10vK9txKTxeRJnoRco9QNUaQbwH5
XUDuRqu/7YrUgaYss2hyfntu3Xo3tXzyWGFqB+begPTH78zeTCEw9N7Rszws
Xh9GyQPi+eee65fyQECJ93RlmUWT8z3KA6a5mZeu7tTAS1d3rnLRuzta+X1c
LivNAwG5jy53AZWS/8oyiybnO0rvzVP7PF2/qfGWB0xzP4xrgfVyF9Bi/uf+
n/SVagZZytihd5ayyfkWbr7xTq6HScGe4v3pp15N7bFInbEMKPf/pDOqmkGW
TrN6zVVu/KdvG3pPN6BWZ1hyvqF0WaXrK11o995z+ZGHr+Z6GA0tdqM+hyI3
/lOzv5oIkOfB7W2Bllqdwcn5NdLFlU7RL3/p++kNdbqs0vWVLjQdMuyPPBEg
r2tRTbjIPf+55yedwIOHv1qdwcn5RW+//eMXX3g9nZDpzXL6Nf3/Pg+QwZzc
8597ftIJPHj4q9UZnJyvpDBPl0BquqctteHTtTD0HkFvBgx/tTqDk/O3br2b
TsIc7+ls13RnPJaGfy74yYsmBZvtNVqjzfkU7+nt5EMXrqSzOjUzxDtkueAn
LwFXzfZKraDcIM/zQXZzvajS6cvYcj69hfzO7M0c76nFoq0CTaRgzwO+eX53
LvXP4V+t89BvqacqnR6NJ+fTSZhO0Qfuf/bpp14V79BdDv9qnYd6qWdV5996
JrgqnR6NIefTyZbOmXQSptaIYSDYqlzqWdX553U+H3n4al7kMy/u1OQyVKXT
o8A5n7to8ltL7/tgQDffeCd3tufFWvMKn9UM3xz+c7MOW1fp6NVfFDXnU2Mg
NeDTSWWAFfZTNcM3h3+1vEP6Y7W2z6aPqVd/qXg5n06PXABviUgoS17eITXv
q7V95or8z63z1Ku/VKScTydAfieoDQ9h1Iv8F+s850p99OovFSPn05mQ7uPp
BPD5HTAGVZ1nvdTnkYevfvqxbz/2qZc+/hff+LsnX7l9+3+H3s19ESDnX7n2
Vrq564uDkZsb7V3s8F+6sMMYxm2Lzvn33vtZ+gmmlrxqSWDRXId/fWGH3Ofz
9edvjGHcttycT7fmhy5cST/Bfh8WiC0v7JD7fO6/75mznP/Xj973TG7Yx+v+
LTTn04043ZGNtwJd1MZtL/7957+bcv7Jz12r1/lU67kVnTYl5nxqwz/91Ks+
ywnoaM1srFznU63ndufT2z/6zIW/vFKt6lBKj3FxOZ/eVaUbbi8PBdBQfQbW
3/7Nv+dVHe6953J9qDd9z36unVVWzqeX8YnHX9aSB3Zs1Qys+lBv+nou70+/
1tfzGTyytpHzs0l61IPD6VG/T5RulI88fHXwVwwYoY1mYKWwmqvwzL39ly5e
H6TDp/+cTyk/mZ3+flfSd3+idD8NXPgE7LOG66qtqsbPvf3pEaoOn7Tlcd48
pXeryd97zh9NDyf5Pc3dQd/xidKr9ODHvqYxD+ytjVZRS8Gex3nzlN568ucP
7eqxq7/3nD9rzi/J+S5+7Vf/6IO//kDHBwHYHx/4wK/84i/8Vt5++Zd++zd/
409/93c+/fsf+qfqZpG2D/3eP6Qvdn+ufnN+S+35dGt76MKVbrsG0LM8Dpu3
6T++VuXzY5966fJXf5i3vPZm3vIHr+Qtr8aWtzxuW9/yGG7eOu5k7zm/vf55
y5QBrdUDub69cu2tuYDNW54wNbd95MNfqTe205brKvP215/4tz978Ov33/fM
J/7qm5cuXq8eKq+ln7dB1kvvP+e3XG/zxS+8ZmF5CGlpDleLEi9uuZplccuf
V7UmkOtbyvOlD54XQJjbOg4RDrVm2jZyfqtPlH7i6c1OulcWPQ0ZipPHDRe3
XDq+uOXCksUtV5gv3ZZ+f/UhI4tbvWejvu3nNNUBP+uquJw/Pj3fnn/uRkr7
/LlR+zkBDXZvVXt4aUjmeT1Lc3VpCOdqkMUtTwVd3HKh+OI22gt2wM+6KjHn
K6lJ/+ILr6fmwQP3P5tOtlyGqvaSfZZSbjH68tv55v0Si73E69vDq3I+Pe/S
KB76RYppwM+6KjrnK7dv/zS9g8tlqOkSSO38dOvMNahin43kRWubR/Gli9eX
Rmte9mpxS82SxW9erLVY3y/hrC5Rw5lW2xAj5+ekdv4r197KF2Bu+eT6pTzg
kvPfxVKiTcfp8q2/eddE9SEUzaO4Op3mNuNH7I+QOb8of5pkLqCqGmDVm9+l
PY3VBVt9xDCL8gu7abfwXEVxw06JFuN0uStP1wR7btt1OCPJ+fWWVg5UGZI/
YvjcAq16ueyabU3ytNvy+tibbqsG4JqXRixO9GjeLXz57opinRKM2Q7qcOR8
C0snXKT3700Cdk1PQrstf97NptuqATilEbBjO6jDkfNAGJt2gGz0/VvqXdlB
HY6cB7akSzC2+LebdoBs9P0Nv7nFbu+gDkfOA6t0DOrW3c7t/u2mHSAbfX+T
bx5wxut6ch72U/dego6P0DG1unQ7t/u3m3aAbPT9Tb55wBmv68l56F0vEd2x
Zdj9ETqmVpdu53b/dtMOkI2+v8k3n7vbzU+MfscC5DzU7UNEH/fRMuz+CB3H
B7t0Ow84dbSL9bvd/MTovf9HzhNGmIg+7qMGo/sjFBq2e6v5idF7/4+cZx+I
6DndM1ZK75vmJ0bvlZZynu6GHe/LIkU0ITU/MXo/heQ8x8OVz2UimpFbcwH2
MiAr5xmwfC4T0YzZmguwrwFZOR9Ju1v/gOVzmYhmzNZcgH0NyMr5MFrf+gcs
nwOWXoC5zfbU57/by4CsnA+j9a1fUMOAFi/Aeput2r790putn0LO76F23S8D
fvok0KN6m02/TUitu180yyGGeptNv01Ie7sUErAbVZvtX/75B/mz7To23uT8
tm3aCaP7BeiXnN+qFp0wul+Afsn5rdIJAwxOzm+VThhgcHK+heZd7jphgMHJ
+U3t7UdAAiwl5zelyx0oi5zflC53oCxyflO63IGyyPm6fj9jHWAfyPmKAVYg
JDlfMcAKhCTnKwZYgZDkfMUAKxCSnAeITc4DxCbnAWIbVc4rjwdGaDw5rzwe
GKfx5LzyeGCcxpPzyuOBcRpPziuPB8ZpPDkPME5yHiA2OQ8Qm5wHiE3OA8Qm
5wFiKyXnmy9ZYHEDgLoicr75kgUWNwCYU0TON1+ywOIGAHOKyPnmSxZY3ABg
ThE533zJAosbAMwpIucBaE3OA8Qm5wFik/MAscl5gNjkPEBsch4gNjkPEJuc
B4hNzgPEVnTOW4IY4Fzl5rwliAGaKDfnLUEM0ES5OW8JYoAmys15SxADNFFu
zgPQhJwHiE3OA8Qm5wFik/MAscl5gNjkPEBsch4gNjkPEJucB4htC/F7ND1M
jzqZW1mslyeyEDHAprbTzE5R33/OW4gYoIWCct5CxAAtFJTzFiIGaGGXOV/X
4kEtRAzQQkHteQBa2Eb8zianTfbD6dGWnwiAc6mfB4hNzgPEJucBYpPzALHJ
eYDY5DxAbHIeIDY5DxCbnAeITc4DxCbnAWIrJefdJkb+Cjj8oXdhSCM//ONy
8rOU/bQD+8nhD70LQxr88EvfgfHk/LA7YP+L3v+RH/7gO2D/B9+B3TxR6S+U
/S96/0d++IPvgP0ffAeaPxEAg9hNzgMAAAAAAHsuf5L43R8kvu7r8aw40qUf
sR7Quh/00fRwMtv5Hu3UmsNPRx/+BFhx+PnQox/8iXykS87yUAGYDub0EGeT
uw9o1dfjWXGkR9Pp7M5fh34F1v2gT8/02Dm/+vDT9R/6B39q1eGf3d/P/j62
Za2ZWAH4/hHefTyrvh7PuUca+wVYc/izyWQWvT2/8vDP2rOx73Orf/p3Yu7k
HBhm13ZpyVkeLADfv1/ffTirvh7PeUca/Exfefj5uKPn/KrDrxrzsd/OrTv5
R/Bm7sySszxYAGrPrz/Ss96bsFYc/vvN2ThdlMuM/Pxf157PzfnIP/xK/Pa8
/vkGPbSzaeCXYP0POnp7ft35f/qF4C/AeZf/KAYpRtA/fzw/rFx/vxK8LVdZ
+grcqbYJ30W7+gQ4ETzmTqw//4P/7FcefvWGLvrxz9fVjTEAAQAAAAAAAAAA
AAAAAAAAAAAAAGBf3VkgcTI9+T3+IokAY3QS9Snng3+yC8CojeQDjADGKX/E
w90fdAJAEEd3+uVzP71GPQAAAAAAAJv4f6TxgcY=
    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->169777575]
}, Open  ]],

Cell[TextData[{
 "If a list of angles of attack is specified, nested lists of ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " are returned."
}], "ExampleText",
 CellID->571494656],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]List", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "5."}], ",", "0.", ",", "5."}], "}"}], "Degree"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "aList", ",", "bList", ",", "cList", ",", "aWList", ",", "rC", ",", 
     "vCList"}], "}"}], "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]List"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{
   "aList", ",", "bList", ",", "cList", ",", "aWList", ",", "vCList"}], 
   "}"}]}], "\[IndentingNewLine]"}], "Input",
 CellLabel->"In[14]:=",
 CellID->42630738],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}]}], "}"}]], "Output",
 ImageSize->{267, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->240396878]
}, Open  ]],

Cell["\<\
These results can be input to the function ForceAndMoment to obtain \
aerodynamic properties of the airfoil in the linear range of the lift curve.  \
Listed below are values for lift-curve slope, angle of attack at zero lift, \
location of aerodynamic center and pitching-moment coefficient at zero lift \
(couple).\
\>", "ExampleText",
 CellID->24035690],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Doublet\>\"", ",", "aList", ",", "bList", ",", "cList", ",", "rD", 
    ",", "\[Alpha]List", ",", "rC"}], "]"}]}]], "Input",
 CellLabel->"In[15]:=",
 CellID->34907031],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.785134327086685`", ",", 
   RowBox[{"-", "0.041283210139379974`"}], ",", "0.25983834312323684`", ",", 
   RowBox[{"-", "0.05341961850756942`"}]}], "}"}]], "Output",
 ImageSize->{298, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->408107196]
}, Open  ]],

Cell["\<\
Note that the location of the aerodynamic center is close to the thin-airfoil \
theory result of the quarter-chord point.  Display below the ratio of the \
lift curve slope to the thin airfoil result of 2\[Pi], and the angle of \
attack at zero lift expressed in degrees.\
\>", "ExampleText",
 CellID->47127959],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], ",", 
   RowBox[{"\[Alpha]0", "/", "Degree"}]}], "}"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->274981366],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0798876676983469`", ",", 
   RowBox[{"-", "2.3653537057381597`"}]}], "}"}]], "Output",
 ImageSize->{135, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->216015670]
}, Open  ]],

Cell["\<\
Consistency between these two approaches of computing aerodynamics \
coefficients from a single angle of attack and linear aerodynamic properties \
from a list of angles of attack can be checked by computing the lift and \
moment coefficients at 6\[Degree] using the linear properties. \
\>", "ExampleText",
 CellID->328772922],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], ")"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], ")"}]}]}]}], " ", 
  "}"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->762946865],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9906497314355553`", ",", 
   RowBox[{"-", "0.3108284033392637`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->287563983]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Alternitives for discretization",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->421192202],

Cell["\<\
Fitting a B-spline through the points in a data file provides a means for \
alternate discretizations.  This is currently accomplished by the function \
FitAirfoil.\
\>", "ExampleText",
 CellID->5610347],

Cell[BoxData[
 RowBox[{
  RowBox[{"spline", "=", 
   RowBox[{"FitAirfoil", "[", "rD", "]"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->242241179],

Cell["\<\
Graph the data file as points and the spline as a curve to check that the \
curve provides an adequate representation of the airfoil shape.\
\>", "ExampleText",
 CellID->299806311],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"grD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSpline", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"spline", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"grD", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->278559890],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PFPUdx/Fr+pf037hEueMOFAk9D4vYWmrhZAtt1Wo0MagRalsIQrrx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->27308021]
}, Open  ]],

Cell["\<\
Rediscretize the airfoil using the spline description of the airfoil.\
\>", "ExampleText",
 CellID->176584194],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "100"}], ";", 
  RowBox[{"layout", "=", "CosineSpacing"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"spline", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"n", ",", 
       RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->664892474],

Cell["\<\
Graph the endpoints of panels for this discretization and the spline fit to \
the data.\
\>", "ExampleText",
 CellID->829463257],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"grP", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"grP", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->702755110],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PE3Uex/G93F9y/wYJbJcFFb8h+AWjogJSQT2/kxgICuK3Q71r/BK3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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->729372723]
}, Open  ]],

Cell["\<\
Solve the model using this discretization, displaying the airfoil lift and \
pitching moment coefficients.\
\>", "ExampleText",
 CellID->187376629],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aP", ",", "bP", ",", "cP", ",", "aWP", ",", "rCP", ",", "vCP"}], 
    "}"}], "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "clP", ",", "cmP", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "aP", ",", "bP", ",", "cP", ",", "rP", ",", 
     "\[Alpha]", ",", "rCP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"clP", ",", "cmP"}], "}"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->539184285],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9907124449232629`", ",", 
   RowBox[{"-", "0.3056061027535282`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->232744314]
}, Open  ]],

Cell["\<\
Compute the percent difference of the results for the discretization \
specified by the original airfoil data compared to the finer discretization.\
\>", "ExampleText",
 CellID->169245216],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cl", "-", "clP"}], ")"}], "/", "clP"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cm", "-", "cmP"}], ")"}], "/", "cmP"}]}], "}"}], 
  "100"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->208999159],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.1297682888240874`"}], ",", "1.5872459456052275`"}], 
  "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->312612995]
}, Open  ]],

Cell["\<\
Compute the surface pressure coefficients for the relatively fine \
discretization and show the pressure coefficients at collocation points in \
red.  Compare the results of the two discretizations by superimposing the \
results of the finer discretization on the graph of surface pressure \
coefficient shown in the basic example above.\
\>", "ExampleText",
 CellID->511124957],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCP", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rCP", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpP", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vCP", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpP", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xCP", ",", "cpP", ",", "rP", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpP", ",", "gCp"}], "]"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->567786021],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3X+MHOV9x3EXcBQ5Qimq3LRFrs8RglYQg0RMpatyZ9UC2zUWXMFGFlDO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    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->638789552]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Options",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(3)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Epsilon",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->30521753],

Cell["\<\
Collocation points are displaced inward a small distance to insure that they \
are computationally internal to the airfoil for application of the internal \
Dirichlet boundary conditions.  In the following example, the model is mapped \
to three values for the option Epsilon, the default value used for the model, \
2 $MachineEpsilon and zero.  Transposing the result groups like results \
together.\
\>", "ExampleText",
 CellID->120830056],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], 
     "}"}], "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PMDoubletQuadraticDirichlet", "[", 
         RowBox[{"rD", ",", "\[Alpha]", ",", 
          RowBox[{"Epsilon", "\[Rule]", "#"}]}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"10.", "^", 
          RowBox[{"-", "10"}]}], ",", 
         RowBox[{"2", "$MachineEpsilon"}], ",", "0."}], "}"}]}], "]"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->210128799],

Cell["\<\
Differences are computed between results for strength parameters using the \
default value for Epsilon as the reference.  The maximum of the absolute \
values for these differences is displayed for each case.\
\>", "ExampleText",
 CellID->112154987],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aD", ",", "aME", ",", "a0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"bD", ",", "bME", ",", "b0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cD", ",", "cME", ",", "c0"}], "}"}]}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"aME", "-", "aD"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"a0", "-", "aD"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"bME", "-", "bD"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"b0", "-", "bD"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"cME", "-", "cD"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"c0", "-", "cD"}], "]"}], "]"}]}], "}"}]}], "}"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->703042737],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3.927871916609149`*^-12", ",", "14.034842232066072`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"1.673470251262188`*^-9", ",", "11658.780483805793`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"2.6355478155437595`*^-7", ",", "1.856262368762043`*^6"}], 
    "}"}]}], "}"}]], "Output",
 ImageSize->{555, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->426901297]
}, Open  ]],

Cell["\<\
There is a discontinuity in velocity potential across a doublet panel so if \
small numerical errors place a collocation point outside the airfoil, large \
errors will occur.\
\>", "ExampleText",
 CellID->937232338]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "InterpolationOrder",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->233233938],

Cell["\<\
The list of external surface speeds associated with collocation points are \
computed by using the jump conditions for the velocity potential to determine \
the velocity potential just outside the airfoil.  An interpolation function \
is fit to these values of velocity potential, and the velocity is computed \
from the gradient of the velocity potential.  The default value for \
InterpolationOrder is 1 giving linear interpolation as a conservative default \
value.  Higher-order interpolation may give better results, but risks \
excursions of the interpolation function fitting the data. \
\>", "ExampleText",
 CellID->64752385],

Cell["\<\
To prepare the graphics below, the model is mapped to values of the option \
InterpolationOrder of 1, 2 and 3.  Flow speed just outside the airfoil at \
locations associated with collocation points is plotted versus distance along \
the discretized airfoil.\
\>", "ExampleText",
 CellID->507899588],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PMDoubletQuadraticDirichlet", "[", 
        RowBox[{"rP", ",", "\[Alpha]", ",", 
         RowBox[{"InterpolationOrder", "\[Rule]", "#"}]}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s", "=", 
   RowBox[{
    RowBox[{"Accumulate", "[", 
     RowBox[{"PanelLengths", "[", "rP", "]"}], "]"}], "-", 
    RowBox[{"0.5", 
     RowBox[{"PanelLengths", "[", "rP", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"s", ",", "#"}], "}"}], "]"}], "&"}], ",", "vC"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<s\>\"", ",", "\"\<\!\(\*SubscriptBox[\(v\), \(c\)]\)\>\""}],
      "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7.3", " ", "72"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"AbsolutePointSize", "[", "6", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"AbsolutePointSize", "[", "4", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"AbsolutePointSize", "[", "2", "]"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->49740593],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3W+IJOl9H/BOZEdjosijvIklKxGGkzREPvQiLzy+SDoJw3ngrJM4JOLN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    "], {{0, 528}, {526, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{526, 528},
  PlotRange->{{0, 526}, {0, 528}}]], "Output",
 ImageSize->{530, 528},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->125347478]
}, Open  ]],

Cell["\<\
Except for a small region near the maximum surface speed, results for the \
three interpolations are reasonably close for this example.\
\>", "ExampleText",
 CellID->520516665]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "XWake",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->104403840],

Cell["\<\
Results should be insensitive to values of XWake if they are sufficiently \
large.  Differences are computed between results for strength parameters \
using the default value for XWake as the reference.  The maximum of the \
absolute values for these differences is displayed for each case.\
\>", "ExampleText",
 CellID->391229248],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a10", ",", "a5", ",", "a2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b10", ",", "b5", ",", "b2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c10", ",", "c5", ",", "c2"}], "}"}], ",", "aW", ",", "rC", ",",
      "vC"}], "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PMDoubletQuadraticDirichlet", "[", 
        RowBox[{"rD", ",", "\[Alpha]", ",", 
         RowBox[{"XWake", "\[Rule]", "#"}]}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10.", "^", "10"}], ",", 
        RowBox[{"10.", "^", "5"}], ",", 
        RowBox[{"10.", "^", "2"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"a5", "-", "a10"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"a2", "-", "a10"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"b5", "-", "b10"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"b2", "-", "b10"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"c5", "-", "c10"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"c2", "-", "c10"}], "]"}], "]"}]}], "}"}]}], "}"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->451142620],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.34974843724045`*^-6", ",", "0.00135270356456485`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.000014278409139478754`", ",", "0.014270682549124558`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0.0003347030932445705`", ",", "0.3345202415896864`"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{536, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->393813574]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell["\<\
In the specification of some airfoils, the trailing-edge points for the lower \
and upper surfaces are not coincident.  This appears to be a problem for the \
doublet models with Dirichlet boundary condition, but not for the vortex \
model with Neumann boundary conditions.\
\>", "ExampleText",
 CellID->416625656],

Cell["\<\
This example uses the Clark-Y airfoil specified by a data file located in the \
folder Airfoil Geometry.  Import the file and plot the discretized airfoil.\
\>", "ExampleText",
 CellID->728813289],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{"AirfoilFromDataFile", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\clarky.dat\>\"", ",", 
     RowBox[{"NumberingConvention", "\[Rule]", "ForeToAft"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"gD", "=", 
  RowBox[{"PlotAirfoil", "[", "rD", "]"}]}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->112529997],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rFOkWx/Fc7l9y/43AMAtxIS7ECyGLkI0XGt3MbHSjm2SjmwQa3RiQ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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->13335572]
}, Open  ]],

Cell["\<\
Note that the trailing-edge points for the lower and upper surfaces are \
close, but not coincident\
\>", "ExampleText",
 CellID->390242666],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptsTE", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"First", "[", "rD", "]"}], ",", 
    RowBox[{"Last", "[", "rD", "]"}]}], "}"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->238007975],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "0.0005993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.0005993`"}], "}"}]}], "}"}]], "Output",
 ImageSize->{241, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->633670472]
}, Open  ]],

Cell["\<\
Specify an angle of attack, solve the model, and compute the lift and \
pitching-moment coefficients.\
\>", "ExampleText",
 CellID->25666953],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"5.", " ", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "a", ",", "b", ",", "c", ",", "rD", ",", 
     "\[Alpha]", ",", "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->592619],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.372085353476276`", ",", "0.1150808925130209`"}], "}"}]], "Output",
 ImageSize->{141, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->519408813]
}, Open  ]],

Cell["These coefficients are not close to expected values.", "ExampleText",
 CellID->722709344],

Cell["\<\
Plot streamlines near the trailing edge, using a scale that makes the gap at \
the trailing edge visible.\
\>", "ExampleText",
 CellID->492689119],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xW", "=", 
   RowBox[{"XWake", "/.", 
    RowBox[{"Options", "[", 
     RowBox[{"PMDoubletQuadraticDirichlet", ",", "XWake"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rAll", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"{", 
      RowBox[{"xW", ",", "0."}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aAll", ",", "bAll", ",", "cAll"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{"a", ",", "aW"}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"b", ",", "0."}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"c", ",", "0."}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B", ",", "ic\[Psi]C"}], "}"}], "=", 
   RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
    RowBox[{"rF", ",", "rAll"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "aAll"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "bAll"}], "+", 
    RowBox[{"ic\[Psi]C", ".", "cAll"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xMin", ",", "xMax", ",", "zMin", ",", "zMax", ",", "contours"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{"0.95", ",", "1.05", ",", 
    RowBox[{"-", "0.03"}], ",", "0.03", ",", "13"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "contours"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "gD", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->266881112],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.95`", ",", "1.05`", ",", 
   RowBox[{"-", "0.03`"}], ",", "0.03`", ",", "13"}], "}"}]], "Output",
 ImageSize->{196, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->392346976],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx03QeUF0X2P2wVUBHMYs45gLrmNdCoq4I5gQEDqAgYEBDFCCIqJkQQRcWM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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0bsrB1AUwPFjIZHB+/1KWTxWk0IZ9Cvlh2JRxGCgmLD6B2xkIFYGKY+S
R3n8B+Rt85ZsBuUjw7fvOfeec+693arB8a6xlIgYx0d+xHVBxEB1xCXnyNe4
X77On/LhkogRPMiH+J5nOMteoiIikzvLIjqsJQvFnMCGGRu8iS1xpZpNrtWz
y83FEU0YK7Wmb0ndIhbM+7KeURmRjj218868El+jT82FvFdNN1L1p+FOPOuM
Gx41o6E8ohE1qEcdfnCME6zgDKdocX67Gc88x31mvIjPzWmVt+FNXuTur1zM
y/Z6qyK25T28w0fudogp9ft88Pd26132u5HEqr4JnkS+OYUowKO6XM5DNp7k
Ofyd5z/c59ab3/VOl/z/2y9wb0Wc
          "]]},
        RowBox[{"-", "1.3199999999999998`"}]],
       Annotation[#, -1.3199999999999998`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0s9L1GEQx/HxVkFg4a9sdXeFtmP3QNywIg2WEhJFszCjg+hmHUQIOkT3
PBkbBJqGBOkSBPlXiJZgkoKZqAhqRFh5qJd0ePN5Zj4z88zz3U1351v6SyKi
gMtVEfMYqIuYo+vJiG9Yw3QqYgpH0hFH8dZ5sDJilfcV1+Suo0K+EmMVEYlE
xCgtF5dhl7+Dgr6m2ogXtJk28BbUZdVfwJq7Sw/n0hP0Z3lE1+mIGl4t2k9F
pGgSWTUTZrzGKMbxCn/1TOst4oz4LDLodc+SWU9rIp5guTrimRk36J6eIV4r
2rAjN2LHH/SYHb/T5/oLvJfI6Ouzw33U82b1X3VfGhkkzX/vW75TW8Rn8SJy
zsPmbtMWM5poTv4KPW7+OdqNSTWP6Bt6j+7yVp0fekdR/ZRzm3OHGXm6JN6Q
38QWVsQP5Afwxf6L4hW6jC573cQd5z9q93lD6m7b+xZavalU7i6/B9W++WO/
3QfvnMEv3m/5g8N+nBQ3mnMRl/DJTp3qOlAi/ig+n/j/H/sH4Apirg==
          "]]},
        RowBox[{"-", "1.331`"}]],
       Annotation[#, -1.331, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0k1sTGEUgOEzNpY2fjqYakcmkUgpm0YqWsGGVEoqEn8VsdZJ2ZW2Vrrr
WAq1ICmVqKRGojMlUQssNKwaWkkldNGaKRK1YOG5sXjz3nO+c84938ytP9d1
9EIqIkr4nI74tDbizcaIWZ4TD6+LKKM1GzEpl5ZbJT5bH/G6JqKTX3HJWYO+
cS5nIjLrI7aLt2EAh/Vd4zZ+wUXnT/BS3LcpohclfZNmpTxPyOdr7eFd8/IL
WMSyOCXfxCv4Sl3EZfTgm/MOe3Z4PoaKuIpHKKjNyQ1yw4aIMXvu4D3qd/KI
eee5jxu5Xc8hHhQvcIHbeFq+yE12rLPrVi6aUSufS3I4iKk1Ebvdr9E9utw3
p7asbzX/tsOQ5xt6fqlJOz9l/gm5k6jIHedFXjJnpecqt6if0vsWzebMJDXe
tUX8Hu/Qq2eXeXnz7rpvjZrTdpjjfXqyzobtuzn5r+QfmJlVl09yPCIe9dvc
53v4a+Yf3DFviG/jJlrMusVf+Lm6Z5jAU3Vn5NvlH/IRHuVx+U4uJd8Ot3rX
Xuy3xwHMq+u2w1dedtcZuw2IZ/m73E9cEv/gaftV+aJ4iSv4mHxf4g9cQL/n
6/zY7DFctVt/5v83/g/SaHxp
          "]]},
        RowBox[{"-", "1.3419999999999999`"}]],
       Annotation[#, -1.3419999999999999`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{6157, 8803, 6158, 6700, 5568, 6313, 8515, 8517, 8516, 6257, 
          8133, 8134, 8135, 7063, 7185, 7186, 6571, 8189, 8190, 5770, 7055, 
          7263, 7162, 7163, 6684, 8087, 7516, 7517, 7161, 7520, 7519, 7518, 
          6258, 7866, 8025, 8024, 7264, 7265, 6572, 8680, 8682, 8681, 5690, 
          7064, 8519, 8520, 8518, 6314, 8521, 5771, 8191, 8866, 6259, 8487, 
          8136, 7065, 8879, 6160, 7252, 6411, 7272, 7273, 6701, 5569, 8566, 
          8013, 8014, 7750, 7752, 7751, 5772, 7266, 7267}], 
         LineBox[CompressedData["
1:eJwl011ozXEcx/GfhGFcmM3GHkxyoYU5M+LGldmNxEoetrK05sJGKQ/lISSm
XHjaA9sULpgoNytcGNuZmXMOW260WbljU8wxF6O8Ti7efX7f5+/v9+9fWF2/
rW5KCOEvnmSHkFwYQlNeCLcWhTCRH0IGX6fzU6zMCWGDeCwzhPKCEAqwFHny
V9DlKZ/8UvqLflGfpC1qmlGWG8KVBSFs1auCf4P4afZ59Rewg93Bjog/SvWk
J9n99AQtoiX8w+bnOvcvDqGbv0ZdDx1n/6I/aJKupaVYgyg7RjvskWa/mYjq
1Yt4lt52i9Gz/OdwBgPue53/GqrU3aCNmOvciS75fXImC0P4g/vowAPcM++n
2JYlIUx3jqubQdvs0I5W1LLb5d7GHvOO4xiS7Kdq75pxB7PsWMvelzqb+V3d
V/VjGEUau1jOakRw1dt+8CZD3mmTmiykmz8bRWKZ+mdhHuYjA+Nyn8l7jt/y
JvDJrFepN8YLvEQXvmGv958tvsz99tutTX4rRvg+s2/aowWnxC+z42YkMOx+
lXIuym3AJQyKv5UbS30LNPNVy5t0/oM36Mc0vUbklpm/GeXolfsa4/wN4j9o
nzt8dJ98dsTbFOC93AHE8Q4JPLbH7tTbYxeqUImoNzpID+EA6lGHqfqtMqsY
+WZE6Gp0y19DSzHHnuno4SthPzSjwre4Y4ft9C49SsfoETpKB/QqpoWpfnSQ
3a1HVO1avnV4p990b5KgNXbZKZZQ34gmHJO/XqzZea8eab7PRr4xvYadh7Cb
P4ce5svO/f+//wMCTaLF
          "]]},
        RowBox[{"-", "1.353`"}]],
       Annotation[#, -1.353, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV02tM1mUYx/FbGs6iRTXxEAcP1SZSxlJLXJZJMrdKZk1BXyRZQqYCbdme
eDyglUSKNQ6uLFe4iopaUY0lZqtcCogUoBum6zyVWuLmTEqzPv8XX37X+b7u
+/kzYVnZA6XDQgg7/cm8LoQNY0OYMTGEnFEhvJvGprfz14tPki8fwxc7nxpC
KXuIltF/1F5Aipoa9SNpW0oIl+t7in8FvWl0CKvGh5BFd4hVZoTQSIP+dPEm
c1/mbxB/Pd35/Azxd+hf/POYpPZ5+dnm3Y2dZuXSOVjn/PfUfsZOEK+kOebd
KbZebi4/zs+jS8RqaK49j8s18xvZy50xh73fvQ4gy3lTxG5BNg47uw8DaleN
s4sZK2k1/cicD5Gvf43aNjVH2efE+mmrmlnOf5Od6l5V/I4JIXSiz4z54hvV
bkKX2Bb5g3QrPWKXw2jk78JkxO3Wo68X7fzN0W9EM/GFHSvlp7H3skvVrMYh
/khzOsQ60Y6t6g7SLXSYsx+N3ob9UHQne7bghN6TKJbr4i+nhWYtRgH2qL9R
7w34RK7F/T9GNV5AudhKZyRiOKrEjuF7/CQ3S9/P9Dh/gf2GzHvV+93hzHrx
bHpW7JTe6eypyOBn0puRpu/6KIZ56PLtzdQ/xR12m9eKa9Wf0/83fkAL/yzN
M38yXaP+Cd/NGTqIa9zrFXfdgUNmdmMXu0xNzHkViCPR7ES54bTbzMtoAo7a
IU28n6b73VOjXdXHzMg240GxIX4RfwB/ir0htpTdJ96Lx+21AjG9NdiGb+3W
jST5VPd7SewifZFeoGujO5oVpxVoVtfEH0SR+afpUvsVoUR9q3sW09f8Bse8
xVzn56HZvE30ffoBRqtZQMfQUYiZlUJ/NOdLfTPMHSc24L7P2O8RsdNmJrGf
w7NYFH0bYgtpBX+Jnt/pET1j9d5j3pPesMM5nbhL3UXzZ9N6uR67NtBeWks/
NWu1XB27lA7yz6DKzM0oEPuNP5+dj3X8++l9+EX8V6xlx5Erd4C2Ixn78Q02
On9i9P2yR6AH30XfptjD3nYZFmJR9A2KJditzrvVoxbb0YBLco+50wqUoE3d
brxlh3/lFqspxB/uMsJbJNLtzk72HleZPd6ZDfx6bEO1nhNiJ3G1fDIKvOeV
6pOwD3vV9Kq9lV3nW5hKc9TNxClvnhD9X9O66P8MtdHva96laCdMV9+nfxrN
t8+9cv+JB/0ltBhZYv30NmeVR28uV4i3xZrwtL497hmjn9Ov8RX24X9R/f49

          "]]},
        RowBox[{"-", "1.3639999999999999`"}]],
       Annotation[#, -1.3639999999999999`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1WdsllUYxvHD0gAuZJUltAKKLEEwIksZUmhrZBa/yBKiiCDLAW1ZykoE
DZTdmhgpQ1BWGSJBCSYKNUBoQcCCgIB+UCkQ2jL9nQ//XPd9zr3OeZ7nfRNH
ThgwvkIIoUHFEHbVDqFGgxAex8J6IRQ2DqEIr9UJ4b61/vT3xBCKcQbncBar
xK7BrKQQVtNL6sxrEsJ8zMVCLECTuiH0xGBxPWihuD40nZ9Mk9APQ/l96WX7
vekQ/is0EXcRzNHMWi921YQQusU9/i3xt9m3aRK/O7ud/ZdpU/5d63fYd+iT
/JfYPeqHcLqh82AyexLK7A95IoRD7MN4DL+iAAP1XkfX42HkYS0Giy+VN479
LorUK0Rz9iB9WutXN94jO4G24Q9mDzPfInezGLvd9R7Ut1/BvdajY+QfdKff
sw+ot5dmyBlAj3kmq9irkYNTZlhD+8npixx5XfT5UGy+3I/oLfUzaCmdRsvo
dFpOP6CPiHsUK9R5W+5yWlOf486WwO+iZmdkm28H/Yfm6JUtfwR/FE1tFEIK
juEo5lmboeZMVBU7EZ312sgfhxn8mbjMvoR09izMxgA1B6KJ3iVmaKffDDM9
S59De2TxV9FkcStpH5pDc7EafeP7SauolxjfQzRGbnznrL8hf6cZd2G2s5ZY
vxbfLVSWU43eUGOTs2wx934zbqVN1dhsba+96XKzxda0VytiLSPOhkzcFL9A
7VKa6ix/2b+CArHN1O+PVtbrxGevzltq17M2UUyW9ffol2LL7Kfx/+anxvnY
Z9k9xPdEL6wW96a1HfqOpvn0sNjtdBR/Kx1Jt8VvV+wJZyhCIYqt/2TOg6iM
zfpV815VR1WsUH+4Wmv0Xe/MG7ARY8W+g6HyM+2l08/U3i+/O/9nfhV5i+P7
wx9m/VP7g+I9xW+BTo7flpnW4yvkYS0WiRtu76w+55CHdfjT+7DOPBdpobgi
HMdJnMByNU/TlfQ3uoKeomlqfaNmanwH9d6Er7EZ5e6gujk/V782vxb2eT+a
i98nP1j/kb9HXAY7M/rWt3tm2/CDuBT+J7E+nUvn4GMc4Jfpfwvl8RnoXzm+
z84wE1noqvcsWmIvnVaUs0e/Ceb4jk6N36Xe4zEBv7jzQ8i0fk6PB83QG2fc
SSu1W6Ml2qINOqo/Rl4Heo+29ExboLd+JfQailGGG6ihbr76u9HaLJ3ib2L8
3XbuRkhCA3Va0afjmvj2tAOuyG9H22KJ+i/SzngI3dAVp8R3oqX0BXqTTjFn
JfHD9CrnF6uf6i7SkOyMF+O7YK2heWrF/w9rNemreN09pdEK8kawK9Lr/H/l
XsV/KFT3Dr2gTgrthwIxx+kGexvjGdWeI7+AHorPnV0h/oeY7T7u4bx7CHpf
oMlyzrP/wCw9j7qvI5hkzom4Kj5fnYT4XaM+poldHt9LLENX+0fcwdF4p+pN
U6eK3Afi8+Y/Zd6x8Z7pt/wtuKHGdey09owztIj/keKb0lya5RksNfda+w31
zKPL4u86spFqPyX+b4jvrn+3+FumXga+UD839sUJ/kksZS9BB3UqmXmymlMw
Ce9jKubZy1TnefU7skfL28Cfzd9I51v7HxnlSkI=
          "]]},
        RowBox[{"-", "1.375`"}]],
       Annotation[#, -1.375, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV02lMyHEcx/FfSiWyYaRSZGLaXLNh5onZXDlDNtcDD2TOMB3PWIebMY/c
G1seMPdNbMQciXmgmU0NiWJyjAc5Xv8H7z6/7/39/quspWvz1sSEEEb6ca1n
CKPSQzjaN4QjOIzs1BAW9wlhEf71ktMvhOu4iqT+IXRCq5zbavd4b1fTIyOE
bXQrcqJYVgh3UI0PaMJJ/mo1OWkhxOMe7mKXGUXqzolvpOdpMT1Lv6n7jjZc
YR+Tf0uP7uZlew/AC3sO1KPYuwSn2aeQy1ehZnzkZx9lX2AXqp3sXevupxje
2zfgG40xuJkZwg00mLPZHjVqNtH7tEafe6hW/4B9ObqBnZwSwkzf4idfPd9L
/PK9fiMPszELdfLmmTdYbjc91plfy5fpvvn8GTSfZvM3izfYpxFx9tmhPpZO
ZCfZ55W8h95j+cfZoZ6dzP+adqbL9SrAPn0+qWtBE76iFX3kldFKpOkzCI/c
PCG6lY52w0j3zNB7KnrLb5DbiDfI1fsU3wm3PFYzyZwn0Xyx5Xol0gTsRzK6
YiX/KqyONLqbLwMr2EvZXbxz9KzQu5/Zy9xWgBSxL77JYrG+YllRHG/534g3
ogHf7ZBn1290ir1io79ldzTRqewf/HPEf9Jcdhz/PvHO3p+9F+ixEIuwRN58
9wzkz6eD6BYzk+xwiH0QB5DAF49E/pNYpVcVrTTjmZoK9nNaizqUs5/SGPFU
s3ez02isb9ABpWr/urWI/qEltN0uxTRF3qQoF7PVZbj/uVgmbbbzR/qBNtMi
33Ij5urZblYb3WDucfnraSK7E/bqVSFezb8AC7HL3ATzWrxLxZOi/1l2K/sz
dorvwHYMUDvd/RfFp9FLNF1OGg6KnYm+gX2u2KuSDkWe3YfQjnKHyRnBzmeX
eRfKW4fVWIs16KjvULF39H30e0eVvrfMuIlysf/8Sbl+
          "]]},
        RowBox[{"-", "1.386`"}]],
       Annotation[#, -1.386, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1HtM11UYx/FjMq2mAZqoXESgEMVWYVFaSLW2ZltpWM3bVgqEIMFSlInp
ltbyAl4qUxMVU6vNdTUvK1AzyWqrtbYwoiuiaOnESy5pZq/vH28+z/Oc53zO
c87vxy9tRmVBRY8QwiF/dg0IYX1qCBtwPiWEC1iTHsKreAVvJITQZ2gIfbFw
iD61zIEhzJIPo9cODmGuWm+6m1e/xBBq5f1pPC4nhzBzUAgXk0IooWUosl5K
M+yZL06nmWk81T43x2GMdO7f9txCd1j/w/pbtJ2+SWfr2U6fo9voX+qncYO5
YtGl1tN81c7PFd+FDfKVekaLa+ndtI42OmeTe9ej2x13meOs+AneqXoS7Duj
Z5p6pXyEmW801xK1C866iDoU6KulE+lVGnhfod3y/+gP3qMFr/M4F703LqDB
jMXqW2mFtd7OrpQ32V8jX0qz6DL6trOHi5eLV6DB/k+9+x4csOcgMpCO7/nd
bM5V4tXog5WoQ4EzHkOT+ISef/R20v3y39R7RZ8pHjX3eBy39rWeDnrVevBO
Nerzket+V8w0gG7RUyaehW/ls71RnD1ZvJ5VK0dHdBf5MXrKeidOYq33vced
XqP30gXR/ZGiL5bHMHvG88yI3hNZzm7Gx+JN0buId+sbQbNx2tucQblaO//p
4n7m7o857lAVIW63v0v8pD3x8mJ5LI1DIt9kJOGoN97OoydisFV/A0r1X8//
OlTzmYc4cZF6Ky2kfWle9P3yvqPdby3vp9RL1NrEFfx3YBt2Wn/Yvd+lHdYG
0nHe9RHkeItcHs1mecAMX9FMHoPxkt7FSIq+v/R9epy+R9fbk2D/OppP29Ty
zTQWxzEc2fjSTMv0HKGV8mPiObTSG06JPNUn0w+iz0E9Pfp8zbrRO9SjxUxH
8Xj0/yu/hJ/krfgRJfYl6n/I+R/KP8Jmd1qkf4+59qJB/rueLTRJfaEzFmGm
WUrwp57L0XeKV4L32ucNGhHvDQ5ZD+rf6OkR/R/yWKEnqKeJJ6kPir4/0feV
R7a1CfJ/xbeKh9JOeSo9YfafzTdN3Ean0unmTqPnzHMem+Uxzi3lX4ax5s7D
ED0H7TmAjXwn8VzHbzKNsWeGWk+ap6/Q/uX2VolPma9Q/KL5xugZp7ZTbbH8
CN8l9DD9As04qTfOeov7Pyj+VfwLNkS/peY7hPt5FEW/b9brxa3W88X34QV+
I61lY6pZx8hrnDtFvIr/M7RarYjOo8U0hccxdznhLu3RbwM6kCz/jncSncDj
Gv4T+Sbrf9kcSzGXx16+VXQf3a4/UX+p/WVYg9X4JPpdQy99+2kTGvG0e3Xx
OYtuvp9F3wc9C5DjzNvU3uF5Ox0lf149TU+5fXfIc9Qv2TuK3hn9JqnfpOd/
PuwQ4g==
          "]]},
        RowBox[{"-", "1.397`"}]],
       Annotation[#, -1.397, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkLlywVEUh396W2OJCGMr0CioSd4gOtIJCmYoURGF2vIAsT+BsVY8gbQe
gkIZhe9ffPOd5Z57z9xAoZ6tmSR9wp9DagYk24vUwHbcwmZsNWpByYI7r9KZ
sy7yFHnS6BPfsBlfsQV3ndLeKx3A75F2eAtFiNP7epPyMIQB/FBbuqUqsws8
4p0YtQR5mbxDPMcV8hke0B9CiTjCnkX8jif44pOm+IN8jNP4F2dwn5kod+V4
c8Ku/37pAW2jxm49zoQgDEfqJ7gzU2B+x73feI23sIEVf5Gi34YnSWAweg==

          "]], LineBox[CompressedData["
1:eJwl01tMz3EYx/GHMafU2DooVOYwoRZKTZqwscYyV25yCEOt2JALXLDQ0VxY
XIrFTaWNS3OobJ2MC7IZuaALbWzcuZHX5uKz93P4PM/3+/3998+uOrWvblpE
fKIPaRGvlkRsyIrYSDmLI0ZTItaL86mYiuiN2nve7csihsWb+UZwh3xM/V56
RH9qxDb5kPqkeBDL5H3iCfpG9zN5qYPy5Oft/si3xx2OL424yT9bfkI8B1vs
7VFrxd/O/EXn1Nv0b1ArJWRHzKPBDPfRO2t396KIM9iDNWaqaY14LWXwpVNf
ckShuevuX4CNuAmvYTE2YxE24XR7a83U0SE7HqkfxF68Y/db/UFvmFDb5b6T
8hH175jIk0TzaZ1do3as8u6V9NjMU7Uu73vCOyo+yvcaj+EQHsERPIzDWIXv
nFONn+UncRxr8Ar2+yZX8SU2YB+W213vjA7f/K4zO+kBJbtLk/5qvmaca0cL
vtB7TgPmUnny3DWX+tSe2XHJrv16M7xxJo3xFNqRhEWYiCW8CfjDdy4V/zHT
bnel+WL1A1jrW02p39J/qPZVP8X8bjv/Yj3me2sBz4A9ZX7TQVzBn0YN/Jcp
nfcndtlxW30n9qolm283W4ptztuqXq6egxflp7FRv8TsFmox20bL1S/oV5ib
4s+WZ9EXZ6fgOHa6SwFvuftVinP59uJCeQUuwB67u2lW5v//2j/K/oIN
          "]]},
        RowBox[{"-", "1.408`"}]],
       Annotation[#, -1.408, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0l9ojXEYwPHnlDtyo+PYzjam1Uhys5o6SMqGGWfD7cqyqZFZzR2Fc+TC
aYXsws0w+TcpkTMl21IbtQtstOspyZ9L48b4vLn49v09z+/5877vObWdve0n
UhHxHCsqIg6viejEskzEoaqIjtURizURf/GsOmKju9GVEevdjYrLGFQzvipi
g9xLM+oTi9fxQm3EmNxPHudfSezusnmb+Ao/NeMT5vHN7Ly+NqTUN5kdfEpf
n7s59XdxDyX1u5I92Yhm53rew7uRcy4l78ADnDGvyXnQ3Qj/0F+h9yLXcUa+
DlPpiO12vuKGSnv19eOPmhZO87yeO2ZcVX8Ni+qW+C4puUt2/RZvdl7g7+Ys
df7KObUD+qf1N/Kc/Be7suJj+tLcw0N8AxPqd6jLJ7H8LfEwbmNC3CV/BDfF
Q+JW526+ztuSd/LNtnLX2oij6EZB3GvnyeQ3UzeGvXL3uYUf8BN3xz3bC7Oq
zNgnn+VW/iz/zu+Q875bUEQBj/R8SH4vO2bcT/pWs9ws/ij/3nmn8xsz95sz
Ys9DnPbsZ9Dh/q0d53AeZ1Gjr8BFtJt/EAfQ7xmKuIA2NcPu81yyc7n5U57n
NSZRFpfNflz5///9D50xctU=
          "]]},
        RowBox[{"-", "1.4189999999999998`"}]],
       Annotation[#, -1.4189999999999998`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0j9IlHEYwPFHKqiW7vpjd3pnWeDglDQIokTmQS2KF4h4NtRSQyokRZvo
oKCBnRpOKkQ2RCYZjUdCRDgFEVkEQRAUNBaakeHnaPjyfZ/n9/z5vbxv7ZWB
fH9FRMzhc3VEcypiXyaiyJPclY7oror4eSRiv/gXrx2PeHE04nJNxCpf0teL
V5URnXJ5NKAD7finJ8VpHEYGVbimfl3fVR7JRnyyZ9Lei/xDz01nt9CIkp1j
dm06G+eQ2yW3LS7qvy9exF/9g+55Sv402o5FnEEO9XacRGXZ6pbVP8Ks/nO8
17wc3zO/hfNowh7ndbybz+tdd/f3uGDGV/kNs1vFI/pWzBguW/wMy+hW11uO
5Z/rv+65cCJiAfN4J/9B30f0O+vDitxZtU+5IC7xk1pzfI/HXOAl3uAJ+zf5
DvfwN+//HdOYwkv3HnXPhF1JHMCWuoP8m9+oSZr/x/MhubS5OXdOcRt/0fva
jIfuN6juAd/gRX7rO2Wd3xZPq5/BXUyhiJKzOb1JtQl0yLVjKPv/f9sB9y5f
vg==
          "]]},
        RowBox[{"-", "1.43`"}]],
       Annotation[#, -1.43, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwlkT1LglEYhu8sqsnAMCut92NzKqzJhEr6A0qLgYG2KESBRB9Lm0JLRYVj
EDToEgYFQUNDfyAkUFoyyiWiGmqqoevQcHGf8zznvs9z3tfJriZXOiRtwfaI
9A1f0BWQ0ra0CD7oh+MBadmRWoOS15Ke0D70ES2hzSHJ40oNtIJWoQRFekX8
cXLb8AJvZFlB6XJUSuG/QBfQPLUc+OjXqJ3DNMzCDKxTf6a/T8aeyRqWyvgy
aDe9DXqbMA8N7jzkHTHWR+gc2mPmQMucraJn4OL3k+VCGK6YOULeGBRC0g/9
U86dmHvx/VL3kCO4hh2yb9A6eo/eoUnOJKATf5T9A+tXvkMev8M7XAiADRak
IQITMA5reCbNmrxbZlpinYUpU2eOGNoic5degcxe7vkk/wOi/KMDZs7xjnf2
dXwV+////gEAFEfy
          "]]},
        RowBox[{"-", "1.4409999999999998`"}]],
       Annotation[#, -1.4409999999999998`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0L8rxHEcx/H3KUw2HTmOYzFIGfw45UqYLGI1OLuTgWJlMDExK4ufJe5O
IX+ARRJl8qMMysjC4nEZnj3f7+/n9X5/P99vZnZ+spCIiDxWGiIeMd0e8cCv
TRFvuFHftkQMtUXkkE1HDKIPA+hHbTKi2BpRQq/+SG7JXJnX+IxLKOK5spPz
Zl7kD9UHWJTb5y6cuENJP4ekfQXu4A/5J/NZfVVzxIT6Tn0qP2XuGuv6K77w
LMEb3vMrt8k7qYhd/DRGLJjv9rwH57KdvjGD+oqdH8vtYcvcMNfYVY1L2W3v
eFA/YsrZvX7WnhnU2Tuuf1d/ue83Rt19DDmsOhvhMqfNLvNn6v///wEcNT30

          "]]},
        RowBox[{"-", "1.452`"}]],
       Annotation[#, -1.452, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdVX001Wccpw7ZbUK02pRi63hba46JrWOf5iYuS1KRRRnVZLIUR7gllUh1
DL/lUm6KishLXi4Lj6QYl9a0rpIbufI6Kb0sWq17e55/+p5zzz3PeZ7f5/l+
P8/3+/kY+//isWWKmppa5Nuf8v9djMHQmz/uks0nhU49UQaFj5DiUFayvWAV
8Umqf2bm8wgax2faNd1dR3iy7B32vEdoO7XPdlS+gVQaxQ2vrhxFy9oIw8TH
fsRABTAKba65ue/ZVhJqr/ziH7i3z4v6biKYtEqVMQLB4UrOLSaUmKsuGMGQ
mX+wMDaMKNHeQuJI0/TlFw5EEGU2Tj1D+Dyw3LAjLoqo4OyH0Dpt07hGwh6S
ka6MQUjWHOz72HEfeW6mBBxAwqfeN7+8Hks8VAkOYP34ohonpwO0vn6YX52S
t7HpIK2nHy9TZFy44BDZqoqHMCs+O5LeHE+uPlMC9sGrddfyWtfDZL4qwT4o
bJdqjUkTSbSqYAXKp+k+1XQ7SlRwsl6YJg7v0r1xjFirohddobcM36xKIio6
kx6gunKA+Af+SkZU5fbA7n7vealZMnF+VzD013RM8geTSY4SLrsbHxRVpvbm
pZB379UN0/6oZBKUSvmXY94Zw3y5JUf57oK+b3XDfyMc5fce2p3iPKUXf6N8
3sVXh7gJ7ZDjlL87yJ6YU7N5URrlqwOtrjprZcNplB8ZBM+1bPgXRJSPvxH7
Mvxx07Z0Wv8txE1rLYy2zKD1tkMvMtY5fCyD1ncTcybvfWJSeYLW8ycsIy3V
+6NP0vzbkO3u53rHOpPmK0WnPEQwoyOT5vcHjrbxJbl+YppPI6ZYzP3O4pqY
3t+Aux1LbutMiul9V1AcMFPh+UJM8WshMvfQLC0UU7wqSIxu7A6exb4vQ+5V
nkT4WSY9X4jzK/jGvo0n6Pk8HFC/35SWn0HP5yA/BBY6c9PpeTFObWs3GVmY
Rvc5/K6to8mv58jE3qDqsNQEDA6Le3b+mExe5T3+a6X/PljJHd1mORyj6x1I
5CcLTsfH0bUfzEhWd83rGLp2x9QKefN2z910vQy2wRu4Owt2EbX3gu1/0Wip
a28eAPa9qUCY6poQAobvVlV/2achAuz+nzmY56zYD5bfA03h3jnGR8Hy5z+5
37pZkAJWn0dMTf3+yXSw+jttjC9aDWSB8TPf9lLPKa0cMP4yE3lHluWfA+N3
2Yq+luLnuWD8+/30ckeMogDsfbgWm8s5C4rB3u9h9m1Hw+QSsPet3uB9plR6
Cez9BVVZAQWdpWD9YVb0zezhujKw/hEJIj1aosvB+mvGm+V1Qu0KsP4TyLmV
BsIKsP40kIr227RVgPVvY+hx5/U8CVh//+sXkHtriQSs/7sUPoufeEnA5oPn
296qs10CNj8iLtRBFiYBmy+XqYqx0bf7bP6SXDyHXntKwObToSB7lftiCdj8
Or/26656UQE23/nh8VWCEpa/HEZP9TJ5vhVg+uDdsXvdh6/KwfQj0cu70yCp
HExfmu8ZBzl9VA6mP81Hvq8rSi4D06cHEpndavUyMP3aWViNr7eUgunbqGmA
UFTD+FdAunR89vzpl8D00XahzkSCWwmYfmpcX1cnSigG01cjNamuSVgRmP5a
cN2BJo0XwfS5LLThByGvAEy/o62Dal2+vQCm72lXamTl/rlg+r/HK89xMOIc
mD+slOn7zt6bA+YfmRvb9MThZ8D8RUvjbGDfxiww//GtrBmtDTsJ5k/X7GL0
eXoiMP/qyt1kzUtNBfO30ojh0ybjx8D8b8LqpPH0+INg/hhvez3PShgD5p+J
CstYriMczF/VazurQz0C8Z7/4n9EbM4S
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504,
  PlotRange->{{0.95, 1.05}, {-0.03, 0.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 313},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->568513827]
}, Open  ]],

Cell["\<\
The flow field near the trailing edge is dominated by the point vortices \
associated with the endpoints of the trailing edge panels for the lower and \
upper surfaces.  By placing the cursor over a streamline, its value is \
displayed.  This tool can be used to follow a given streamline as it \
approaches and leaves the trailing edge.\
\>", "ExampleText",
 CellID->38752132],

Cell["\<\
Repeat the computation after altering the trailing edge by making the \
trailing-edge points coincident.\
\>", "ExampleText",
 CellID->254018838],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rTE", "=", 
   RowBox[{"Mean", "[", "ptsTE", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "rTE"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "\[Rule]", "rTE"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gA", "=", 
   RowBox[{"PlotAirfoil", "[", "rP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "a", ",", "b", ",", "c", ",", "rP", ",", 
     "\[Alpha]", ",", "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->230503503],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.015846149412974`", ",", 
   RowBox[{"-", "0.35365269030505875`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->48322270]
}, Open  ]],

Cell["\<\
These are plausible values for the lift and moment coefficients.\
\>", "ExampleText",
 CellID->88671999],

Cell["Plot the flow field near the trailing edge.", "ExampleText",
 CellID->112543031],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rAll", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"{", 
      RowBox[{"xW", ",", "0."}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aAll", ",", "bAll", ",", "cAll"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{"a", ",", "aW"}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"b", ",", "0."}], "]"}], ",", 
     RowBox[{"Append", "[", 
      RowBox[{"c", ",", "0."}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B", ",", "ic\[Psi]C"}], "}"}], "=", 
   RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
    RowBox[{"rF", ",", "rAll"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "aAll"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "bAll"}], "+", 
    RowBox[{"ic\[Psi]C", ".", "cAll"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "contours"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "gD", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->240459914],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0nQV0VMf793GHFnd3d5fBi3sDxR2CheAWJSQhCUSIJwQvUIq7lAsBirsV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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzrkuhGEYhuHnl6AxZmwHoLUVjgAtUYhmLAlqZpyBToLSUltLlWX01oOx
TTKiUbimuHN/7/q9wxv1hVqRZB6tUvJeSX74sS95wiI2+5MH7Mg3uGcomSon
Jd4SF/zVm/wNJN+8b8ce6mrT+mo8w9s8omcUz/a+4BRnuLP7wMwHPnGtf0zf
OCZQlYu+G75FU/1cfG9uV3zlfYkLNN0w6685PYd8hFf5N3SqVXhpMFlGFatY
wVr7dn+tc9nMMVry3eIT7y6ebN9nb4cdBX69/wGVOi5W
          "]]},
        RowBox[{"-", "1.9617000000000002`"}]],
       Annotation[#, -1.9617000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzkkrBlAYhuHXEplZIpTyD0yxM22UlY35MxdlWGKB+uwUG/MeG3uElR+C
+AwZyli4Fnd3532f85xT1j/ZMZEWEUN4yYroL4gYQA/60IskVrCeF7GGjPyI
WecZTOPUrJJHzetyIoa5lkd4KTdiGTfZEe8y1xxF3rPL5Gq5DB50TucEd8l1
40TvMZ7960rHNWrkiwsjSlGCZrMp+0/5L3zgB9948Fabvidu4Udu5SO0613g
edyb7zjvYg+LOv/Mf7Ht3MxNmEOn3Zv3qvRf2B36z71ZCklsmW1iAym9Ff7Y
KFPODTyuYwwJ9+vtL83PZM/xqvdWxx0OZFfl9vkfay5ACg==
          "]]},
        RowBox[{"-", "1.9656000000000002`"}]],
       Annotation[#, -1.9656000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzzlPlGEUhuFDgViAIkrFgJBoIHSyFmCQYemg0OBYWEEvDiQaAkGhoZ4x
LoV/AGgYMBZQwK/QwigKhpEom0vCGryKO/d7lu85MzWDw3cfFUREBgOXIiZL
Ip5ejXhfFlHN17Gtt14aUeVdiQRuXY5I6nUibf5b7w8O8A9/sSkvKacLd/Bd
3ckLyPnum7r4SsQGT6jHcWJ2jKz+V/0O7ydu7ctbVx+qj/DOzTH7S5y4FtFi
p4JbeYRHMYw0HmPP3hz/NJ/lXzzPn7jNrWbelDeFaXxxa8/Nz3xu72J5RBEa
7V3gIb+hkAf5ob17MlawjF23NmTs8E2zG2jyXa9eD/rt9GHR+4f8Eu9tfq5+
hjOZp3ij38PdmEDKrE5WLVbNZmXm9bYwg9d6r/ASeXk1fvdtO9Xczil+gAFM
qu9zjjOyFznLL3z3Vn6Wj8xX9dYw4780qPvtpdWjGEGVvXr3PuID/gNXYli5

          "]]},
        RowBox[{"-", "1.9695`"}]],
       Annotation[#, -1.9695, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0MtLFVAUxeEtqRXlNR+F2kjNqaZTX4E60SBQEaGJ3nk2UuLqDUV652vs
xPL6mNgLg6Js2v+Q18hJipWQVjb0c/Bjnb33OutsTmXydvdQTkRkMFwY0VIc
sZmIeFIU8RRTuHMh4kj/Hx6rm2kTOksjfpVE7OOP+i/eFESM8L+mj3ivyiw3
r8BlDLlzC7vmS3QZGaxiBXv8X93fQgoPZTxAo+wv9sryvFOXyRrUq+MfoLV0
gT7DRVzCcyxiCRm8lPcKB7wv6Bo6ZH1XZ5038ZZvHd36ozSFe94tpqUoQR/f
jv3POJ9FPm7wnKbDGJT32Z61eknnOjpm3zRG0a8+z3cOc97Jo7koQq/sn7Kr
+d6brbq/rfcNdzGrN4NpZOWUe6cCZWjg7aVp2kPHaNqd+3w16nb1FdpGf3hj
yht7tIpWoo+vnb8N1+V3oZ6/i7/RvAmneJppLj0wO8RvJOxegHGzm2ZHeh/U
HzGvN6f3X6/FuRXXkJBfiEn5G3yfTv7aPuN8EzgGxXlaAw==
          "]]},
        RowBox[{"-", "1.9734`"}]],
       Annotation[#, -1.9734, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtszWEYx/Gn2k2cnvacnuO2GCQurZRBopYmolSFatIUA4mQdFJDhTbC
4LIQejmt3izKJjGIWgxuodKJtunFZGgpEsRlFJ//8M3vufye533/73/dibam
00UR8QxnVkT8LY0Yw+5MRB324Gc6IpWKuCQ+Si/SI/Q6vYF9aMB+tKvPZCPO
0q2oLIuopu/sTNvT64w34u8847QfJ8V99BTN8qf5J+hrtVdq6+UZeUHejOdq
ZWqjzhumd+kQHbC/lO6V16MPBTwsjyhCqiLigH6Ii7EMi+7TbO423wD6cYWn
3hntzmqiJfoz4gnxLr2n4hfivPiX3kraYa4T59Eiv0lb6UHaiG70JO+WvCGm
7NimX+W73ot77ZukXbQH3Rh2t1t0hL5113EM8aw1swbTmMJOd6iya7s4Jz7M
89LcarX7zrpD79EROqi/ik7y/ha38NaK/9BC8h+wwLuIT6jWm+N/wDtLv6p9
w2d8wRLa3K9WP2N2oz3ldBOdTd4NC/qP7RnDIRzzHT94Lqg/Sv6F/7KBv4Qe
l/9L3sJZH5N3ojvULtM5uzbzLbejWJzlq5Tn+PJ4ov5BbZq3xsxV+TWc451P
3oi3Rp7nyaECS2qjdIv+f6ina5A=
          "]]},
        RowBox[{"-", "1.9773`"}]],
       Annotation[#, -1.9773, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UtIlHEUxuEztfGa3UA3RYLQMhC67IKIbhTktKtdi26QYXY12pgZRKWb
KKYctWDGbqNBEETWpiLIKWtRKyNSqBZmZVFRZs+3+PGe97znnP83Wrt9X7ox
FRGPsH52REtlxF7cmhtxE01VEVv00xjV/zcnYhp/MIW/aNTPy/tQxpfi1ayI
a3wrXeHOS7qMDtPltICc/DlfYv4FPcA344tsAm36Rf2l6v2+4928iCF+nP+M
Ae82me+nJ8wuNnOHnpGdRQfOYUx+eH7EERzCgLmjtEDrzNe7e5Dv5xvUadTY
u+itatrL9+CCtx67dVKvPfk+ZO0sdGMBnsjqzGxWd8t+8kv4rfw2ZNSXkHU3
514f8tjh7YzZLO1GFz6620M/0FV2K+lDu+X0AR02f09ewW+Qj+At8sjhrrzT
XIe3Mt7opN8xYmeStslvq1eqK3DebLtbn/RO0U38Rpw2N2b/tZlR+obe0L+O
Sb/xG97rf6WltCT5H9kZlBdpOV+GGW6m3K7Wr0n+DnyrnV16O/Hb3Slzv2gD
3yI/br+gPqZuxhr1OqzFtBtd8j3qK7Ld9Cqt9dsX4Zmsl68yd1mWUgeN5DuS
78FM3Jc/NRvqony193/QIfwHjwJ4Cg==
          "]]},
        RowBox[{"-", "1.9812`"}]],
       Annotation[#, -1.9812, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ldsjmEYxvGHWFHdrRUixKoKB62DWokREkmtAwlFjUO0QhAxW6OtT4dd
MQ9IHCDBiVaMBKVDWxINQiSOHYjECDV+z8H/u+5x3ffzfO/7jlxXurSkRwhh
mJ/NqSHkZ4TQmhJCWXoI5biZHEJJWgg36H75F56r8iv4i0r+KlQggSMo5ZnE
Oxl/eLrRhW24bs8+9b24g9v4pJaWFUI6kpGKFGzh36O/G3n2trjXO/Vb8uzM
EFapjXVWER1DV8azzWxGM+9Hnuf0j5kVej2zQxjNd0beRU/T17SevqeL6U66
ntbRdbSW1rlfA/0sb6Q1WCOupmtphvs081yjl9V6O7cP+mKEWoteL/F7cb77
FInz6CXeZ3rp6glxsV1HaZO7PkON3oZ4B3o0nocEOuIdaDvNNTvRrs4Y0yb1
UnpWPkRvKF6IL9jXRi/SGZ7PdroDr/RfohPL9Jtpf/PHeU6gSC1PbYA4GSvl
3+N7d6ckek/eFs9AO76qZZnviO9MPFA8Pb4vmiXPRL58CnLFE3DXrgPu0kCH
yOfrzYu7zHyTL3fGLHkf8X6+MryRv8UHvRWo8r+f0MO0EhXIND+OJ4Mu9MwL
0cpzRG+82lT7djnzhnyafDjG8+fgAd9B9fv0EF3Mm+D9Z8dvvr+0mzbE++OR
3i/5Qf5j8n7iQnG2+JTeFvlWzMZj93+Cp1gi325XNU8K7xozOWo/47OhJehy
/iZ6Mn4r6ovi8zAzG0mxrraa57C8AgWYigV8D9V78tTyVMfvQr0m3tvZjThg
ZwFPOZ1OZ8RngdVmZ9JV9IfZcWaKxWPpU/WN9Ix8oGc1KH7j4nP2NdPzNFtt
VPwm7B1jfq54Dur1B8d3ovYfyPmaLg==
          "]]},
        RowBox[{"-", "1.9851`"}]],
       Annotation[#, -1.9851, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0jlMVFEUh/GDCjPghkLlNg4oaEEixI1CkWihcQ1GgdYSXBoLrNyiicZS
RVRMRC1IrFwTcIngaEJjIpoI6DBTW4uNqL9XfPnO/9xz73tz32SPnWo7WRIR
ORQWRiyrjBjixiURKXUar+QKLkeT/rC8XL1jUcRYdUQrv9Z7rveGf8mXFkf0
V0XcwwY0YsbaafP7sB97cRAHcMiefnvemRlyzgjP6l3V+8fv5WH9Uf4rl6rv
Wnsrv1C/xG/9vLNm+Ir+db6Bs+gx+9haj/5usw/ln/IjnotSTMvz+KaZci7K
FVyGNApyii9bb3PmYXxSd7iTTtxSD3Ifr/OM9Zg0X8916NJfwSvxTT/Dq9Cr
X8O1mNDP8mpc09/MW5DX3+7srGduTc5Vb0rm5G3qDG+U96ibuUZuUddyN756
9y5u1zuKI1gjT3HO2b1LfT8ek3f6VruwVl2HZ/oX7H/KF7nbe93mgtzHRb7D
0/zAswfw0dk/nJHHJL5jCsftbUn+S8ndIo2MfV/0xlG0XmWuGk+8U5n1M3op
bpc7MG7tM0Y8o0E+l/y+5C6ck/K+Jeo5yMqd1v/YmzMzYc8HbtI7zyeSezLT
nNwTLzA3HwO4jwbr/wHlyGjL
          "]]},
        RowBox[{"-", "1.989`"}]],
       Annotation[#, -1.989, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzrkvH3AYx/HHYlPnxtJJ1fUT52BVuqBYmyYGiTRYmiiSNrQSWpqoOBe1
sjGQOIr2H2ji/AuKEkZHW16Gd97P5zm++T5u7WrqTIqICbSnROxlRuxjF4c4
wI9HEYmMiBIU4adczIv4lhaxJSenR2zzvPyOC8y+81Pe5HxeQJ29Hn6LDf0e
uRd9eO32TP/Pw1xeN89Td6ZG/PKPNflYPsEp2u0v+vNvdbf9J5yLN5jBirtp
XuVZ/srjWM5Su2twP8ZL8pj+jPer1C3qCm7mSq62V8Yv5FJu4nKetD/nX1O8
7f0d1Nttk4ftnNoZ4km9FL0tuVHOUT/nTTlJ/cX8Mx/JI/wKA+bHcj+Pmofe
hlwnZ6treV2+8/8R82G9Q/kTv8QH/xrER/y3c2nnH6/Zeea2Azd6tzhXl/CN
+XvzW650V4GEXIyEeSEXoUy/HNf2LvSvuFQuMMtHjfeq5L/697d9WbA=
          "]]},
        RowBox[{"-", "1.9929000000000001`"}]],
       Annotation[#, -1.9929000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvhFEUh/Gjxxi0JCJRaa29CrErFRJGROxLzVfQU1lja/kKdq1lbGNf
SzR+Uzx5zjn/e9733rLekfbhnIiYwXxRRD9SuCqMSGMpL2JWf52MuEEad7jF
uSxXlpfNnb3BstmcPiN/wD2e8IgLWb7sqDiiMT9iQH1r5w49+hdnqviZq/mV
E85s8LGdJrMf9TBG0Kd/5xp+41r+4AI7m3xip9nsVz2KMaT0X1zHn1zP35y0
s8X7fIBd8wr3GjebwEBBRKu+JBHRwqXcxpfeVOj8n3/t2TnMvg/3shXZoL0O
dSfa0Y0uXMm2fXcHk5jCqtmQ86c4w5B/1GTfhUp9Wl6u/lEvYBGfzkybrclS
+nV+8P0MTtzjGA3u9g8OoE/A
          "]]},
        RowBox[{"-", "1.9968000000000001`"}]],
       Annotation[#, -1.9968000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzUcyRmEQBdCWhrIRJtI2FMaoYgkG+OWcLQcl51Al5xymDIU9yJzBqVv9
vtuvixo66zuSIqKbxvSImdyIiYyIaTnHLEPmk6yIU54zI97p1U3Oi1jwvsg8
yywxrH+me86L7gd9+in6q97XWGGDdUb0L3QvedX9pF//ylzOpLnN7pS8MV/z
6L3NbjsJWmmhyfcjecwhp5yw5calvOKMC85p1u+UXXTQQzdPvte5U+luFRUk
3P9iwFuqeUdvl2322WPUnVt7d7zpfjOon6ZfnRNRQzGllDCmf6+br5eaHfEj
fymg1vunvQ2dA//elGW+jcsHO4U6aXb+ZJgH5T+CAkrs
          "]]},
        RowBox[{"-", "2.0007`"}]],
       Annotation[#, -2.0007, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Ecy5WEUhvGjzOWJltoKLMEALQy56Kou2ZXjBLtgAUzllpWwBDm20GxC
HvrdwVPP977nfPUPpZ2j9SNpETGFREbEa3ZEFb/wL37jstyId66Rk87V/JEX
sZATsYh5dGVGlOvmzVrtHumO8ScrokNuRxsWzPP13fZ/pO7LnfoT51O02E/K
3ejCknmBPmm/kJflHv2Z8zna7F/xJS6wYr7nHXvs7/OqfK2/wS067N/zHf7h
r/mBvV77h7wmP+gf8T/1Xfb7Pa8PvVg3L9L32S/mDXlA/+T8nHpP+8PyEAax
aV6iH7Bf4f8MciVv6X/qt7mUJ3nO3V1Od2+HZ+Uls0+5NvXPuY6/OEs/433H
5SZuxm9MyI2cQAPG5Gl+89xvKQFJ5g==
          "]]},
        RowBox[{"-", "2.0046`"}]],
       Annotation[#, -2.0046, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0LkyA2AUhuGjVMhCbKXGdglmuAA6pQljIpMZDb01Kq5C1oqCwloJqZQR
W22taNyAJ8U733aSzJ+R3Pr8WldEFJBPROTwmIlYoTO456fpKrrxILfRQlae
S0Xs9UScysVkxC62+R1sYAubeHVz57aJPze3tIEC6rbFtO/DMY7woht29+2z
QzTvrqa7lut+95kf1H/JAzRnr+qu5Jr9ie/Xf8oZumyv6C7laueNfJ/+Q+6l
S/ay7kKu2Nt8Wv8up2jWXtKdy+XO/8An9W9ygi7YD3Vncsne6rxX/ys36U3n
zfiRG3TWfdHNiXzgfh8T/CRGMY4xTOEfK9c/NA==
          "]]},
        RowBox[{"-", "2.0085`"}]],
       Annotation[#, -2.0085, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdVX001Wccpw7ZbUK02pRi63hba46JrWOf5iYuS1KRRRnVZLIUR7gllUh1
DL/lUm6KishLXi4Lj6QYl9a0rpIbufI6Kb0sWq17e55/+p5zzz3PeZ7f5/l+
P8/3+/kY+//isWWKmppa5Nuf8v9djMHQmz/uks0nhU49UQaFj5DiUFayvWAV
8Umqf2bm8wgax2faNd1dR3iy7B32vEdoO7XPdlS+gVQaxQ2vrhxFy9oIw8TH
fsRABTAKba65ue/ZVhJqr/ziH7i3z4v6biKYtEqVMQLB4UrOLSaUmKsuGMGQ
mX+wMDaMKNHeQuJI0/TlFw5EEGU2Tj1D+Dyw3LAjLoqo4OyH0Dpt07hGwh6S
ka6MQUjWHOz72HEfeW6mBBxAwqfeN7+8Hks8VAkOYP34ohonpwO0vn6YX52S
t7HpIK2nHy9TZFy44BDZqoqHMCs+O5LeHE+uPlMC9sGrddfyWtfDZL4qwT4o
bJdqjUkTSbSqYAXKp+k+1XQ7SlRwsl6YJg7v0r1xjFirohddobcM36xKIio6
kx6gunKA+Af+SkZU5fbA7n7vealZMnF+VzD013RM8geTSY4SLrsbHxRVpvbm
pZB379UN0/6oZBKUSvmXY94Zw3y5JUf57oK+b3XDfyMc5fce2p3iPKUXf6N8
3sVXh7gJ7ZDjlL87yJ6YU7N5URrlqwOtrjprZcNplB8ZBM+1bPgXRJSPvxH7
Mvxx07Z0Wv8txE1rLYy2zKD1tkMvMtY5fCyD1ncTcybvfWJSeYLW8ycsIy3V
+6NP0vzbkO3u53rHOpPmK0WnPEQwoyOT5vcHjrbxJbl+YppPI6ZYzP3O4pqY
3t+Aux1LbutMiul9V1AcMFPh+UJM8WshMvfQLC0UU7wqSIxu7A6exb4vQ+5V
nkT4WSY9X4jzK/jGvo0n6Pk8HFC/35SWn0HP5yA/BBY6c9PpeTFObWs3GVmY
Rvc5/K6to8mv58jE3qDqsNQEDA6Le3b+mExe5T3+a6X/PljJHd1mORyj6x1I
5CcLTsfH0bUfzEhWd83rGLp2x9QKefN2z910vQy2wRu4Owt2EbX3gu1/0Wip
a28eAPa9qUCY6poQAobvVlV/2achAuz+nzmY56zYD5bfA03h3jnGR8Hy5z+5
37pZkAJWn0dMTf3+yXSw+jttjC9aDWSB8TPf9lLPKa0cMP4yE3lHluWfA+N3
2Yq+luLnuWD8+/30ckeMogDsfbgWm8s5C4rB3u9h9m1Hw+QSsPet3uB9plR6
Cez9BVVZAQWdpWD9YVb0zezhujKw/hEJIj1aosvB+mvGm+V1Qu0KsP4TyLmV
BsIKsP40kIr227RVgPVvY+hx5/U8CVh//+sXkHtriQSs/7sUPoufeEnA5oPn
296qs10CNj8iLtRBFiYBmy+XqYqx0bf7bP6SXDyHXntKwObToSB7lftiCdj8
Or/26656UQE23/nh8VWCEpa/HEZP9TJ5vhVg+uDdsXvdh6/KwfQj0cu70yCp
HExfmu8ZBzl9VA6mP81Hvq8rSi4D06cHEpndavUyMP3aWViNr7eUgunbqGmA
UFTD+FdAunR89vzpl8D00XahzkSCWwmYfmpcX1cnSigG01cjNamuSVgRmP5a
cN2BJo0XwfS5LLThByGvAEy/o62Dal2+vQCm72lXamTl/rlg+r/HK89xMOIc
mD+slOn7zt6bA+YfmRvb9MThZ8D8RUvjbGDfxiww//GtrBmtDTsJ5k/X7GL0
eXoiMP/qyt1kzUtNBfO30ojh0ybjx8D8b8LqpPH0+INg/hhvez3PShgD5p+J
CstYriMczF/VazurQz0C8Z7/4n9EbM4S
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504,
  PlotRange->{{0.95, 1.05}, {-0.03, 0.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 313},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->30705349]
}, Open  ]],

Cell["\<\
Streamlines near the airfoil surface show no waviness, there are no \
streamlines interior to the airfoil and the flow leaves the trailing edge \
smoothly, satisfying the Kutta condition.\
\>", "ExampleText",
 CellID->667775740]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMVortexLinearNeumann",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMDoubletConstantDirichlet",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ForceAndMoment",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PlotSurfacePressureCoefficient",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PlotSurfacePressureCoefficient"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->37738621]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["3.1 Introduction To Panel Methods",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["3.2 Validation Example",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/ValidationExample"]], "Tutorials",
 CellID->499723042],

Cell[TextData[ButtonBox["3.3 Implementation",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/Implementation"]], "Tutorials",
 CellID->336290191],

Cell[TextData[ButtonBox["3.5 Convergence and Timing",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/ConvergenceAndTiming"]], "Tutorials",
 CellID->351529306],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "Tutorials",
 CellID->8122694]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "MoreAbout",
 CellID->229715577]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"PMDoubletQuadraticDirichlet - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 58, 28.3290000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "PMDoubletQuadraticDirichlet[r_p, \\[Alpha]] implements a panel method \
for uniform flow over an airfoil using doublet panels of quadratically \
varying strength and internal Dirichlet boundary conditions. Panel endpoints \
describing the discretized airfoil are located at r_p, and the angle of \
attack is \\[Alpha]. The function returns strength parameters for the doublet \
density function, the strength parameter for the wake panel, locations of \
collocation points and a list of surface speeds associated with collocation \
points.", "synonyms" -> {}, "title" -> "PMDoubletQuadraticDirichlet", "type" -> 
    "Symbol", "uri" -> "Aerodynamics/ref/PMDoubletQuadraticDirichlet"}, 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[15163, 472, 460, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->59031018]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 367093, 7308}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[608, 21, 76, 1, 70, "SymbolColorBar"],
Cell[687, 24, 191, 5, 70, "LinkTrail"],
Cell[881, 31, 4000, 88, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4906, 123, 70, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[4979, 126, 1431, 35, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6447, 166, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->295041469],
Cell[7030, 185, 251, 8, 70, "Notes",
 CellID->1067943069],
Cell[7284, 195, 1751, 63, 70, "Notes",
 CellID->275911084],
Cell[9038, 260, 1566, 58, 70, "Notes",
 CellID->884219735],
Cell[10607, 320, 569, 17, 70, "Notes",
 CellID->252999978],
Cell[11179, 339, 833, 20, 70, "Notes",
 CellID->631099542],
Cell[12015, 361, 797, 28, 70, "Notes",
 CellID->1720708],
Cell[12815, 391, 674, 28, 70, "Notes",
 CellID->119343517],
Cell[13492, 421, 546, 16, 70, "Notes",
 CellID->509195412],
Cell[14041, 439, 70, 1, 70, "Notes",
 CellID->75751524],
Cell[14114, 442, 1012, 25, 70, "3ColumnTableMod",
 CellID->14117100]
}, Closed]],
Cell[CellGroupData[{
Cell[15163, 472, 460, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->59031018],
Cell[CellGroupData[{
Cell[15648, 489, 148, 5, 70, "ExampleSection",
 CellID->165605336],
Cell[15799, 496, 131, 6, 70, "ExampleText",
 CellID->77267041],
Cell[15933, 504, 100, 3, 70, "Input",
 CellID->326492779],
Cell[16036, 509, 444, 13, 70, "ExampleText",
 CellID->301361980],
Cell[CellGroupData[{
Cell[16505, 526, 369, 12, 70, "Input",
 CellID->317289154],
Cell[16877, 540, 218, 7, 36, "Output",
 CellID->1561761]
}, Open  ]],
Cell[17110, 550, 264, 5, 70, "ExampleText",
 CellID->167522],
Cell[17377, 557, 217, 7, 70, "Input",
 CellID->979024211],
Cell[17597, 566, 85, 1, 70, "ExampleText",
 CellID->20057380],
Cell[17685, 569, 147, 5, 70, "Input",
 CellID->233544807],
Cell[17835, 576, 791, 28, 70, "ExampleText",
 CellID->442126641],
Cell[18629, 606, 294, 9, 70, "Input",
 CellID->439469742],
Cell[18926, 617, 520, 11, 70, "ExampleText",
 CellID->10578989],
Cell[19449, 630, 305, 6, 70, "ExampleText",
 CellID->99130043],
Cell[CellGroupData[{
Cell[19779, 640, 211, 6, 70, "Input",
 CellID->544103304],
Cell[19993, 648, 164, 5, 36, "Output",
 CellID->402709323]
}, Open  ]],
Cell[20172, 656, 189, 4, 70, "ExampleText",
 CellID->59684772],
Cell[20364, 662, 622, 21, 70, "Input",
 CellID->509204874],
Cell[20989, 685, 623, 16, 70, "ExampleText",
 CellID->342367202],
Cell[21615, 703, 827, 24, 70, "Input",
 CellID->555628545],
Cell[22445, 729, 484, 8, 70, "ExampleText",
 CellID->260053747],
Cell[CellGroupData[{
Cell[22954, 741, 1024, 26, 70, "Input",
 CellID->130177],
Cell[23981, 769, 92246, 1579, 70, "Output",
 CellID->22126918]
}, Open  ]],
Cell[116242, 2351, 290, 6, 70, "ExampleText",
 CellID->259606597],
Cell[116535, 2359, 270, 5, 70, "ExampleText",
 CellID->139902411],
Cell[CellGroupData[{
Cell[116830, 2368, 452, 14, 70, "Input",
 CellID->180266037],
Cell[117285, 2384, 259, 8, 36, "Output",
 CellID->21026143]
}, Open  ]],
Cell[117559, 2395, 283, 5, 70, "ExampleText",
 CellID->527976917],
Cell[CellGroupData[{
Cell[117867, 2404, 89, 3, 70, "Input",
 CellID->123809147],
Cell[117959, 2409, 194, 6, 36, "Output",
 CellID->138380640]
}, Open  ]],
Cell[118168, 2418, 164, 4, 70, "ExampleText",
 CellID->753558053],
Cell[118335, 2424, 162, 6, 70, "Input",
 CellID->435840926],
Cell[118500, 2432, 276, 5, 70, "ExampleText",
 CellID->139054009],
Cell[CellGroupData[{
Cell[118801, 2441, 447, 12, 47, "Input",
 CellID->671472236],
Cell[119251, 2455, 7060, 123, 351, "Output",
 CellID->169777575]
}, Open  ]],
Cell[126326, 2581, 432, 17, 70, "ExampleText",
 CellID->571494656],
Cell[CellGroupData[{
Cell[126783, 2602, 712, 23, 70, "Input",
 CellID->42630738],
Cell[127498, 2627, 459, 16, 36, "Output",
 CellID->240396878]
}, Open  ]],
Cell[127972, 2646, 365, 7, 70, "ExampleText",
 CellID->24035690],
Cell[CellGroupData[{
Cell[128362, 2657, 346, 10, 70, "Input",
 CellID->34907031],
Cell[128711, 2669, 338, 9, 36, "Output",
 CellID->408107196]
}, Open  ]],
Cell[129064, 2681, 321, 6, 70, "ExampleText",
 CellID->47127959],
Cell[CellGroupData[{
Cell[129410, 2691, 236, 8, 70, "Input",
 CellID->274981366],
Cell[129649, 2701, 260, 8, 36, "Output",
 CellID->216015670]
}, Open  ]],
Cell[129924, 2712, 337, 6, 70, "ExampleText",
 CellID->328772922],
Cell[CellGroupData[{
Cell[130286, 2722, 353, 12, 70, "Input",
 CellID->762946865],
Cell[130642, 2736, 260, 8, 36, "Output",
 CellID->287563983]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[130951, 2750, 221, 7, 70, "ExampleSection",
 CellID->1293636265],
Cell[CellGroupData[{
Cell[131197, 2761, 252, 7, 70, "ExampleSubsection",
 CellID->421192202],
Cell[131452, 2770, 213, 5, 70, "ExampleText",
 CellID->5610347],
Cell[131668, 2777, 154, 5, 70, "Input",
 CellID->242241179],
Cell[131825, 2784, 190, 4, 70, "ExampleText",
 CellID->299806311],
Cell[CellGroupData[{
Cell[132040, 2792, 555, 18, 70, "Input",
 CellID->278559890],
Cell[132598, 2812, 5842, 103, 70, "Output",
 CellID->27308021]
}, Open  ]],
Cell[138455, 2918, 120, 3, 70, "ExampleText",
 CellID->176584194],
Cell[138578, 2923, 437, 13, 70, "Input",
 CellID->664892474],
Cell[139018, 2938, 138, 4, 70, "ExampleText",
 CellID->829463257],
Cell[CellGroupData[{
Cell[139181, 2946, 312, 10, 70, "Input",
 CellID->702755110],
Cell[139496, 2958, 6364, 112, 70, "Output",
 CellID->729372723]
}, Open  ]],
Cell[145875, 3073, 157, 4, 70, "ExampleText",
 CellID->187376629],
Cell[CellGroupData[{
Cell[146057, 3081, 718, 21, 70, "Input",
 CellID->539184285],
Cell[146778, 3104, 259, 8, 36, "Output",
 CellID->232744314]
}, Open  ]],
Cell[147052, 3115, 198, 4, 70, "ExampleText",
 CellID->169245216],
Cell[CellGroupData[{
Cell[147275, 3123, 305, 12, 70, "Input",
 CellID->208999159],
Cell[147583, 3137, 262, 9, 36, "Output",
 CellID->312612995]
}, Open  ]],
Cell[147860, 3149, 388, 7, 70, "ExampleText",
 CellID->511124957],
Cell[CellGroupData[{
Cell[148273, 3160, 640, 19, 70, "Input",
 CellID->567786021],
Cell[148916, 3181, 9727, 167, 70, "Output",
 CellID->638789552]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[158704, 3355, 223, 7, 70, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[158952, 3366, 227, 7, 70, "ExampleSubsection",
 CellID->30521753],
Cell[159182, 3375, 451, 8, 70, "ExampleText",
 CellID->120830056],
Cell[159636, 3385, 691, 21, 70, "Input",
 CellID->210128799],
Cell[160330, 3408, 259, 5, 70, "ExampleText",
 CellID->112154987],
Cell[CellGroupData[{
Cell[160614, 3417, 1246, 40, 70, "Input",
 CellID->703042737],
Cell[161863, 3459, 495, 16, 39, "Output",
 CellID->426901297]
}, Open  ]],
Cell[162373, 3478, 225, 5, 70, "ExampleText",
 CellID->937232338]
}, Closed]],
Cell[CellGroupData[{
Cell[162635, 3488, 239, 7, 70, "ExampleSubsection",
 CellID->233233938],
Cell[162877, 3497, 643, 10, 70, "ExampleText",
 CellID->64752385],
Cell[163523, 3509, 308, 6, 70, "ExampleText",
 CellID->507899588],
Cell[CellGroupData[{
Cell[163856, 3519, 1935, 57, 70, "Input",
 CellID->49740593],
Cell[165794, 3578, 11988, 204, 70, "Output",
 CellID->125347478]
}, Open  ]],
Cell[177797, 3785, 186, 4, 70, "ExampleText",
 CellID->520516665]
}, Closed]],
Cell[CellGroupData[{
Cell[178020, 3794, 226, 7, 70, "ExampleSubsection",
 CellID->104403840],
Cell[178249, 3803, 341, 6, 70, "ExampleText",
 CellID->391229248],
Cell[CellGroupData[{
Cell[178615, 3813, 1654, 52, 70, "Input",
 CellID->451142620],
Cell[180272, 3867, 493, 16, 39, "Output",
 CellID->393813574]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[180826, 3890, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[181060, 3899, 324, 6, 70, "ExampleText",
 CellID->416625656],
Cell[181387, 3907, 206, 4, 70, "ExampleText",
 CellID->728813289],
Cell[CellGroupData[{
Cell[181618, 3915, 385, 10, 70, "Input",
 CellID->112529997],
Cell[182006, 3927, 5179, 92, 70, "Output",
 CellID->13335572]
}, Open  ]],
Cell[187200, 4022, 150, 4, 70, "ExampleText",
 CellID->390242666],
Cell[CellGroupData[{
Cell[187375, 4030, 212, 7, 70, "Input",
 CellID->238007975],
Cell[187590, 4039, 345, 12, 36, "Output",
 CellID->633670472]
}, Open  ]],
Cell[187950, 4054, 151, 4, 70, "ExampleText",
 CellID->25666953],
Cell[CellGroupData[{
Cell[188126, 4062, 805, 24, 70, "Input",
 CellID->592619],
Cell[188934, 4088, 239, 7, 36, "Output",
 CellID->519408813]
}, Open  ]],
Cell[189188, 4098, 95, 1, 70, "ExampleText",
 CellID->722709344],
Cell[189286, 4101, 156, 4, 70, "ExampleText",
 CellID->492689119],
Cell[CellGroupData[{
Cell[189467, 4109, 2588, 73, 70, "Input",
 CellID->266881112],
Cell[192058, 4184, 270, 8, 36, "Output",
 CellID->392346976],
Cell[192331, 4194, 102309, 1731, 70, "Output",
 CellID->568513827]
}, Open  ]],
Cell[294655, 5928, 387, 7, 70, "ExampleText",
 CellID->38752132],
Cell[295045, 5937, 155, 4, 70, "ExampleText",
 CellID->254018838],
Cell[CellGroupData[{
Cell[295225, 5945, 1204, 37, 70, "Input",
 CellID->230503503],
Cell[296432, 5984, 258, 8, 36, "Output",
 CellID->48322270]
}, Open  ]],
Cell[296705, 5995, 114, 3, 70, "ExampleText",
 CellID->88671999],
Cell[296822, 6000, 86, 1, 70, "ExampleText",
 CellID->112543031],
Cell[CellGroupData[{
Cell[296933, 6005, 2131, 59, 70, "Input",
 CellID->240459914],
Cell[299067, 6066, 62878, 1082, 70, "Output",
 CellID->30705349]
}, Open  ]],
Cell[361960, 7151, 238, 5, 70, "ExampleText",
 CellID->667775740]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[362247, 7162, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[362667, 7176, 886, 29, 70, "SeeAlso",
 CellID->37738621]
}, Open  ]],
Cell[CellGroupData[{
Cell[363590, 7210, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[364012, 7224, 190, 4, 70, "Tutorials",
 CellID->341631938],
Cell[364205, 7230, 167, 3, 70, "Tutorials",
 CellID->499723042],
Cell[364375, 7235, 160, 3, 70, "Tutorials",
 CellID->336290191],
Cell[364538, 7240, 177, 4, 70, "Tutorials",
 CellID->351529306],
Cell[364718, 7246, 158, 3, 70, "Tutorials",
 CellID->8122694]
}, Open  ]],
Cell[CellGroupData[{
Cell[364913, 7254, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[365335, 7268, 149, 3, 70, "MoreAbout",
 CellID->229715577]
}, Open  ]],
Cell[365499, 7274, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

