(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    293643,       6072]
NotebookOptionsPosition[    282959,       5717]
NotebookOutlinePosition[    284675,       5760]
CellTagsIndexPosition[    284588,       5755]
WindowTitle->PMVortexLinearNeumann - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.1 Introduction To Panel Methods\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"], "\<\"3.2 \
Validation Example\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ValidationExample"], "\<\"3.3 \
Implementation\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/Implementation"], "\<\"3.5 Convergence \
and Timing\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ConvergenceAndTiming"], "\<\"3.6 \
Aerodynamic Coefficients\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"], "\<\"3.7 \
Analysis of an Airfoil\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AnalysisOfAnAirfoil"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PMDoubletConstantDirichlet\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"], \
"\<\"PMDoubletQuadraticDirichlet\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"], \
"\<\"ForceAndMoment\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ForceAndMoment"], \
"\<\"PlotSurfacePressureCoefficient\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PlotSurfacePressureCoefficient"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/ref/PMVortexLinearNeumann\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/PMVortexLinearNeumann"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
PMVortexLinearNeumann.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/PMVortexLinearNeumann", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["PMVortexLinearNeumann", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["PMVortexLinearNeumann",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"], "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["p", "TI"]], ",", 
        StyleBox["\[Alpha]", "TR"]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]implements a panel method for uniform flow over an \
airfoil using vortex panels of linearly varying strength and external Neumann \
boundary conditions.  Panel endpoints describing the discretized airfoil are \
located at ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["p", "TI"]]], "InlineFormula"],
     " and the angle of attack of the airfoil is ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     ".  The function returns strength parameters for the circulation density \
function, locations of collocation points and surface speeds at collocation \
points."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->92080746],

Cell[TextData[{
 "Collections of vectors are of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "The discretized airfoil is specified by ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]]],
 " straight-line panels, where the circulation density for each panel varies \
linearly with distance from the beginning of each panel (use the clockwise \
numbering convention to identify the beginning of a panel).\t\t\t\t\t\t\t\t\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Gamma]", "TR"], 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], ")"}]}], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["i", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], " "}]}]}]], "InlineFormula"],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["i", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   StyleBox["N", "TI"]}]], "InlineFormula"],
 "\t\t\t\t\tStrength parameters are denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["b", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 " and the panel-local coordinate is denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["x", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 "."
}], "Notes",
 CellID->275911084],

Cell[TextData[{
 "There are two unknown strength parameters for each airfoil panel resulting \
in 2 ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " unknowns.  Strength parameters for the discretized airfoil are grouped as \
lists.\t\t\t\t\t\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["3", "TR"]], ",", "...", ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["3", "TR"]], ",", "...", ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"]
}], "Notes",
 CellID->35560001],

Cell[TextData[{
 "Boundary conditions at collocation points provide ",
 Cell[BoxData[
  StyleBox["N", "TI"]], "InlineFormula"],
 " equations, continuity of circulation density between panels (except at \
trailing edge) provide ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N", "TI"], "-", "1"}]], "InlineFormula"],
 " equations, and the Kutta condition (zero circulation density at trailing \
edge) provides the final equation for a system of 2 ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " linear algebraic equations.  The system of equations is solved using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Notes",
 CellID->631099542],

Cell[TextData[{
 "Output of PMVortexLinerarNeumann is two lists of strength parameters, ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", a collection of vectors locating collocation points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 ", and a list of surface speeds at collocation points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1720708],

Cell[TextData[{
 "If a list of angles of attack is input instead of a single angle of attack, \
nested lists of ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " are returned."
}], "Notes",
 CellID->164568021],

Cell["The following option can be given:", "Notes",
 CellID->443257480],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["Epsilon",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/Epsilon"], 
    SuperscriptBox["10.", 
     RowBox[{"-", "10"}]], Cell[
    "small number for displaciing collocation points", "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True}}}},
 CellID->409281092]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->296522323],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->511814029],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->395972740],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->76286106],

Cell[TextData[{
 "This example uses an Eppler-205 airfoil specified by a data file located in \
the folder Airfoil Geometry.  Use AirfoilFromDataFile to import the data and \
arrange it in the form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 "."
}], "ExampleText",
 CellID->48545141],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", "\"\<Aerodynamics\\Airfoil Data\\e205.dat\>\"",
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"NumberOfVectors", "[", "rD", "]"}], ",", 
   RowBox[{"Head", "[", "rD", "]"}]}], "}"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->43842758],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61", ",", "CartesianVectors"}], "}"}]], "Output",
 ImageSize->{155, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->366275460]
}, Open  ]],

Cell["\<\
The collection of 61 vectors of the data type CartesianVectors locates \
endpoints of 60 connected panels.  Generate a graphic to plot the discretized \
airfoil.  This will be incorporated in a subsequent graphic.\
\>", "ExampleText",
 CellID->60751918],

Cell[BoxData[
 RowBox[{
  RowBox[{"grD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->493524749],

Cell["Specify an angle of attack for the airfoil.", "ExampleText",
 CellID->711853039],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"6.", " ", "Degree"}]}], ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->847786885],

Cell[TextData[{
 "Solve the model.  Output consists of the lists of strength parameters ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", locations of collocation points, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " and the fluid speed at collocation points,",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " ."
}], "ExampleText",
 CellID->20624687],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->53812608],

Cell[TextData[{
 "Flow visualization provides a good plausibility check for model results.  \
The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ContourPlot can be used to plot streamlines for the flow field.  \
Compute the stream function at the location of an arbitrary field point ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 ".  Since the primary focus of this software is numerical computations, the \
standard form for output is a list of results.  In this case, the result is a \
list of one lengthy function of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 ".  Remove the extraneous list brackets to obtain the stream function. "
}], "ExampleText",
 CellID->342367202],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rF", "=", 
   RowBox[{"MakeCartesianVectors", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", 
      RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B"}], "}"}], "=", 
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rF", ",", "rD"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "a"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "b"}]}]}], ";"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->133172956],

Cell["\<\
Generate the graphics for a streamline plot for flow over the airfoil.  Some \
experimentation with option values were made to obtain the plot below.  The \
number of contours plotted was used to avoid streamlines very near the \
airfoil, PerformanceGoal->\"Speed\" was used to obtain a contour plot in \
reasonable time, and MaxRecursion was set at a minimum value to avoid \
noticeable numerical artifacts in computed streamlines.\
\>", "ExampleText",
 CellID->76299467],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", ".5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "22"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "2"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "grD", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7.", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->808226483],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0fQVUlM/3PnZ3KyIqBhZ267UTu7u7uxW7xUDFFkVREaSlh+6O3QUp6ZQU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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2248, 2630, 2520, 2626, 2627, 2266, 2703, 3224, 3223, 3359, 
          2368, 2661, 2660, 1996, 3454, 3453, 3668, 2278, 3550, 2279, 2665, 
          2664, 2863, 2862}]},
        "0.451`"],
       Annotation[#, 0.451, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{1940, 2495, 2609, 2610, 2663, 2662, 2229, 3679, 2613, 2861, 
          3358, 2277, 3649, 3357, 3246, 2792, 2245, 3205, 2109, 2631, 2632, 
          2411, 1975, 2628, 2523, 2635}]},
        "0.41000000000000003`"],
       Annotation[#, 0.41000000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2230, 3168, 2231, 3185, 2095, 2611, 2612, 2398, 3623, 1972, 
          2607, 2499, 3191, 3400, 3192, 2791, 3195, 3194, 2108, 2629, 2247, 
          2410, 2246, 2524, 2112, 2636, 2251, 2413, 1976, 2633, 2528, 2637}]},
        "0.369`"],
       Annotation[#, 0.369, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzz8vg3EUxfFrKqregz9d0dgMDDaRNpE0sYiks7TYjBa0DzabN8BgUaL+
bBYWQyUiWtRWNt6AT4eT7zn33Ofm94yUKkvlvohYpiQVcTYQ0cxEPNPqUMRJ
f0QJJ3BqMKKOK3bO8R5zuKVvYEvfpiN3XnTH2JVf+Vn9DD+HC/iIa+YP2MF5
zJsXqCw3fLvjbjPtLTRKu3LFu651e/ybWYvGqCqv6250Nb5t9k7jlMgbulvd
Pt8x+6IsHcibujvdIf/Bd72lzl/2/ns44gIn8cnOtr7If9v55H/wSp/w0+4t
yqf8L5+394cFLJr/Azp4OHA=
          "]]},
        "0.328`"],
       Annotation[#, 0.328, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2687, 2640, 2641, 2280, 3606, 3607, 3455, 3456, 1998, 3251, 
          1997, 3629, 3250, 2864, 3249, 3248, 3247, 3040, 2123, 2849, 2122, 
          3039, 3404, 2532, 2121, 2624, 2120, 2531, 3403, 3033, 2119, 2847, 
          2118, 3031, 3402, 3025, 2117, 2844, 2116, 3023, 3401, 2527, 2114, 
          2620, 2113, 2525, 2794, 1949, 2522, 2784, 2783, 2401, 2235, 2504, 
          2503, 3186, 2232, 2779, 3188, 3187, 2096, 2603, 2604, 2497, 2496, 
          1939, 2494, 1930, 2765, 2764, 2216, 3169, 2084, 2479, 2766}]},
        "0.28700000000000003`"],
       Annotation[#, 0.28700000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{1953, 2795, 1947, 2790, 2409, 2244, 2518, 3624, 2517, 3203, 
          1974, 3438, 3202, 2848, 3015, 3014, 3200, 1973, 2406, 2241, 2516, 
          2622, 2621, 2530, 1952, 3032, 3437, 3034, 2846, 3030, 3029, 1951, 
          3024, 3436, 3026, 2843, 3022, 3021, 1950, 2526, 2787, 2786, 2404, 
          2237, 2509, 2508, 2614, 2615, 2400, 2399, 2617, 2099, 3189, 3190, 
          2778, 3396, 3397, 2498, 2770, 2769, 2394, 2219, 2483, 2482, 3163, 
          2214, 2763, 2215, 3164, 2083, 2588, 2589, 2476, 2475, 2597}]},
        "0.246`"],
       Annotation[#, 0.246, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2243, 2408, 2407, 2625, 2107, 3204, 2242, 3018, 3399, 3012, 
          2106, 2839, 2105, 3010, 3398, 3006, 2240, 3201, 2405, 2623, 2104, 
          2515, 2239, 3199, 3198, 2845, 2103, 3002, 2238, 3495, 3197, 3355, 
          3196, 2842, 2102, 3001, 2236, 2403, 2999, 2402, 2619, 2100, 2616, 
          2234, 2507, 2782, 2502, 2098, 3178, 2222, 2777, 3176, 3175, 2489, 
          2598, 2599, 2393, 2392, 2602, 2086, 3165, 3166, 2762, 3395, 1929, 
          2477, 2756, 2755, 2754, 2203, 3151, 2080, 2473, 2757}]},
        "0.20500000000000002`"],
       Annotation[#, 0.20500000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzcsqxHEYxvHHynkjySCThZK94hawEGUhK7uhuBNLh1mwdCgLm0khJo38
kUGZslTcgQvwsfj2fd73+R3G1rYWN9uSLKDanjx1Jxu9yTOXUOAB+7o7Xtc1
eAB13GJPd80V3Q334wqX2NW9dSZ98jt/diSv/NuTNPmnK/nGiLsz5iE+xglW
7aecf7H/kkt203LNWxdYsWvpH+3uvVfwjv8avM0t/QfOnKnoJ3nCfMo1Z5ry
OY+bl/WHXNgd8JJ5WJ7lqrkuz8tzKJsHzaN85H75P+MPXTgwoA==
          "]]},
        "0.164`"],
       Annotation[#, 0.164, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzz0vQ2EchvF/B6EvJCISk0YM0uAjePsAJG10waSNSNAaWFiNVvEJiITE
UengLbHQ1UCUL8DuZfYzXLme+z73eU7O0HK9VEtFxAIaXRHFnogSprCZixjI
Rozrm3zBdV0N/fKYnHDCG7p19Mmj8imf85putTui979PR3Q4t/U/+ryc8Z1B
TvOvLsdZXHZGLOknsZuJ2MGr995s3tHGJz6Qsm/YL9pOYNt2Cy/2Lc+/+YG/
uMJn/Oz5inMVBXlYHuECN93xxPvuTJz3uCU/omw/j0PbWZ7DvX7af83gxP5G
vsYVDuyOdUe4k2/xB1hKMeg=
          "]]},
        "0.123`"],
       Annotation[#, 0.123, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz7krB2Acx/Gvyf1zbBRRv8HCyGDh96McCzYpg8IiFgN/gmPAjMTqyDHI
MTFgchVRBudmkSIGL8O79+d7PM/TU9k30jWcERFDmMuM2M6NGMyP2OFCbGET
s2brPGC2wQmsYRUzZgfZEYe4zorY5/u8iD2+zYm4wYe6TN1ivxVt+NX7waI7
F1CeiKiz08sFKERSPeX8NOrlSZ7AqPzt7Ju3a+19ye3urNAfNx9DDx7MU/qN
aEIaj3ov9l/xiGc8odv+nVk11+BY7whX8q57++Uq/0uql3lHb4kr1e/cYT7P
XXzpPxfolJtwLjfzGV7kV5zKn/ZPuFhdhAa5EbvuTHMKpXYK1CW84s3S/4w/
zN0+7Q==
          "]]},
        "0.082`"],
       Annotation[#, 0.082, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzTkvBGAQh/Fxn7vb0dpVUasVQocIcaskQuL6ABKNKNE6IqyjUbgKWnd8
ARUqIo5OHKHyUzx5Zub9z7zpwcn2iZyImMJ2cURbMqKvPKKeezlVFpEx3+Et
7jHrRkKf1m/zJucnImpLInK5hvO4u1QeRfpPfSF/8L39Ly7W9/pnSH1QFNGk
vvNW7mYrWvBi/ib3zBtyzWbD/rtUX+EcI/oLXpBJuJGW/3Ynw13+70TW+zrW
UG2elPuV+XVvwP4z9/OQ+c//v95y1XlYtLOEB/c73HrkFf0yCrzn41X+DO9u
PNk/VZ9gTvbYf7N8bTdHfWOelcvo62SreFU/ymNolClze8bOtH6aG8y+ZCb0
47g1q+BKpGSTOFIfY0t2n/ewi3l7G2ZZHOoP8Ad93kK4
          "]]},
        "0.041`"],
       Annotation[#, 0.041, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz01LlGEUh/FjmU6jhjrTwqyFoNFCyBklLDfSBygJF1EgOLlWxO+QLhLU
hYKLIBVfAntbmpW2FXQh6C51odKL+NIiISl/s7i47v85537u89Tkeh51F0TE
OAaKI2ZLIjrLIuY4iRlMo19vkjv0pjiBCdReiXjFdfzczH39x86FlyN+O1/i
YjnNRZzi63wD19AkV/MdTpm/ijQa5cFkRJYHuI+X1J8lIr7wVywjJ//N78xn
/NrcP16xSz3/xA98MPse75DN/w9n+BhHKJDbvbPj3pjzKMJe/3mnNOK7mTZv
vJHf4kC+qf+Lc3JXfjeUyLfsEM7r5rfdrczvJFfwU3e21J7wN943/9DcvP4D
3lC7YK5VfUSt104hb6pf5GO1EwziBTbt+1FvEQv4jE849K1S/TIkcdvdKm/u
8h7+6Dd7Y0hvGD3eaZHv4S5O9Vd8J2O2XL+BW+RV5zX0mx82U8kJZPSymHdu
4kak9YvkFL90v8K5HOdKOE9l
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0r1LlWEYgPE7kPSUH42CNPg31DmhJYFFJeqQRmSLorY0pDmaQ1CDOZyG
VBTUAm3SIfCcsgJdNVpKgxoaKkGsoyU4lB/Q7x0urvvrvZ/nPe+p7uxpuXMk
IqYwfSxiBtlURBE/KImYFD/kZ/wU6bKI05jTz5TKMahfw7XIqefRXxyxyGfN
1qIGo+Y2eI/fm/3HdccjzuEM8no57IpnuVl/jn/I08jgs7237f3Cj/WySR/f
UVke0ac3Ih7GE6TcuQ93sSB/jb/2vOU3uOmMl9zGr3jZ3h2z++KD5K4olx9y
GZ9AvXMqeNXsJv9Eq+e37W3h39xvfkW/oPeOB+T3sK7/Nbkzd7nroPgbCvLr
9k6Lt8zP8HNctatRvRlNWEt+V/VPPMSPcM2z89zjrF50J9/D7C0umFtyzlF7
qtXuy1/gj7kL8ovoRhe21Tr5PGc9cyN5F/GE3b98ry2c0i/wB70R/sijPMYT
zqjiYr6kdhnjyX9HfpJTfEWtzo4G7rC3Hf8B1GpfGg==
          "]]},
        RowBox[{"-", "0.041`"}]],
       Annotation[#, -0.041, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0LsvnmEYgPFbRevw6WaqBSHBJqQGh8GCgTCQEIf4A2oQZROHj1FtDsFI
Iixd23SwSxhsDoNT8KEWJKV+33Dluk/v/TzvUzQ03PktIyLGkcyOKEhEVKIC
H+VZuRFtORHtyBR/wIL4Vb+Ut+Rl/CafM1/LP/in+jx/lR/zBp/wJo/lR+x+
ihjl7+jBL2yr/eY+c/04kQ+md36OGOB9eRd341C8x+V6O+KUO1ziCh3qU/ZM
Y1B/hmeRxIHZFrVWNOM8L+IM9Xp1mNC/4Vtc49WuFP/jB/7Pd/zG93xk/pnz
nPvECX7hXB7xBqf6Vc6pkTfhC6rT56qP6V9wjbxQ/dHb/MFfu8/seEj/q16D
eNJciXjRXYt5iTOxgl79ZZ4ys8pryEKh7+vMrosbzbwDRRFGcA==
          "]]},
        RowBox[{"-", "0.082`"}]],
       Annotation[#, -0.082, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzr0ug2EYgOGHSD60LP1qsJmoto6AmrSjxsygg5GYkJBIjFqStmG30cFJ
+BkQDsDCyIxJuDrcud/n/51qbK1sDkREA9tJxOFIxMNYxM5wRJqN2OWWXBNl
+RIuRiMKajNI1PfFB6jrubQj8e56ZziLkvcRP5l9RFmcG4/II8W6WtueHE/3
d9j7Ji5k3Nd/Y2dD7ZaLcrPo6bnCH1K1PN7NzJkv2nmnd8/sPVfFNZRQN7uM
D/kv/kYFi3iV++EmWjjGKU7wqfbLG24scRU1TLrX8Ydn+Ta/cJc73FGf4EGe
l1tAV1zhM7lzDPVvi9f89dqNVf4HIsAxHA==
          "]]},
        RowBox[{"-", "0.123`"}]],
       Annotation[#, -0.123, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D0vQ2EUwPHTyW253dpeE3apDYlvwKRiY+ADMFOdJBaDalTCZhEaPoqX
4gN0ZPGySUr43eGf/7nn5TnPc6c2txtbhYhYxU4SURiLqKGK75GI32LEIpbw
gyH2kanv6r8oRTS5LXeEmTSijkv5A/lpfQmnvpfVGyiJi+iKTzFQX+GefWX5
M/FGOeKcD9Wu5K6xLtfjW2feoKn/nh9whz4eMTTzzC94wpv7vGJP/0f+Nue+
5+/kT67wF49zYkfGazxrpmVmUtwejZjgY/5zh4odHfGcnhOu5f+OM17Q1xXP
q/0DrJMt9Q==
          "]]},
        RowBox[{"-", "0.164`"}]],
       Annotation[#, -0.164, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{1900, 3360, 3529, 2155, 3530, 3074, 3527, 2153, 3528, 2154, 
          2431, 2430, 3367, 3366, 2714, 3091, 3090, 2041, 2560, 2380, 2381, 
          2559, 2558, 2438, 3100, 2173, 2725, 2174, 2451, 2450, 1910, 3376, 
          2937, 2057, 2805, 2058, 2938, 3377, 2455, 2059, 2561, 2060, 3117, 
          2186, 2727, 2185, 2459, 2061, 2672, 2388, 2389, 2188, 2460, 2062, 
          2678, 2390, 2391, 2189, 2950, 2064, 2814, 3118, 3415, 1963, 3119, 
          2953, 2954, 2816, 3120, 3417, 1964, 3416}]},
        RowBox[{"-", "0.20500000000000002`"}]],
       Annotation[#, -0.20500000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D1OQmEQheExFoC/wU4NJmxBO3YB2mphawKFiUoE5eJF7JRO42/FMliB
vWJYhZoYJCQ+Fm/OzDkz893c4n6tUp2JiB0kcxFtlHIRw8WID4yyEZe8nDqD
LB4XIt7oO1JZB3vYxSAT8SS/QQ/XeHXjy81PHGGWV+Xdma/RNi/Bg/4eqfrX
nTGd0DXz61hFw/zBfMSU/222wCv7jr5+Q921c4WWuWf5Cw5lt7xjemq3gR/+
Ga3YbdIT2TltYfz/H+i2LKF12QVNMZEtu91Rb8q7NK+f8ldoacn7vC3ZH86L
MLw=
          "]]},
        RowBox[{"-", "0.246`"}]],
       Annotation[#, -0.246, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2285, 3257, 3255, 2000, 3633, 3227, 3632, 3228, 3542, 3541, 
          2267, 3667, 3226, 3648, 3225, 2704, 3072, 3071, 2030, 2550, 2373, 
          2374, 2157, 2549, 2425, 2426, 2161, 2707, 2708, 2709, 2437, 1906, 
          2920, 2921, 2797, 2044, 2922, 3368, 2924, 2046, 2799, 2047, 2925, 
          3369, 2718, 2175, 3103, 2048, 2806, 3104, 3105, 2177, 2930, 2049, 
          2808, 3106, 3107, 2178, 3108, 2933, 2934, 2810, 3109, 3412, 1959, 
          3110, 2935, 2936, 2812, 3111, 3414, 1960, 3413}]},
        RowBox[{"-", "0.28700000000000003`"}]],
       Annotation[#, -0.28700000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2156, 2548, 2421, 1901, 2705, 2423, 2031, 2552, 2032, 3076, 
          3077, 2706, 2160, 2903, 2033, 2796, 3078, 3405, 1954, 3079, 2907, 
          2908, 2798, 3080, 3406, 1955, 3081, 2429, 3083, 3084, 2717, 2165, 
          2442, 2441, 1908, 2926, 2927, 2801, 2929, 3407, 2928, 1909, 3370, 
          2931, 2050, 2803, 2051, 2932, 3371, 2443, 2052, 2642, 2053, 3494, 
          3350, 3352, 3639, 3351, 2369}]},
        RowBox[{"-", "0.328`"}]],
       Annotation[#, -0.328, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2551, 2424, 1902, 2899, 2900, 2898, 2902, 2901, 3362, 3361, 
          2905, 2034, 2904, 2035, 2906, 3363, 2711, 2162, 3082, 2036, 2554, 
          2375, 2376, 2164, 2914, 2037, 2800, 3085, 3086, 2166, 3087, 2918, 
          2919, 2802, 3088, 3408, 1956, 3089, 3547, 3548, 3236, 3238, 3237, 
          2253, 2655, 2656, 2364, 2377, 1957, 2688}]},
        RowBox[{"-", "0.369`"}]],
       Annotation[#, -0.369, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{1903, 2712, 2710, 2163, 2428, 2427, 1904, 2910, 2911, 2909, 
          2913, 2912, 3365, 3364, 2916, 2038, 2915, 2039, 2917, 3231, 3232, 
          3233, 2854, 3234, 3626, 1983, 3235, 1984, 3444, 3443, 3602, 3601, 
          2269, 2855, 2856, 1986, 3334, 1985}]},
        RowBox[{"-", "0.41000000000000003`"}]],
       Annotation[#, -0.41000000000000003`, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdk30wG3YYx5lT61Adxm3OMK509dbSpdrVd5ptZah5K/Uy0izGKMtWi3dV
VFALahKltqxa6qWaeK3L/NRwipY2Y7KezVuuWpWE9Mpym0629Z89d889z5/P
53Pfx+pkUgDjJQ0NjcNbrZ7/lgIvNhUtTxG7IEecebDvzuTnvUwz/VmHUjkM
pp67jXEpxEYmeMrXlSPd+PrRubQgsr3Igi4Lk8H3ARHer/uUNJ7197p0ZgWD
nL0sB6sk0npkxK8x8wkiSTQlIfw0KTCR3F0PXMZ0p12bx65Ucqln7UStzmM0
t0xHfe2XRSoklhfO1yxhqOgNn58UOcSe8fp8qOlDmDjnhLOUeeTOIyFvOkOK
Ff1e56q32WQgI1Xz2b0FVAr1mM3FxWT5+LiX3GweEc0Nt1z1OGShP6fUPnoW
y8V5nTXeZWSHUqo9fXQGtASrYY/tF4iiaDZ7j0SCxLj9W2gVxIJ0PRrPmoKp
aGmPp0slKZQPNJtSxVg9I9wdksIlB60/Ss91moBdd6h/bhyP3AspjbG/OAIp
jT/lKucRup3tr8GegwjIClgRr/IIoySN/SGrD1X6+24Pn+CR1d0aQy6x3Vg0
2FabbsAlV2kbbJ6hAIbroaoJ7W9JtiikxWfjCjT3dyS0OJUTo2pOPHWQh3Nh
YtGCcQlZzK290ziej/c+N7JdP5RHclWVbpEmdHT2esaO3jxNVmMX2B0bT92d
Ei9rirSPoPXlza5y83hoHBzjmkZnw/47aeoXrHPwYQZLWB+UvuCC6v1am0iX
KpgUuJCLWnX4R58FH94WPd/3Mq7jK+8mKybnCn4xXPMYj+mA5f2kKJ2717C4
/s5fEo4ITEsbXV5fC7Sox7vSjvWDflLJPNVwA6ydhwKXREPo2xX/M9VViDUd
rfEfC0aRXcfWa0ppA4X5JaH6T8CTZJof+KwdiT5+ofOaYoS4jypnZe1w+SOm
2kw8Ca98Qb6lTgeSFPm3g25Nw7zCWfystR2r9LFI7+EHKI/YpKpW2sDOV4v6
DZEf/76vflSInr2HaYU6cxAMaI1cjRCAEnReSeHPQ2/4E/lmSitozAPKJrdF
DAgct4w1o61DLVIKo+5kil9yA9THO/o/xLvrbzq6yerA72Uc4w4uoSGgTScs
hw/2q/2XS6wfQ53OoIIa5M7cOOUfswxfh/CtyFVCUT/kTSl8gg21JuMy1Pxg
ffPPghWUVc9ty8hiYzh9ciQvSobkbzQlyzPZKHuFruuxQw7thmuM+Ewm5riq
1MAyOerfem3I5GzEf3xySG0n3c05bvj///4NQNjiEA==
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504.,
  PlotRange->{{-0.5, 1.5}, {-0.4, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 224},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->9226975]
}, Open  ]],

Cell["\<\
Note in the streamline plot that the flow appears to leave the trailing edge \
smoothly, satisfying the Kutta condition.  There are no streamlines inside \
the airfoil indicating that the computed velocity there is zero, as it should \
be.\
\>", "ExampleText",
 CellID->14395635],

Cell["\<\
The function ForceAndMoment computes panel contributions to lift coefficient \
and pitching-moment coefficient and sums these contributions to obtain \
airfoil coefficients, which are displayed.  The reference point for computing \
moment is the origin of the coordinate system, which for this example is the \
leading edge of the airfoil.\
\>", "ExampleText",
 CellID->80454523],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rD", ",", "\[Alpha]", ",", 
     "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[8]:=",
 CellID->499718542],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9893202729989343`", ",", 
   RowBox[{"-", "0.30314844461786883`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->233574312]
}, Open  ]],

Cell["\<\
Surface pressure distribution is computed from surface speeds using \
Bernouilli's equation.\
\>", "ExampleText",
 CellID->753558053],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->435840926],

Cell["\<\
The function PlotSurfacePressureCoefficient provides a conventional plot of \
surface pressure coefficient versus the chordwise location on the airfoil.  \
It is also conventional to insert the airfoil shape in the graphic.\
\>", "ExampleText",
 CellID->139054009],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"gCpD", "=", 
  RowBox[{"PlotSurfacePressureCoefficient", "[", 
   RowBox[{"xC", ",", "cp", ",", "rD", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}]}]}], "Input",
 CellLabel->"In[10]:=",
 CellID->671472236],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3V+oZdddB/ArvvXFP0++KFbBF0EfpVekSAlaA8YINdbiy0QOCf4JagI2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    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->39437295]
}, Open  ]],

Cell["\<\
If a list of angles of attack is specified as input to PMVortexLinearNeumann, \
nested lists of output are returned.\
\>", "ExampleText",
 CellID->571494656],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]List", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "5."}], ",", "0.", ",", "5."}], "}"}], "Degree"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aList", ",", "bList", ",", "rC", ",", "vCList"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rD", ",", "\[Alpha]List"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{"aList", ",", "bList", ",", "vCList"}], "}"}]}]}], "Input",
 CellLabel->"In[11]:=",
 CellID->42630738],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "60"}], "}"}]}], "}"}]], "Output",
 ImageSize->{178, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->139254121]
}, Open  ]],

Cell["\<\
These results can be input to the function ForceAndMoment to obtain \
aerodynamic properties of the airfoil assuming the angles of attack are in \
the linear range of the lift curve.  Listed below are values for lift-curve \
slope, angle of attack at zero lift, location of aerodynamic center and \
pitching-moment coefficient at zero lift (couple).\
\>", "ExampleText",
 CellID->24035690],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Vortex\>\"", ",", "aList", ",", "bList", ",", "rD", ",", 
    "\[Alpha]List", ",", "rC"}], "]"}]}]], "Input",
 CellLabel->"In[12]:=",
 CellID->34907031],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.784515153124065`", ",", 
   RowBox[{"-", "0.04128080764467444`"}], ",", "0.25938923204817543`", ",", 
   RowBox[{"-", "0.046593438540552076`"}]}], "}"}]], "Output",
 ImageSize->{298, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->66217255]
}, Open  ]],

Cell["\<\
Note that the location of the aerodynamic center returned is close to the \
thin-airfoil theory result of the quarter-chord point.  Display the ratio of \
the lift curve slope to the thin airfoil result of 2\[Pi], and the angle of \
attack at zero lift expressed in degrees.\
\>", "ExampleText",
 CellID->4111782],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], ",", 
   RowBox[{"\[Alpha]0", "/", "Degree"}]}], "}"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->274981366],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0797891231015622`", ",", 
   RowBox[{"-", "2.36521605293123`"}]}], "}"}]], "Output",
 ImageSize->{135, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->389260845]
}, Open  ]],

Cell["\<\
Compute the lift and moment coefficients at 6\[Degree] using the linear \
aerodynamic properties of the airfoil. \
\>", "ExampleText",
 CellID->328772922],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], "}"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], "}"}]}]}]}], " ", 
  "}"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->762946865],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0.9905430304392666`", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"-", "0.30352963451686593`"}], "}"}]}], "}"}]], "Output",
 ImageSize->{170, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->70763756]
}, Open  ]],

Cell["\<\
These results can be compared with those for a single angle of attack for \
consistency.\
\>", "ExampleText",
 CellID->251970426]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Alternitive for discretization",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->421192202],

Cell["\<\
Fitting a B-spline through the points in a data file provides a means for \
alternate discretizations.  This is currently accomplished using the function \
FitAirfoil.\
\>", "ExampleText",
 CellID->5610347],

Cell[BoxData[
 RowBox[{
  RowBox[{"spline", "=", 
   RowBox[{"FitAirfoil", "[", "rD", "]"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->559405563],

Cell["\<\
Graph the data file as points and the spline as a curve to check visually \
that the curve provides an adequate representation of the airfoil shape.\
\>", "ExampleText",
 CellID->444428628],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"grD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSpline", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"spline", "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"grD", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->249332617],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PFPUdx/Fr+pf037hEueMOFAk9D4vYWmrhZAtt1Wo0MagRalsIQrrx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->220597783]
}, Open  ]],

Cell["\<\
Rediscretize the airfoil using the spline description of the airfoil.\
\>", "ExampleText",
 CellID->176584194],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "100"}], ";", 
  RowBox[{"layout", "=", "HalfCosineSpacing"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"spline", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"n", ",", 
       RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->343427282],

Cell["\<\
Graph the endpoints of panels for this discretization and the spline fit to \
the data.\
\>", "ExampleText",
 CellID->126580234],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gP", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gP", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->274596420],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f9vFHUex/Fe7i+5f4MEtqUUxMqXooiCPQRk5TTiiRI9OE9A+RLUc4Ma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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->4533229]
}, Open  ]],

Cell["\<\
Solve the model using this discretization, displaying the airfoil lift and \
pitching moment coefficients.\
\>", "ExampleText",
 CellID->33075010],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aP", ",", "bP", ",", "rCP", ",", "vCP"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "clP", ",", "cmP", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "aP", ",", "bP", ",", "rP", ",", "\[Alpha]", ",", 
     "rCP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"clP", ",", "cmP"}], "}"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->252090154],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.9880152301014966`", ",", 
   RowBox[{"-", "0.30214613319217754`"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->137745002]
}, Open  ]],

Cell["\<\
Compute the percent difference of the results for the discretization \
specified by the original airfoil data compared to the finer discretization.\
\>", "ExampleText",
 CellID->169245216],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cl", "-", "clP"}], ")"}], "/", "clP"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cm", "-", "cmP"}], ")"}], "/", "cmP"}]}], "}"}], 
  "100"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->208999159],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.13208732595181247`", ",", "0.3317306811448689`"}], 
  "}"}]], "Output",
 ImageSize->{141, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->342113056]
}, Open  ]],

Cell["\<\
Compute the surface pressure coefficients for the relatively fine \
discretization and show the pressure coefficients at collocation points in \
red.  Compare the results of the two discretizations by superimposing the \
results of the finer discretization on the graph of surface pressure \
coefficient shown in the basic example above.\
\>", "ExampleText",
 CellID->511124957],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCP", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rCP", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpP", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vCP", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCp", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xCP", ",", "cpP", ",", "rP", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpD", ",", "gCp"}], "]"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->59705953],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3Q+MHOV5x/ErmLMVKTKtTcEuBYdIVyRIXEEj6ouwEzlWQxAlpo5pgAhk
WyujgC0SH2pBgK+lPqHEysqUlmupTzI4TTCq7LZZB3KmCKfhTrJyiGBq+Ywo
p0RHJP4ITFSu2N2+u8/ue7OzM7OzO3/fd74fTQJe1ruzd7O/ffeZ533nU5u2
37Tp3L6+vq/8Vl/fR+p/tX+vAgAAAAAAoBAqpb6awfJ01nsCAIjfdLlcqf1T
pT1JDwA2q5TIeQCwWKVUqjj/3AcAyEjEOG95rOYQvlm9acn5SE80MqIeorp1
a6QHAYDiiRq/XqbLg/W8r5QdhZsknggA0FHs8esc4DsrN+Q8AGQitfiN+YkO
H65+4QvVsbE4HxMAbGRkzquQX7SoVq5X/w8ACGRkzq9YUQt5tS1fzpAeAIIZ
mfPSe/PJTzKkB4COjMx5QaclAIRgcM4DAEIg5wHAbsbnPA2WABDIvJx3Bbv0
3nA2FgB8mJfzrmDnbCwABDIr5ycnZo5tuItgB4DwDMp5FfJrrh2V7cj4qVj2
CgCsZ1DOD+8c1zk/tKO2RJpK/rG9x14e2cupWADwY1DOH73v76cWD4wM3K5y
fv9TU3p4P7toCadiAcCPQTn/f5fWzsD+77n9o49Pnj49p4f3oyvWU7EHAD8G
5byrtebA06/oMs7z9z5G6QYAPJmU89WW5vm5uTP7n5ravu3f1PD+7CWXUroB
AE+G5bzfrCgZ6l9/PaN6AHAxLOeDZ0UxNxYA2hiW88EY1QNAG8NyvtOqZZMT
M6eXLmdUDwCaYTkfWJmRjnpps/xoyYUM6QGgak7Oy9TXU1t2BNTndUc9M6cA
QDMi50OubKM76hszpyjUA4AhOd++so0nZ0f96dNztN8AQNWQnHdOfVVJHvav
0X4DAIbkvHug3hVG9QCKzYicj4RRPYBisz/naaoHUGzW57yzqf7ta77IqB5A
0Vif885enXcXX8ioHkDRWJ/zzl6dqZu3cUUSAEVjfc579+p0WicHAKxhfc57
o9kSQGEUNOdptgRQGAXNecGoHkABFDrn66P6X99023P37Hl35TUM7AFYqdA5
3+yul3WMz/YvzHp3ACB+ZuR8Yu0x0l0vs6j+67LPUa4HYB8zcj6xQrqzu/7D
C5prI9B1CcAiZuS8tMckML/J2V0/N/xw41k4PwvAImbkfMrougRgEXLeF6N6
AFYg533pYhHlegAmI+c7+mjZxXRdAjAXOR9scmJGui4PLVv98sheBvYAjEPO
B2P5egCmI+eDeS9fT8UegDnI+WDey9frVhwCH0DukfO90K049F4CyD1yPhLH
RN0T5X2zl1/92tAjWe8TALQg52MxOTEji17OnXMebTkAcoWcj8XwznHdfklb
DoBcIedjQVsOgNwi52PRoS2nmuAS+gAQjJxPkHM5ZTpzAGSEnE+JY1W0969a
dXTzQ0fGT2W9TwAKgZxPmayKNnfOeWuuHaUzB0AKyPmUjX9pi7TluBfMoYAP
IBnkfMq8O3OqnLQFkBRyPmXenTlVTtoCSAo5n0cspwAgPuR8njmXU6j151DP
AdA9cj7PnMspDO2oUMMH0ANyPs+cJ233PzXlW8Mn8wH4I+fzzPekbdX/vC2Z
D6AVOW8DR+bLPKyz/Quz3icAeUHO22RyYkbX8xvrKjC8BwqPnLfJ8M5xXc+v
nbetUtIBQM5bxX3etho4/YrYB4qBnLdJ0HnbamvmV5l1CxQFOV9czLoFioGc
h3vWLQC7kPNwz7qtUroHrELOw+PsLaV7wCLkPDzO3rrO2DK8B0xGzqMzhveA
ych5dOYc3jO2B0xDzqM7jO0B05Dz6I5jbD85MfPcPXveXXkNw3sgz8h59EaF
/JprR6XxnuUxgTwj59EbWTNNGu9fWvmVxq1U74H8IefRG4+u+yrVeyCPEojf
6fKgetRSJfEnQpa810yj8R7In2TiV0U9OQ+G90AukPNIkGt4DyAL5DzSQxkH
yELU+K2U+pwGy9O1W71z3inSk8JQzTLO5MTM2N5jrIEMpIPxPNJTL+P8+qbb
GlewvXIbc6yAFCQRv40xfmNsn+ATwUT6YuUyx4qztEDS6J9HynTjvcyx4iwt
kDRyHikLulg5J2qBBJDzyBH67YEEkPPIEabTAgkg55FfDO+BOJDzyC+m0wJx
IOdhDMo4QE/IeRijXsY527+QubRAV8h5GKNexjm0bLW03xP1QEhm5Dxf2FGn
59LWlk3YUeHAAMIwI+fpu0Cd+yJWHBhACGbkPH0XqHPPpeXAAEIwI+eBMCjj
AF7IediDMg7ghZyHPSjjAF7IediMSg5AzsNuVHIAch52a1sA8/2rVh3d/BBz
rFAo5DyK46NlF6sDce6c85hOi0Ih51Ec41/aoldOqE2nBYqBnEdxuKfTVjlR
i0Ig51EcHpem5UQtCoCcR6HRco8CIOeBFlRyYB1yHmhBJQfWIeeBFlRyYB1y
HghCGQfmI+eBIJRxYD5yHgjSWsaZnJjhKuQwDjkPhKRCvjaR9sptU4sHXht6
JOvdAcIi54GQ5Crks4uWqKP54wX9We8OEBY5D4QkyyaMrlivjuaTazdkvTtA
WOQ8EJLHsgmCnhzkGzkPREVPDvKNnAeiYmoV8o2cB+JHJQd5Qs4D8aOSgzwh
54H4+VRymGaFTJDzQBrqlyAfGbhdrmZF1CNN5DyQhnolRy5BztVpkTJyHkhD
vZIjlyBvXJ2Wc7VICzkPpMM9zYpztUgLOQ9kg657pIWcB/KCSg6SQc4DeUEl
B8lwxG+l1Fc3WJ6ulMvTyT0RAC/tlRxG+IhDI36ny4O1fK82/70Ue9cXOQ90
rXWEzzQr9KYevyrZBx0D+OlyKfbhPDkPdM8xwudqVuhZLX5dMZ/cEwHoFVez
Qs9q8VspJVCn8XoiAL3ialboWT1+VdDPD+gdVZvamdlSuTzY1xd9vE/OA1H4
Xs2qyuladOA4D9un2230f60Ffe3PlVLkAT85DySFhkwECozfSklCv/nPxJ4I
2Zud/WDq57/S25HxU2N7j/ltj+75mRpYdrUN7xz3e7SjL77hfGrZjr/6VtY/
EnPQkIlAQfHbGMXHU74n59Ono1t931dxqr7vO4N3/Y1Pyppast38te+HjGW1
HXj6lfZkDt4CPjjuv+/Z9s+FO7ce1Pu2bu0T+vahHRX9F9Xr4nPBm9cIn7bM
wgqIX8e8qWSfCL3RMa5SV3JPknDzpmdc0a0S3pWKanvnnd9k/QrCmps7o3db
wko25yeX83NBfYTJjep7h9xT/u6bb76X9UtJS9sI/0R539TiAVkAn6gvGv/4
jaEmH+6J0IGk3NEX39AFk2/c+kNnjLvSbPrk21nvcsbUR5jnJ6D83NSmPgrl
Fvmvhw4el/u7z29a5L3zL9IL4LP6fdH4xK+M5ePsqifnwzj+6lsqbXQ0yRhV
qhb33/esLpgUaFyaDPVRKMEuP+rd3z0qsX/9dWPqB67+3/kpoL5BmPX1x9Mv
btmuF8CvrX5fpYZfIKxjliEV1zJKV+MrGWqqYNfxQs05K2pU7/wUUL8dfTpD
KkL6HIF8BBjxLcCjLZMuncIg51Mj6aHeayO7XlBvNxUaKttllK7igiG6EaQi
pM8RyEeAfAuQMprza1feC2ieC+AzyLcROZ+c2dkPjoyfknOFahwo1QD1x8OV
EyoEst47xExOiztPo8gJcfm9S/+SnAjI9We6/yCfdh1zkfMxkhOmMsxT7241
wFPvbulyMb26i57J9zhpK5UTAVKjkxJQ7vLfpxX/9Qd263Ymot445HxE6ru5
Gp+r968avMkJU6nDGFGzRYakBNSe/1L/UbfoGWRq/JDljtZH+B8v6Nc5T7uO
ccj5Hhx/9S3ph1HBruJ9ZNcLajyW92IsDCH1H3VE6Rlk6jBz9lzJ4F/dLaUd
qo/wX1+3Uef88/c+Rg3fLOR8SOptpd5f6o12/XVjd249KP0wGQ+0UBjOORQy
+FfDfj0RQObBJdqg5WzXOXvJpR41fE7g5hg5H0Ad25MTM4/u+Zn6Qq3eVur9
pd5oFGSQHzIRQNa10BMupPIvlR91AMcf/p6NOnRp5hg53+7NN9878PQrQzsq
6suy+n/177k4QQaEI5V/qfyoAziz8HeM8OnVyZYxOZ/8t0IV5upQVEN3takx
vDoyk3suIGUZhH9zhC9XPKRXJ0PG5Hxi3wpnZz9QX3sl3tXRztAdxeEZ/tLw
I4smRZrt1RzhyxUPZXviz/6aMn76jMl5z5JgBCreDzz9yuZNz6ijevTxSeId
ENLwI0vA6dleahQkJ2FlPkhX7xe54qFsH16wnDJ++kzJ+bjqe3NzZw5XTki8
qxELzZBAGCrY5YSvzO+WVn8Jf73Og1+rp7NXZ274YS6Jkj4jcj6W+p46CNVh
tv7GJ0d2vUC8A9FJ+Ot1HpytnrrPv/NMcFZaSJ4ROe+s7/UwF08dbOoR1EGo
BhV0RQKJklZP3ecv63zeufWgLPIpizu1vA19llN7/6pVclUUzt5GZ0TOO+t7
jaWzQ5ASjXy15DgBMnT81bdkcC6LtcoKn3qGr4R/y6zD+iBfrorSGN1R3onA
iJz3WDq7E/XRoAbw6qDiBCuQT3qGr4S/Xt5B/XFsU/nokj987LIN86M75mFF
YETOd0UdOdIAzxKRgFlkeQc1vFfh/5d/8eM/v/mfVcj/ybq9d33z0O5b94xd
esPUN3a0nFxjkB+OTTmvDgD5JsgYHrCGs8nf3ee58o4Dv7d26oIrna0+nL1t
Z0fOqyNheOe4OgC4fgdQBI0+zy3fe/Syjdu/vFtafe7cerC05V9u+dzDoyvW
D11x97M/Ppn1buaFBTmvPrjVhzsf30DBHX/1re13/+ujn944MnDH3St3fHHN
PzQK/t/cP7bm7qM7/6mwF1w2Oufn5s6M7HpBjeTplgRQrTdgqMG8iptDy1bv
f2qqUfC/4oaxS2+4/zN3ORd2GH18Mnh6l03MzXn10bx50zOHKyfifVgA5vLu
zWtt0ZeFHfY/+MNHV39r+8Z//Oqf7lPhf+vXfyBNnkfGT9lX/jU059UHsfpV
cr4VQI/qjZpn+xc25+Y8/nd/+5LK+eGd4ypb9GKeej03o9PGxJxXY/iRXS9w
LScAvasP8o/90Q1+a2lKn49ez02W9Nm86RmZ2CurOphSMTYu59W3KvWBG8tD
ASi4btfSnD75tvRtyqoO1183Nj+3q76Gfz7XzjIr59WP8f77nmUkDyAWHdbS
rHa+KpZzbpca6kt7vx72eyzpkIUkcr5SUo/aN1iejveJ1AflnVsPZv4TA1Ag
PV0VSw/79ZIOUu1XnyaZFHziz3mV8qVK/Z8tSR/9iYZ3jtMkDyBVMV0VS6r9
6ruDLvioTc7zSntnoskfe85PlwdLsnJwa9BHfCL1U7r5a99nMA8gE7FfFUsF
u5znldX7nckvF+2KsdQfe843h/MeOR/FJb//5U+tWB/xQQAgPz7xiYvOXzwg
2+/89hWfvmzjys9++/Orvqc/UNS26prvqBujP1e8OZ/QeF59tG3e9Ey0XQOA
mMl52Kk/WD21eODnS67Q+fzgAz8Z23tMtvvve1YN1GWTC6/IJquxySbnbZ2b
nMOVLeJOxp7zydXnWaYMQM8agdy2HRk/5QpY2WTClGtbt/YJ52BbbdJXuf2r
j23/7Lc3fX6Xvv2Wr/9AP9TRF9/QT5fJeunx53zC/Ta7v3uUheUBK3nmsF6U
uH2Tbpb2Ta5X5R3IbZvKc88HlwUQXFvwKUL3le9yszx+Ejmf6BOp37j6sjP6
+KTR05AB48h5w/ZNWsfbN2ksad+kw9xz87y/2tRDeT6Fs7Lh3LKapupeXSc3
18AyLuer9eNN/TBV2st1o/I5AQ1In9942DMkZV6PZ656hrB0g7RvMhW0fZNG
8fatQG9Yz0ucZ8HEnNfUkF59UVLDg/U3PqkONmlDpfcSeaZSrj36ZE5N+LpE
e5U4eDzsl/PqeT2jOOsfkrWyutaV0TmvvfPOb9Q3OGlDVW8BNc4f3jkuPajE
Proii9aGj2L1Dd0zWmXZq/ZNDUva79zeaxFcl+CoNpHMqB26ctvU4oHXhh5J
86ntyHkXNc5Xn5jyBpSRj/QvyQkXyX/eLCbq9jydfPSHL03oi1CEj2J9OLk2
zh/BRWbUzi5aotLw4wX9aT61lTnfTq4mKQ1UegCmv/x6Vhr1G7YIl5vpmfxg
uy0LuzqKQxYlejhPJ6U8ShPIA+nGkctdnVy7Ic2nLkjOB/PsHNAZIpcY7tig
pT4+AmItTPL0tsn62N1ufifgwrdGtE/0CF8WHmvtKKYogSLwvtZVKsj5HnhO
uFC/wTABG1BJ6G2T6910u/mdgCtuawRgL3IeQGF11QAzf2f/CVBZddQEI+cB
5FBvgan+1nP37Hl35TUtIewZy4cPv3/VqpGB2+eXlPe5m9zoXH/+fy662D0B
qn631x/YHX6NeqcT5X2zl1+dXBMOOQ/AT8TRqcdfb89Sr3RVuTe1eEBCuPHX
A0NYP51uaDnbv3D+bp7zUus3zp1znsTy0I5KwN3Ujc715yvX3uGeAFW/28cL
+vV9ag8Ybt0Dtduyz2pnEvoiQM4DtuolpVsvk+fd7x0icqueWV31ilyvdH3v
/It0CNcC0+durhsliqWh5aWVX5m/m+e81PqNh5atnl+Oxv9u6kb32jUu9bu9
vm5jy33a9tnzN6J2W/ZZ7UzjxcaNnAdiF0uR1vtBwmVsqKKE50M5osm33ztE
5FY9s7rqFble6fqLW7brEG6EamAIy586RHGbrhpgwtzZfZ/W3fP73Ox2t3tA
zgNO0SNaPYK8l1XMzj9OmJgNM5YOl7GhihKeD+WIJt9+7xCRW/XM6tB6a0HM
sHExDL/PzRR2m5yHNSKWKaqeEd1lPlfrb2ddbp0fx4aJ2TBj6XAZG6oo0WmV
rYj5k/PUTV/APKmku3TIeeRBj8d56wC48yi6PaLbCrzuiO4yn6v1t7Mut86P
Y8PEbJixdGjEbN74/UY8D914k5+cR+Z0x5o62ls64rpJ6VCj6PaIbivwuiO6
y3yuxhSwpHRxtB+63oOWCMh5ROc7fyTcH3XHmhztvrEcmNKhRtEJVyqAHrQf
ut6DlgiMyfncXIHLSl18SWzLamdfh3v+SHBQN/+o+w3kaPeN5cCUJqJhqPZD
13vQEoExOZ+bK3DZp/PJR+cfvbJa93W4548EB3Xzj0Q04PSfP/1v/Zb80b+f
iP6AxuR8bq7AZTD/skmHk4/OP3pldUtfB4Boilu3QQgei3t0GopL2aTDyUcK
JkCKilu3gYszwB1rKLkX9+g0FKdsAuRN7G9Jcj6HWs6KtuW5x+DcsYaSe3EP
6l1A4ZHzeeM+K9qW5x6Dc881lACgjpzPktdY3X0Kpi3PqZMD6Ao5n7bA2ov3
WVEAiICcT5oU218e2duI98DaC2dFATjFstANOZ8gx1zR+Rn9nBgFEI7zYoVR
op6cj5+uzDjmirpn9ANAJ86LFUaZMEXOx6Y13vXQnbmiAHqz+zsv6pz/q+Hx
nh+HnI/E86SqozJDsR1Azx568Cc65791z496fhxyvgcnyvtmL7+6djW3gNmm
ABBNXJeOJee70FxeQPe3n9qyg2wHkJC4CgLkfBeaywvo/vZYlpIDgESR853p
IjzLCwAwEDnvq71/po5TqwDMQs57kIRfupSZTQAsQM47yRTjxkVOFywg3gFY
gJzXTpT3yWrAzF0FYBNyXnvv/Iv0MgU00gCwBjlfUy/I//KP1+llCmikAWAN
cr6m2VFDIw0A+xQ651sb4ynIA7BSoXO+tTEeAKxU0JyXkfyGDQzjAVivoDnP
SB5AYRQ05ynIAyiMQuX8/LrxAFAYxuS888pNPZmcmNHrxke8eDoAGMSYnI9Y
UT98+I0VK/9j6dWsGw+gaIzJ+YgV9frHhKxpwHRXAIViTM5HVP+YOLl2A9Nd
ARSN/TkfubAPAEazP+dplQdQbDbnPJNeAcDunGckDwC25jwjeQBosjPnGckD
QJOdOc/yNQDQZGHO00gJAA725fxHyy5WT3a2f2E6TwcAOWdZzk9OzIyuWC+L
2LBYGQBULcv5+mJlIwO3yyI2LFYGAFXLcp7FygCgjVU5z2JlANDGqpwHALSx
JOfppQQAH5bkPBNgAcCHJTnPBFgA8GFSzlOcAYDumZTzFGcAoHsm5bxfcYZx
PgD4Mynn/TDOBwB/NuQ8J2EBwJ8NOQ8A8Gd8zlOcB4BARuf85MTM6aXLKc4D
QABzc16F/JprR2W1+V/ecEu8Dw4A1jA35/ffNjK1eEBWm2epeQDwY27Of3jB
cr3aPEvNA4Afs3L+RHnf7OVXvzb0iPr3Mw//jXrQn37mOpaaB4AABuX85MTM
7KIlMoZ/eWQvbTYAEEYCOT9dHlSPWnJVzKM/0fDOcX2N73cXX0ibDQCEkcx4
XkV9/Dl/4OlXGhf4vnLb6d+9mDmwABCGQTk/N3fm+Xsf+9XSFWfPXcBgHgBC
Mijna2TJMtkYzANACGnmvFOPDyxLlhHyABCaYeN5AECXkojfSqk+ZB8sTyf8
RACAjgzqnwcA9ICcBwC7kfMAYDdyHgDsRs4DgN3IeQCwGzkPAHYj5wHAbuQ8
ANiNnAcAu5HzAGA3U3Kej4mC/wR4+VnvQpYK/vKr5uSnKfvJDuQTLz/rXchS
5i/f9B0oTs5nuwPsv9H7X/CXn/kOsP+Z70A6T2T6D4r9N3r/C/7yM98B9j/z
HQj/RACATKST8wAAAAAAAAAAIOfkSuKtFxIPut0+Pq/U8xLrFgr6RU+XB0uV
1PcoVQEvX7166w8An5cvL932F18jr9TjKLcqANWLqb/ESqn1Bfndbh+fVzpd
Llca/9nqn0DQL7p+pNud8/4vX73/rf7F1/m9/Obne/O/281rNGNXAM6/wtbX
43e7fTq+Urt/AAEvv1IqVWwfz/u+/OZ41u7POf/ffiPmasdANruWJo+j3LIA
nP+8bn05frfbp9MrtfxI93358rptz3m/l68H83Z/nQs6+AvwZa7J4yi3LAAZ
zwe/0mb1xlo+L39+OGtPidJLwY//oPG8DOdt/uVr9o/nqc+HqNBWyhb/CIJ/
0baP54OO//oNlv8AOr39C3GSogD1+ar7tLLz+4rlYznN8yfQ6LaxvkTrfwDU
WB5zNcHHv+W/e9+Xr7/Q2f763X11RQxAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAADyqrFAYqlc+6f9iyQCQBHVol7lvOVXdgGAQivIBYwAoJjkEg+t
FzoBAFhiulGXlzo9g3oAAAAAAAAAAAB04/8B38IQuQ==
    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->28737660]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Options",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Epsilon",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->1295379749],

Cell["\<\
Collocation points are displaced outward a small distance to insure that none \
are computationally internal to the airfoil.  In the following example, the \
model is mapped to three values for the option Epsilon.  The three values \
place the collocation points outside the airfoil, on the airfoil panels and \
inside the airfoil.  Transposing the result groups like results together.\
\>", "ExampleText",
 CellID->120830056],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PMVortexLinearNeumann", "[", 
        RowBox[{"rP", ",", "\[Alpha]", ",", 
         RowBox[{"Epsilon", "\[Rule]", "#"}]}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10.", "^", 
         RowBox[{"-", "10"}]}], ",", "0.", ",", 
        RowBox[{"-", 
         RowBox[{"10.", "^", 
          RowBox[{"-", "10"}]}]}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->210128799],

Cell["\<\
Differences are computed between results for strength parameters using the \
default value for Epsilon as the reference.  The maximum of the absolute \
values for these differences is displayed for each case.\
\>", "ExampleText",
 CellID->112154987],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aPlus", ",", "a0", ",", "aMinus"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"bPlus", ",", "b0", ",", "bMinus"}], "}"}]}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"a0", "-", "aPlus"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"aMinus", "-", "aPlus"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"b0", "-", "bPlus"}], "]"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"Abs", "[", 
       RowBox[{"bMinus", "-", "bPlus"}], "]"}], "]"}]}], "}"}]}], 
  "}"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->295212498],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.1915591633382405`*^-6", ",", "1.355167393857215`*^-6"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0.00007252730948437147`", ",", "0.00008317959149906073`"}], 
    "}"}]}], "}"}]], "Output",
 ImageSize->{417, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->459621414]
}, Open  ]],

Cell["\<\
The tangent-flow boundary condition imposed by this model is that the \
component of velocity normal to the panel be zero at collocation points, and \
this component of velocity is continuous across a vortex panel.  The small \
changes in strength parameters are consistent with the normal-component \
velocity being continuous across a vortex sheet.\
\>", "ExampleText",
 CellID->3193481],

Cell["Next, look at the speed computed at collocation points.", "ExampleText",
 CellID->79242491],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"vCPlus", ",", "vC0", ",", "vCMinus"}], "}"}], "=", "vC"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gvCPlus", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"vCPlus", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gvC0", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"vC0", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gvCMinus", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"vCMinus", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gvCPlus", ",", "gvC0", ",", "gvCMinus", ",", 
   RowBox[{"AspectRatio", "\[Rule]", ".3"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"7", " ", "72"}], "}"}]}]}], "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->23699121],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJw91gs01HkfBvAhSrqi3FoMEbJl0wUpHiUkxYz7fS7mlnSzSik7KVuntSmv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     "]]}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw1lglUjHsfx6co3cpSSupaprqI3BpF2tSXFu0q7evMNNMM0XZFZBkpN3FF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     "]]}, 
   {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJw1lgs41Pkax8dEp3sh1WIZCelUKJVF9XW/xIz7xAzmaqZISNrkMkraUttm
i6QyIic61WpXqj2YY5dULqXSUSnpctBVl1WE03m8M88zzzyf+f4///d/fX+v
iWhjgJTJYDAav37//zv2ebv69Rue7mF+xWr6Ayu92Ylu4yXEE/Dywfvu0Uob
4hlYYRlcFu7nRzwTEec/m7BdOcRzUM+NLX2Y6k5sCG+99gkZMxyJWbAqf3mr
ycaaeC6OPzjzyb/ZlHge8vM65tu+mkNsjjYr3oGhH3SJ5+NA6e/9vVN1iBdg
eUhFGxqnES+E8RXLfcvs/0a8GHLZ59psfwaxNbwnzvxTXvl51Rjb4PwkZtG5
PZ+Il+DLbTanR1/NS7G3L/efHs8GiG1hmF+LBwNqXoaHw9omdUvV2y8HNyI0
/rqWmlcgNTbty0E99fZ2GPZMucf+8JH4O/CEeuNtZGq2R1ZgbbxV91/EDri5
62rFO51BYkdMcKiUJ8cOE6+E7QZN9x271Oe3CvsPbbllX84kXg3T61Ff2gc0
iYHZlrmu61fS9VEAm180NJS4T6TcCQaqx28duydR7gT9IVZziOMUyp3RoNUy
LWfLVMqdMXOZ4lq06XTKXdDG2V24/dkMyl0gdhvqNpKq75crXnoyjhc00P1U
uKJv1mDm2Xl6lLthskP+uKQTsyh3Q+vZG8cizdXPgzumpvxm0LPnG8rdMWN6
6zG806fcA+ZG9RUFTYaUeyA5VqTNHTSi3BMWHj8bvtjOotwTbgUedYcTTSj3
wvOQ3MITqXMp90J+0Jp1HafUz6c3nDlPWUeuzKPcG2aB5npb680oX4OO26E6
UY/NKV+Dx1bHSk5unE+5D/wOOx+/bLmAch/YKn8qs6v8O+W+uLux3bLOcBHl
vohMr3ty8exiytkoUlQ8HVxO74+CjVeb3gqHNdTvJweB+cwtPqeIFRyU/RL3
mV+4hHI/vOJottsrbMcYfjBOPzUxpmY5be+HspvBz13P2Y2xyg9D/HjL3T72
5PvD/cOsKW/cHcj3h5Oexf1fs4kV/pjSLMGogljlj/dx61IaLIgZAbgp3jmi
rUn9AAEYfm5RHJ4P8gNw+NErPW6EK/kBsJOvfNGa6EF+IC55SrtGBr3ID4T7
7KWD1VXEikBMjDu+kmdN/UcVCJ9ihvIbpRP5QWhc6OyXGkfngyBcmF31nqVQ
n38QJnMSZmb/5UJ+EKqVMVdbn/iTH4yUBYbcDLe15AcjrdzxhlKbT34w9tTa
NqbNCiM/GOODbpfshLo/hmA9r3NkdTQ9HwjBuJj/WuS00fVWhGBy362hzSN0
vqoQ5N9h19f8m00+F0sOLMoZ5x5EPhf3n7bq+sbLyOeieXdu9KScRPK5MNDs
73yXpSB/Ld64jHgnDO0ify1+zniStGXcHvLXQhLS6/BF5xD5a5HB39XqwjpC
fijCiw/iWAXlCAVPu19LtzqX/FDEHk17ODe2iPxQGK0P+905uID8MLTkOR5o
1zhIfhiMxnszM72zyQ/DvZdxyX/6pJAfhnLjR1zWznjyeVg+2FQb//R78nko
KW29EFyZQT4P1p9W6N/l7yCfB89+ztP06Ezy+aiduqFpsQFdD/Bh1txRfHLb
NvL5KI3ce7AxeDP5X/PDyjvnMhPID8f8+71JVjbECMcl0/O8HhNiRTjqrrT9
ZBpGx6sKh1VZLZOZHkd+BJyuKtebam0kPwKZTl4TVpXEkB+BwoXpOjrS9eRH
YPiA3xyfIDn5kbj7tXnz0+l+IxIeXslRnhlR5EdisN7sYsFRKfmR2Df5j873
IvV6LsDJznFTq+vEY8wSYG8lk+3QIqL9CfBmacfjIm1igQDbfYvbE0yFtH8B
bl7P6+yrEIyxUoDdYXYmsbbEKgGqrCcpdHdFjnGXAD6bNGpmbIug+kLM2yt+
IWgLp/pCsH5MG2LaEEOI5Oye2m1Z9D4JhOiPLL6r08Oj+kLwNfIsa4qIlUJk
9SRXF+YQq4TYq6VRUxhH3CXEhgbBrfkJxAwRrme8qTl3iZglQtcOzrVeF6oH
EfYn6MzRqFHXF+E/m2Y6Mk3p+BQijM7KjQkwIFaKcHTy1pv3X9P2KhFeX4hO
7iwn7hLh0oawzpQAYoYYHwvvDE+7rK4vxqGiTpZsAjHEYNY+upfoTf1DIEb1
DsMeYXYo1Rcj82Sp6sQd6j9KMU60FNz4pEesEsNVuf8kM4BL9cVoaMw+rr81
hOpLILBcxDifF0z1JVjxbSmz/R/qfiJB0vSSl2WnA6m+BFXGC9OE2wOovgS6
rlAOOVI/VEowMJjYMOce9TeVBFlKj99OT/Kl+hIofvD60aOX+jNDirA/uptK
j1J/Zknxr1/bMssjqd9Ciou3L5RadtJ6IJBC3GK386rnKqovxTWzXzqrJtJ6
opTift9IUs+nFVRfitEe44/fipZRfSmerGvWi5u2lOpHwbVk4OK7Olo/WVFo
SjOPtj1D6y2+smmM/fv9tD4LonDD17KyMMeC6kfBJnfxEk0nWu+VUbA75tq4
hkHzgCoKJdL+lg/GNC90ReGsMCKp9IR6vpAh9fKtyt5X31J9Gbo5Hdb1WbOp
vgwVFlNeq5JoPhLIUGy3MC+lTD0vybC56kZu3wWal5Qy2L3wbPg+luYllQwh
/qNrirdS3iXDERfZRwdv9XwlR8O1dHbidzRPseSYzRhg5uvT8UGO5kv76k6b
0bwgkONgqtLIQIfWT4Ucddobh7RG6f4p5Qi97SRscVCvt3KMOiypbPjybmw+
7ZJDsuPosw8O6v6zDmc+69j0sitW/w9RPohD
     "]]}},
  AspectRatio->0.3,
  Axes->True,
  AxesOrigin->{0, Automatic},
  ImageSize->{504},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{508, 156},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->1101057]
}, Open  ]],

Cell["\<\
The effect of small changes in the value of Epsilon is dramatic.  The green \
line describes the surface speed just outside the airfoil using the default \
value for Epsilon.  A vortex panel has a discontinuity in tangent-component \
velocity across the panel.  The red line shows computed surface speeds when \
the collocation points are placed on panels.  Numerical computation using \
machine numbers causes collocation points specified as being on the panels to \
be numerically on one side or the other of the discontinuity, causing the \
result to randomly switch between internal flow (zero) to external flow \
(green line).  Collocation points placed inside the airfoil (blue line) \
reflect the internal flow computed by the model which should be zero. \
\>", "ExampleText",
 CellID->189149207]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell["\<\
In the specification of some airfoils, trailing-edge points for the lower and \
upper surfaces are not coincident.  This appears to cause a problem for the \
doublet models with Dirichlet boundary condition, but not for the vortex \
model with Neumann boundary conditions.\
\>", "ExampleText",
 CellID->416625656],

Cell["\<\
This example uses the Clark-Y airfoil specified by a data file located in the \
folder Airfoil Geometry.  Import the file and plot the discretized airfoil.\
\>", "ExampleText",
 CellID->32738591],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{"AirfoilFromDataFile", "[", 
    RowBox[{"\"\<Aerodynamics\\\\Airfoil Data\\\\clarky.dat\>\"", ",", 
     RowBox[{"NumberingConvention", "\[Rule]", "ForeToAft"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"grD", "=", 
  RowBox[{"PlotAirfoil", "[", "rD", "]"}]}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->112529997],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rFOkWx/Fc7l9y/43AMAtxIS7ECyGLkI0XGt3MbHSjm2SjmwQa3RiQ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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->126312528]
}, Open  ]],

Cell["\<\
Note that the trailing-edge points for the lower and upper surfaces are \
close, but not coincident\
\>", "ExampleText",
 CellID->390242666],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptsTE", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"First", "[", "rD", "]"}], ",", 
    RowBox[{"Last", "[", "rD", "]"}]}], "}"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->238007975],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "0.0005993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.0005993`"}], "}"}]}], "}"}]], "Output",
 ImageSize->{241, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->824618374]
}, Open  ]],

Cell["\<\
Specify an angle of attack, solve the model, and compute the lift and \
pitching-moment coefficients.\
\>", "ExampleText",
 CellID->25666953],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"5.", " ", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rD", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rD", ",", "\[Alpha]", ",", 
     "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->592619],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0118375549372975`", ",", 
   RowBox[{"-", "0.3469074964891561`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->428331775]
}, Open  ]],

Cell["These are plausible values for the coefficients.", "ExampleText",
 CellID->46735897],

Cell["\<\
Plot streamlines near the trailing edge, using a scale that makes the gap at \
the trailing edge visible.\
\>", "ExampleText",
 CellID->492689119],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B"}], "}"}], "=", 
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rF", ",", "rD"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "a"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xMin", ",", "xMax", ",", "zMin", ",", "zMax", ",", "contours"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{"0.95", ",", "1.05", ",", 
    RowBox[{"-", "0.03"}], ",", "0.03", ",", "14"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "contours"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "grD", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->266881112],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.95`", ",", "1.05`", ",", 
   RowBox[{"-", "0.03`"}], ",", "0.03`", ",", "14"}], "}"}]], "Output",
 ImageSize->{196, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->183231109],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0nQV0VMf794Hg7lakUAhe3KGDu7VAoUCLQ7AQXGNYQrDIEoEQ3N2di7tT
pLgX3V3c6Xuzm8/M/05+bw7n9Hw7c2eemXl8ZAv1GPxb72RJkiRZmTNJkvj/
9nH92cWOApOf/7ojzsg58ID5T+GjQ/IdG5LPIfHIUfF/Cnv6Xizme1HhAfGf
53RKXL9B/J/CPxyLb1DhN03nv206X+Ezp+P/FIa+h7ma+218GCXpA0MfGPrA
0AeGPjD0gaEPDH1g6ANDX+Ys8X9hkj4w9IGhDwx9YOgDQx8Y+sDQB4Y+MPSN
yb6u8b2xkyR9YOgDQx8Y+sDQB4Y+MPSBoQ8MfWDoa/LDky2BrQZI+sDQB4Y+
MPSBoQ8MfWDoA0MfGPrA0NfOjQX0gaEPDH1g6ANDHxj6wNAHhj4w9IGhb7x7
PiV9YOgDQx8Y+sDQB4Y+MPSBoQ8MfWDoy+rmR0kfGPrA0AeGPjD0gaEPDH1g
6ANDHxj6HrvlWdIHhj4w9IGhDwx9YOgDQx8Y+sDQB9b0s9D0s9D0s9D0s9D0
s9D0s9D0s9D0s9D0s9D0s/j+X/yfQyRx/TWpZXf/iV9d/DlOxL2Nb8Ah8S9P
I8x/dtHKhedK+QJ3S7fN/OeUmP7AfN/c3Z7E9E97lEOPjqkPfZSD9fb0+shf
q89LWn9eouqD9fHquI0LT5PrSzn0UU5/en0w7bV2z48sBzOfOmb9+B57q5XL
+UUfQh8Y+sCMn/nhe/QB34P5HqzRI/kN+uF35ht+B1POfKaNH043h+jkwp1F
hYrxf+iTQInrucuN+9VmPqg2U9WPl55ivuiDIE1fBMlyj3lVzvfzmJdgv5wS
Uz7aNb7hRqcNKTpvSKH6A0MP9ZO7vxe0B0aeGe+u3fF/il7mV7dXzMeEMtfM
f3bZH/Onz5efm145Xn080A998Avl8APzSXuU6+Nl/cH6+jN+rVzqB+v8K3lf
5fpT808580c54wHr9p/v4S/aZ/309eV72mO89I/8Ug4/gXX7TX3apz5Yt7c6
/zCf1NfXl/Ejv4wPrK8n9eEnxg/Wy/Xv4U/KGQ+Y8WBf4E/4Hwz/Mx6rvrFJ
jL1nfne55mOmbB96wl0fqPas+sqm+Vc22d6x8K6lPx0Jl/Xpj/FQzvfMD+sL
Zjy6Pwk90Ie8Mz6+p38w5cyvlb5AwXogD/AH8xvs+rOL8pFfe5woOyUhrnCI
4S56ehnx3NH6sz0Rdo93QoK9UeUudT9fYZf4nlbYRc4DhfO5/BG7uH0r/m+e
MdT1P5wSow9YT62+0OpL/YE80R/0ov+YPzDzg71gPbBf1Kf/uTHxf1MlPcwf
mPWw+r+Bcn7d4/GT/K3zB/QgD/CDj6sDh+jjws2lf0J58s7xC+wQAe751fzx
QMF66POhxxv6eqCPGZ+uv5l/1l+fD9Ybfme8pePFZ4JDVHGPR+LsLnqHCK0/
Q+vPgP8Yj9W/D5L8CT1gXZ/CX9r4hTZ+Ke/wBxh5gt9YX+aX+Yef+J5yvm/X
Pv7PIZ646B8l22d9wfAH/TF/yDf1wdRHfqkPv+v+E/WfxKuXX9T6wG+sX7RL
DlQ584d8UA4/8j3jp5z1BsOP6DPWk/GynmDWE/qZTzD2C4y9Gu9SGErfMV4w
5fr4dH1J+X4XA6rxWO1ToJQP+BWs86OuP2kf+WG9kBfmF8z88T30gukPDL9C
P/wH/bSHftX9Z93fohxMOfLMeGif+uhLMPOLvqM9+Ad5BzMe6Ge+8HeQN/gB
rMc32A8w84V+Zj3xL6iPvgZTH/6lPu1h7ynne8Zj9S9V/kTvj++ZD/wRa/7I
JuWJeBt9BGa8YOgFX3UpIBWvr49XL50VDnL5E4nj+bHu/qX/AqZ/MP2D6R9M
/2D6B9M/mHgXDD0t3PMn6QFDDxh6wNADhh4w9IChBww9envwJ+2BaQ9Me2Da
079H3vgezPdgvgcjb+gn2kOf0h6Y9sC0B8b+YF9pD/6lPTDtgWlPz5fAz1b5
tGnyZZP9gekPTH9g+tPlhfwE/YPpH0z/YPoH0z+Y/sH44+hH7INuf8DUx97i
HzDf2Dv0A/oOjDygDxkvmPHq/gvfo88zuu2dpAeMfQCjn2if8VGOf8b4sAfU
x3/R22O8lOv+J/4K9oHv8R/AzJ+OaQ99zXxY89eB0j/H/uOPg5kP9DPzD6Z9
7O1Nlx+qvme+Xvwa75GGSf5k/Ngb3X9O4coXzBCu9PBAu4hfvVzN46S9x9/A
/wTDb3xPOf4C/hHzBX/xPfGnbp+wD6wvGPsGZn7B5LfB5LfB5LfB5LfB9K/b
A30/jXLoA0MfGPrA0AeGPjD0gaFPt1/6fh/l0I/9gF4w9IKhFwy9YOgFQy8Y
esHQC4Y+nR74gf6wT/QHpj8w/en2T9/Po5z+9faxZ7QPpn0w7YFpT7eP+v4e
9o32wVZ7o/bTKKc/MP3p+yn6fhj2D/ui749RTn9g+tPtq75fRrl1P9GmxV9R
2v6iTbMHUdp+o03bb7Rp+43KPuv7Z5Rb9x9t2v6jstf6/p6+X4K+Y3yUMz59
f41yxqPbe32/jXLGB2Y8uv3X998oRx9x/oDxWbGSL/w18FZXBaeMn7AH8CPl
2CvaqxafTa4SKv0D7AnjhV/4nnJr/jFK+ntuexkp4xfy1fAv8oy9wz7TPhh7
GeP+S8i3OyUm/w2GHs4f8H0m93hlvh4Mf4DhB77H/lPO+MDwP/XxtyhnPvX+
kTfsOf4b9M5xj0fOHxh6reXORJj5hn/A0It9Zrz4N8wf9RkP/EN+hPgAf498
GfZezz+j3xgf9Rkf/Mv86v4g8wM9un+rx+usB/0z/8gDGHrgV/hTz5/hn0Gv
zt9WfWQXiy6lrDFoQYTUL3zfJH6536p8DfPN+FzqZ5TSV/hXzDf6SM9HU996
viJQ+nd6PhJMvo18CfPF/IJZf6s+CJT+LfQhv/h7zLfun7Je+MuM32rfVH5F
35+1yr+ST/Q7mPnQy2kP/ann8xgv60t/2B8w9DN+635flJQ34hfkB/4Gow/h
Z2s+W8k3GHvhms7dTlGyy6yD74rHynw1mHwg6834WQ+rvp4i1xt6wdBHe+gP
+AdsjZcitf0+m8zXIh/EY2DkAfrQL8QfYPgH+aWc8TF/8BvjATMe1g/64Wd9
PPQHvfArWOd39B3tIV/ID5hy8n2sP/zh9icc4rarfl9pL5kfMPShX6CP+BEM
/5R1r4/0z3X51PczWU++J55i/XV9wvjRX5Sz/tAD1vdrfnfFmbMl/1Cf9WK9
GT/rC2Z9GT/rCf34U9Z8bpiUn+HX6yzPMHyOzP/r+Xv6h1/BrB/xCPJ9373e
EkMv+oT1QF9BL+ujY+J763k1pR9Zr9ou+pziiHs9pf/hpidI2lsw9gHM/IB7
u9p3auctlL/p9ocdCfI8UcyIX95qyt+EHviN/qCX+jq/gaEX/wT6wNAHZn5Z
T7e/7RCxLn4aI1zdzbSLka7yEOnfwG+sL/KIPQfTPvrWHc84EvIz6vwN/I/8
s54u9XXRLtJfXexTO22QcLHrLYW7uuTBIU641m+otn+pzitAr4v8p+p75AX9
YKVnpvQnrPpB6WP4CX2AvoVf4Scw5VZ+cyaqv83dv6wPfyHvYOQJjD0CX3B9
75TtfXIlAJ3aeR+n1K+FCsf/Kf/Eam/DJYbf6E/Pz4HpHwz92Gv4FUz7YOix
2nfFX9gzPR/J+mKPsd+sF/NNe8wX7YHhBzD8/L/P04VJf0a3P5Tjr1FOf7o/
gH9kjT8iJWY+6I9y6AMT31AfedXjQeaD+pSDKbfavwlSXvV4WM/fQg8YepgP
+BH7jPzjv6Gf+J71AOvxKeVgPR6lHEw59myLWx9JeUT+sW/7O76eVtSIlvac
+eB77B36kvwB80P/YPqnfew7/YPd82GOxzUhtgT5UPoUf4n+WS/wKRd/OKQ+
d8cjjoT2JyfYF4fY5Bq/t7Rf6G/kXT+v5Ja3KMm/6EcXnGBP+H66pIfvXex/
jPkMFitd43WIii5+GSn9NeYPeWI9GC/5fuiFX6z0BQlXemmDXTw1ue2HJzaR
w1XfIemjff18A/OL/kB/Y6/Rr5SzvtCDfiX+A2PP0bfW8/NBmr8eLv0BMPpJ
L0e+sF+U07/Vf02cH+R7+tf1Nfk51hPMePT8DP4k8ghG/sDIAxj9ACYfCiZf
CCZ/q3/PfgH6DEw5+RDaB9M+mPbBtGfF6rwn8TKY78F8D2Z9yKdDDxh6dEw8
bt2vnaTt107SzluFafnOMNkfmO/B1vO3UVKfga35iChJHxj69Phfv08Bhh4w
34Pxj4i3iH+Rf/iPeAP9in5HX+nnmcHsl1IffQ5mPqnP/h/l9Id/6RYL5U9D
P/kKeR7QTb/MV1Lu1l9KH+PPor/xd4if0Xfoc/Q9GH5F36Dv0K/oe8aHvIPR
v4wX/Ul8i/7Gv7eed7fJfAX2zT3/Tpn/gx/A0MN8Yn+xb1b/Q50fw36A9fPQ
lMMP+D/4d2D6BzNeMP4qGH8bjD8Mpj/8K/gPTP9g+A0MPbp/BoY+7BX0UY6+
BkMvmHgRDP1g7J81flHxNPoefct4sZeMF4w+oD7jp5zxg1lv6jMflDMfYOYD
jP7Ty7Hf6B/aZ/6oz/yBKed79B/fM7/UZ371+EyP38DMLxh68R8ZDxh6wNAL
pj8w9IDpH8x66+XkO6CPcvwL6/6Oqs/8Yv+gl3gAesGUE39BPxh6qA+9eryr
39/R29f9MzD9gZkvvZx8DvYKew191Ic+MOV8D71g5AX9h31C/+FvgBkP8Rn0
oe+hH0z/YOiz3s9xaudVEpfr+yPEf/ArGPrwR5lvMPKDvoZ+yqEfTDntMx7r
flRi/1fPb5Afg378WfQJmPGAkT+9nPYYLxh6qc94wNAPZj30ctqz3m8Lk/lj
ff8afxB/hfwI/g32Gqznd5FXF/stUf4F/Ei5y3z/p8rZD4Ae6kOPq/m3yp/h
ezDf0z75QdpnvJTjH1FO/hBM/lv3T5g//DHiS/wVMPkHMP0jf9b7Dup+DvLL
eTPiT/Y3wZTj77qsqbddTHA5vHFavkmdN2P85Fut8bzyb9AnYOI9MPwCJt4E
Iw9g4k0w8gAmvgUj72DOh4CRBzDnRcDIA5jzImDWE/vKeun+Af4K9IMp53wZ
48HfAVOf/sHof/pD3+j9Yc9pD8x8gZkvMPOl7z+AmS8w8wWGXj1foX+PvUZf
6Rh+Q19TTn9g+tP3R8CMF3vOeMGMF8x4dfuvY/28mp6P0c+roe+s56+UvaTc
+t6C2r8BW99fCJT2Bsx40Q+MV7fXOtbPr1HOeHWMPoMfKYceMPKNvbTaC3We
TbeH1IefwcwvmPnV7b+OyQ8w/5Qz/2DmX9/P0+29jhkP9lK3n/p9e8qZD90/
0LF+Po5y5gPM+oNZfzDj0/0FMPIGZvxg+ANMfI29wP5jjynX7TP5XeJlxoc/
QD4C+2I9X6XKGa9+Pod8DfqafBrlh93xvMzvgGmf/AP5V8rxFyjHPwZz/geM
P0N+hvbJ91v9X/V+CfJAfob67vhU5WvQP3r+Rj9fQv6GfD/5cfxT8jPke6Af
fiPeYv6s+RWV/2N9dX+G8TM/6Ee3/DlEStf6+ibwm9ovhh78H/gd/w7+YrzW
/TA/db8vgR/gJ8aHPILRV3q+bZ97/mX+j/Vgf4N8PvMJZr+J+oyH8bv1qRo/
++P4a2D0M/xKOfoWf4LzFG45nC3P27Ae5LeYX/Qt5dDP+Jkv/BPmSz8/ofsv
+vl8ytHXYPQRGP7X80H6e2D4P9ADhh4w/AuGHjD0gKFHrw//Ux9MfTD0g9k/
1b9HX1EfTH09n6Cfh8ffoD09v6Cfh6ec/sDW95OCtPeTgrT3k/T7TOp9JuJd
6AHTPpj2wLZ4BdFPxR+sF/qP9sG0D6Z9MPoReUPfIr/oK/ZzGI9+PgkMP4OZ
XzD+Axh+1b/X75fgr1OOfaJ9MO2DaV9//033tylH3xOvcV4ITHv6e226P23d
f1L5dOjV31vT/WnKwfAn/evvnen+rXX/ya7tz6r4n3LsEfaGcugHw0+6v6zf
19D9W8qx//gz1vvHSj50/5Vya75M2X/d/9Tvg+j+I/E87evvken+IOW0D8Yf
4f0fMPth+CP6fjj2Qtsv0+2vPG9C/gV7Sv/YW86r4z+ArfYvVmLGx/mAIbXT
misyT9pfvgdT35WP2ucUUa7pVu1BD+1x3ht/Egz9yBP6Bcx+Gf4W9gp/hvyK
/h4R84O91vcXaR/7jn8HRr9zHoHzbG41aRf+8eT7qfND1Gd/jfOOYP09Aqv/
ofxNzl9wPgKM/SA+YD8NjLy74w/kNUCWW+9DK38J/gczX1Z7p85/sL8Dxt9h
Pq37z0GyPcYHRh/hby1wn0+R54vwv1gv9A36iPbc8ZcaL+ePwYwP/mA+8NeJ
n8GUQ7+Ux4TzJ2D0Of4l44ffwfALmHwqmPUFk59mfsiHst5g1pvzQ/An38N/
1MfegOHHQBfBDrHP3b+o6tJHCqNv9PNL9Ec+FP+D+eP8H5j5Yr04Hw4/gq3x
b4A8T8X8ID/4A9gj+AV7Az+59b1TvsfhXm/n/yceskn/h/iMeFW/nwDGHhB/
kw9A/2FPoR97Z93/V/4A+m6pT7wCDpX04U+AdX8C/iSeAzMe7A3yhj8HJj/r
Ep/DThE/e5dSqvhfP/+Af4i9wR4gD9gP5AH7gX7V43/8Eev7cTYZD+v3k8DW
973CxWIXdohnbn5K8KeUfoPfiG+t+2FT5Pk1HSOPnG/mvDjzT33Wx2qPnInu
C4Ep19/Ps95PUv2BoYf5o5z5ZXxg9AX2jPjaeh5tgtQnlLvUwQ5l3/FX9P0V
5p/9nEouuxAh8ylg5EmXL9Ybfch5SvaTwNTHPmKfsN/oJzDrhb0CY99YX8qx
B+gj7DfrC2a9XrrY0SH9E/gPjL5F34DhD/Qv+R30L3hBfHcnlDyi34nv4Sfr
eRWlD5kP4hm+B0MP+Tm3fVbyTf6XeAv/nfie+Ah9xfzp94F0/c15JfJh3DcB
o+/w11lP8j3kX6iPfwAm3sA+3XWNc4b0N8ivwE/6fS3oAUMP+uyQ2/7J7+kP
/p3tmq5ZMt7ge/wX5ges20f0FfEP84++wb6xHrxnAGZ+wfh/2Cv4j3Iw/hL2
DH1mfY9R2VPw/36fNkquB/wE1vMN2Bcw5dhzsHbfSWLoxT4zv2D9vSzWA3+U
+mD9vTXkH6y/V0576FvaA9Me+oZysH7/i3Kwfv8PeUU+6R9sfa/emeg+mfX8
beL7zWDr/WU/ma/FPwNjX7D/xHfIj46RVzD5AL4nvoJf8LfA+Bvsz+Nv4D/q
+XD0O+sLJj5mfugf/c/8oB/AyDv6D3nHPmBPrfdv1H1b7Cf7G4wXfwqMPmD+
4fcot/8g/Tf0FfkQ8p9g5Netb5T88r31fInyjykHk+/A3lvzTzaB/cC+o9+s
+y1Kv4LhX/xf9Cv+DfXBVn/YIeujL/BvsZ/xxHYtHWNgD+AXsP4eAPLHeQ38
K+TL+t6O0sfYAz2/BoZfWF/kG/uGPgHjj8GvtMd6YG+wb/AP/rH1/cZwmb/o
FD89HVX+2DWc7HHSX0TfWfeTp0j/ifyKdh9I8gv6Hoz+Rv5YTzDrqZ0nl/lV
8mnk98Dkx+Av1hN/Vbt/Is9PMR7r/bkp8j6kfr4J/cR8s37QR36P9cS/xL9j
/Zhf7Af+OP1xPoDxMR9g6Od79C/f4y/o79fq9+2I15lP1gv5Qn6QXzD0g/FH
wOgP6/cKox90/MwtH1KfgenvZzf9sj8w/YFpD/mlPR0Tb/M9+hl6wdTX80/k
q6EPTH0w86nHv2DoBbvqh9nFA5eCCZH2Cf+Z+BeMf225v1LFkcCfgdI+oh/h
B+wj/jT+4XRXvOcQS1z6Y5jsH35H/xDfwE/oHxd8bBdxLnZV790if8Rz2Evi
RTDxA/4F8gz9+Jdg/HHWl3gf+83+OJj2rOdzlT7HfmBfGZ9uX9Bf7NdgT637
HX7aeEJl/K/vn0AP6wv/IJ/YU84rIK+sB/qP9QXTH/oAfkjljifl/T7sG/oF
/sJ+7nHp+bmC/BAY/mF+3fpKYeJzMP4YGPsGRh+CoQ+M/QG75KmxQ0S41quf
gb6lnHgaLH+vKCE+xv9Gf+A/Mt/UJ/522ftYhzjomv/R0l4Tr7Me5CvgH+w/
/iv6jXzk/77fqPwDMPlMMPYJfsAf0fmD9WT/BMz40Idg+A9+I39I/KS/J8F8
wb/k9+B/MPxg9afUfU/at+yHpXYk3A+dlMB/dtHW5SAEJ/hrTlHFLU9y/4D8
N/KNP+W29ypfhz7HX2L9rfbQKcvxJyjHfljzo2q/nPkgvwomX8P8UA6mnPmg
HKznfyjnfJ6Oqc/5NMrBlONvUA7W+yMfASYfBL/o5eyvgznPAX36/R7KoU+/
v0M59FEOphx6KAfr3+v+J/ET9SkHUw695D/A+H/QSzlYL7fu36l8sPX9w0Dt
vmaQdh80UGL9vAn2hnwOGHr1946JF2iPcjDl5KvRF/An++9g/X0B/f0yyhk/
5WDKGT/lYP39Bf39PjDjA/O9/ns++n1Vff8YzPj1+6f6+TfsA/4H9pf9FOy1
Sx+9sIvD74qb/2eywJ6S77SefwyW8QrtE7/SP/Gbfh9Uv1+B/uZ79Dv5CfK7
2BfsJ/pMvy+o3wcEo0/R1+QPwdg77DH5FDDrR3vwBxh/mvwY9gGMfw7GXoBp
H/l222Nln4kPsC/u9VYYfkK+4Q89n4L9oX8w40G+mC/sDfMFZnxg6/tEU2T8
r98H0rEe7+r3d/T8Pf4H/jfxAfs9xAPW/N10mT/V+8deYn/B+GfW82cqfsSe
g1kPMPMDJt8IvxGPkb+hff08Av4a/h78SH0w9ID5nnjCPT4Vj0IfmPrW96lV
fAEmPqU+8kz/8Js7/630PfXBzC/6m/GgD+B/yqGXctYL/UX/YMZrza85E+Wb
qQ9/IY/ID/yGv0b8ar3PMEXm/9GXLv4a6xClXe2PF67pm2YXe13zoPY/0Ge0
x/rL30dNKIceK78pjL4F0x6Y/Rcw+Vkw+ST9e/gV/xx+pBx+o30w7TGfjBdM
uZ4f0c8vUg696DvrfU/1/qP++0XYD+iH/6gPZv7gN8aHfoNeHVv5ScUr5DvJ
9xKvgNEHYNf6TraLFRniW1Dn3cgnutLoAYnzpZyHYT+Y8zMue3jCLsa44raE
35Pr6EjId/i747s/HQn60lf8GB8OLXKIjK7xj5L7F+hn/A/yJewP4A8wHvQr
8TD7+dhX6EN+iY9d85PNKf51v8cj+Qv7B38QD3Oeif199AnxnUsekzklfS75
z+hIiI8nCev5+kCZL9LPCxBPu/TLZofo6KJ7hNxv0ffb8YfgJ+QB/wfs4r+6
DvEtNl7CBsn9Z/I9Lv/Rn/bGynz5UBe/zJD88MRF/xCZ/2d90FfMr3v8TpHB
PR4pX9gH6/0vP7lfiz5H3+j7YfiTrA/5GfQh/ZNvt+RPjinM+oGZTzD7H/p+
IvoI/sMfIH9Uxp3/lvoDe4b8Yk/Il9Ae+gJ9RX4LerDHen5H/z0N9An5D+wJ
34OJ58HMp/4eE/oH+wBmfORjrfcPw7T3pdT5Zf336Vg/1kv//UvGSz4P/Qd/
UE595BF/Xn9vBf2M/SUfCj9g/5AfypE/7CX+AvUZP/Wx/5Sjrymnf84zwE/I
B/qPcvQF5eznUE4+k3LO51GOf0I5+y+U4z9RzvhZD/Sj9b0ip4y3kBfK6R/M
+lt/70t9Dz369+znQj/yBL38Hg3ySX3sGeXwo/X351S+jP4oZ73AnGdHXzFe
zpPAD9bfY1Hn4Rgf9eEXMPxCffqn3Preu03mr/V4lnLr+VqbtB/Uh37KrfeB
bHJ+yAdCP+XMP+0xP3r+kPqsB+X4l5xnkb9nmpBflO9XJ2DsG/Xle9AJ5YyH
ctYD+8H6Ug4/guFH2uP8JOfv8Jcqufw3H5lvZ//Gql8D5fxbzhd720W0y7+a
Lu2r5X5Af3uCXYiT+2XW93EVRt+jX7Bf+v488kw8CiYfDybfDmY+8IeJ18F8
b/29U6d23lT5u+QLrPdrHFr8pTDjAcOP2DfyF2Dopz75Gz0+w/4wPuwJ4wNz
PoPxuv0xtf7s32Bv4E8w+hx7iT8Oxj7hbxM/kJ+jf8rleZ0E+ojv8N+Rf/28
IPlD3jPhPAT5LPxPd/yo/P1m8ew2XGH4V8fwL/47+rR//PREqv0j9/6GU8oT
+Ur8WeaT+IrxWP2xxPsp+nvy1CceIF4BE8/hD2D/yB/B/6wHGH1FffQV5fCz
VX4cmv1V5fjLYPw1xke+k/G59F05R8L6TZDyhvyz3rr/oPsLYOaX87HoW2t+
R8kf/jX6W/4edYK+tP6eXZSUZ+v+kSPR/Wb6Q97RD9b7H2FSn+r6A/62npeO
0t7/V+/DUg7/Qz/5XMaL/DK/2Dcw+wNg9/0wR4I8TZT2i/miPf09ZNaDcvwh
yvX7cvp7w1Z9rtYXfsb+kh/g/Vn0Dxh5ALv4q4jiN1dxSYWJX6z2Q43Xtbxr
lb7E/2D/hvPj2E+XOC+yiyb34j1k9fvt3I/F/7XmQ9X9W/jLmg9V5awH5fAT
5dBHOf4E5fgTlONPUI59oRx/iXL8Jb1/7DX2Xj/PzvlV/B3yY3xPOfJCOeMB
Mx7qYx8pZ3x6ffQD5cgr49fjCTD0WO+/OLX3FJza/rlTex/Dqb23kDhesP7+
ifJP8J+hH31JfI08g6lPe5TTHvPBfTLmg/MEzId+3pT4g3gb+8h49fjD+j6a
yjcyXvpnPrBnjB9s9dcnyXLr+Vzlr7EexC+0b/29cIWZTz1eQV8zf+hr6+9N
Rkn9iD6Gn3X/DX3C/IGt7x2Gyfkkn8H8ga3vD0bJcvpnvuif9aM/9A3+I/pG
P++GPbH+fnSUtGfYP2s+L1rWp33KaR/+w5+V52kS+kNewNb3FJV/bLW/ClOf
/imnf+wp+gv7Dsaeg2X+NQGznmDoB0Offl7Sbbdi5PfoH+I3/Cv8eat/pTDx
NvWJTyinP/175B/6wPC/9fcgEr93QD6C+AX9AD/r9zWRT/oDQz/5COi3/r5P
Ymx9/19h1gv+hx4w9FjziYkx/AV/Um59v8Em4y3reXl9/03xu8zHJmDyT8Tr
5J+QB+yL5XzBQMW/zKf1fr+Kr4jfLfYqTMUv6Csw8Tj2mvwo33NeEky+E3vA
eUj0P+2hT2lP13/6+yiUu8jvq/IHtI8+IJ+LfNE+/Mp5b/KjYOt5GkfCeddI
uR9OPp58JvEh8WAS9/6lzJeQHwHjD1rP/6n7msRvru4GqfFxvgTsqv+b2m8i
3szpar+7pA968X/ZDwMTf+M/U855ZeJtzkeyfwW2rqcqZ38AfeYSh1NO4Zre
8zHG1Hh6jysMfzL/7vupduHtchhD5XqyXu74Q5VLfyWBPznP6j5PGC3tFf4e
8w2GP8DwJ/4S/I2/QTxgzceo807Eu9gbMPoDfsVe0z76lf7188T0R33kG/nH
nhH/cD4DTH7VNZ2R6jw69l3/PRXqcx6d/Tfib/QT/Hnf1d4cyQ/IA/4856vB
5L85D0x9zpOTLwFb3su4rPZfyadwHwPMeR3iVc6/w0/6770QD4LR54wXebee
h5six8t+Llj//Ub998/YH0H+9PcxqA+mPvGhfn6B+mDqk7+hPv4d9cHUZ/2p
T36H+mDqk++hPv4v9cHUx75QH/+B+mDq409QH/+W+mArPao+9pn6YOpjr6mP
f0h9MPXxF/X9Ls6rgfG/iA/wt/B3sZfEV2DGz3kNMPLCfFCf8YKhD4w/xXlV
MP6aPG+dYK+hn/pg6jMe6qN/sW9g6+8vKvsPvWD4U38Pk/Op5HM5f8b6UQ62
3nd2au83Kgz9YOiznhfX4w31voNVnwfJ9xrJ95Kfwp9Ff2LvwcwX8kZ7lKP/
aA9MfpzzDGDsB/ly8lHoL8YHxr9iv5l8+br4CbrhEDXc30v/Bf8EbDkveVfV
5/wI60X+Dkx/Osb+kI9n/4j8IPJIflA/n0C+B/uMfGLvyT+BOf+Of6C/D4m8
Yy/0/DUY+bTuTyt5x36Dsd9g4hUw+zOcV5X8mHA+A0z+hvaJr/Bn4C/iBeIl
MPJpfd/YT+PfcMmf1vMUjkTvHVMfeaM+mPrMH/bXyt/R2u/F26T/Rn3WD8x8
ghkP9DC/8D+Y9pkv4in0I/4N8SXltK//Xhvjw74xfvwFsPV87myJ9f0r4g95
vjpB34LhD84fpXX7/+r8dUJ9MPWJF6jPfjXxEhj/nffgOB/GfjcYfYK9AZO/
R77d8hoo7/eB8R/B7Eehz9kfxP/EfwLjP6GvwfjjxDtl3PfFZXxEvMN5L+Id
sB4/0x8Ye0C88rOr/any/i718a/A8AP5HebHfT9gtvb+j9p/sv6+nCPR/ib8
hf6lHMz35B/Y33DNr49dlHPREyf5jfGBsU/wm76/aTmvm0yVg/m+nis+U/1z
X5D9QDD2033eUtWHP5FP+JPzVfAnmPeOdIz8uuRvl1N0cz0oEOvmn4Jqf8u1
XOdUvEF+EEz+NK07PpPnKbEvxKMH3etrWM9TRmi/Xx8u7+Ozfu54xyHs7vOI
Mt5CP2Dv0CeUw09g63vzid+X0M+n43+61FtPp/Q38Bf19yOs+W/ln7nzCU55
fhL/FXqxn8S31vt8Cb+vWsUpxwt9rB/0W8/Lqfs/0I+8Y7+QR/af4S/iTdaX
+8zEd2D43aVeb6j70egv4knyj8wP+QI9P8l8oZ+s+692Ld5Q/g7l5C/Qf2Ds
E/qGeIbvyRdSX543S8D4/+zHYD/x//CnwdbzVpNk/tT63o6OVX7W+j5PpFwf
+Jn5Qj+A6Y/7y6wX963AxK/sl+HPMz+sD5hy/feg9ffcWR/r79WGS32DvcSe
oV/Jz2Cf8P/1fFcj1/+3SX2h/z4r9pJ8Cvkf9AkYfYn8kE/A/wKTr+L+j1se
oiT/g+kPfeWOB5Q84M/RP/NnPb+m9pPA2G/sG/KMv4S8g8l/kf+gHHvL9/I8
dEI5WP+9VcrJb5APBFt/382REG8FJNwnV/k15p/8FvcJOA9A/AL/g+F/4jv4
H38OeZPvwyXIJ/4d7yXCj+gbMPqGfBXxGPkm/fyBft5A39/XzxPo5wf08wJg
7Cnyg78Dhh/AyCMY+dfPBxIfgokfiV/d44qQ8Rrfsx9k7U9h9KWe/0Gfoh/p
H/0IZn6pz/jRt8if9T6lOv/A/FAO/4NZL+ozf5Rj/8DoQ+ozv5TD77o9oT7z
Tzn8BUaewNh7vmf+rfQnPp+hn8fge9bLSq/C+AfW8Tm18Se2d8Tj0Kefx9DP
X4AZH/G5fE8gIX5nfGDGx/4U8SbxG/wExp7q5yn0/VP0Ae2hL/DP9PMTfA8/
oQ/gN2s8oOwN7+ej34lPwMy3fn5CPy+B/kNedYw+RH7Rh9bfiwqT/WGfWV/9
fIR+nlbH9Oc+L+qU/SFf2Af0n/7+j/V8t7rP7j4v6pT2nvnne2u+JVDeN0vq
CkxDZX6AeAlsOf+STL2v4RL/b3aJiQew1+gj/HnsO+sPxl6gnyjnPC35OvI7
1vMOCpO/0fdnweSzwOR39PuY6F/yMehX2tPfk8J/Y/2RP75Hfslnkf/GH9bv
Y5APZ/0oZ/+efJr19z8maL//MUFY8+dh0l9GPsDMP/lBMPpOv4+BfDJeyqHX
+v6Mkjf0vf5+ivV8gyq3vi+nfv+LcvhF9zfx/+A/yuEf6/5mYow/R/6d8w3Y
H9oD0x/6hnJ530yTX/33vNC3YPKn5De4v4z/BWb+rOe1VL6Q+xf4++RriHet
7wsFavHIKInZH+K9LPxN5gdMvGh9D0j5++S32D8nXgETj5Dvwv5DDxh6iMfo
n3gMTPyEvww/Uu6S95rq/TPqY184r8D9bzD8j/9MOecTyMfAv8ib9X3tMJmP
4v4j+8v6+2noI/jX6i8qjD4Aow/A6B/r/qnSb2D8Gew95bRvfZ9J+Q+c50a/
kU/D/wDjP5BPoxz9ijxwP4X9Bvwb9BvY+r5hYn2If4B+0c8LIr/4A9hXsP57
vdTHnlMfrL9XbH3vRp33ct/fVudJXP70coWRF/JjYOwJ+WH245AfMPlV7AeY
9SHfyvke7nODeT+L8zDoA/Q92Lpf6pD5OPQFmP719/QsvzedUeXz4AfkB/oo
x99g/l3+yF6Vb+W+EfqE/DDnNazvoQVLf4j3wsDklznPRTn6X3/flHwtmHwt
+Rr0A/NDPpt4H/8MDP+7yG2BPg+Q57XAvG8HJt+j8z8Y+8D4wfrvx1CO/oO/
erneb1T7s/hPzC/0874AmPiF8fAeH+MB0z/n0Sgnv0E+E/3EfoH1vSn9vqTa
n8Ofohx5JL8Kf8BfYOQffiD/T35Xv0/P92C+x35RH/sFRv+hT2R8Z7kvpPQR
+o9y7C/rxXiRb/wJ/fdEsD9g7BXydDO++etKHtnvw18Bsx/H/hf2D3sOxp5j
D7HP2EMw8SDxBfEkGHni/h4Yf8p1Pma4et/Fff9OYevvh02R/GK5v5pCu5+Y
Wr1PAcYeEa9S/tG136P2A+Af+A0Mf6J/yc+ij8DIG+fTeI+V9y7AnFcjX0g5
94cYHxj5P++K7xxS37ns2weF3flIFW+yP4k/hb+LfIEZH98zfuJXMOuH/43/
Q3wFP3BfEYx+oT/9vQbr+5dKH3Ifkv0b9An5DOaH+8jkUzn/AeZ8B/k5ysGU
W99biNDsyWzt969ssj/8N/Qf96Pw54lnwey3Ez9RH3+E+mDq459Rzn4j76Oz
X8R+B/pG/31f8tnEY9RHn+q/90t95I365IeoD6Y++RPrfStVH2x97zHxfj/8
z/4+9g+s55vI7zN/1v0BFe+hL636RPmrYOw9+lT//QT0D5jvec9Z38/GnhAf
w19g+It8DO/nsD+jY/iV9cLeYv+4Dw2mvvv9Imei9/qtv6eu/B8w49viOn+m
/D/3fV61f0v77McyP6wf+pL1w77o54/x38D4b4yX/A+Y/A/8RTmYcuYXesDw
G/u97A8jX9bfh7TL9+O18ynS/2F/nfOgxAtg9CP5Cfxx7C/xL1h/PwP9y/yi
f9FHzC/2n/kF0x70oJ+t91vDtPzsFImZL/K1zCfzA7/hv8C/YF2f6u/9of+Y
X/QHGP2B/0E5mHLyrZSDKcceWN9L0PNDar7xJ5hv8m/oO/Yr4D8w/Ef8Sn3i
Vev+tKqP/qIcTLm1/ihJD/E9/eNfgok/weQz0af4T/SH/IPRF2Dr+4WJ38Mg
Hwf/gMmPor/Jh7IeYNaD8fI9+XHWA4x8yfvxCeuH/qQ+mPqcR6AcTDn9W+R7
uNKn1vdDZsp4xvr7Umo8fG95zy6F8pes9ihMvudLPhZ+Jb8BJr+BfdXjEeIZ
5BH/EXtFe2DaI17Q88PYH/Q58YDWv7T3yDf0Iv9gyrGPyC8Y+SVfSH7C/Zm6
TwRm/si/sr5g1pf43PpejIqfwdTHX9Xf96Cc/BfnM+V5nIR8HZj9BvJ76Ffk
0/r7p05tf07xI/Ki3+eEHvQz8aU736XeK8C/AnM/j/sPnH9L6pZ3iTkfLfdf
E8YHZny0RzzE9+QbwcSLxAuMH8z45X1h7b1fPf5g/fkefuZ8Jveb8DfA+Cvo
V+K3SHd8K+Nn4j/yW8R3tId8c/6deByMviPfTHyBvBC/EC9Zf1/Oof1+qion
P0g5/EU580E5/Gr9XpWTb7a+F634gfbhR+v+3Cj5PfaH9SE/Sv/oT/rX76/h
b+AP0D6Y/pF/9DP8DcZfgL/AyB/6gXjB6m+Okv4n/ZE/oH38bzD6i+/BfI8/
Sn34C/st7zMk2Hf8Q+Jh8rHcZ+O+Ked/wbx3RHv422D8bfJb+n0IMOersPfI
i/U9t8Tn7/Xf58XesX8Htv5++my5HuzX4+9iP/Bf9N/L1eNl/b1i/f0M5NH6
+y4qHsWfBePPok83uQJ8m/R/iBd5j4bzx2Dr7xklxvhb5Pf138sGsx74c2C+
R38R36FP8O+J96y/T6XyabSHfuZ8IPk+8inkayjnfhFY//115BuMfuc8HfEL
718h/8Q/yC/8Y30PUt3nse5nBhmcZyTeY77hB/hZfw8P+yrfz0iw/2D9PSn9
fSbaJx/P/q/8/amE9ogXiDe1/S6J8Zegl/Ejz+hnMPob/5v6+AvW+1Aq3kA+
rO+bKv0O1n/fEvtPe+h7sB6PwK+MH35jvPA3mProb/gHfUE8DdbjFfxp6/s1
NkmP9T6T8r+Rb/x54huw9t6hzLdyf594V39fC3+a/W38aeyh9XyAmm93Pl3F
Iy77mkftN6CPmX/2o8Gc38afZv3AnLdi/jivAsae6xh7zviJh/APmF8w8+t+
71nll9z7awozfv29DOaf+cD/wj+y/h6Y8ufgb2v8o+Ij7tdz3oD4A4w9Zr3Q
Z/p7Otb9qMTv3YDhB+aP/A3ns8DW80EqXqF/+Iv8lPV9UxUf4r/g/8rf00go
Zz9MjyeJJ9if0uMJ5gOMfee9tG3x2w1bwqQ8os9ZLzDrhf7H/uvn1XjvW74P
lhCPyPcgEjD5YG+X/LST/qLuX4Kt9jxC2k8w9pL8K/EF+Q38fX7PEYw/xviw
59hLq71O/L4KmPFAL+fF4Hfr7zONMsjX8t43+S36wx6B4Vf4Df0BJj/MesA/
yDf8AyZ/jD8Hvcgz9FryR3+q9/3JzzBfYOyBa/pKqv0w/HH8GzD+D/fBuN/A
fgn1yQ/zez/4C+TzkDfmF4x+xj6x/4V/CSYfxfkT8sPQh/+DPwp/oq/QR2Ds
h37fFP+M/Wgw+9HEE/h71veXFOZ+Afqc9dPPc4PhH/2+Epj4zzJ/wxV/0r7+
Xp11/zzx+3Bg7DH8Sn5O51f9vTIw9MGP0Ac/wg/W88kKkz/Sfy+b8YPhJ3kf
0B0/yPyY/l419hJ7hX9BOfEd+UMw52Fi3fwh8wXW81QOzT45pH3A32G94Fcw
9hD7SnyEvpfvCyaczwfjn5J/1PND8CuYeIL4Tv89LPw/5AWMvEAv+h9+wz5S
jn2knP7Zz2V/9le3/Eqs34fBP6U9y/3nkio+xN6AWQ/r+Tqln5FP/GPsB/qR
9SKeQ5/ovydKvpL4ivMkYP33RYq75UFi4hXGf8/NLzK+oX3sDe2DaR/9yO9L
o4/ZjwPTH/EV9Ym/qA+mPvNFfeJH6oOpj/9Effw56oOpj72jPvqE+mDqY++o
j36jPpj68C/+B/oe/wP6re8hJn6fju+RXzDyS3u0j77EPwWjX3T5Jf7kPAPy
DD3k29Av+C/YT+qDkXfyA+QX8I/gL+If/Dvkzfo+jNq/IH+vvyeOv4Y/B7a+
Hxgk6A/6kS/kFX2MPgVzfsztP6vzAtg7/Af37xEpe4g9JT5wv++f2J5Zzu+X
TOxvES/RPvYM+WO+8E8Yn/V+abCWP42S8Tb+DPwBP8Mf6A8w/I1/bf29CqXP
wPp7KORHOc+KPwO/MV5rfi1M5tewz8RT6H8w64E9J95GnsiPsP7YP8ZHvoXz
TPAv59exH3I/JAHjr2IvsCdg9uPR51b5npjwnrXiL/if+cT+cH5V/v5Qgr6Q
79lr+gP5YbzID/kt5od4kfrsPxIfYr/ByAf6A/4Bo4/RD8wn+zH4f8gb48d/
oX34j/bB2BPr/rpDyh/vM8yq9iA4Z40w6S8sWlF3Tud7oZJ/b/uv+vu3WaFy
f8Zna/pFC5qEyv2Shp+rT9jZJVT6vxfv7yh1/4iqf/7a7GdnQ/vJ+t/y/prn
2bV+cj/lrlfJnfOve8t4dMTMsEefroWJpDW7/tNwmHqfEP3umdV7TGp/9T5h
Dt811+I6h4nb1TJeOHMi8e8nva66qUzLhtHyPYqaX24P+G9mnIw/x3U4lefO
z9HSv043+caDHNujReMZk2s3jXOKFR+m2MOrhhlpLxQY8eq4U4QuPJS81NIw
o5B3hgGP8jhEi41tiry4PNDItqz91/XeTuH/qp7PDY/BxtgU4w+2OuUUjSaF
v8w4qZ8Ij7wS92c9k76Pn/65/2SiWHX1yZTBc51iTcHNlfP6hopMIyt1HDnS
Ib58XWV4XYgSd5JU+zbmtFNU2NJ1ZsNrUaJgJY8pATkcIix3jcUpK8aJfyuW
G/LolENUGTT94t7qcaJI9Ra7vw50ipaX1r/ukiROeFaM8d8VbheFv/vXy11o
msiSs+r84Ei7yN9j4bnTT0PkfET+OLHTn4vnSH2ZI+h940OdvY1zaet97tlQ
7QfDT3PTDk21tOgAub5tSkR9655jvDxvErvl15rZZwxS71G9Lt49k/80EZdq
XN7HBVV+XNbfEZiqetgk6f+lH9M45bQUXsbHhg9DZuxxiLiz2+2OmsPFgw71
l3aJv68f9H5qp7+Gi52djzn6vFf7SciTd0yKbL2T9ZPrf/j4hoa9xgSLFJnb
VCvzyC4a3bjZIo33FJnftiXZ+GLPK7V/7t+5+rK4Tv2lf/Wm7GXPDtnVe4nt
Cr84U/9BqBjUf8yVrXF2sSDs4ejqzWYb5WcufDLuX7u40D5HsSdpZhue75/8
duidXQxNcblbsu82I8+tf73/bOQQ6a4N3nrBsBmP/jk1skVLU56yDRySZbfN
ON7lz+B6Zn8BfsMurQy2Ge1qJ8mxaqlDvN3yIntmE68N6O0fG/972O02Xu4/
zGyvUZYvztJOEX6yzdCDoTYjfd/ArAV+dopU20amKhluM8Y2SNYvxrSHtVf2
+vL8qs2oEpTl6eY/neLZDzfKnr9nMzKNDBi3a6JTZK2Tq1bPirONwmfG9HXO
cIpuR24/H2GOJ1XxVjn3mP7R+YLpGrRfONWYMLT98Hj7/ihdUPlCw0OMkY2T
Nj76xSF6rfotacqI8caG5ymWpknmFDcKZPrNL2i8Efn5bdUypr2eWW/B4nWt
fI1ptmOZOpZ3it27Xq+qNdfXGP3i5pGOpv3usjBryf9qNxeLjlYaFBhsxsOR
ReN6ZLywb0OT+XXD4nGJn8/0c/y9LyLz3G7/bjTjrcUBgUnu1jcaBeQZkNa0
R68nRmXu/aWxke+E56shJUz7PLphrg+3RosD/xXtlST+PuKPFa89azFNnKhR
5FV6E0dF7FvdzsTfjU+xyRuY/u6g3MPvvbCJAmNz3q9j6t+JO8rvrPLUJiY8
9dpUaJLp37QfePrfn2aLh8u6zPvPHH+BylmPtSltE127/F5ilRl/1rIvLFs/
p01UvpYzMN1Luxh1psVtUXKuKFdgaqVtr+3i3awiOd+nmCtqpDwQeHqBQ1yM
STaq4fc5olD5N59nr3GIIad8RnjvmSMKXN4edNqcr62hxbst3zZXXJ8RV66z
OT9HCl2ZZjf1f9NUxSZdum76x5Gv26QoMEvUm+AdVLKHSf/NizkurgkSFetn
GZza5N+rq45eW3ZSvffXdps43XdZgCh1PfuHEB+7KOHZMdvTwUOML30Xv95n
rm+HmknT7EsyxLhf6WP9jiY++/FD7shkQ+R5vDwrp6Z4XXmIMbFC1NkL8+yi
wmCfG9UW+Bip8s1/92qBXeS9ViDsVpiP8XDEn3WWmvw+/cWNjQvGTxZFNq8t
evS4XbR3Nry5d/tg48SnZe/bX7CL7T+lGji432Cj0KsJp+rctgvn2tBWa994
G1M/dLmw+bFDbD838P6w9er3nGbe6lRx2ZZA8aDQaq+npr6r3nJN8IHAoTIf
3WfLkF+i//QWtS5uLjvspkN8KrO8av0lPlKf/Vhhy93VSWeKfte7tt08xC4+
t5qSYWiSGaLakC/vXpv4a/PQL5e/ThcPjq/50myQXQy+vu9m5R5xImr92h//
nqXeQyBe2TjqdNYsGdTv83bu8m321NE2Y+GA9dnPn1Dv8z37u3Tf6BzqvLb8
vXiv/jv9/1Pv+d5Ot6vK3WQh8n3qNW/vtf3FY5q0zycfNz4+P079/tP0NoVL
NFs+UNrb4KWDdo/KV1X6p3va/XooTcqBom/sv0Nf5lD7T8RzlVus9suefrI8
HzPj6AF7UFNfyS/TrhT2L74sVOrTkd1W7Sw3Sb33++Rj1l63h0yX+dOAPE+7
P7sVqt77yuHZr2Fu9ftQC33ufw4fECXt6+GA7zsWhtvE0nSrfb4uVvtV0P85
YvG7XPWjZb5gf5Prc94/nSvzqVuCoy6uHBUn/GOijeab7eJWQOr2n2v7GKuq
lh5/dYVdVC9X6GXXu7FiVNN7FTquiy/f3vv0nlixsvL9hx7j7WJ4iYtxfutj
jC1BU+euWekUl5eUGr3ViDEGVGh88xfDKYz0jlJlX8YYy9p6tL1+yCk6F27q
43gfY7QvWKnMMPP7wiEpbpYoHWis9Cyd7YQpH0MftilVt0SgMWfZ8g4b19jF
yzEFntc/FCDXr3Gbnv+GdAk0HjTr/uzdJbuoO+Zy9I+DA4zRByfPSpvBIWrm
mXh89Et/Y1Gzs1FNTP91zqF6z/4Y4W+0qNnrbK3FdtEjyav6NcqHiMcnr/k3
WOEU09K3P9l0eaycrw8RxZ+l6xYrymwVhQY+Vflgr9GN3zUz6e238OCpagUj
RaazL+ImJTP5NcnWW7mmKn/19evG/X67Z5PrN79QkgFjM0aItDU6d05l+tev
tzT5N2D5BJnv63P6w7tsDeNEhL3mD9d9VP7/VpNB5e56OcSUTo0vTj/gK6LP
tKg3opuKf/Isb1g1ebRDNFty91urv0YLv5Znrkya6hDjYn/22uYxU/rni/58
1ed5s8nigzNZuaubTf9jVJffTjefKP5+nFbEZTDjwRWDvy+sFiT+vN7lTda0
pn/8rf2G0IAgeX4j4z7/qxUCp0n+TZfyYcHVz/0k9nla4fKPHYKl/5P7XPFZ
eQ/FSP/35NFa89ZFBkj/pf/9lbkervWX+Z8h0w6PKPNsoui6+Gb27Svt4u0w
41C7oBjDuW//lh2HHSKZ54ABVfpPkPmof9/vHDht2gCZv4kt8qXrgreBIseY
kkOcu5yibnHPosMbxwqPNX9k+WLGS4Epy6QMSxUrfgk58ufgo04x9O+Cs/7L
qN5z/LY/1S+tTnjJ/NHcbs2X31gZIbKeiXPY75r+hzNLcHbvCLFrcxKRLf73
0fulLTWsSoQ4OarZXs/zpv+X4frKI3fVfu2MTl3n5986Tfrf48PbjEtef6J4
X7VDL/tJh9jWa1ryZUf6GH9Uub/96kGHqFy4WvJJafsaJ7zqrDmyyiF6X1ja
wffvvkaXWh+HdNlq+l9NK/+ze1xfmS9sfeSWV9pLQeJItmv7L5n1H05KdjVf
rZEyP19z7rxNGWJHiO1tAiZsdZr2rH+xJu09porWkW2SVL3hEFXb90rt/d9U
sbnb8HH175j0XTqa5pdzU8XWtF4BBQ47xfVe36dWP65+L3S1X/3dr2N7G6Nn
ln3833WTvvwNNtSr2Mcodqpaj553HeL48sEby33vLfXtxhefjg68qd5jzXsw
4uDnQ0PErLPRNzqZ9u2H1l2LrfKZaoyq1+my09Q3Xeun9r/QZKqx/UYXU5ZM
f/Rb/yUjNgYb9fPufjsprUPc/Jz3zc9xwcbsNJW6Pu3qEI3f93reyyPYKFqo
+T9DujtErll1f76VJNh4ci90ZoadDvF7tVG/HvYNMp5dnlc+PKc5/oAHyzvE
TBS5lw+ZUCqXQ7woXX7MxNCJUl8XPlZtnD3NHGNL71mD/jT5a067tfuPLJwq
Jnicelm3rEP8EzetxOyfJ4jcvWx/OO7Yxb95Rza5sGuKyL1g7nfnTbtIE5F3
xtbH6j24RdfbF+4VYRODBwSvvGQo/5zzFlfy7Bvyzxt1/33KgqTbbY6ZIkXd
C9s3jFP3d5m/nsdqDljjpeKL3qlOvbYfDhen7c40rYeZ/kDr0R13DZ1tbCm/
KJvnMqcYOeRZuxYTZhuj9l0M7m3yZy/PCb19M001LnVrKyqXM/3x9FmyRXYI
NmasPfDwxxkOsblXvzUbdwUZYflvzvKa5RCzvs0dWmR7kHH5Wfoeb4Mc4uSl
1etb/xIhWr8t87pWJofosCluz6s2c8SucZ2ck8o7RKRP0ch2Y2LEIr+xNydU
cYgLIRkCU3aKkfHCvE9F7l/+PFjK18c2lfOPKh0k2u0tVH7SdXWe6mvuHLaR
gQ4x40nB0sbnyaLMDz+vODbZjHccuSMzG5PlfA3K/GnxqJtBxrtzQdsGDU38
Xlv9UzMH/iTCRAqPLLP/e5T499ZGZmzb6cn3UBEysVmHdln/z3mPdc/Ck55P
/Ptq7/s/qjBtndpPS9q84+Z6c2KMO7aJ1dfY1Pll7MfQgk1ab/5H4TLfWl7v
uXy2UWRxuOffe1X+Lyiw7Su/uSpfQvtBA+6eq+s7W/h2Xpu+3kx1Pvtx/8Ba
3u8cYk36d17pP/Qy/cVuOde+MdfHO3JQxfS9pT91K6x/819Cpkpc6fbfSf/7
GGB0qlhr843/8Xtr3WY3+9joUrDKrx9eV/Fq5QAZn+5e+uZtjxLBEjc4H1Z+
yDs/I9P6lstzFnWI1sasRg1D/I3DdTrVXLFW5QdrZl7U9m/Tv31wZu+K1tVn
i0U7y7bpusi038UDVhXKO1ucm3BvYfRqh/D70mPJ8hbTxd30mce+PuMQ3Vbt
vZp3QYiom2RF6dmmvnywO3xMhRMmfny+faVKJv91+HHtiScDjDeXer4sZsrr
kXtvk7eYNcDIlSVfsbwH1H7cmn57NiUz48dt/v92i2gRJW53a3t61j8qP/7f
9xF9q04w7flx7wzXMk8XBYKvfa41yS5sYa1m+byZJmoOPla1jalfc1TtfP15
s5Hij++7Jtcz45nJrzbkvrEoVKTc2XBs2DOH+H4vqNyyD6GSv8J/7jtxxB9T
xb0hizJdeqDOK5AfPXlxee9Dk6eIspeKb4ox/alBBV7V9jpqEyFbB2zLtMUu
Nm9fPuztApvoZNSuu9uM1w/9M3f35eHT5PsMGxu3upUuvbovWa9m5hIDv8WI
7lvDfY3/Er+P99PFe/t3RMSZevR63gObE79/57M3eOuHGXHSXyn32n/zyFYx
cr2/douOdWaIkfF7jtsFPoTciZb5tjubToiPZ6Pl/sbT4vOTpn4SLf3rdNdO
Tj7rGSP99VSFHkwJHRcjvy88YOKjiZlCpby8/rd0yRPD1f3x3rZT+4rWC5Lt
L1paZF6POUGyftdnX9+eKKjuHy799dmk10UHyf4ej2wQ+fg/H1l/7NKgV3+N
GSbpW/LtS9JPTYZLf7jV43Gb/tk3QfqDjTYEz7+7LkjiTZkv/p7/2yyZXynQ
vsSe03sjpT/05Ppvec+miJH+/LCQb5GXKsbI8ubVozMWqjxPlt/5cMYxrMM8
UaBb6Tvl/ezmOnfYP2NtjPHTqNced035/Xrgh9PNTH2zIH/hPTdMf/zUhNnj
F5wKMMJbTR8UYeqfgQ28UoR8CDBihj6ulsdc/5dJvhT9L1uAMaR3yb2f3trF
tQcdd6crEWBUm9y8YP7aDvH5xeAtB4r7G4EX2+d5LEz/Ik9z42h+f5mv+dGj
8YDrc/2MfUsDegW3d4glQ9o0XHzMzzgzbf6tfCZ+1C3jonon/Ix+T3ds/TLH
9P9T7h9damWIeBqzp+ka03/NcKv+sKt/zRG7o4qkvrjWjI+Wv/jWKiRW+HSa
dbXpJlMfrql89edhseJAyKeD1dI4xL6iA8Z6DhpkfDtUtc5Z038vs398/971
B8n9tk8dHzW56fCV5xm9QzPsXdLG14g8lWbo7i2m/jOa9i/v5WuYBvPwzQ8O
sbhy43slNvqLzVE7un0x5zMgetevO9JHir15naMzzbCL/f6b39dZY+qjJC/X
ZPdwiimvAqJzx/YVM9vlNl6ndIq1BYcdNr71Ft06RtTYF+UQ1055ZtnRbIYY
uLLtmSlzzHg08reu3z1nyP3jD7sL9Y6uGCZ2fn1ZoN1luwgOGdzqUY8YY95/
aWIb3zDXr3bmp2n/Mu3BwtG3npc2/a/MlY+kLxRjtKm7/aijuhkPOP321M0d
Y4SEVlhQ27R3n8KnGMVeRhu5ooJbLTL7Px988ejDh9HGnNGvbx2/bfpbb3xn
HDkfbbzYk/PbSVP/xxYsty3LuWijdstsV4rmd4pCDSJOFrsebQTbj2x55ukU
LfamSvrsXrTRyHvs4tQtnMKjQtyn1xljjAzTuz77+JtTHJ16vty5PDFG0VoF
8mwf5xRfh5aIbmbSf6Lioc7D/Zzir0p+lXf0jTGqdUnVtXKMU6z6aXSBv3rN
lvYiR0ffVc22h0p98VO2b33z9Q+V+qLJq5fVupcONT40C7/dL8Yh/tieOTJ1
xVCjZJV+1Q4fMf29faWensoXagwcFXKi6kaHKJsjY9uMnqGGvbpj3krTP33U
6unZQtlDjf1FjFdLXpvl1edUWJw51BhyOlmmUplNeSwwZks+s3zWihwe6831
q3W8aqX+ZvmjxvXydjftf66NYmnDNkHG++HJb9d76RCb2vcrM6yZ0ifzjk+x
TTLpKV1qzPGs5vw17LvFa2SBUOOnGsUvTCrmFOcP3un3vmSosbftoyoRP5rj
P7pscvJBQcbGY8c3hP7kFAOrP360c2SQ0ncdqjQ9MzPUiO41039mK6eIPNtg
R61qwUYS717rP4429feVCRdTe041HhffuCJ7MxM/SHso5JSfkXHe+jTN+5nx
++3N2e9WCDB+vl274D/x61F6Xa4VawKMReljhm+xOUXWppXXpGoVaJTr1Plq
rQinKHo89aITDQKNk23Ldq9rxrP1g7Jsq3My0Oh2bU62AFP+jn/+dfqGZ4FG
PY8XS2uY8c+j/r8krzVhgpH/5rWnbfY6xZkbl38f0GKC8WeKzCE7lztF84CH
z5JsH2qMv+LxT0Hze6+eZbJ2TTpMztfV3s1zhSftazg7Nzmx0ZyPZe/fFw05
+Jd4emm5rbg5Hy97lO7S/fCfwq9dm5I/N3eKbJ1mbDsQ1UaMqvr35F1m/337
97kZVKSl0et0xmOPa5n82eOSrcqDkeLL0eqVKprzFZwtSfC+jiPE2fv99o/y
coq3NcvdaVB7mGhQ8nCFU73M+Zzz0+bik4ZJ/Tk/4uOKZnYf8eB+huHpxjiF
c/KvA0Z4DBVnVpd92XmCU9xveiRTXOch4r+95/7OMd4penk8DKvfM1A8bJ3z
y2dfp8jZ7Hy6/m0CxeT9o35aavrPbUXZef13+Ev7+dqv99Wi+6eL31eGlhz5
3oxPO98sXStqhkhzqtG8XekdwrP1nSHXukwXvefbU/sXMtd/86p3PYNmin0p
82d4EmnGF0VT1d1zMljUrb6z86eVTjHh2c6j9/MEi8aFr/gvPOQUxuDsH7PU
DBK7x3Y8sNRwij+axq7u1SVIDJ41dfnK9U7xak35XMnyhYrRgxcGVzLlR6xb
8GFFsihhK1D4XenqTrFiQedzX86HS/v1YdfyInGPwsSaHwN3tTflPWW73mfu
NwoXH96fu9KpnVMkzfZjntxZwsXnnRM3HGppzs+i0jc+j4oU3f46/+VVGzN+
qPDo3J7ukeJdFv/sV0s4RN9WL9oU3D5PNJxS+M+c1RyiUbrQ4nW6zxNdxtwv
UNqMz53VWqVZWHOO2LBl6cD7/5r++YjCGX39TX+k0tK46OcO0eLPvL2HDowR
leteSZvMlM+Laxb+2udUtKg1eF22e7cc4nqJlDUX3Jon5pUpPuSFwyE8Xtkr
LZ84TxxP27hiTD6n6Rcbs+/8HCvOPsmcf7/JDxFduvW58SZGXPjj6ppO5nr+
9fjlm0tjY0Rky396CFNflXNEdFw1OEb0y31wRdFQE99t+zJTmhiRo9ut0KGm
/I0t/fOKijvmiRyvbtwLD3CKKn29C6yZot5jTH//0KyxLQPFspynTs407W3o
yl5b8g72kef1tjm/2zu+HWTMOdD34LakDlHiXeaxmTcOMrJfuzh87He76PHX
Ao/os4OMTLuOtCp/0i5GejUpMSO5+r2bck3X5i9abbKYVq3vud9fm/Zz2qs2
SddOFnM/nj9495tdZL209u01j8kmXR37TLxkF/0PNFi0qv1go8pv4XemPLWL
S3vu/PZqurcR0PCvgd+f2EWtbL+fuhTmbfRs+2mq9y27SOeV7kb+L96GV4ND
S4eH2MXzQfmDYo+GiTlJvjdeGmQXrdsWujfmepgY9sV+3eN+4vceJyx/n3XS
opnifJeeg96NsYsvs/YNXR48Xe4PXz6+b0L1jgONmqlzdMxawSF+yFn584Uv
A4wvb9p+HG7yS9NKX72imw6U+Z86uY42EsNijGIX3ifLaM7X1HrrT82vEyPz
Qfe37B4xtnSMMbz5grYfOpr+fKVSAx4lj5H7YcF/zDr+/E20ETEo2f3zpn3I
s3fz6rI31PuStvK9X227GG3syf2pzI8mf62ZcyPy+Tn13uTXwN1di1+JNmo0
/tBzZCWnOOJ5MNMCh3p/cvFf3mO2epj2+vze22d6OkWl9tuWPa8cI/PB9bNs
fdSzdYzR4uX5vdtNfbvDa8b60uHqfsU4x6WFzf1tkp4m42bPmNctyIhodrJd
ozROkWb44Wdl6gdJei579u2WtV2QMbXMhn4h1Uz9uqFx+zcngoyyM9L0OGn2
/2C4UTHP2mAjz5Aq6QaY9sAjMHDq+NPB8rxP2NBMN7vXG2DY/s4asX6mU1wf
512mcUf1e3KB4Vlb3q431PD2afl1xX6nsI339bqQYrjsv9mmvzrV699dbOo7
YHfqqqb+qFP0Z/v138WGSfMrtazpFPm6955WdFJ7ef7cK13ZlZFjPeX5UP8P
87a/fTpeZN/Yd9PR7k7xrl72UWWGq/fdbvXrniroZKD4tjp7/l/CnaJzrkf9
X4YGiHxZft+ZwtSHzVpVq/3CO0DuFzfv9uqjb6NZ4vcuW9O0NNdn9dt6H953
mCHPc3561inm0PVpkp64gaOyev8QJpJ7rL7y0z5Tnw0ZUrT3llni3bVFG0/+
j/crN4WmLlO+sk1cyVG58q1dZvyaqundMXUi1XudHSPKXd4dKUb1bTvTs2Di
3/88eC9q796TUcJ30ZmNnUz7M6Tindw1780Wexad+VzbXJ977QPaLjs4W54v
OJRk7fc5f9hk/qDuwpjOi9fPFYvGX5h8tpNDdH+yOjp9eKxo1/HXSmHhid+r
nPJPnp15+s4VRZvl71gqrWnfamwumOxyrMj7z9TLnTKY69VpyAa/7bFid96p
h9ub/BhRbvDz4DzzxNFVHqXnJ3eK2PBWz7yy+wn/Sh/rLknlFD/Xin3Tbbqv
WHXs92qBv5n+1+J/vz4fGCoatfO9tOV3h2hf+PyaT21CxdcTLZOlTOEUmw9X
+K2kiW0//VAsmylPeVt4X/JuGCp+uBjb880HU7+l/HvP85uRYtqww7vu7LSL
bx8XTxw/NFaM7fbx4Ugvu7hb7I+NtQ7EGGXSzr3Ud5/pD9u2lq8xL8A4V+bB
nNOH7WKE15ylPWcFGNOe5ii1PrupP26FT/E862+0e7I6e45BDlFFHN2XYqCf
UfPayuflBpjrGbo06q9hfsZNrysFrpn6uFVDn0+2O1PFwu5fR+w2+198d7Vn
h9HRok6Tc2nrmvHz3nxpA4/ERsv1+D1ZxQyZxkeLh3kqNau22Sl8nx3PUvzX
aPG9T3VPz3VOkXZfy0H9+0eLoV5D+8xf4BQP07z+vcL5WHm+6dGbGM9eFaYI
73Uv0n/dbRcz3jRte+p4sOi//O/ZdwMcYn+uzMl/KeRnfLi9weZh+u+37rX+
sCmLnzHoyu+Nbpv8l7dSk5p11viJW8XXr8hsrvfx9aVTX0o3RmSvkmNvvqT6
/SWHWPfT5yr+Dfzk/cRS63rtGXYzWrQ08rfPsV6dD//6yafYxYrqvOeo74eH
Vd/hFO/ftp/Rt1q0mH5rbuY6pvzPXdO2/6Ys0fK80/davkUbHB8rip7vfDlm
VuL3M8dHVo6b3GOaqDzjc6vmJx1i+sqbu/quCxPFu72a3s/0159VaFb835Nh
Mn8Qfm9lm0Me4SJZUN7Ttw11vpl8XOUdST7ca+Mv3zv7+/uiZrtH2KS+Gva0
4R2vobONqoUyeHSdlfi9y3X1WtTeny9M6uOUk7yPRPcPkPnm3quyFcx/pLXh
uSRV/RR7Er9nGdmgXpv1q/pLed/k3z1ZiSojxZY+p/tPr5r4vcoaNfJFvu07
Se6v2ZJ/q79qXLDUJ9WbG0v/aB8ttvX88k/afnaxqFmWQ5d842S+9vWlNVnv
2GOkPly7okLDL7tixP6C7bPU+j/vUbbxWPdTviWm/n702PPivGjxd/qCi/Ob
/udPpdIsGBoRLVI9X1ln62q7OHNkuOfcyTFGvZ8Pdplg2MX2Eiv+uT08xljs
USFrEZP/K39bU63eTz7GpRQl76U25W165NKe/6b3McqOXCM+ZHMIH9ur2+fT
DTLOThxUZckJdX6wcUiN6U8ymf6yY+majLl6ioq1JtW4mtXUX23G7r3/Rw+Z
v2316G7aoHqh4k14vQL5Dqn3FT5tOxg5t69DDMt08ZLngVmi1vs/v+Uz2ztY
5lH+Sldnyfz6/qXzQ0pVmiXtx49ZHc9TRUeLan4BIUdWO8Ws4DWfUh2OMaI3
B7wbscVcv8N91vW7EmOU3tzp0cObJn8m9/V91znAGP/3wQbx/k/fx/84/6wb
IOPP7jc75/p6e7Lcf2t2tsCjgb195Hs/LzenWrzzdoh4kKTqvuhIh9jZqsOW
lRd8ZT46ZuBsjwylBsv7kDcfXFx/PN0wcXbN2m2LDjlE/5PizbvBw0SmN5ML
NI22i9/nxK3M2DtM/NhxeouhsXax78z4rEsaq/dyJgTV/bR6+wD1+y6jRgXX
7TRdvH8ReXdGgDpvzvnTZKUGLa/jGSyK9Qw95mX6Pz83SHNyxhJ/yW+nn6eZ
cneDn8w3NRwV03b2o5HyPN6zaxnjqqyfJPLPvvquq2kPS3XIZ2rm2Ubtzj9M
6bXT9HfnlvtcZf1s4/OnbDF7fBwiVdYj7evfnyL6lhx3clgrhwg4naNcr14B
YmjqFcFl2jhEn8J3DuVuHiDPOz6d8X7Qp67B4tm0r7Ov2eziZv27S+qf8DHa
bI34fc8bkx/2fGzmWc7bePQ+9FPcO7to8nbbjCcFvI2Jf23wrH3ELlavDe36
6Opgo87ITX9mv5P495FLPfJrvODHQOExtdTUQ2dNf+rJm0zFyg4V01rYVm1+
6BDNJ5V09PAaLO+zt8/2IWXq/nGSvslz1tbw2N/fKN95TPoqXU17dvrh+x+8
+hsTgjfN+dW0b/P+6/GgyPb+8rzm9B5nZ5z/7i/2tXv9bmsBU1+vv3J23qqB
xtjJbzy/FjXHn+/BoK1eA+V5jWa2IicG/RRmeOZPtf/VMKcYM/fS6eDTlUTP
qhfrXzXj8wF3Fg54XLuEcDQZOtW3sVMkm/B0RM5G00XyfNOu+ZjxVbboUWmM
D9PEuwpdKhZKnfi9yzEnQ9em62wTQ7pfPvTMjBemP0my4WzyWDFsaHZv23m7
uFE4sn7Pu3NFwyvHQzb4mvrngteBr0fmiiIHb7Y9VjXxe5N1Pi5pfbjhXLkf
FTTsz4f9yqv3Jm+smFWi04BeIsexIh4V06n7MvZy9u8+6+zibHSS6VHHQ0W6
BrWP1t5oFy0nea27tiVUzBh4aktQFqdY/vCfShNf9DS+LypTLLXpL3xIHzcq
zcaexsxxL0ftNfVl2iW7mr9cFSPPq3qNe5/1xrcYY3T3OqkWHzb9k2tex2I/
xsj5fdDbFj4z3Rzxy5XjE/ovTvx71cOKdRyUo8A8MfPMlJatTXuVP6pJz8mT
58n7jlOaVf7e+so84XkwacWJpx0iKunLP/zy+BrJxre44nnQXN9ywdl8avoa
fsea5G9r6sPwJI8X3cmp3qvcumrn/Rf7w0XBwe07NvvmEI9/DmvVZl0/8W/K
k/0aD3OIAo2cXgVDxwv7/kvdfhjiEDfe9d318Nx4eX/nbYsL1S508BedY2Zf
jDP9y+W7Hu7b6pwgLhaasS9/NlOf9ju7sNwZ9X7lPz8FJ815M0i+RxlweND0
HbUnCa+vafflzPl/fh+tXtKIsmfM+Lnat/S/fw4UX9P2/NR6u1NsfPyk3rI/
YkXBS59qtDX14UPn1V1GpQhR/ZfwTPtMedtQYECcvZhNnCga+vdBU78MLbb7
ZqG8NvEy88te/a/aRfkjI0ZnWh8h72sd+mON5+mQUfI9ACNq8fMdH4aLxQP3
/11ntTo/2+5dYO7FZjzf+kSupztqTxU7FnzMeu6LQ5w4/t+1hZODxZvTd1r4
fjL9lyJH2kXPDxaT180bHnXFnL+5YwsUrRoiZk4v7JnqpFOcqvVTxfTJ5xh/
HD747I5pj/J+LTp9h8cco1OB+yd/mOMUqVYOdK65GC2uFT+SZ5Zp3w5c7Lgx
19hQMbFZ9qxDTHtbf+GjQ1VGq/eOry/ZNTDwXT95n+DZ4Q2HPA+HSFwi47Kp
V7/6Sv/n26Uq+TaU7id/v2ROdBLjWh8vef+ieqcsfXou7G3USJEzJGM+p5g5
tWfrD696GXdfjpj/2MRZK43MkztVb9n+mtmFz70KCzP6P2vS7oPJnzfO+hlH
54eJyA+9y+875RQrQzLmbPstxJj1MNn+PIdMfyb01q65Z0Lk75XUCP/iUXht
XRE7Y83RzIOdIsX0A6fmpakhVtt6jtlixhd5fBwPW+8SonT5wZMLmvNVbnzD
HxtN9BUHVi4cPfqIqX9a1Un9+x5fsW584O0Fwine2vZe3rlpuugQ65v0em1T
Xl9Nbrrk1HT53kbe3yLiTp+xCUfRxlHVzPlb7V+uj38p9f5W8x+WRNyYZJPx
4uZRb89l6dHL2LfRq9WqXOp9HfzVnh1Lv7gwaYpY5l312kJfdT9x4tXJmYd6
qfsRd3ZOWXN0nnrvs+jH6vM2pzXlx+Ne6s7VY4xsyZM//WDy/+ePJfeNKBdj
jK10bZLDyyFSF/Dx3fAl2hi7e1KBrIMdYuzm7z/2+RhttP7yvsYb0x9duvBA
Rp/L0UaRR83n/nLcIe7+l3flk7+jjR/q/bpkWman2FquQKYSl6KNLnPWDYkx
9dekkG4+c0wcterjhrTm/FSflrpcoc/Rxsv6+UpWq+MUL4zTjcp+jzZ6tQhK
dsjLxC1W2Z78EmM8XF3n6j5zfbr9uqjarOYxRoZaexfnsDlFmWN9LjnDY4wp
w6curGXipF1a5IvIH2ZUSnPtm4e5PgUHj2iXYW6YISI7V4nZ5xDFtrd5vHpk
kLFr1t1rRc85RN17Z5b17hVk+BQPDvUx47u6n250/L1RkLFxyvoPl7Kb/vyd
gqVXtAkybrRsUaFCddNf7HP7dp4zQcaYaysui2in6OmctHDKXTP+3z7xedW5
TtFx3dR5K9IMNWwtSuXPfNDUFz2KpR6Ve7gR+m1jSQ8TN/h/XX15PFXd+3aD
DBkqlFIiREVkLIo7hEyVWRMylpmIzPM8HJyDY24UFZKhQW0lFE0kQ5FooOLs
nVKm8q7n+T5nn/fz89/67GPvvdZe676v6x6T1KiqdDdYT3X6Lo/u96o+684v
x1jYYiPCM4L226u/GDVjQzTsb4u9N+dFQODL4ynXR6PAqvTEFnYkv58pzC2W
jMwAwRA59zl0nldcKFLGdTLgaJfFAZVGHG7uf0cd3ZUDqXwHdodzInnr/7Em
OLoYdl17tPAIzf9mSL8be3gxrD5c/dwKrZds+3WOfoEi0v/9890aEcozH4xZ
L5tzutMww8YdU91dRw/diYPHOxnN63VRUNF+4dKQHwOy715VU3f2xRhSgcKX
QpH+tFylt3+XL2ZxkqNaO5xVn4SZT3Tm22Rjq1cI+bx8gQ+9ozGZ4Ej7zVFH
ZeWvY3XaFpcaWfkszPiL80+ORZhcTINe4ZZocSR/H9uc3LKgFA+fvsgp+HUx
YHDFhmk3agbc1lDZHY3G3CtyhhOzMyCrWvSyBDoPgw288hdzfDHV+gqXHXGs
+vFMfVY3HoB1rffFbJP+Hr3tj/BN/+QyzfJT2MAePjjrhUPt8mJz1fensCtq
mY3ODjhsSVpoDzNyw9RPtvr+PoXmp2C8MY7TDUs+yDMb7svKf2TiJ/no/Vmd
pqx671VcXuPKQVSSTx2KX7607II/dlotoXTVd1b+MJMPyHgXNb/WKoSBw8cW
G7ew+nmcmP5me8WDVc+P6e+UDHyr91ndCQsvORjiPc/K51v68BFjhT8Dfr9W
F1TYnw+zgqmLN55lwO7lMydipfKhseDQZ+FyHF6tTNJ3GoiBCxdmHrkhffQi
i39G414MOFbmsIcj+frO+aLn/V8FsFr/wvogJI/tNuxX3yJdCCNHFV+lBOPQ
wWv3LizgFOZme2RRaAQOyrwlhS6GpzDCWZkKyTgwkk592jh+EuuceS9eFI8D
bSPHmkTuU9gm+x+R7Ug/UukpYV0KJ7GNugdC7xTjcNSpNqRV/SS2JCiw+xri
8z84Mh4mnz+JOfvTTNloOHA5utckpZ/E6lfkJ31CeFYipbHw8nkX7LXGtXKp
Jhy+Wctz+2xyxcw5p6OzKnAoFzqkp9Tjim1NlKl+jvRvSbFLZ5S3Kzbxzc6g
1gCHK0JrHo5Ku2OKw70xVa/R+63/avjJ2QVrSGoyUR1F+i9X2J77pjP2voDx
l6cM4d8roCRES8Amq0VWjBvjUOyaEdhzkwpNpUq6Vh2s/oTJNE2nQ/k41Aj8
GUlYHwT+Fn230jtZ9XWY37v4wHvvCF0q9Kd6RHuh/SvQJCYjsCsTu27O27wZ
nTfeNt5X7pKZmGJv75HjuohfPtnppvTnFBb3Z/FV+kECNjffssb3umNfC/cu
lZLEYeHz9tm5i5ngpR/hGSWPw8zk1McF60xQsxke+oLwglHECd1lLpnwZtV4
diDC2/HBL57gppkwKlv/rieUgExhkfMqIpmgu+/Ut21o/7HXDS8vkM2D72cM
eszWErBH9GbXqBgrPkIvP3P77H0Pcn/n3d+X62dziuSnsfiFF209uSS/+r7p
uNuz0lTQOXDS50ARqx7Rrv3SB+7TWfWnds7O8S25gPjYvk1zGvKxkDJ/5rOt
CNJ/otUqAn4p5P3qwg+8Cy0OwybbdyhuYMfh7qrJI3wpsSBbMKas/ogB7T9t
d546lAi/L7fcOoLG7iIxmmkHEkG7vlXiVyIB555LyJUuysSKozz25dQjfeUy
kCE75Q7phwfbc5F+NnfUsUtQCQHG4K+wtfIIn6isYcv+GQuPK68pr0P6MoBj
6J3Km2zIkvpoLuGCQ7hGyfIqfiqMBG4+9dUch7nGB14TF/IgKvne4bX/2N+P
Ml5uTM6DtW+LiV6EX43uhj/k46YCV6vL5hAeArr1W1pjDlHBryVYWUGbgAf7
9xN9f/OhcvNz23/8UUdzYotpOgUkHye8dTwi4+kkXz9zvLmzdCmN9Bcbnpna
ZXKPVX87YY53xjKRSvobdbddqHfMpJL+1bzhTZuiBljx30qRb0elNWlkvIiX
+bMR19NUcuxQtLn+QXIoeb89hqdSDH3CyPvlOtbL1IckkmPvGHnJwisR5P01
/RknbkckkWPX2kX5uQuR2N5n6ZW7U4j/U7+agMGI6Nc2scnk7xeJudqpvui6
T8aPnCG472C65PvI7ynZ0LHiCNjF3W9dto1V/4h5Xfx9p+dejyDSv7cYFPln
/uqDYbyt00UbVr4783rNOT3dCuMU0j/ao9ybJvotEpx66Zepsaz6SMzrngHH
M7Otk8j4FnHzpWBUFw5Pgm7xTlWx8lmZ9oj6i3sphnwUyFPutLx6hFX/gckv
uR0DhvlXUoDLMJsvjYNVL4g5H9fWucoLTWnkuP0hp76obDb5/IAdn5ckiVNJ
/+u5SG2trOgc8jxJa5yrK/qcz4pHrq+dK++gkvMXTMyVuyiSA+pxwq3WNqx8
V+b1v9c8w7kP5JPzT3j5ckGLm9Wf/oHo7/zpqUJYFvNj0R19Vn4oR+5DS71l
rPxY5vu3rmN7rVZaQNp7/lppa5+tZNWXox6euHetLZK0N3WHd4fwukSS9eYU
Ys2ubWCPxNhEv9X6HsbJfj5M/ntC9MiPLLdkcH54Z8uF4v/bH50AytxMQ1l+
IVhGntE8NcGA/QvfDllOxcGcX49tVxIOYbidUNr8WaB3G3tdjUPzm617lxAQ
TNoHouW+3z8lmgT6JmXf2ORwWLxLNJuSkAw93e4zbrI49KfVVnAWJ5Pxbftj
Bj7eSGf1+/g5XOa8f10O6b/oH9pnMdOSBh9XHYkdv4Lwx4tdf/NxCngXvFvZ
iuTVctrbvOwQKmb3TIR/eBMBezvuVF5AfMP20J9BHOGRlNjsswqrKZh9tq1z
FRsBDvsmm1etpGAjBnJqy5B+0KSJGq4+noC1lckOv0T88/IKhSD2fQmYjV1M
xz3EL35eWq70NSEK2/GUYBtsQ+ehv8JDKTUa28jhkDd0G/EPx/JHm3ZGY98O
tkvHbCWgz2WVr2C0C3bGYdkvDykCVta59n6RRvr6Vy7/Z4R/t5k6yVxp8oPV
i5bsdEb7J6JXKIyi5Q9xye/P4YtY+iGwXrhmDPEze4VVoeXsCeDUfUz1NdrP
HU/46JJXEkAfJyp3ITw/qvpo5WK9PBAyWK0tvoIAix/bP4/754Ebp+0jabS/
HjSGp5x/lQe/vXRlLiD5ous9mOMqTifPXzbtsobYA1a9F7t2bfkgug/GlXu6
0myaVZ+GGS+uNdCQ+inLm6wvuS/prINlsxdWjiv9aP7IIOtDMb/niI8ndloy
C/i+9JzaHceqz7T3cb1FwDcGfGz4JD+smA4VE0WJ/uj/rz77NdVCSyfzGejs
G0LMFlLh2NQTfMkPhM9j7RqNEV/adC1xU5Ap2u89RrutuOhYQ0uXf18lDvH3
KYUSA3kYIaGcr4Xmv/B8e9DDF3nYbwfG88WKBHxv25fzczwPczR6c3P4OAHS
NtF6T2XoWEFkR4ZeEsIXOx5Erw2jY7KSzQn1CM+bGCw5qsObiYmHtdvbduHw
9Lr+kSyEb2t1Rs4pLELyIf6eszfSD1UVW8U1kbwysfeIuBFAxWpO/zR/dYuA
YyIcP9+GZGLLCEMJvfsEZAksz5lKysQ+tIQUb1xCgI/51sNjWgnYTP7jpZ5y
SJ7s3abqW5yATT0SfxmO/r//3IfrelnJGPXpNq1gjIDdWrc4ttxOxmbWhiss
OkLA73Q3SZNEDyzY129DTxri7xtwC0tjX4yty2ae1oDwrFFRhEj6aQy8RDdG
2BFw8tPUMF+wLrQuaYjd40CAqvw7g93zOoBbOHaOoevivg9bXROj4bflL0WZ
u+j9BgQD6CfCQezI8VnPRgKWhaYm25mEQ7eC1kCKAgFPu5Yau0WnAfdD2/fH
EhAeXLtIc+NHCkx6fnz2Cp0PDyEugf43GRCxgU3uOsKnF6REK5SKcmBOQK7n
6mK0P9//Uea7S4WsRknur0hf0dLsJWYic+GplaHQIgl0vjsGTF2ac2Fnx8DW
V2j/bhmJ1deboYKwyJcgl0wCJo0/3zF6S4XrBgLl04Y4fNp9SPALXghzu37F
6CL8MvPq1Nn1WQVgZrXUM+8wAcI7MzsTooqhxDTA1jsZne9WCxMf4yISXxjj
m9amdheS8ujHTpvBkm2sfhWK+2Rn/E9nkfaiuL73RxccwsDRzY7tCMJHzP59
TP11aK3gZopzApQK7s+0PotDX1nY6aR3ISByznFVcCgOgabHuc5Hh0CS5Bj7
2WQGVB7gWTmXlwLPFwU4O6Qx4ENs9a5KL1a8rut4ogX+gEbaU0oU2vZRkPxj
vt9Nky1LhDToZPwlYxvFzXQRK77AcOXMAdG+PNJ+q7Nm+M3uzjyy/urw6Grf
1z/zSHuSJPchrwx1Ouk/S7lxNzU7i07+v/bXlN9NqygkHrbhe+g2VplJXq+Y
fL+ZH8lT5v1lJVf3ZHckkPfTeZhaz2kQRdq/NvDLjOo7R5PXhwSX6eLnfUn7
7wtCpl3uiD/5+y8J64fmVviT77v09+vqD06nyf6uPAqdei1a0eT6mRGCuj4m
CaS+GjF7KvsliwLSBov0Lt9k1fdm/l5qe/uLlbkZpH/yPFdyWuruHOjOXRxk
yMGyPzHfV6yJUmPwkzXmT3hUCGuKSP2a5nx6OfaAjnFnnbjQmcsANr0Ldr4H
iuBhwJpZhSIGHL1zNr9QhmW/cHSTEKl3LQKeupeXErNY9Z6Z+UGm88WiHjeK
gEvH/MKzeAZgb67qXW4sgvEX3uY+MQwQMzAq8e8qIuutYxy9eqE6hTCsfNzF
OJwBW/2Cjr74UQSCJ5u0kp+w6kV01lXx4eM4zPLmtCjEeYKdBl9T1A+En3it
/Lpn3OHLq8TzgUgfcG41lv7WmwAyEtJi5dZInwsYyIXdiQAavlLkItp/PA45
r4iacBgLV7XLPI/DJr3DlEKZQKCHWPLInsNBiX6+baVFILA3ZXTvRPzX/8f6
3WaCcSAv99gnNBcHDoXwZ7xPY8n4h98rHszY6WRA35z0MkoXg6wPtiozFbc5
iMPvqf2J924mwqEf1Tf2H8Jht/OPnpzLieR6eR58uvbWYl9Mzqbt/VXEf2/f
+ntSLyUKPNsczmsN4tB6LsExcgvLn3Sz+UsZR4gPNOll4I3ovIlXKmWkofPG
3N8IjaQIURyx7BHve7e+M0AU+rSj57LI/Cnu2znCccExkHKzbnXadZY9/ukl
RfmtSP5lcVbv7ddIBJ6ceFNrPhwOq9dhO/ljIe3akfc/eXGoNJlnvBGKJfN9
ZGxtrEMNo8n4quOPx9vFjrH6tVQIVAxd/p0NUc1JC7QnrHrC6mu0IoRu4sCr
+RlbZhIA9qNbT/ugcY6+qM2UdgDpb+R25lkU2ZMIHptsDGp+serlMNej5MPb
17eGksjzcGtN6xeV4AQyv2tDbyDOZpKALX18ie+nJg57p0sxhUR3zPpNZrDi
PrR/tB+Mbz/sTtYjMw82lwA3X6xgV4EzNQoHq55OS7uJYKgVnWM8P8kAQ/6H
sw5RaaD/3r67AMnj1Pw5r3dKvpiKwB6emmgGcE+tPR21wZfMZ1urf3VB/WMG
SCZVVUSj7+NZpOXwBOnjMKlL7AsrCfjw0TBWFulvpjxafI2oCBFIg6p3C2qL
1Fn125jyU/MjzZbNu5DEI2+zR875WeeT9cF8Sv7M3uUuJL+PmZ0bv+9nF7J+
9eEHf3jSLrmS9Vsc9yRQeoRcyH4kS3VkpRW6MyF17Sn+dCQ/w7xMDsWW+pPy
VHVxtODN8mgyHuxhhmYgW4wLeT3ZQ0JujhEPA3YPChrWseIljBoeFTYgPl3q
ufzy2eQsVj38N+EZSt9zSflolfhEo5Ldi5S373vbtD6ep5D+vxJ20znnVazf
b84NXywvU0zaO+bHbnXEEwWk/3jelCi61xqGtXaZig1cYdUbZtY32qXWiouL
FUO44u7DchdZ/ROY9dT0zJZneXNnwr67Fxoj0P76Xq+veiKCSu4vt+vNTX7+
VOzOCbdGKhr7+XYsd0fjH2Mqni7iBMzd7LsnGkcl5+MnavVSzIaG7eNoWXk2
nQDe7TE/ao1oZD3WixdcN/en0ki82r6s7rLV7STMzVJ420H0fSYrEijK55Ow
2pHRcsUhBmy/xiO9bzIRawnOtHUcY4Cs6ZfNHO8Tsac1qi/HVRD+5HTvszRJ
xMQWsw8I7kf7gW2NwxXZROz3Ne3mD4fQeTfM326xLxHbvsJtsTzCI981H898
8k3E7qeyCbFFExA6Hb135nASJieg/zcthoArnxJk+ByTyPlf/pPHU9sUSsof
FQld791hoVjgXJuLKxcBMafv69xAY6b/xWkFo9T5TygZ7+ec/8nKQyCC1Jdp
kyOYr2gkdlsy2+wnwoNPmz/E+nJGYl//9i3ttCUAV5DysXobQdZTTHnMzeNU
F4nJR/oVmlkSoH7yYJmPlhGpL68Hm7xa02WIZVg/Tz6A8OIqC/mprrT95Hnb
ZVk+LaIbCMrClTyHlJC+NExTdngVCPevKwdsROPSXXIR0MfqTx8zFbzcY1cA
XH66wqyqigDllDdG1qIR8OyS5fmP1QSsbw9f/2F5BOlvCsnnpu0OTYfDOv2P
NiH86Cg9J3zOPR3WfXhK9CF8KfWUUYt9Y/Wz5n+Tkm/8NInU1woXv3hHjiaC
lc1SMR4KWo9fAwOevElwqK9l/nkqAVrdVRSO7az+YN/79vknCiSC5KLlQ8O7
cejtd8ykbqKR/NXwYK+Ju1A2yXeXNTlPDWjRoOrczeWO35F+OqT9R1WIRr5/
uMPUMSI5mzx/8zyGn8ReZUHb/Cg9AI1LHevcA3uy4NtD6T0NCN+ed9jQck44
m5yP/SXfTC8jGmzpsDwxEoXwb9tM7ZkdaJxqSrlylYDDfP3nOiyorPyvprob
lhPZ8Njn8d9NiJ/IyVuOUOazSXtJj+Egz960fNippmos/pcBfTJYx+l7rP4V
X3O9c3lO5YNtJcc2vxocnGoXndhRmE/Ox2m8hCq5UABr9HsujW4moIfH4ozl
UAH5fX+NyzTdR79n7kethieJ75eg+915Vy/kiPDos8MW+Wv/secfLGNH/CQ2
XEXTRikfinSXMw49Z8WrpZ9e4KwdZfUroP6z3qcY8LzVzDQmtBiEAz7olKFx
t1vy2JuzxfDuo/PXbe4MiDh+sY3Npxi4lCV4R4oRf17zMk6+nE7Gk03XC2cs
rqBjVuPE3TU+DFjyPW/6YQANW92/+2HhP/Ul5NsiopE+Sbr/LP7LGA7ywWzG
kUgeffNVIzKQ/h36bXRIVyQJM8NVn6iIIX16u+KkUUAiplEz9rlyH9pfVcvW
VLElYu17xGPqA5D8dfb6/IU/CdN30Y3cd4yAms4tzwWfeWDGgVsErZwQ39ul
vhD22BPbJyD93HY/AXrrHrWpBpiCnUuu9Mh5JK/196UtnY0Azt/xbAKI35gJ
Cb/7+JoCo/fWfLRHfOnBcSGjl1UUEIg9OfMe6YsTDw0fxv+lwY6/5lkVm3Dw
0lo2Gd9Bg11TKRqDb3DopwpMzabTQF4juT4C8b17yTQJilEu2Ec3c5kqI/z7
daRERCUXtJOto5vOID4tMv651YcG0bnW25U2EPAtYk3pYcVCoHMF72kzZfVj
YtaH+zwsF7yppBhkaTziqxAfP+8cWvHsVDG0tvBJ7UPfv/zVTOAcFJP1vOj3
LTLdjHwwx+V1aUIIr1f4D2iPafqQ/KYrzlL97XA0OB3ozfdHeLnLwf/b5TA6
iadVwkOUPpymk/i/bEHPQjSlEK6+kpU/eoMBuntE17mUF5Lxi+u5BM3TU4vA
w7dakCOVAU+e8qe35hfBTssftnwpDLDM7f8mcI5Vv+zp1gytvpCz4DO0olA5
jdW/QFGyX274LIO0HzLxhMolmTAT1xwYsFRZeWuWAQ7rMQvJ+1mgtm7LsbQv
rHqLX67I3e4LZoCN/M9fisuLof2+7DA3GlPcznQ4rygG/mM5qR0BDFijUfh+
YVsx8F6HI3v9GMDR38+3SPu/fEwvBmwRUPFMsy7+T94hfTp2edWn10HQ7HbX
akcODnpN9yVKsoPg8odbH3qXEbAzKnH/674Esv+SzoYLhxdo0TBC/Nz18//r
L8Gsl3eXK1TTHY8m5cPEG94wFz1X7IUOLlzdx+rfwKznlvSWUtwm6kvy7x2u
79pyjiZhv81VflsUM2D08+h8v38SFnWxNNzhFgOud6vE3IUkku/WH6Tb65Ql
Yo5ctcH9PxnQtmLFivdtiZieYQMYr8UhvXNQaTwmkeTD27bE6PAuScSwJ/X8
V43Qfj/TufiMVCKmPXzj20tFHJJfNHDrzEaBx76jqsQFAhR3tsdDGA3zshle
tBed/8BFgeL7upOwQ7seSUmdZsDrtuOpWs+TSHvsvRuTa1csSiLzxx3zRLi3
myViol1nBnkv4MC2b5ryKp+VXy5Z9XP/hcM0mLx/bfk7JVZ/E7koq8+akUi+
mER+SPDKhmWnh11vCuIwWushqS/H6v9gZ9G5p9aLDlcPd+yt1cbBvk34kB0f
HU6v/nG/OhCHR39Tp9cNJGCUHWkOMUg+Rbj9+sW+lNV/71D7+lM2mplkPe7w
N4av2HblQOMxRt7qHgbAni0/IhpzSX7xNuKk1PBMLpnfS6P6LRbeWEDauxtt
VGsbWqkQM9zcwYbw04aB4WpVOxomsvHU1kVJDPgiNat4wJaGiYGRRUUlAW6x
6+7vyaFh5nl4n3YNAR8n2LqiimnYFapbj24jDgsHleyr30TDwXdRp30zcZib
5W55uZRVH0PgQsSDGxgd/rxVOxmMziezv8TZ29FBpui8a0Z++Gk8G0ni7bq8
NytaV0WR9vCLTVfe6MrTwNpN+KPqZQasPihysX+BCoqj392ul7P6985Tskfo
W9F6P30xVR4VDZ27wnIlZdD+X8VYxeUeTfrzz72smBkfSyLjWY5E0GyOXcoG
Hpia1Qpi1T89MrGUi/s6A/q1q4+lH/HBjp6x2DWBxpzvaq7EW/mQ9b1/xfta
fV6IgHNXdHrZFxAfn9hlvWppBAxx9VTnlyL9tWLmhNk2xB/M01Zu/8YAjcnr
twJM6ZiN6LVt39B++PHsWFkYPx1b92i9fmgB0ueJdVM2H/Kw/qzza09P4bCz
yAk4X+RhuQ9lxVq2ILz0q+ppMrquFWj89pM1AUOvi5aXbqJjW4bMt9YlEFD4
1/jbx7N0bHXkOtvl+QQIjjUUgAsNu536+29SFQ6ZyWl1uBSFxKu8mlxbe1dR
MHO7s7GiA4gvmr1fL7Gagu16d+N2CeKXrjeKd8utpJB49QjffP0bCQr2pSq2
rW090v93eQRERCiY27lvWcLo/QazeiefylCwgz1bvoXJ/lNvyNDRLSeBxLfz
U3qbnmgkkng1lTr9eF4jCYOGa2WLkLxZb9U68HMqFDs8J5yg8RGNz8of7noe
itnMIw4rSACkZS6vLwrFNH/eb3DgRfqZvUzsS3QotndQcWrdOgJyn09Pv6oP
xWSFXwaeEUX3Hx6vqR0LxRKdjx7tN0DrI8M3fP1xOLbIpE7J1ZuAitdml24c
icRq/rj4tpxG+DvMhPo7MJJ8v0NNqwJiD/tgpx7YSPogvD8mGnf8Q50P9khu
caoo4gMly3SbDc77kHwl4O9eJZX+KMzxupfuhnPofY1Xb/hVGIXd6npxqw2d
n3vld72buaOxEHHLOOVa9H1sxMuO259mrY/nqe4X6Qeg/Emm9B5LVn+OOm6N
wkzED8/YKmwcjTTB+Jfe43q7lwCPDi/FzvgzsOL0joetegQETuVw2s8HkPjN
dlfpcKBODLzY2LntL7rfq50Hi0umo6HlcO9fLwuEJ3t/bxTgjiHx6Qmdl24F
t3xhIqIm9jTCO2cc/e6c1/ODI9uoWupo/lvttce+GPmS+FrfL/1o1+kI+MMW
fqEN/f73Pc6/m9cng4W4WHpjEAE2A0+dxeaS4My7s8t5igjYkrxR4h0lESY2
ODcvR+tTLd87bumeCIHaCuV7bhBgV/M+9JEghdTXUyWa2yx0cuFi2vBmm3yk
H6w0v03O5YCJTG9O4SeWPH6p5LUyGO3HHWbNnrSWbCg3OAo8IgSIFPIO5jVk
k+txTnGN2Z4dWeAh1pwfi9bL/3DK0zjvLCjbpCbNbkXAi0cfFnGzZ4H5nF7z
6RBWvXU395jbxo8R/xjSzVn1PBty12zTym8hoFdY7tuRN9kwst3ax+opDrEp
sLV2Bavfh5uuK+YQRIf8FY/Of5pBfKNFWMVDkg4imUWlifM4jEz8Pf5btwhm
f2UuMxBh1bMwW0NxttAnYO/Tuxs+9OVD8tRY8X0jAjScRjuabuXD9aczY40+
BCRRnG8lPKCT38/VUvgi5xk6HOs38VSPJ0DefCFmtRYdHj5KZXyPI2DKfrbu
mUsRhD8avBPdzIClLUNhkb507MndpSdsED5ohTK+A1voWDxv6j1zpN9a7/vf
D8bzMLcbepdwJB+EKlc7Le3Mw4R41jU1o/WeUnyruLc/Dwv6cVGcA+Hd66YR
vjJcdGzr1wrZYnSe8HvqjwgzOvbiUb+WZS6rXxGzP4xC6R0uKKZjoo1vn1LX
EtBa+XQg2CaB5L88D1Y4Rt1NxNIXe3RKIPxp7e+41DIhEWuYHQl18CLAu/Du
Q/0viaQ9YX/2B17vB0nYsWnPDRLp6Hun60mIlyZhExbHRc3QWPQlI1nmXBL2
YEC0uxjJx57NglO/R5OwtfPT227lEVDQ//iJ+iDi80Gbwr+cJIArLvfxTjMv
THbs91QC2t+/5rUb4194Yz7VM395zxLwQ99yq5SID6ZRh7VcR/heeKw0f4ef
H8mnIzsb1E33WUH9Dx73DXJoP7nxLGUMHobX8jb3BLUIeMff8FGj3BwOe3l1
f0X7cbWW17mDVTHg9XGSQ9L4H3+kf0uHZwxE/a7MHkPryZZT0lNbG0Xy4SEP
ZbwpKhKU9prtXZtEQMLxpoQfnyLB7ZOAj2chen4UT+1BlUjo0+OTUEXrP+fx
RcEyiwIHo4WSdS4SIPBytx+HGQV2ToeuSLxEwPabhTveGyE+UjGm5nwWB9U9
rgfLsVywa35S+yIBB/7KLU/yT+XC1UYLt3YNAj6kNS9iG8+BVNM0wADJV4Xu
j1aDObB7fne2Jdq/uXI2u2mXcmDc8fgK2iYCfmbI6Se+yCXrZx+vPJmkMM+y
X2Xd+fJJtZsGGpi1TO5RAnSl9Ylf63JgLjZQZzP63mxX/TQOXqRB5UO/661S
OHhUhn5oe1IEaqcsF94ivFRuyjl7e7CI9O+kvE5mL3xSCCaSjeuOChDwSbMr
YDCyEKKW9B1/5UaAw+j7RfZ8xTAhW/z8AeJHRw2uSRQ/LAKfKbf9ZzEGqGr3
vbY9UEjm+7wdLWwwYg/DduZbEH1IPlW6hD6inTpL2te61kr5aewIIvMdO2u9
PK6WhZL+oJVjqadWENmwot/F/7I6QdYDYvY/GuTbfij3ShZpv/Pap9359XY2
mc+0rnl500Gc1a/noM2DMTNhCkQsUa8c5UTy0maDepJnDuTm1Re4rUT8cJed
o+6eHNi/RrwzI4oBq0Jl1ikx6JB4Fa8Lj/unXtOZDvwVnfSnTe8MTN05VwQ8
m/Ujf1FwSAnyFe75FIZVbaO2yLxD5z+3sKRpQxRZb9qHvnbQqTcS2lVU3v/w
RPLkRIni+PFi9P07hi55MP7DXcWI5x9QNbLAYe2ec1M3+CLBW443xQp9nyep
mtXXvZxARzu+aDCM1b/Cqf2kogXCT6V9ty+dECoi7Y/st4U4Ds4Uwltf+wc+
xTgs2rc8LvFCINCvdsUrFrLqQf+v3xQOm6qt2SMGA8n62gu1fJUfl+ZjrWtG
hC2RPp3SOzFg/peOMftn1PkLB9xyo0DcvmCKTwMDIqVv8/EmUUCN8Hzu08SA
LBO9CwEGFMg/3Xu74R7ia8o3guqPUUD38M8cy4cE8PFbjjdw5EGgL7f9vVYk
D6w1pX9O5oLQdurS2Mc41DTv1r+0nkLai63U1mstWUsh90eHw/g8ZS2rvmXS
XX0OemYUmQ/nZJj+h57sR+JZLe3KMPO6HFgL+biMM+JrWSdfWKrnkf5PR7G7
0vwr88j9U5GoNX0gIovMV5v9uXctm703+bzEVdP84mj+zOuZbV6HXg4XgQif
ZMZJP1Y/FGa/rSM5iQdE2YtZ/Xe/1gjCvWSwyTi66m0OA2IzXYLEPiXDQPYX
o+uaOBxWOO1ysigJcl7mDqmfZMA7t4fWO3Lz4VPPe+XP6HvV3ZkUJ+6EYXOL
9/gEnUP414PDeKoijLTXvz3OPisaGIbdy82pPnINByOr3B3L4sIwvQ8bk7qu
4MB3bnMwb2YYWS+933NdVGtEAjjtmYqs7WbA1fi9hdZ2CVAWVtLciPjTt533
zdK0WPx5t77EbEHVaaBzzV6JwHDAE1diUqOn4eLPV1Hz9Qxolr3961cqFcb8
ky1Kb7P6PzL3T5TVQcLHgwoF6kKRBQivrOY0L6OciwXl8QoL3yJW/w1mPoaQ
eMWdihOs+sgHbEaeGQENq6rezD+B+M9dzzex6wxoJH8VvP904/wadN14Wd6v
IQYM7BwMPLaSRvJtg4nZyI8EFWuveamqu8CA9cb+eSK/qCSfdTG9/rDkGRU7
krVl8MhOhD+KQkrL2qkk/+4dSbDnqKRivxxSV/08jkNTtCtbdxWVrM9z2zfW
yDybiqWzrxs4k4H4nrCQ2Z0slr9G7s4U5+tSKrbixLA4vpOA/DfKc8klVFY/
oFjRmPZWKna3iFp5yxTJ278et86j5zPl/zL+lWczf1Cx0Feb351yJCCi4bhp
xgSVxOPbVjIuF0vSsOdKNKn+KALcgw2MBOVZ/gLO8jUfhnWSsTlORsOn6wTw
q9aIOVklY9HTc1HjEzjcN4i/M1IXiuXNn7wqupmAaIdi/u51YeT75zzg9+n/
gfZPynfvJ8oEfL9fP5T9KAy7wrA/aIXwcrHo1nBL0wjsmUzMmWiEF3cpe3gu
eERgx2lKM3vDCdjsKlF2qzES69ju3bI/kQAzvxUSxJ9IEp+snD1+oo1LGpNK
3yHRlUWA8Xj35TcMSfL9x6tahM+k7cWWRqrqBSP+7aCtVPLVUJvkX/adJjn8
dWdB3eYQ5oHe/+alNkXC4izYBVW23D6E3rdh5vNPsQB44Hw0Q2ieAekW9tNP
9dNI/RrHd15zVWsyeIVJqLx1IoC68/zEZG8yTFcctm1CfEZcA3gDspLg+OLU
nb/RWFSTt92AkgRKAuu8Va8SYOTvVlLClwi5podHrKQQ//jY7xrqmg2HuWRN
RbcRYLLgpCa8Pxs6b58cMUZ8Y/+JFCGzgHxSHmWvXLn7ungCFL41EHY4iYNe
yRY1Z6sEmPmle74BcLAXy971ak8UnA8vqr+hzcofZOYHiOkXPiZmIuHEPjap
pfr/1AdNUaFuSSLtG6kfgstVFhKB/U2VW+IBln+UaS+s8vmAnxv1wdg3h2fV
pzGAN9oXm/7iQ/o7FRQ3Xqrxz4LN4UrsiwMZ8OoS8A4ezIJ0/gVGYBADzh+y
n4vWzSL138SBD+ZLrnrD5x/XIpYM4zD/hjC7LuoD1Yd5W7Lfo+tRyg0Wsj7w
SzNKofUH+n+2rS4m99KgvX2MO+g7q38K0/926K3xsY5rqaBSeTmgO4ABwWqf
iIxHqTC9av7pynAkH9Tn9yaLZ5L2EnWvwgSVtZlkvdzdnWNmSyJoWJnT+6tT
d3EIPtxdrRZBJfNdN5m+qSoIoZL1OjIri9ckbk8i63M0znx5pBSaiBW+tDT6
rIP015/SrJFFiWT9jKlg1bySJYmkPpI583DbmflEbKFBQPvABYTvDGdXsQkn
YxuUOKS/Xkbnd/mqnUfkkjF9n5n1lej8GxFN0ak67lhNv7kGxyFWv26mvXm7
242es1Pu5PO06mylflabQVqn/tdwxPdbVbOgOzuUzGc4PUyRPr80lMzfDl4v
fXHbhkjQl5NbMaeMQ2lNNUVLKRN22xPlvOr4/+kHjsN29fODSZMUsOp9q+aE
5MsHhaAsMeFMOGc/oMkbweofzuy30qvw0+rwPIWMN4/llCo6P/H/xZOW2Yrr
D+eBAf/fkYiDOBl/UvrCy6vnGQ73WqJDQnpoJJ6UTa76WNhII/Wt1PFraQfS
aRB3dIbvczkBakuq4h2PU4HZX5UxnL7sXQCVxJeu5saPdB0KQWxf7PX9xQSY
35uy6RooJNejjEFJtOktBNWDthw153EoSh76IZWfxernVjJmIpLKyo+c908y
sHyWA35TyaHiSH9MPfsTVHo9Bzy2Ys0ei3B4tbHphswlVj+5O+++8qsPO2Kb
Cq92Ja4k4OGUhbJjryO2+YzV3vU8BMyntYlxFjhizHxICWXTHzXFjlhNEP+s
GzsBM/usd+H5jljHqmmZguVov9Gid7xOc2T1S3HdrnT3Ex2TX/Dq6b5HwJXY
atdtX+lkfNEvuXnfJ9/p5PndOcd9MVUnCiuP50hfdpoB5U8nTF7vjcKgLjYp
Bp2XnRka316uisI6f79310b4Q0PwjUGQTRR2jK9MzcGHAX/t9ULpelGY14Uc
2bCrDOiKyVuz/XYSqZ85J+5FCLckkfGYNriF0KYtdFhWcPLL4QsIn6pfqpXk
pYNsxbkNllcY8GjOnf7rWx7QZ/98S41mgFT/5x+7+opAdrGXRGUUq//7v21y
IxH+5hNSbx4rIvEET3Tfx9NPE0FqXTMmi8aa4r6Sed2JkLwyv3wA4dNfG38E
E2xJIBL0S+awKsJLEkJfw/mTSftzjtpWrkuaydDmUjLhKs/K92B+/2NLml7/
zU0g6yn+LH9zWUIqC7r27A2x5kH8z2dOWkMvC/KPSap+W45DwgV3aRzJQ7E/
phwb0X65REtN3fswC9YkJ2pmzbD6uzD7/yga5/2sGs0i6wlxS7G7dhZEQ/8Z
O4WUf+I1+OPO0PWKyf20LPrOlM3PeCh5Wt6azYf01bGYrKjNCZA30TNJR/vn
58rAC9ODCRBemtFisIwVr/7v+VxCgKnYkBfnukQQU6zfbtmM+MCg1qbC0Giy
n5WFfQV+YiEKeD9sUl+KxoFyW+IecEVDX3ds7Q+Ez6NPzCaoKEaDU9jGxw5o
f1X8ND1OkS4k/bFfNu6844DGzP5521c2cNabFsKDM6bv/omn1FsOrYtNCkHS
Oez5041ovYO/BnuKxcCeNZn5DmI4+G5hHBDmioHV3yZ5Up4xQKJp5p304wSQ
NhbamvOSATHfVUcuFiSQ8SAH+4Tu7nhBwww4Tg16PSLgR+G1TT8e00g8rLJl
WWWkfhYMaajtWFr7T32XnOi7CllgNRT6c/Q2DktOnz+Tz5cFAYxODvluHJ6+
jahQz/aFr/VjS4d60e+516cWbfEFe6psTrw7A455X7ZVysoBle1yV/QRn5uc
8D+wOT6HzCdbvzZZ1zwd8ckdl5S71Vj9cpnyNEJ1d2p7cRLZj1Oq/+HAzv3R
sFjWUNBRltkfNxrU2CRj+V6x+m//ewwGGXDqidsZsf542Ljeuyc5COGFVfu2
lQ6nk/m8O3IDUoyPpJN89YFolbfrKRrWdePx6HN0Hh7yNC4KUqJhZ1+9jvap
RXxS0vRGrCqNjM/3Tf2RzvGbgp2t7QE+xO831JRPln6gYMGT/DvWXmPAiP6l
FWVTFKzb+YbfJioD8sy0pvp5MjGK2eID9uUMsNb+LWI4TSHx8Nn7zZJTtxJI
fHpCObomdISC9Z01Zis6TcABPp1qajsFG1orz/E2hAC85GjL5iEKdsuQMrwc
4UNBRa9lu/5SsKKAb+cNEX50VTR75vuJQuLBQc0702vcPaFR9EfH1DkCkvvX
3xSJ8YKY6Vs8N6+g/bjme09fhSfcdnzw1b6OAMOwj3tXrPeAIHaVNu1rBLzk
l0jX2OVJ+vsLh23vqjfFQefXSGWTDYjPRdzJfykZD1z6ryuuorG0ilWQ+8Z4
+HXBol1cBuHVlOTXRgpxUNR4EDuH8OZp9l9elIQ48jw3tzNWRVyggX2get3g
Nhz6je9atWbQ4P7EmrwBRRwuWZdt6z5KI7+f32E+75TROLielirRk4TO56j4
Ezt0PympsQntQBzq1yqueDmQQPajtFuYecKOJ5D1jY9EdttvtaBhlg8Gr17O
Yvznp6aR+d0yL3M2hHdmgctKqbgXDQT4H8kfdB9E+mHlBvobdD4Tv6cqtAzT
Maa/OnVJo5WRXxIsS79x8BviqzeWzx7qs6PDaA728XM+Ay5P73phq0sHYbsj
L7t1EV9/8yll+AEF3jy4YcyuhcP3Ys+Ta0YosGz1i3A7tJ/8paJWJ5lTwUJW
cOFzIwNevu7z9HaikvGGv2MKNLesTIVx+oLEP3wVu1r8sMc7FV7l68a3ovNK
61UTq6anQGtU0IA0Os/fTS1ue71P+d/5uo/w/unz9fYqhWR84T3L1DQLx1wY
Ur+ztWsC8dPv7Rx00VxY86DibfAAA+hqN88JZeWCQbSaRco7JJ8Vk7+fjc2F
H4kf1tiX49B2bVg92TcLbn08GWt9FYfhdUXv65yzYKVbruCKYQZos+1ytq2I
B0bKK2tbJL/Ymxl7v3+kA/VjmfExdJ6Z9W2Y+0H9wpuqqTo6NEv1egMbDvKL
vCovFxbDtff1nYvv4MD7UVpmey6rnsftPMqQ8+NwbHL1pTP1hjikmGpPBE2G
YwFtS6KhAYfwC5zKb+zCME318e9GDBwONXQ2rzgYCd78Oku1cRwyiN06AjqR
pL8xa1WnlVYHDZJMd6RcpzBApH7RjlPZNLIeQ/P0ajnhQBfSXmcuGHysSzGN
jF9dnTbLl2ZPJ/my9WYf68YNdPK8m7zO0/k5lkf6z3qkPTXPvcgj+dmqVfuk
uwfzSL6b9T7AKUiQTsoHvg+9oxud6djG9JMZO9oZwP166aadEjRMk5YcVP6C
AfafI3gdNtKw3W8/KrMJ4cCw7ede94GK8Wxwy8nlxmHvFlV81zgVU765yN5/
E+JDjvTNAm+p2NcD18Mb5HAIURLdNfWSir3+8In/bAAOM1L0ri3nqNhai3Xv
DR1xMBaf2O17jYrNh0xstTmL9HnxpgpGMRVbUrrz6pdUHIQn7aKWUamYyuKw
3e+0kTySmO6gVVMxLqH6wa9I3mvma7van6diAwNevO26BHC3rOI7XIeet+P9
UJMJ0pefnfvCm6nYCRn5KSUvhEd9dGWk2WiY1T3DbbdPEaBtxigPn6Viv33f
qrQGEHBt7I6hjSANcw+JF54JImBD8vBQ6HoWn+eKMdsfap2J9Sd7L/IuRfiX
PsrFrpGJSU6KWU8i+ddyfzxPxDwTK9LpeltwE+HR7t1KeV6ZWESk99lzSP4N
3WsfDj2WSdpPpri2a619SsG6eFfJcT1iQHLjjdiRdxQseuNkT1M3A64nn5o5
9IKCpS4JvxD0FY2TFJc436VgG8N/3frxlgFHl3U8pz+mkPaWNY8fUpZcoGB2
FpyVs6txSBpIl8epFExxVTVxA32vsPw1vlgRBYtaojDbg/hf8ULdssEaCrYu
29BUFeHpB7qv8S9lFHK/DZ5tUjcLpWAt0RdcYyRw+PxHXN0miYLdDTG/0SqD
+MJYqHlCNAVzKndPKEDyx5zd+f1jHwo2LRP21WA3Ds4q30ybAyikPcdqNFDt
lQ3SJ0TyA2dPpD+33Fl27yAFUyiuKap0+yf+w+xGiSkFO+C6pG6pOQ6aFbsv
iDtSsDWCz0qCrXHYEvfX+YUdS9/FD6+zu61GwbS8a37rI3l+udK331OLgjVs
y91iF4PD4sXExca9FMz8WZX/U3S+2u5OUp8qUsj4nzOi71dyb6KQ9paf8Vf3
1Okh/ch9/PohIMDnJO3chBkFw4IzysY0CGibF9hncoiCCcz5S3MrEXD1nE1r
8R4K9rzn3CNbNGZPV+GQ0mD5pxnb9AWqfFn+5iAtv8W4PwV7MvmtsGE/AbcN
RGS2uVCwKzUHai2NCJiIvX08252CWVOkfU5ZExAyuLnHM56CsSeWB4SYE/Do
JK35RhiFtE8tie8Q+1xOwRpjMzsrvQnojvb0LmmiYNxi79XHTxIwy7ZEUaGa
glErY7+r2hJgkcgWHpxDwSYnx6US/4mXSuWZnDhPwfYf27DCCs331o3+p906
4VhoX5l0JZqvceDw8UC5cHL/D9getS8bYvmTJC8INtV7nMRSmnUSRtH5tNIc
NVl27RR28O4rL77dBEx2hJ8oqz2J4W6hMdgOAhQV3ZOEPVwxa8djOkqqBOx5
M6qbLsiqf2LoxHVeXcYWViz+9GVLEQHVhy3nXXyUsV1s9saaNAJ2lJWs30Pd
irkLxa4ZRvij/quwHP+7Xdjy4w3ucWUERG37YnZMUROzOGCbsVQInd9j9kSX
VAhErE1QGRdF+OHO/vs/Zs+S/qrG5LH7d7b5QKfPn+0zBf/IS/MKLgNvUC2P
ul+VS8CLoOfuB3q8wfbyr42+aQQQ6aL1ynQfaLz5QFYxgwDH9Nn74SE+pL+z
/sJPqWSbKJK/Cidcnh6yTyPjZQSGFhnEiKaCUClbjp8wwrsPg4PkC1KAHvak
gged17gntsf9RlPg2kqekQBOHGy3XZmay0sFS5si/hYkv1YLzD4Id02GpJEm
zRD0ffEzx5TKKln5mFuORMr7KFFgu3/6r4VyVv5rj8Jfz2+5OImPmfE8099y
jKrDaWBtpqKcNoT0/TvDJVUBNNI+d6xzzuNjcSY4PuuZCUH7Sy2+nk/iVCaM
CO3dn4fkp5Rh3H0sJRPiUtr92uwI2PhdgfNuWyb02uo9XTiB+NOiIRrfnUyW
/3+2UbvOLee/eoMEkvdJJ6I8aHDD9UXUHzQufiQa6nOKRvLFsCmD8wnhRaT/
ml/xSWnWxSJg+mvVNTwEXF/nQZORR9d4HgHOHpJqK/vz4MGTDA9RtF+SPO74
XpvII7/Pm8u/uwwKiqDhhJid7xMG3Nq5cWkfFwX+TeddYEDFB4GK6o+xsG6C
3Q5DeEHD1kiQoyQWnmRcTfy7GIfHfi/bAtpiwc/3Vl7yHAOiziyVFZKKg+aA
OYtQFwaodTkJWjzKglm7mj+VXgxYqlEcSEnOAjcFo/WSCB/tdKkQdL2STvKL
8sO3/L9PpkPZTasioRAGhDncYewISiXtJfRZ9S0i6pmYQcyPeQVNguw3wvTP
Feo/XB3xOQGbj/m2VzX8n36WX/T275cE4zDGNY1/8r///du/h2kvGrT3MaDc
WU36X35zdZl5vIyBHned9r1rCbjBHZdlIZMBPB0LmjUbWf18mf5RcUlxeupQ
OsT9HatQMSWgRqa+qr41BUwUBU4MHSHIeo5M+1l3SI/g9awUsr7kov3sG/Z3
5EKyWuHPP8dx0PpubXdNj0rir0/q+XEdYVTYUmco+foeqz8K016Y4GSUT5+j
gcAm/z8zSP+ly7qa+OYWgIi5jNjxUQZZj4yJR/MTbArbXQpI+9gd0yddcZzF
kHZfNDpIAv8//iMc4cyLzTqyhdCjU+DQ645D4/aSoPrthfD5wZqbUQivXOIp
sjpvWwiPAqdCVDPQ+3tcbow/wcpn2FSj8CJTqoC0p12Rb7mdL1QMl7KNproH
Wc87YM95xyCXlc/N3M8uaa3usb8KSXxoeTp15auRMHhVLB/IwUVAbs5gftbB
MHK9em75nxc8QiHf/8BxEeqAdzhWt0H6CccZHNjWFrGzGYZjhZzjXMIncCjH
zI6a5YeT/W+dUs/w9VDyYKngLqk6xA/EJf0OlDqx6nWOQ+vWp+vCMfZgiSpe
hM9cf4i4+2uGYy4DMdF3U3A4L6uqsn4mjORDf5eWrP68IgU01N9e5NiDw2uR
adExvygYfHBymI7wQM5Sns07z0aBXOaHJno6A2Klog9wHU/5n3zMZMCgDVu1
qloKDFwTlg1rJ2C54rvh5b00rHS8MCPkCQE5D2M23OqmkfbjTpEEgU9NmfB4
kZT/5uc4XMt97CuZl0nWD4k/2v7syzYaaU8m9h3zf/+OSsbbpZ512TtXQiXt
u4872p501FBJe/KuogCsgZuGTXXMiZcifWGhPeLKuSHzP/yB9Fnxz05hvkzy
/30+9bTsjwrHTvVM1mYi/c7Mp2eeZx7ZrHPOfqrYvoyuKrwJyVczfke1225k
vt0imZgWNWt30p768djFeYp8COglh4hUIn1bvfY9X79b7H/yEZ3/l3zrLG7F
kvbaG8uCEo7rJcPtTI+8udc45Eke7ascoMNU0LrFr0dY/Igp/5uNIjxVb9Kh
78v0ogQ/AlRPBek71NNJ+Wxbdu7v9jw6ae9NGDvOdYCeB8qRIXKJaD4dBYdW
vazLg+2pbH9Fkb7ZM1PKMxmTR9oLNVtEm04J+WAaAmoHKm4x4LTpVVWfzT7Y
3Up56g7ETx237WcUcvhgTHtb6ugJzz2PHaDuzfZOX+5/6ktEmx5xcQJ9j0fT
hYIE7Pyib3Rv7ASc339M7z36vhIPSh+bA2v/q71TtS6PywCxN9Nc4+i8Dp9a
7DPxPQO4LWW+6iH+sWu1tYgrTwYY+zUt4ffBwYC31VTFNIO09736y/HC9kYG
UAih3Ns8BGCvJ8qGl1CgfZ/L7oPo+YHRFebb/TPgkLSq4VUBAo50cA/KR2ZA
n+ejmTBPBtnfmWmfajDMDzgZlg+/txcZ2zQifBVu/9F3byFocri/UUb8uSzg
49zOnYVQp+H6u/EmAx6ltj3j0kqCirOe+xbXMODSs3OOOkeSgPuSlMmVFhyC
2r88LFI5DTJqfKsPP2bActcMhx2CieAsX8OT18Eg7Y//2v+Rfju0TjG6bD6B
3F/5bHftK2oR/6E9eGB6iwBOjorq6ms0TObN1ohF/uh8UtU5X9fGk/2ya2md
fz+bRcKOZv2fK4xxGFKsOhaTEAlP5FRcJvVxmPyTOspojoRr7b/+aujicLbW
4EzBt0gwcrN7MqnJ6j/E9JeV3rjj/PNAEkT2RiVUIzxv7S6zSxYS4crqzpPb
bHHy/Zn1DdebeJ2JWonmJ5AwLojkS8UGtje2nT6Y20zr4w4kP7ZGL49c+MiK
5+/Xy5/NM/cn359/WcjKp5NumEaFw889iM9fTxz2Wy/hjim4cWUJout1XNP3
Bn67Ycu6TAl/C6Rf4p7WvGtzw7qOc5joH8IhZkH3/YYJN4z3iFZplimrP/m/
8t0M4QGhF1u2bI2EE71+txqWEzCu77I88QSVlN+nXUY23cmiguTrxubX6Lx4
TUVP9mdQyfjorxc6psqnC2Cv2ycb31cM2N7QpMrzvICUv3y5Q7/UrhTATkNx
bGsoDht+bp5/gq4fTZ9SdUH82PfTz/4o3wIYOv+hyTcerd/6R1Ml2QXwqmVI
7iaSF7N9Vsp79QtIeVHytmB9lB8adz6XG6tlgPK/8/H5n/+OE/1+/4TfOgdn
Mn8i8sVNH6G7FLBRYeuvQPKoNLfEqd3OCduTqvJmzyKk7/O6PN8qOJHyuM+C
vXqZTBg2cln16spnOKRryEi0Cv3THzh4obQJh+SarYrWe8P+k6+Ir11J8JZu
DAUegTl7NXQ+j4etfSdvHUrKP4kjgUuKEuNhx7xOw431BFnfz2nWeEhtOeKT
id8Cyw7EQvvEDR1VDlY8w//mg4OciubuYNdYMj7JtNecyNxIheikqE2ZzQyQ
Hlgx0K1Khcs58yvVG3CI1NFsrnrtD1oRBUfs7uBkfZvUf+3rOAjmVlWfv+RP
9ne/GbAvwSwnEUT2wpdPf3B438yJe3kl/pePhfY/ft2E51wUiAo/dNBC+u9/
9d2iSH2vWvDgO6OKCgE1R9dmFxNwwrV448EcKkzsWa3RmU/A5hOvlErLqdB3
03rfC4RnGe/8Uh43U+GP9o4lixDe3cofkmt6i+l/Q3i11tbcZ9IDW1zb8OnG
ZhxWN65x6pxPBhuDuYiNUzhI2ESZvc53Z+WT6F+SvXeL2V+LABOOe7O9dXQS
H1Rx8jeKV0WS+bKv49vLTMMjSf/MUu0lr0YHIsh6x2N5OjPKEREYMz7KWVXF
8K1QMqk/KNV3dt+9VQj3hpVc1VYTkG3Yf9rpUjxkitnc10L7ac8ZZ7FHQ+Fw
QENGyg7hfweuieYNk1EwMDBvl9zHANU2e1WnsmyyPvrN5S//GKlkAzO+RjXu
5K/7L7PJ9RiI3MNenBMDnUNSihZIfg6e0m1etTyFVS8kyfDVVn8aOT8t9dtD
9WuSyPmYVBwmuF0TsZ3iMm1d6PmvUvZXc0gkgM0am2vfkTySptV77c6nk/H3
xy7pvl682Blj+nfSOfd8XoL4GbO+3pFJt5s1HKlk/rSIJgS0NFGgrOz5vd+j
OPzKKFydfTKJPH/OjQGXD9+hkvbEDb2pSw9dpJP5CHdbehuM3keS/UFmLsYf
+iISiTH9H++/tm36IR7xn32ZgKw5J9d1YYX/+YcJGHMbb2gTTcSY+v6mqutD
WZEkjHn9Gbuc7Jnfh8jv527gsV/3dQTJByjy+8YVdxSS/InTRl6spskTY34f
4+V9rgkZXhjT/5JkqLlpUtKDfJ6JcAe/0v0iUl56fGk8ZmRAAeb7HjEYY5jb
5cGkB5vys6sM2LRRsB/vziP1WcVR9WtW0nmg932Zx81GJA8bR+6t/ZtJ5mvJ
2y798DyUTs5/R5HvvZvP6GQ9mhBonvtgEokx48Wihi8HNB3NJP2FNa5P5Li2
eGFMfZSp89DZIM0NY+YvvfxeuZCZwprPYb6w37mbFMj1nbz8qGzd5lRyvRhd
2Cwx60TWp6hzPZre/iEZY8avZebFH/0lp0H6224MJG5JPh/GisdsyRTRfZBK
xruxr3G1Fqv1IuOXVbhcV2jGU+Df7YbwSITosWvt9sUQLC7BebKCAYkf731d
/4EKMX+Xr/uK3t/Wy+TF7w/R//u+kkg+77MsLGmJJuVXrVa53HVGEqmPzvjp
DXu0J5Dz5ZbcfU36CJ2U/3/LwrUVNlAw5nxNqek5B04kkPLFwcGi93KmH3l9
//HbF/KU7Em8eZ0wqf9GiSLXX9erWG7fjTRyPU0y/lg2ZuWQ9v19UQ8K7ZqL
SDzLva/RqRrxK+GnfzNPriNg9Kyw5O4ee0j5FdryDo1X3+mmr7hvT67nyYPT
u7k/54Ak38f2NG0Cum4VcAY9zgHumFd3HusRIOJxhC+rPAcM/3kff3T+BMrU
CxSLyef5cyrP142EkvEB95NrBywuJmP/D11snno=
    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{4795, 4488, 3882, 4779, 3883, 4489, 5328, 5327, 3977, 5400, 
          5644, 5643, 4726, 3881, 5330, 5329, 4375, 3853, 4035, 5747, 4034, 
          4600, 3852, 5723, 4237, 5275, 5274, 5581, 5580, 4452, 4717, 4216, 
          4679, 4020, 5052, 4140, 5539, 4139, 5756, 5102, 5152, 5151, 3726, 
          5153, 5101, 4794, 4897, 4896, 3836, 4678, 4895, 4894}]},
        RowBox[{"-", "0.018500000000000003`"}]],
       Annotation[#, -0.018500000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzlOgmEUheGLC1AEpaMwcS5xCcQNmLgBaI10akWMpWhtUBOF2koEHBpp
YSdCgo36Y+LwUJy837nDyf2WSpWd/VRE7NLVXMTyYsQ1lucjzmcj+vyA3rIR
jZx+OuKGX8G2Wsvs2OwBP+QPcYT1hYg8HtlZVet4/2Qifqkv993OtveWfqJf
wAn21F8pMd+lR/ozV5Y3sDfUm1FLUdCanSe8xw93tfAT1/FZfQNfpn135uRs
8nvYNNOg2+lfZBbpRH7CP5j5wjZO8BTPqOrGGn6bq+Mxf4kXsjPuy1JHdlW/
Rncy/wFoNDkq
          "]]},
        RowBox[{"-", "0.0222`"}]],
       Annotation[#, -0.0222, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz7cyBFAUh/HjBWQKVi7NCDWFVErjEbTy4AH0ajkVmNlKbNTyYwhrMSik
ZVbht8U33z33/O+599YNTwyN50XELJYLIhrKIlZ4uChiPj/iVH2Gp5KIrfKI
6sKIDXUNv8m8oqc4Ylqd5Eu9C5yjXW8OWXOanc3INHErWjCrvpKb4Wu+kkvL
X/OfWVnU6h26+4DfZT7xgTr1kf16Ps71vblMvkE9wqdcyiWYMy9pbkpuzP49
j3OnXgcy+hX2KnGivimF9bY33vIOj8rv8p16kxPqVe+o4mezn5DWm1A/8CQ/
8oJZCV6TXcee9ac7vnJvdO+Lc13W3WizHjB7EL3oRx9+5Br5l5fMW8SU+d/O
nNlLOXfOP7m/4MAd+8jgH5grT6M=
          "]]},
        RowBox[{"-", "0.0259`"}]],
       Annotation[#, -0.0259, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtPlEEYxfFHDJdKRdlVwBCgURAbECvUxMoa7Sy4NKIkgqChMMZtoVDu
oh8AxNtSCCFRQTdRv4QKISZQCQJLogX6e4t/zpxnzpyZfbems6f19oGImEXm
UMTl0oi5IxGFxyKKUIx1/mBZxJr90XREgfV589ThiM/WZbSZn7F3ji4djWii
jdjHAL8gN4+3KHHHPbO76McZmXrUJffZ6zO7gx70osis2LlCWkL3veOK+T96
2plTyHjjJn0ok0Geb/CePXqW9tGPqYgcPuGLs9flv9K/uv6gze9oNZui1TK1
qEE7f9W8g16jo94whvfu+YCs7gq+Evf1DeGdcyuyq8l3wRh/XO659Zyei+7r
5m/RDh1L9pcxrmMC5XLj/ARmrX/JbSKne0P+knW937Wjo47u0uWkB7vyL/AS
W0m/vk78tLfDb+M3TjiTl9nDPH9S5rV1hfkrWknf0HL61DueYRJTeIIH3jKt
cwY3ZB45/xjDaNGXt59yPo1F/hsd8dZB8yqZ7/yP5HvqGkFaxzSf9X0uyHfx
N5P/RX87cvx/wiJjxA==
          "]]},
        RowBox[{"-", "0.0296`"}]],
       Annotation[#, -0.0296, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0d8vlnEYx/FLVHJAz4NSytaB/gf8Ef04KJpkoi2hE+sontnYysnDSW2t
kFLmwIZRqSb/Qx2gNUrSrwOxDlRbr/vgvfd9fa/r+nzv+3lONF0/25ETEU8w
WBhRWRJRcCjiABaLIibSEb2piD7kYZ/+3+KIf7iMG2Yq+SQKSyOKMGVmGjO4
czAiI+su38Zb/Vv8jjPuG5d5wW67nDru4HK9YziCfvVR/m2222zG7pDcYYxg
w9muvT+oRZv5wzyoV8Y5dvcgF6fUp/HDNy3Kq/d8z/5rvatyX3Erv3Q2j/bk
fXAGDXJ/2mvyXGCuU33fHQ9wXF2BJc/LWEneTU6P737Iw1jVH+I1vunuMfnn
ZbXKOcfXeABtdrK8babLfJe6mz+aX0t+/+R/Ue/lfOxHs3pW7jPMIaVe966f
sYFP9mq4xflTHke1s6zdKt5x15Zev/oXX8FzOfN4gQX9JXNv+KJvq8eA8yy2
MOr9H+GL3Aa9S3hv/pv6KzaRlvnYzCSPcTF/d95o9oPZSd+cVpcm93MJp3gG
/wF9NGRq
          "]]},
        RowBox[{"-", "0.0333`"}]],
       Annotation[#, -0.0333, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ElsjWEUh/FzsWvpnVqusbWstL210ZawYIHEQg2rokOathK1EglWpqCG
oBXTlQhLl003NrQkhkqwKtpUGxbstNY1/Lp48rzn/M973i9fVfvh5t5ERAxj
ZlHEulTE5YqIBq5GUzqiERPO3/kb7mciFiYjjprLOl/IRoxzh94XbucxHnNn
HKXq8+URJVxw57OszXm/bB867WxVN3CxLOKuvIA7+IRRDLp/zve1mC+a/aV+
xNP8VG9a9s93hHqW/+IPNnlvI1qQNvdK7zWWe2eH91Zwo/0Z2Rv9txjBFVml
bJt7lbKtXMW39G+iSbZKfZUPya7xBtyWrefVsr1c4DN80MxZ3oUO52a+gZWo
8M2LkcVpdTkX3XuMD+oa9XtO2J3jn75vD//g3TzfvgVIYMg/mceT7k7hhPqj
+8f5t3+UdE7hkrsX0YceOx6afYBjZga9U+L8TPYcQ9iulzSX969KZcN6L/By
bo8sLauXLZG1er9OfV2/lvtwQK+Gl8nbnPPO/fIBLNXbrJfjLXyP074xg7X2
1yOPne4MoNdMP6fm3nDu8W43Tqm7+CQ/seMIr7HjHVfzCIf3yrjWXB0m7Z3C
V+TwH8ZdZjo=
          "]]},
        RowBox[{"-", "0.037000000000000005`"}]],
       Annotation[#, -0.037000000000000005`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV07lPVGEUxuGDglsxw6igAQFNiNHStUBN9A+woXEhxmjAXRDQAitlm3GB
whi3Ak2kwSFRK40asVVhoDJEEvdSsVQ0oM8tfnm/873vOefOvZk1h1vqm4si
Yhx70hFDZREP0Lw8ogVnULU0ohrbSiMe0jq6IRNxCqcxru4pj5igE2a0L4sY
kXuFeRhMRczytsrM0WPujiJt9lr9KZpBKV7yQ26Ezpgz6Fk2Og/Kt8q2ocu5
E6PmDvO38/N0B13tvgYfeefMO4sB89K8yzINyR5+St2vLqVXaB+u4qa+x3bc
ovX63vDn1LN4ofc5nuEGb7ff+sW5FhXqShx3PoGT6LanBx/MWMWrRhUKZq9w
P0ab5BoxJVPG22nPLjSZXex5jtASWkEv6LmISdlNejZjCx7J3zerl2bRL9OH
Sj0Zda33eAjt6jr6NnnvztdkCs5jGEW57Hz+lFlZXg7fku/B+0qL6HveP7l1
nmk9WuVfm9VGa+gBv+G6bAcK/PN0nB6kOf2X8NOMp2ZMu+9EF/a635d8f947
3qfkGybvDsV6b5ufp3doCf3sfr/8pOywvWn1QveNdAFN0ZX8u/KL1QN0Cb1H
F9GsnTl0oxc96LD7t54Z/MJf/MG0+yf2/JAZ0vs9+Y/QhuR98/L0PzOMdYk=

          "]]},
        RowBox[{"-", "0.0407`"}]],
       Annotation[#, -0.0407, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV01dsj2EUx/Gn1AXSQSlNlBgJiZYY1YpaTYyo2CMxelGi0iatkRgtxZVI
jBotonbQGzFKrDZx4cKFEbpCWyHGjYhxQaj1eS++/985v3Oe85y87/sfmF+y
oDgmhJDqpyYxhGNJIXSmbT1DaEd9fAgNPUKoo0t7hbAEu3qHsBMfUY4dWMRf
jHv6nuu/S6/za3ENeWZ+wZ7kED7TT+oZ+vbJx9GxyHTfOLSI76i3io/apwqd
nNmkN0m82z1NdCWvga6gjbTRuSbEyLe7M9BqZ87jHJbL//Hr6R9aR//SDtrF
zN80Q9/jhBDS+I/oKXvEmXmSLlR7pqfUXluj58OLde8H3nrnN2Aj9qi9Upuk
NhntvDbkmPc+erZqW/Q8FieY+YSOUB+JE2oDedV0Op2BaUi1w1FnqjDenP7y
LLofLc6X83egH7+rOd3RDdXyb3boqy+LZuKw/q80Den4pacDJ/hnzCgUF2Gu
eA4q7TLRDvG8bJpAZ/NzkWzuIeeao2cu7yNPjN6DfJv8I421xzDnhqJdnkzb
aB/61Oy+NAVr9RVgDdLVX3oHrchVm4UCc4/x88TD3DPT7nPoW/3vUCQvxANx
Er9S3wT5EZodfR/8BoxWy0V+NJf2NncIrbDvQfSST1HLwVTUyo/b86JdLuEC
MuxRQ8fQFGea1ceKH+Kn/vjo3YjXic+oHZYP0D+XfrDDPLoaBeavoum8NLzH
cDRH3zgy1crM76GvJxLRaO5Nc2/gtNnF9ADvlv7buBN9y7y46J0hzr27zLnC
v4rdepfxu/O+6/uB++JBaoNRYeYLZw7QdlodfbP0JJ1vl3kYpX8fiszZSxvU
nuOyvknRf9WczXgTfc/6X9NS95RhKM7ySuh/VPugvg==
          "]]},
        RowBox[{"-", "0.0444`"}]],
       Annotation[#, -0.0444, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0slvzHEYx/HH3dZaIpagtSVoSaeLg7b+BC6WmxGiCSqxzEzLBZ02iq5K
CDJjSdQScbHFjYOkSRcEJ8vJUv9AqXr9Du+8v5/neb7Pb34zszzdvO3QtIgY
wq+ZEUdKIkb4RmnEfucmvJWL8k0ck49iTC0vj/LBuREHsGx+xFLs1f88O+Kd
3gIz77lCfoPmORGHUYZyTOql3JnQ+zMv4ilP8DP+y+lZEd+cP5hbaNdHrpGH
sAmf5EXqi1Ent9hVy73qXzgvf+VKbERO3sAD+q/sfo27eK62Va9NfdDnH5c7
5N/cgC1olRu5YKbdnQ6sxjXPvo597vXpDXA/l5tfgTKswkp8d/8n2p1/cNFc
1nwOa5DB8cTqZ7kTa3Ee57DO87q5JzmjCxdwxfxLn6HfudrMA+cavihv9j33
cUq+r17FvfJj50vcID90buTLcj1n0eQzZvi02inUycG3/Na3cQedyf+Ciyhg
yjvVmqtP9qIieQe5ktdjhvnpmLK31e97Alm0IJecvUfBXBHb7TpjZxvyqHJv
XL/E+5TiiTzM3fbn1ZeYGZFH0YWepIdBz0qZ3WHf7sR270yQx/Svuj9pJuP5
/5LvTO0eV5vdZWZPYvNpfiE/4pPyfzYjdr4=
          "]]},
        RowBox[{"-", "0.048100000000000004`"}]],
       Annotation[#, -0.048100000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz8lK1mEYhvEn0PQzcCxblziegXYEQoMaVK4UwZamgi2UKNLUBmc9ATdK
aWDgVFY7DUWccqgzqJU4NBnUz8XF9d7Pc//f73sv1d2rajgTEX1IyYiYPB/x
Gi/xCklm5dkRyTwh382JaHOu51aeQ2NuxCwfZEWc5Vvy48yIy87tfFtOdT60
X5Q75CV+YPYWTfI8H9kn+I7cYZ/n/AjVchqPmr3jZnmBH6LgQsRHzucPfOyO
97wld+pv8BPe5BHe5X7e4QHe40X9f96zIi94a4F3FuKNu0q4GEX4pFeov8RX
Tv+TfSknuIz33dGJcecu3nTXVd9Np0cs68zwZ7MtPLXvxiGe4Tm2za/pz+qt
6M/xDfk67vvdFnzDd7zQP/I/dnxTYV+JVd98kfewi2P7Hr0x7+rlH/JX8yrd
m1jTX8cv8xrzn5zgi3ZD+r/lQf7Dw6fv4nP2f7mWTziNp/Afcipciw==
          "]]},
        RowBox[{"-", "0.0518`"}]],
       Annotation[#, -0.0518, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TcvxXEYxfHHgkUvu9GkvQFcXD1RLok2iBYRFgail80uykxMJKxWvb4M
DNob8LnDyfc5z/+c5zf8y0bnumczImKJPnIjqgsidksjarCcqgsjTvkqfOMv
ZdqKI1ppizbp3e6pKOKZ7umRHtJe/k3vlXb4v7yIBbfyzRt6d9iXH3GDKbxN
d3Ve5J9pm//VmdfJM6/rrNF5ScQZ9cuOyPXqVuKJ7JbcN077/oUHutd2PTJ9
8ikalu3mK/BYJhs/8Qg/MAu7fO+V7aFDvsV+33zl/U73hvkf8xDueSNlN2nO
9O5U+gY2Y5N9EpO4ik9uPVIHP8hP6Oamv7nViE12CWzEBlzGB/l7aucH+HGd
HPOKTj022NViAutwEcfwwn+507ulNr6VZugfzL9FsQ==
          "]]},
        RowBox[{"-", "0.0555`"}]],
       Annotation[#, -0.0555, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0DczRFEYgOFPQSnTKxWMfyGnlXNOI+4uhhmZP6GiQKn0e2RrhpXVHsUz
75xzvrn33FsxvpxYyomIFMn8iJOiiFOyhREbpRGb3NmvLI641zfrd17I8krK
fnNZRAtNtNHKdUFEp3bRTgcJ0uZ7tJdu+unjxvywjjDAEIOsmh/TcUa5Mzeh
t7pVEvGgk9b3elweUepOZew4e7S3rU+6q2ea51uedUAzmqvl5vedv1rvaVYP
9EVnPXuOKWaYZs2dFnSReZZZ4sN8+v/OrJAiybr5L+/45pNffsjYv/K/M2bO
/fMnvdB2e4fOLq3rqKeWRhr+Z72nyr2rqTGb4Mj8oPUfHGpGpw==
          "]]},
        RowBox[{"-", "0.0592`"}]],
       Annotation[#, -0.0592, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ccuRGEUB/AjLLTo7G2x1Y2Z0e2EDQslYk1ipzyB19B7eQN1eAJlYRI1
eAm/u/jlfOd/vnvvSW7j/NL4YkFErJCtjHitj8jzWBfxREo2XhPxXBVR2xDx
otapy/K52ohZcuZT+lHnLfM1Na+/ld9xURFxXx1xro565whDvjHIF/0MMCQf
5sy9nPun6qB+gD7zLJ+kydAn7+fEvTv3j9Ub30s5F6mFTLDBt9m6fMd5m017
tqjNPMiPzK+dryi3fxmfsib9V/Ks76wx5rlL2aHs1nMHalaeoddOKT7opode
eZr9ZDf399SUvocu807eaaeDLnk3u8k+yb5qp76DNvNW3vjV/yUZ7Wy7Vywv
Ycbu0/zIJ/2HBf+rVL+q/wcrGUOV
          "]]},
        RowBox[{"-", "0.0629`"}]],
       Annotation[#, -0.0629, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0MkupGEchfF/sSGIoem9sa3MV2CeiXSZllZWtMS8Ee0mJGJe4AKwMpcL
ME/d7sEd+NXi5PnOe573y1dVOjE9NJWIiBUpzY9YLYj4/VPx/FUYcYzT+kma
Mun5D1bKtf2E/9fZKTbL2Y+IO1tNScQ9zuqbWFYU0ZJ+N7a61yat+rn9wV7L
f8Q5fQvLeW32JLZzO6Rdv7A/2ev4zzivb2MFr8M+jJ3cLunUL+0v9nr+Ky7o
O+nv53XZR7Cb2yPd+pX9zd7Af8dFfRereD32Uezl9kmvfm3/sDfy/+GSvoe/
eH32MeznDki/fmNf93/95zS584nLzvaxmjvAGcdBfsr5rWRJtiScJd1NcKc4
Ke6afoszznK8L1cOiiMOJcPZEWZiprsZkqdXYC6W40b6d9i/AYSwQKY=
          "]]},
        RowBox[{"-", "0.0666`"}]],
       Annotation[#, -0.0666, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdVX001Wccpw7ZbUK02pRi63hba46JrWOf5iYuS1KRRRnVZLIUR7gllUh1
DL/lUm6KishLXi4Lj6QYl9a0rpIbufI6Kb0sWq17e55/+p5zzz3PeZ7f5/l+
P8/3+/kY+//isWWKmppa5Nuf8v9djMHQmz/uks0nhU49UQaFj5DiUFayvWAV
8Umqf2bm8wgax2faNd1dR3iy7B32vEdoO7XPdlS+gVQaxQ2vrhxFy9oIw8TH
fsRABTAKba65ue/ZVhJqr/ziH7i3z4v6biKYtEqVMQLB4UrOLSaUmKsuGMGQ
mX+wMDaMKNHeQuJI0/TlFw5EEGU2Tj1D+Dyw3LAjLoqo4OyH0Dpt07hGwh6S
ka6MQUjWHOz72HEfeW6mBBxAwqfeN7+8Hks8VAkOYP34ohonpwO0vn6YX52S
t7HpIK2nHy9TZFy44BDZqoqHMCs+O5LeHE+uPlMC9sGrddfyWtfDZL4qwT4o
bJdqjUkTSbSqYAXKp+k+1XQ7SlRwsl6YJg7v0r1xjFirohddobcM36xKIio6
kx6gunKA+Af+SkZU5fbA7n7vealZMnF+VzD013RM8geTSY4SLrsbHxRVpvbm
pZB379UN0/6oZBKUSvmXY94Zw3y5JUf57oK+b3XDfyMc5fce2p3iPKUXf6N8
3sVXh7gJ7ZDjlL87yJ6YU7N5URrlqwOtrjprZcNplB8ZBM+1bPgXRJSPvxH7
Mvxx07Z0Wv8txE1rLYy2zKD1tkMvMtY5fCyD1ncTcybvfWJSeYLW8ycsIy3V
+6NP0vzbkO3u53rHOpPmK0WnPEQwoyOT5vcHjrbxJbl+YppPI6ZYzP3O4pqY
3t+Aux1LbutMiul9V1AcMFPh+UJM8WshMvfQLC0UU7wqSIxu7A6exb4vQ+5V
nkT4WSY9X4jzK/jGvo0n6Pk8HFC/35SWn0HP5yA/BBY6c9PpeTFObWs3GVmY
Rvc5/K6to8mv58jE3qDqsNQEDA6Le3b+mExe5T3+a6X/PljJHd1mORyj6x1I
5CcLTsfH0bUfzEhWd83rGLp2x9QKefN2z910vQy2wRu4Owt2EbX3gu1/0Wip
a28eAPa9qUCY6poQAobvVlV/2achAuz+nzmY56zYD5bfA03h3jnGR8Hy5z+5
37pZkAJWn0dMTf3+yXSw+jttjC9aDWSB8TPf9lLPKa0cMP4yE3lHluWfA+N3
2Yq+luLnuWD8+/30ckeMogDsfbgWm8s5C4rB3u9h9m1Hw+QSsPet3uB9plR6
Cez9BVVZAQWdpWD9YVb0zezhujKw/hEJIj1aosvB+mvGm+V1Qu0KsP4TyLmV
BsIKsP40kIr227RVgPVvY+hx5/U8CVh//+sXkHtriQSs/7sUPoufeEnA5oPn
296qs10CNj8iLtRBFiYBmy+XqYqx0bf7bP6SXDyHXntKwObToSB7lftiCdj8
Or/26656UQE23/nh8VWCEpa/HEZP9TJ5vhVg+uDdsXvdh6/KwfQj0cu70yCp
HExfmu8ZBzl9VA6mP81Hvq8rSi4D06cHEpndavUyMP3aWViNr7eUgunbqGmA
UFTD+FdAunR89vzpl8D00XahzkSCWwmYfmpcX1cnSigG01cjNamuSVgRmP5a
cN2BJo0XwfS5LLThByGvAEy/o62Dal2+vQCm72lXamTl/rlg+r/HK89xMOIc
mD+slOn7zt6bA+YfmRvb9MThZ8D8RUvjbGDfxiww//GtrBmtDTsJ5k/X7GL0
eXoiMP/qyt1kzUtNBfO30ojh0ybjx8D8b8LqpPH0+INg/hhvez3PShgD5p+J
CstYriMczF/VazurQz0C8Z7/4n9EbM4S
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504,
  PlotRange->{{0.95, 1.05}, {-0.03, 0.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 313},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->674448689]
}, Open  ]],

Cell["\<\
Streamlines near the airfoil surface show no waviness, there are no \
streamlines interior to the airfoil and the flow leaves the trailing edge \
smoothly, satisfying the Kutta condition.\
\>", "ExampleText",
 CellID->482308682],

Cell["\<\
Repeat the computation after altering the trailing edge by making the \
trailing-edge points coincident.\
\>", "ExampleText",
 CellID->254018838],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rTE", "=", 
   RowBox[{"Mean", "[", "ptsTE", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "rTE"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "\[Rule]", "rTE"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grP", "=", 
   RowBox[{"PlotAirfoil", "[", "rP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rP", ",", "\[Alpha]", ",", 
     "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->230503503],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0151125092347049`", ",", 
   RowBox[{"-", "0.3484951941722312`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->134517645]
}, Open  ]],

Cell["\<\
These values for the lift and moment coefficients agree reasonably well with \
the results for the open trailing edge.\
\>", "ExampleText",
 CellID->88671999],

Cell["Plot the flow field near the trailing edge.", "ExampleText",
 CellID->437823294],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B"}], "}"}], "=", 
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rF", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]", "}"}], "=", 
   RowBox[{
    RowBox[{"UniformFlow\[Psi]", "[", 
     RowBox[{"rF", ",", "\[Alpha]"}], "]"}], "+", 
    RowBox[{"ic\[Psi]A", ".", "a"}], "+", 
    RowBox[{"ic\[Psi]B", ".", "b"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gStreamlines", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "contours"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gStreamlines", ",", "grP", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", "\[Times]", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->240459914],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0nQV0VbnX9vHB3d3dHQYIMDgMXnTQwbW4U6G0BVpoaaGOu7vDwd3d3eXe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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{4309, 5060, 4310, 4644, 4643, 3807, 4847, 4848, 4751, 5037, 
          5093, 3698, 5092, 5771, 4183, 5772, 5038, 5764, 4101, 5474, 4102, 
          4993, 3985, 4558, 4184, 5039, 4185, 5040, 5042, 4202, 5691, 3822, 
          4567, 3997, 5715, 3998, 3823, 5692, 4203, 3850, 4712, 3851, 5696, 
          4346, 4873, 4458, 3853, 4738, 3852, 4457, 4752}]},
        RowBox[{"-", "0.018500000000000003`"}]],
       Annotation[#, -0.018500000000000003`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzrsuBEAchfGzVmG3cKdHyTMoeANBZxMKOhuVYt0SGhQktuMJkOh5AYV1
ictWFg9Aq+S3xZdvzsyZ/8zIUnVmtZBkFnt9SbU7OehP9tEcSNZ7kp3epDKc
bPO7809ekb/aGWXrD+7iFpd4WW+MS2aOcpmnzZxCp86vfNSe7Y2ivMUdvM0t
HOrV5RvrAj/Ij3jCrbsTg8k47uVNnQ1c49TZGV7c6fDuMxd5VK9h/8q/GtZ3
+ME3KuYs4NL9ef0LnuM7/WN/rMmRF4eSP3nXvHN7dfkEa2ZO6tacvZrTxBv+
ASMaM1k=
          "]]},
        RowBox[{"-", "0.0222`"}]],
       Annotation[#, -0.0222, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvpWEYxvHbF7CbznKUzFfwESxBhYRItJaEsTSGxlJYOyGxOyTUppzg
nDinUUxH1LbOEDs/xT//932u676f90109jR250REH4bzIv4VR4xwTUFEb27E
bEnEHHaLIsZ/RLzIOry/clYng0RhRGN+xCj/RqWzat0E/+RLez7MfOIdOc4C
zWbmvTfxAu/rHZs54Kw9Gby5Z8jdCzoZnUXOfu9xPuz8g0d4hh/MPmJV5z/f
o8uuMd7U2cIG6uRldpfiXH7F11jx78tY05nwfes8ybX6UzyNMTy5q903PHPa
7hR2dOv1trmBk9xiVytu7L7FEY6RdOepmXLPFTjTv+M23QvZkuzQfD8GcCKr
ku3K/sr2OO0shUH5L/zBnD1fFZ5N0w==
          "]]},
        RowBox[{"-", "0.0259`"}]],
       Annotation[#, -0.0259, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0jtPlEEUh/EDagsqaiLaINFA4jfQQvECCI0WCIiXEKyUZQELOxtvBZcY
E4UgYEehjY2UIIZbRQAbozasxhZQWBALflM8ed7znzlnJrNb1tpxLVMQEWNo
K4o4dSDixf6I5YMRXzAjmyqJmOXOIxF7fWd5Hz85FPEYeWt71L3yQn6pr4AD
k6hXr9rzwN5u/DK/TnYFtdjGFvL4aa2Gq3EJl5GTzZmzwvPJZp1MOW/yBm5b
+2Ctzf3vYlG9czhiif/zVe7hPvTind7T9r/nef1zqCqOKJM95EX3XMYSLqhP
yC9yOV+XNeKVc16j3+xv8u+4Y14Gz50xrB7B/dSjXtffnt6JP+ur0zea3off
cpOZv92j0d4mZNL7qT9hzMxpPcfTe1n7hy0s6B2UD+Cj/ePowB9nTNlbYWYl
JqxPYkN+Tv6X19U/7O1EXp3lbnRhU33T/FtoRgtuoNU9Hul75rva2U+5hkvN
PIqv1nPpd0QfhtJ9/C/a5Su+c3iDZtmqMxr0r/E9WQ8fS/8J887zGeecxah6
F/7faqI=
          "]]},
        RowBox[{"-", "0.0296`"}]],
       Annotation[#, -0.0296, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz01LlGEUh/HjFygti1apUFpJK1vqQkwXYhlRQVC+zNioJVoSbRTRXimh
VeXGXPXyCRwddRRdOBroNrM2LRQqLcM+QL9ZXFzPOfc5//t+yhJ9l3sLIuIj
7h+I+HHYd2HEtyMR4wcjRg5FpIoiOpFztox5LOAcrpvZN/MPi8URS7iLe+jH
gKwbRyMGuRtv5XbxBCfdNyy3Uk6znDN8iVftfUIOHeoV3jSbNNtit0N9C9/1
lvSy9k7hNLa845qzbZ7kNEr0s+p5fLBzVt1v74U3jOI5GuW+1nuFaucP3FvK
tbxgr8r3jKxZtKINa+hz/obH8FRGrX89rpeR+UQ9xY95mtvdPSS/QtYFM+V8
kXvQZO8OfzaTMHPTTrvMBJLI6n2RMaG/wV+xiTr1CJ/nh/xTRtp7pzCd/2d7
x7je+RAXqUvR474S3nDfmrOUep0b8Cj/9vy78c552tx7PukdJ3BV/wqWkfIP
ncjILndWgYz5OfUsZvDLm7rMvJSds7OKFezod+vv8m0e5b92/3CNvd+8p37m
+z8wJ2ew
          "]]},
        RowBox[{"-", "0.0333`"}]],
       Annotation[#, -0.0333, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0k9Mz3Ecx/F35M+pP/QLlT+dbFxRmQmbk+oQNlumlWqjlMW4SLGp5NfJ
UDanjAMHfzKGm7IZx8qWOfhtjBP640L9PH6H556fz/v1fn8+n76/Shs7atuz
IuIdJnMi1udHtBZGbOASrFkVUYiX1iPyZ9bNqyOaUJOIqEYVUuq1BRG31ffl
RQzxXh7m52Zf4FtuxAG9X7nbHbdke/TslFVglzMq7RM8oKdenuL9Zo5Z38QN
9Ni3eUu5mUH9Y/ZJHufrahOyp94yikd4gsfIdWcOduOn/l61PvRjizvT5lY6
f1Z2TS2JbPc3yZbyRnObMt8Gy91TytncIS+SL7M+xdXq7VyC07JiXiEr4/PO
rpQvsd4qO2efbz/Defybs2THZcED3nAVv9QHnZHEFfTiofyz7AGn7P96/137
HfYjvJ2nfJOPmMAdZ0zyK72vcTTz+9jX8ZTZN2bGcBiHcBBVzujSewH1evq9
67v+LtlFdGOz2qwszT9kPWqXcBkNavOydf62BdlaXuST6idQ4Px/9s38Xn8L
f+AEt8rbMt/B3UXm0vqK+az9uJ63+OP3mscctpk5gxo9nTzn3k7rClk5GtXK
uIH7nHGEPznjPk/zPf6iPmNuwb2LGM78T2MI02b/AzKGc4U=
          "]]},
        RowBox[{"-", "0.037000000000000005`"}]],
       Annotation[#, -0.037000000000000005`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ktI1FEUx/HbqkXQQ8dxm5XLjN5FzBgUqUH5iKzsQY7Ry7CWlS7cBFlY
EGmCraI2QS+nKKhIiJYtcip0ow4G2UKllSOk+bmLL797zvmdc+6d/5RlLje0
LQkhfMWOFSFcKAnhIrYnxNiJ+VUhLKB4ZQg3ikIooklxFTqXh/Bc3JIM4QV9
Zsbu4hB6+HoxwXOLZ1htKc8IrZRP4zvfMvUc/Ykf6FfP2f+QfhC3OJ9BO38H
DvC/NO+I8yt6SS3B20pLaJD/z/NZLe3uKXTaO+letTxrxTPqv8WHxH9oHW1A
fdyjr0u9g27U99TMMfEo/sql5K7IVehLut8GWko3mbsZR+0/hkGeKfNmMI2s
3oIZA7SCbz0+8kyqrZMvR7VZb+Vr6Dv6j/ewWY14zztrTwFzuMnfpX5f7bzz
vHPGeSH+Nvpr3LORzurrNusO7uIszznMxW/IU6CldFBfk/w2nq3Ygi9qQ3Kf
1MbtGJF7bGal/U/oNfXjeq/SXu9ooj20Dw+QFtfpqUfOjHvxu8jvwV6sli/D
I7WsWtaugfhdMWr+CXtum3GSjolfy6/hfxPfLp6mebpLfpxOxTvyNuOX+HT8
/yCDifib2Lkf+1CNKpyy+7q+dqTsOmh+Lb7JJ8wdim+neXSj3Kw2b26Vzzsv
Ag3Se1M=
          "]]},
        RowBox[{"-", "0.0407`"}]],
       Annotation[#, -0.0407, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ldsz2EUxvG3xEjUaqlNuDBic0MrUSQkthJBSURSRbSNGEGiTRUXLuwb
JNq6IpSq1rqwV0KsxG7t2KNWrRuf9+Lb55zzPuec9/f233VeXkZuQgihuz8b
W4SQmRxCTfMQDiWFcBjlkZYhlDYLoUurEMrks3hm4nzrEEZgJDo564wSvkP8
xbRAPc3MfDqMXkdWSgjX6C3n7fkWyTvQdkg2OwmV4j3OD4oPYIZd1e40nfep
fII9O9RSzdlGh9Lt9Ii+CjzmTbfzEc3XswHrMYTvjvquuJ/upLfpfXpJf0Oe
Btivr9qOfbTQPd47X6D+gZbjqZ7neIZJ7nOe56v4G2pxhWe2eiaGmZOGVFxW
n8Pbz6xuZp8TT+CZiDJnX93hG77jhznfUcDTib+e7+pI69Nc/hy0M2MRxqkv
pKfMOIlpzk7EbzUngf8mvY1bWCqvon/NbRS/Gct5K2NN3z88im+IQvXl8hUY
LV+lp494JW1q50fnifQT7aXeE7+dLZMfx1T5H/lncYZ4Cn76pqvyC/b9Etfh
jPwdPU3f00o9H+hHDPRuA9AfjZwfUatAT3t7IN29RmBNfFt5Ph3oLfbwF8e3
j78TFInr4t14msR3oIl0q/oWtNHTB6PUe9M6cxrTLHf+IW6t/pMm0VZIxqa4
18z57pONLDSLvxWaSP86PxXfSrwPD+QPkSMu5llMS+h6niV23XCPQXQvHUzH
ROwZTWvd9QtKnJViO7ahrbPJ7vjSnFd4gWPmbrFnM9aZvVctV62U5tEa9WrU
yJ/grDlzzcmlecjmSY3/V713+e5ht/PX9r/BW5TrO4ylPJV0rZ6jtIj2c5++
SNGzAGPNyqZV8XeGHL4UOtyudFwyI4H/Is20azZWy1dhvPg/XaOwGg==
          "]]},
        RowBox[{"-", "0.0444`"}]],
       Annotation[#, -0.0444, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UlsjGEcx/FH4lDFrLW7NGhCIsTSRmmboAmVWKaYDkotF11mbO20pQ4q
bQ+i5cKNq0TiZIslsRyQVg9iO5Ce9MCFm9TB5z188/v//us875QfK2Ty00II
o3gfC2FnMoT79GwqhM3iLXjI19OtOCf/gF8dx9wQOsUvEiE8on/VH9MS/g5q
0iHU4reZP5hQm25mbI5bGMUNfeO03r7X4id6pux5SuP8XSTxnP8n/4wm+Dpx
l/il+BVmYCay9pfSXrVbdt7GAG7KrVI7KX/J7Fv+BP+OzsMCNPHz6YCeRTTH
L6YLcdpvPIM8TqGAor5+u5pxOMIbm/FG/gjfgjg+yX3EkHyOP4AYmpBFTn4X
3Y1ZyGAPBuX30f2Yjb1oxEX56/Z1iBPedlmcpHm+1Pduj+7y/fIx2hbdNLPS
e8r5FIpq2+S34zi/gzagWz7NF8RT0Tc1M0m7y0LoQS9a9BRpFzrxQ32J/oNu
LNOfFi+lZbSCpugv/MRXu2t9uzpsRA024ZDZHvXz4jXR/0fX0oRbcYyrf6Pf
cQVXvbPD7lb5CfEwRpDBBrMf3GkUD9Kk/nV2VdNKN6qwnr+m3mfHZz3VZr7Q
rNwQvaenUk+fmapI1S9ghf7lOKr+HxGYZeo=
          "]]},
        RowBox[{"-", "0.048100000000000004`"}]],
       Annotation[#, -0.048100000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0MtO00EYhvGPjexEVBDBjRsvQCMtFyGHRonBGENVEhU57lxySBRXJFi1
lgWWllLQBLgCtqgICIQrKFCQa+DH4snTd753Zv7T2+nB1EBNRGTw+HLEUX3E
MdquRiSxXxdRlSe5+1rEHj/kXX7EB6iYb8sJ/R0+lCd4mW9djyhb35K7dD9c
iejkv/KC9RIWUdZt0W1GUd4079B7r7/e4Gwk0WR+E7O+tWRPjm/IBXva9R9g
Db/wGxvYxB+sOmsN9xojxu37aP8Y35VXrJfd+cMdP1HGMpYwpLfAJRQxqrvI
3/UP3J3nU+f/xxmm9E+4imnftXTxBr/n9Ar2jch5HuZ5fsff+CVnuY9z/EV/
11lfOeUbs/wMRfO0XOB/5qfe0Ca/kGvNn3NSPrG+Y565+O/lz/wU8+a9cp63
zat6CTktXzLv5Vb5yPqW+Yy1TvkT9+C+tzzhVn7j/Yd6d7yzwq/lV3iLfhxb
OwcFQmCl
          "]]},
        RowBox[{"-", "0.0518`"}]],
       Annotation[#, -0.0518, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtL22EcxfGfL8Ak5qagLUi9VKFWQafepOAtcRK7SQe3LpUU1MTo5KS2
3VvBO4hodHbRuSVCV23H+i4c/GQ4fJ9znnOePySd8wszn5siYo1uEhGtLRGf
8hFtmKJEOuI734w1flsnn43I0TQVqS4r5yIqtEjLtESn+j/dHdlOZ3TpJhnx
wXv/ZAXbb7KhVMQWDuJXPLE7dH/Q6PB1m1mbv/yUzabspe4GDuCx/rrOPf7G
L3q/8D//wv0IDlNJ3i8vOa9656n9KH/h/A4XfaNKK1Tky1ihZerS3dbrk7/n
H7xV5Z/I38rOnd9gDZfcF5wvnScbv5XOcz6DvZjFj7jvjT3q4F/z43Z3/IRN
WtYjS2E3tuAc7rrfoXb+FT9mc8uP2yRlXbJmfIYJvJZf0Q//QxYzdEan9Ice
AeJ7PXo=
          "]]},
        RowBox[{"-", "0.0555`"}]],
       Annotation[#, -0.0555, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwN0EcyRFEUgOEj041uoeXUcs4sQJjL5iaMUCWO7cAmpD3ImYElWInwDb76
69x37ntVL7uxs7SdExG7LJRHnFdHXHDGFZe8Oz+tiNhPRXyZD/TQfMCiZ3mZ
iHxyKaSAazsJTVJECcUs2S/TckpJk+LGfrVmqKCKSpbt12odNTRQz639Zr3X
Rr3TJl2x36qP5hZ90jZ90A590aw+a7uu2u/SN3On9tDNq3lAB+mlnz7W7A/r
CEOMMcqn/SmdZpxJJli3f+Q/HTOYjpjx/2b5cJ6odE/nzPN8V0XsubPpbF9/
nf3xQ445OPGdpHulZLxzgi370+Z/TJ4uYg==
          "]]},
        RowBox[{"-", "0.0592`"}]],
       Annotation[#, -0.0592, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0VkyXHEcBeCfkBhinkpUqUo2kOCNN1Wq8ErZgAXwYg95MCaabmOCYgc8
0IZl2IB5jFkTfP3w1enzv6du3Xv7W99Ad39ORAzytSxirSZinUR1xCQNzn5U
RqTLI/adH3JAr/Pmqogm5l1v1ev9/mnXJdP6jPNZ5litiEiVRlS657TeadPB
rns9O3uhnAqSdsv2U7JMLyXDEzv2D/KRYkqyz2m3ZJ+Qn/Ui7rlj2/5G3lJA
IRN2i/a/Zb7+iWv+sWV/Ka/I4yO/7P7aj8tc/QMXnJO2P5VnBDmM2f2xH5Vv
3vGVE+fHbGa/oTzKvrPz/4zYLdgPy2c9w4Hr+2zY1+lfSPpuKYbsGvWe7H8j
v7Ni26K310bs2bTp7zCSSlE=
          "]]},
        RowBox[{"-", "0.0629`"}]],
       Annotation[#, -0.0629, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TkzX2EcxfGfnQYJoxNbbH+78AIsMTrD6BkFqSK1QWJXM3QKhta+hMRr
UJohY8/78LnFme89zzm/5977PBVjk0Pf0yJiirIKIkYLIzpKIt7yI24+RKxZ
G+DXcZD6PQ9hHm3JN/RHrG1iKc0XRezLHoojDrCLn8b0jxGf5K1Ya66OyvgF
+aH8Uf8Iu/kZzNArl7dhvW6KKvhF+bH8Sf8Ee/hZzNSrlLdjg24jVfFL8lP5
s/4Z9vI/MUvvs/wLNuk2UzW/LD+Xv+hf4Ff+F2br1SRngy26rVTLr8h/y1/1
L7GPn8McvTp5J7bptlM9v5qch/O60nkz8wf3ZLuUq5tKviH5B8zDW7pL9jHz
35308tv8KL+Dw+b/2ueaxmmCvtEP6//k98n9mCnjc72jCd8BP/M72A==
          "]]},
        RowBox[{"-", "0.0666`"}]],
       Annotation[#, -0.0666, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdVX801WcYpw7ZbUK02pRi6/i11hwTW8c+jcTNklRkUUY1mSzFEW5JJVId
w10uRYqKyI/8uCy8kmJcWtO6Sm7kys9J6cei1brX9/mn55x77vc97/s+7/N8
nuf5fAx9f3HbOkVFRSX83U/xP2mjoK8Cx+4IvYLHSLIrLd6Rv5p5JdQ9N/F6
DLUTM20a761nPGnWTlveY7Se3m89ItvIKgxihtZUjKB5XZh+/BMfpqd0MAJN
YVNT7/NtLNhWceMfuLbNi/huPJC1SBQ2DP6RCqFLVDAzVT4wjEET30BBdAhT
eHvnEkcbpy+/eDCMKaJx7B7E5/5l+u0xEUzpznYQLdM2j6nF7WVpqQobgHjt
od6PHfazFyYKh/2I+9Tz1pc3opmbMsB+bBhbVO3oeJBN5tcH02tTcjc1HuLy
6cOrJKkwlH+YbVPaI5gUnRtObYpl154rHPbCo2X38hrnI2y+MsBeyK2XaoxK
4lmkMmE5yqZpP1N3OcaU7qQ9MI4f2q198zizVFoPOoNv679dncCUcCY8RFVF
P/P1/5UNK9Pths2DngsSk0TmNJkwdNe2T9gPJLJshbusLnxQWJHck5vEJqvU
BeO+iEQWkMzhL8O8s/p5MnMhh3cndL2r6v8bFnL43kebY4y75NJvHJ738NVh
4bhm0AkOv7vIGp9TvWVRCodXO1qctdZJh1I4fKTgv9Cwsr8o4vD4G9GvQp80
bk/l8r+NmGktBZHmaVy+bdAJj3YKHU3j8ruFORP3PzGqOMnl8yfMw81V+yJP
cfG3IsvVx/muZToXrwQdsiD+jPZ0Lr4/cKzVXpzjk8HF04ApZnO/M7uewb1f
j3vtS+5oTWRw711Fkd9MufvLDM5/DUSmbuolBRmcv0qIDW7uCZxF90uRc40n
FnyWzp0vwIUV9obeDSe587k4qPqgMSUvjTufjbwgmGnNTeXOZ+D09jaj4YUp
3L4Qv2tqqdvXCdn4voCqkOQ4DAxldO/6MZG9zn3y1yrf/bCQObjMsjvOrXci
3j6RfyY2hlv7wIRldlW/ieLWrphaLmva4b6HWy+DdeBG4d0Fu5nKe0b7XzSY
a9ua+oHuG/MFyc5xQSD/LpV1V7zqw0Dv/yyEafaKA6D4HqoL9s0xPAaK3/7p
g5Yt/CRQfm5R1XUHJlJB+XdYGV6y6M8E4TPf+nL3aY1sEH7p8byjy/LOg/Bd
tqK3uehFDgh/n59e7YyS54PqI2y2upK9oAhUv0dZdxz0E4tB9a3a6Hm2RHIZ
VH9+ZaZffkcJqD9MCr+ZPVRbCuofET/crTmyDNRfM94urxVoloP6jy8TrtIT
lIP6U08iOmDVWg7q34bgE04beGJQf//r45dze4kY1P+dcq/FTz3EoPngebe1
aO0Qg+ZHJAy2k4aIQfO1cqp8dOTdPs1fwkr3wTfuYtB82uVnrXZdLAbNr9Mb
n67Kl+Wg+c4Lja3kF1P8Mhg800nneZeD+MGzfc/6D1+Xgfgj3sOzQy+hDMQv
TfcNAxw/KgPxT9PR72sLE0tB/PRQLLVZo1oK4q9dBVX4emsJiN9GjP0EomrC
Xw7J0rHZ86dfBvGj9UKt8TiXYhB/qt1YXyuKKwLxq4GKRNsopBDEv2bCLn+j
hksgfi4Nrv9BwMsH8XekZUDNym8vgvg95Wq1tMw3B8T/ez1yHQbCzoP0YZVU
13v2vmyQfqRvatXJCD0L0hcNtXP+vZsyQfrjXVE9UhNyCqRP122idHk6IpB+
deZstuQlJ4P0rSRs6IzR2HGQ/o1bnDKcHnsIpI+x1jdyLQRRIP2Ml5tHC9tD
QfqqWtNRFezmj/f1938r+8dg
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->504,
  PlotRange->{{0.95, 1.05}, {-0.03, 0.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 313},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->33112314]
}, Open  ]],

Cell["\<\
Streamlines near the airfoil surface show no waviness, there are no \
streamlines interior to the airfoil and the flow leaves the trailing edge \
smoothly, satisfying the Kutta condition.\
\>", "ExampleText",
 CellID->667775740]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMDoubletConstantDirichlet",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PMDoubletQuadraticDirichlet",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ForceAndMoment",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["PlotSurfacePressureCoefficient",
    BaseStyle->"Link",
    ButtonData->"paclet:Aerodynamics/ref/PlotSurfacePressureCoefficient"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " . "
}], "SeeAlso",
 CellID->63093083]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["3.1 Introduction To Panel Methods",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["3.2 Validation Example",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/ValidationExample"]], "Tutorials",
 CellID->499723042],

Cell[TextData[ButtonBox["3.3 Implementation",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/Implementation"]], "Tutorials",
 CellID->336290191],

Cell[TextData[ButtonBox["3.5 Convergence and Timing",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/ConvergenceAndTiming"]], "Tutorials",
 CellID->351529306],

Cell[TextData[ButtonBox["3.6 Aerodynamic Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"]], "Tutorials",
 CellID->168730094],

Cell[TextData[ButtonBox["3.7 Analysis of an Airfoil",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/AnalysisOfAnAirfoil"]], "Tutorials",
 CellID->161789207],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "Tutorials",
 CellID->8122694]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "MoreAbout",
 CellID->188537348]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"PMVortexLinearNeumann - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 58, 38.2194000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "PMVortexLinearNeumann[r_p, \\[Alpha]] implements a panel method for \
uniform flow over an airfoil using vortex panels of linearly varying strength \
and external Neumann boundary conditions. Panel endpoints describing the \
discretized airfoil are located at r_p and the angle of attack of the airfoil \
is \\[Alpha]. The function returns strength parameters for the circulation \
density function, locations of collocation points and surface speeds at \
collocation points.", "synonyms" -> {}, "title" -> "PMVortexLinearNeumann", 
    "type" -> "Symbol", "uri" -> "Aerodynamics/ref/PMVortexLinearNeumann"}, 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[12394, 376, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->296522323]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 284444, 5748}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[602, 21, 76, 1, 70, "SymbolColorBar"],
Cell[681, 24, 191, 5, 70, "LinkTrail"],
Cell[875, 31, 4234, 91, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5134, 126, 64, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[5201, 129, 1355, 34, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6593, 168, 579, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->92080746],
Cell[7175, 187, 251, 8, 70, "Notes",
 CellID->1067943069],
Cell[7429, 197, 1436, 50, 70, "Notes",
 CellID->275911084],
Cell[8868, 249, 1213, 44, 70, "Notes",
 CellID->35560001],
Cell[10084, 295, 705, 19, 70, "Notes",
 CellID->631099542],
Cell[10792, 316, 569, 19, 70, "Notes",
 CellID->1720708],
Cell[11364, 337, 396, 15, 70, "Notes",
 CellID->164568021],
Cell[11763, 354, 71, 1, 70, "Notes",
 CellID->443257480],
Cell[11837, 357, 520, 14, 70, "3ColumnTableMod",
 CellID->409281092]
}, Closed]],
Cell[CellGroupData[{
Cell[12394, 376, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->296522323],
Cell[CellGroupData[{
Cell[12880, 393, 148, 5, 70, "ExampleSection",
 CellID->511814029],
Cell[13031, 400, 132, 6, 70, "ExampleText",
 CellID->395972740],
Cell[13166, 408, 99, 3, 70, "Input",
 CellID->76286106],
Cell[13268, 413, 301, 8, 70, "ExampleText",
 CellID->48545141],
Cell[CellGroupData[{
Cell[13594, 425, 361, 11, 70, "Input",
 CellID->43842758],
Cell[13958, 438, 220, 7, 36, "Output",
 CellID->366275460]
}, Open  ]],
Cell[14193, 448, 263, 5, 70, "ExampleText",
 CellID->60751918],
Cell[14459, 455, 217, 7, 70, "Input",
 CellID->493524749],
Cell[14679, 464, 86, 1, 70, "ExampleText",
 CellID->711853039],
Cell[14768, 467, 147, 5, 70, "Input",
 CellID->847786885],
Cell[14918, 474, 546, 19, 70, "ExampleText",
 CellID->20624687],
Cell[15467, 495, 262, 8, 70, "Input",
 CellID->53812608],
Cell[15732, 505, 834, 21, 70, "ExampleText",
 CellID->342367202],
Cell[16569, 528, 751, 23, 70, "Input",
 CellID->133172956],
Cell[17323, 553, 482, 8, 70, "ExampleText",
 CellID->76299467],
Cell[CellGroupData[{
Cell[17830, 565, 1028, 26, 70, "Input",
 CellID->808226483],
Cell[18861, 593, 54503, 957, 70, "Output",
 CellID->9226975]
}, Open  ]],
Cell[73379, 1553, 289, 6, 70, "ExampleText",
 CellID->14395635],
Cell[73671, 1561, 389, 7, 70, "ExampleText",
 CellID->80454523],
Cell[CellGroupData[{
Cell[74085, 1572, 440, 14, 70, "Input",
 CellID->499718542],
Cell[74528, 1588, 260, 8, 36, "Output",
 CellID->233574312]
}, Open  ]],
Cell[74803, 1599, 143, 4, 70, "ExampleText",
 CellID->753558053],
Cell[74949, 1605, 161, 6, 70, "Input",
 CellID->435840926],
Cell[75113, 1613, 274, 5, 70, "ExampleText",
 CellID->139054009],
Cell[CellGroupData[{
Cell[75412, 1622, 448, 12, 47, "Input",
 CellID->671472236],
Cell[75863, 1636, 7116, 124, 351, "Output",
 CellID->39437295]
}, Open  ]],
Cell[82994, 1763, 167, 4, 70, "ExampleText",
 CellID->571494656],
Cell[CellGroupData[{
Cell[83186, 1771, 606, 19, 70, "Input",
 CellID->42630738],
Cell[83795, 1792, 365, 13, 36, "Output",
 CellID->139254121]
}, Open  ]],
Cell[84175, 1808, 399, 7, 70, "ExampleText",
 CellID->24035690],
Cell[CellGroupData[{
Cell[84599, 1819, 331, 10, 70, "Input",
 CellID->34907031],
Cell[84933, 1831, 337, 9, 36, "Output",
 CellID->66217255]
}, Open  ]],
Cell[85285, 1843, 323, 6, 70, "ExampleText",
 CellID->4111782],
Cell[CellGroupData[{
Cell[85633, 1853, 236, 8, 70, "Input",
 CellID->274981366],
Cell[85872, 1863, 258, 8, 36, "Output",
 CellID->389260845]
}, Open  ]],
Cell[86145, 1874, 164, 4, 70, "ExampleText",
 CellID->328772922],
Cell[CellGroupData[{
Cell[86334, 1882, 353, 12, 70, "Input",
 CellID->762946865],
Cell[86690, 1896, 309, 10, 36, "Output",
 CellID->70763756]
}, Open  ]],
Cell[87014, 1909, 139, 4, 70, "ExampleText",
 CellID->251970426]
}, Open  ]],
Cell[CellGroupData[{
Cell[87190, 1918, 221, 7, 70, "ExampleSection",
 CellID->1293636265],
Cell[CellGroupData[{
Cell[87436, 1929, 251, 7, 70, "ExampleSubsection",
 CellID->421192202],
Cell[87690, 1938, 216, 5, 70, "ExampleText",
 CellID->5610347],
Cell[87909, 1945, 154, 5, 70, "Input",
 CellID->559405563],
Cell[88066, 1952, 199, 4, 70, "ExampleText",
 CellID->444428628],
Cell[CellGroupData[{
Cell[88290, 1960, 555, 18, 70, "Input",
 CellID->249332617],
Cell[88848, 1980, 5843, 103, 70, "Output",
 CellID->220597783]
}, Open  ]],
Cell[94706, 2086, 120, 3, 70, "ExampleText",
 CellID->176584194],
Cell[94829, 2091, 441, 13, 70, "Input",
 CellID->343427282],
Cell[95273, 2106, 138, 4, 70, "ExampleText",
 CellID->126580234],
Cell[CellGroupData[{
Cell[95436, 2114, 310, 10, 70, "Input",
 CellID->274596420],
Cell[95749, 2126, 6362, 112, 70, "Output",
 CellID->4533229]
}, Open  ]],
Cell[102126, 2241, 156, 4, 70, "ExampleText",
 CellID->33075010],
Cell[CellGroupData[{
Cell[102307, 2249, 672, 20, 70, "Input",
 CellID->252090154],
Cell[102982, 2271, 260, 8, 36, "Output",
 CellID->137745002]
}, Open  ]],
Cell[103257, 2282, 198, 4, 70, "ExampleText",
 CellID->169245216],
Cell[CellGroupData[{
Cell[103480, 2290, 305, 12, 70, "Input",
 CellID->208999159],
Cell[103788, 2304, 244, 8, 36, "Output",
 CellID->342113056]
}, Open  ]],
Cell[104047, 2315, 388, 7, 70, "ExampleText",
 CellID->511124957],
Cell[CellGroupData[{
Cell[104460, 2326, 638, 19, 70, "Input",
 CellID->59705953],
Cell[105101, 2347, 9929, 170, 70, "Output",
 CellID->28737660]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[115091, 2524, 223, 7, 70, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[115339, 2535, 229, 7, 70, "ExampleSubsection",
 CellID->1295379749],
Cell[115571, 2544, 436, 7, 70, "ExampleText",
 CellID->120830056],
Cell[116010, 2553, 646, 20, 70, "Input",
 CellID->210128799],
Cell[116659, 2575, 259, 5, 70, "ExampleText",
 CellID->112154987],
Cell[CellGroupData[{
Cell[116943, 2584, 938, 31, 70, "Input",
 CellID->295212498],
Cell[117884, 2617, 398, 13, 39, "Output",
 CellID->459621414]
}, Open  ]],
Cell[118297, 2633, 399, 7, 70, "ExampleText",
 CellID->3193481],
Cell[118699, 2642, 97, 1, 70, "ExampleText",
 CellID->79242491],
Cell[CellGroupData[{
Cell[118821, 2647, 1149, 34, 70, "Input",
 CellID->23699121],
Cell[119973, 2683, 8805, 156, 177, "Output",
 CellID->1101057]
}, Open  ]],
Cell[128793, 2842, 813, 12, 70, "ExampleText",
 CellID->189149207]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[129655, 2860, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[129889, 2869, 323, 6, 70, "ExampleText",
 CellID->416625656],
Cell[130215, 2877, 205, 4, 70, "ExampleText",
 CellID->32738591],
Cell[CellGroupData[{
Cell[130445, 2885, 386, 10, 70, "Input",
 CellID->112529997],
Cell[130834, 2897, 5180, 92, 70, "Output",
 CellID->126312528]
}, Open  ]],
Cell[136029, 2992, 150, 4, 70, "ExampleText",
 CellID->390242666],
Cell[CellGroupData[{
Cell[136204, 3000, 212, 7, 70, "Input",
 CellID->238007975],
Cell[136419, 3009, 345, 12, 36, "Output",
 CellID->824618374]
}, Open  ]],
Cell[136779, 3024, 151, 4, 70, "ExampleText",
 CellID->25666953],
Cell[CellGroupData[{
Cell[136955, 3032, 763, 23, 70, "Input",
 CellID->592619],
Cell[137721, 3057, 259, 8, 36, "Output",
 CellID->428331775]
}, Open  ]],
Cell[137995, 3068, 90, 1, 70, "ExampleText",
 CellID->46735897],
Cell[138088, 3071, 156, 4, 70, "ExampleText",
 CellID->492689119],
Cell[CellGroupData[{
Cell[138269, 3079, 1741, 46, 70, "Input",
 CellID->266881112],
Cell[140013, 3127, 270, 8, 36, "Output",
 CellID->183231109],
Cell[140286, 3137, 67521, 1160, 70, "Output",
 CellID->674448689]
}, Open  ]],
Cell[207822, 4300, 238, 5, 70, "ExampleText",
 CellID->482308682],
Cell[208063, 4307, 155, 4, 70, "ExampleText",
 CellID->254018838],
Cell[CellGroupData[{
Cell[208243, 4315, 1163, 36, 70, "Input",
 CellID->230503503],
Cell[209409, 4353, 259, 8, 36, "Output",
 CellID->134517645]
}, Open  ]],
Cell[209683, 4364, 168, 4, 70, "ExampleText",
 CellID->88671999],
Cell[209854, 4370, 86, 1, 70, "ExampleText",
 CellID->437823294],
Cell[CellGroupData[{
Cell[209965, 4375, 1477, 38, 70, "Input",
 CellID->240459914],
Cell[211445, 4415, 67552, 1162, 70, "Output",
 CellID->33112314]
}, Open  ]],
Cell[279012, 5580, 238, 5, 70, "ExampleText",
 CellID->667775740]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279299, 5591, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[279719, 5605, 906, 30, 70, "SeeAlso",
 CellID->63093083]
}, Open  ]],
Cell[CellGroupData[{
Cell[280662, 5640, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[281084, 5654, 190, 4, 70, "Tutorials",
 CellID->341631938],
Cell[281277, 5660, 167, 3, 70, "Tutorials",
 CellID->499723042],
Cell[281447, 5665, 160, 3, 70, "Tutorials",
 CellID->336290191],
Cell[281610, 5670, 177, 4, 70, "Tutorials",
 CellID->351529306],
Cell[281790, 5676, 182, 4, 70, "Tutorials",
 CellID->168730094],
Cell[281975, 5682, 173, 3, 70, "Tutorials",
 CellID->161789207],
Cell[282151, 5687, 158, 3, 70, "Tutorials",
 CellID->8122694]
}, Open  ]],
Cell[CellGroupData[{
Cell[282346, 5695, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[282768, 5709, 149, 3, 70, "MoreAbout",
 CellID->188537348]
}, Open  ]],
Cell[282932, 5715, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

