(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15572,        504]
NotebookOptionsPosition[     12337,        404]
NotebookOutlinePosition[     13965,        446]
CellTagsIndexPosition[     13880,        441]
WindowTitle->UniformFlow - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"2.2 Point Singularities\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/PointSingularities"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Influence Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/guide/InfluenceCoefficients"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/ref/UniformFlow\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/ref/UniformFlow"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                
                "http://reference.wolfram.com/mathematica/Aerodynamics/ref/\
UniformFlow.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/ref/UniformFlow", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["UniformFlow", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["UniformFlow",
        BaseStyle->"Link",
        ButtonData->"paclet:Aerodynamics/ref/UniformFlow"], "[", 
       RowBox[{
        StyleBox["n", "TI"], ",", 
        StyleBox["\[Alpha]", "TR"]}], "]"}]], "InlineFormula"],
     " \[LineSeparator]computes a collection of ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     " uniform velocity vectors inclined at an angle ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     " to the ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " axis."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"UniformFlow\[Phi]", "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["f", "TI"]], ",", 
        StyleBox["\[Alpha]", "TR"]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]computes a list of velocity-potentials at ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["f", "TI"]]], "InlineFormula"],
     " for uniform flow inclined at an angle ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     " to the ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " axis. "
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"UniformFlow\[Psi]", "[", 
       RowBox[{
        SubscriptBox[
         StyleBox["r", "TI"], 
         StyleBox["f", "TI"]], ",", 
        StyleBox["\[Alpha]", "TR"]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]computes a list of stream-functions at ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["r", "TI"], 
       StyleBox["f", "TI"]]], "InlineFormula"],
     " for uniform flow inclined at an angle ",
     Cell[BoxData[
      StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
     " to the ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " axis. "
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{"Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], 
     Dynamic[
      If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
       RGBColor[0.92, 1, 0.59], None]], {
      Dynamic[
       If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
        RGBColor[0.92, 1, 0.59], None]]}}, "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->960183584],

Cell[TextData[{
 "The characteristic speed for nondimensionalization is the speed of the \
uniform onset flow.  The output of UniformFlow is a collection of unit \
vectors of the data type ",
 Cell[BoxData[
  ButtonBox["CartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/CartesianVectors"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->114577514],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->79625591],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "ExampleText",
 CellID->513831186],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->66474307],

Cell["Specify an arbitrary field point.", "ExampleText",
 CellID->659456463],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rField", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "x", "}"}], ",", 
     RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->64953589],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "x", "}"}], "\[UpArrow]", 
   RowBox[{"{", "z", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{$CellContext`x}, \
{$CellContext`z}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->10475129]
}, Open  ]],

Cell[TextData[{
 "Compute the velocity, velocity potential and stream function for uniform \
flow inclined at an angle ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " to the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " axis.  Extraneous list brackets are suppressed to give results in the \
simplest form."
}], "ExampleText",
 CellID->344772720],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u\[Infinity]", ",", "w\[Infinity]"}], "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Components", "[", 
     RowBox[{"UniformFlow", "[", 
      RowBox[{"1", ",", "\[Alpha]"}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Phi]\[Infinity]", "}"}], "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"UniformFlow\[Phi]", "[", 
     RowBox[{"rField", ",", "\[Alpha]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]\[Infinity]", "}"}], "=", 
   RowBox[{"UniformFlow\[Psi]", "[", 
    RowBox[{"rField", ",", "\[Alpha]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "u\[Infinity]", ",", "w\[Infinity]", ",", "\[Phi]\[Infinity]", ",", 
   "\[Psi]\[Infinity]"}], "}"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->374015860],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", 
   RowBox[{"Sin", "[", "\[Alpha]", "]"}], ",", 
   RowBox[{
    RowBox[{"x", " ", 
     RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], "+", 
    RowBox[{"z", " ", 
     RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"z", " ", 
     RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], "-", 
    RowBox[{"x", " ", 
     RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}]}], "}"}]], "Output",
 ImageSize->{369, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->385841835]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["2.2 Point Singularities",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/PointSingularities"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/TableOfContents"]], "Tutorials",
 CellID->182133350]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/InfluenceCoefficients"]], "MoreAbout",
 CellID->692903178]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"UniformFlow - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 59, 4.2870000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Paclet Symbol", "language" -> "en", "paclet" -> 
    "Aerodynamics", "status" -> "", "summary" -> 
    "UniformFlow[n, \\[Alpha]] computes a collection of n uniform velocity \
vectors inclined at an angle \\[Alpha] to the x axis. UniformFlow\\[Phi][r_f, \
\\[Alpha]] computes a list of velocity-potentials at r_f for uniform flow \
inclined at an angle \\[Alpha] to the x axis. UniformFlow\\[Psi][r_f, \
\\[Alpha]] computes a list of stream-functions at r_f for uniform flow \
inclined at an angle \\[Alpha] to the x axis. ", "synonyms" -> {}, "title" -> 
    "UniformFlow", "type" -> "Symbol", "uri" -> 
    "Aerodynamics/ref/UniformFlow"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[7294, 216, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->114577514]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 13737, 434}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[592, 21, 76, 1, 70, "SymbolColorBar"],
Cell[671, 24, 191, 5, 70, "LinkTrail"],
Cell[865, 31, 2768, 64, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3658, 99, 54, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[3715, 102, 2544, 75, 70, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6296, 182, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->960183584],
Cell[6879, 201, 378, 10, 70, "Notes",
 CellID->1067943069]
}, Closed]],
Cell[CellGroupData[{
Cell[7294, 216, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->114577514],
Cell[CellGroupData[{
Cell[7780, 233, 147, 5, 70, "ExampleSection",
 CellID->79625591],
Cell[7930, 240, 132, 6, 70, "ExampleText",
 CellID->513831186],
Cell[8065, 248, 99, 3, 70, "Input",
 CellID->66474307],
Cell[8167, 253, 76, 1, 70, "ExampleText",
 CellID->659456463],
Cell[CellGroupData[{
Cell[8268, 258, 244, 8, 70, "Input",
 CellID->64953589],
Cell[8515, 268, 390, 13, 36, "Output",
 CellID->10475129]
}, Open  ]],
Cell[8920, 284, 385, 11, 70, "ExampleText",
 CellID->344772720],
Cell[CellGroupData[{
Cell[9330, 299, 912, 28, 70, "Input",
 CellID->374015860],
Cell[10245, 329, 608, 19, 36, "Output",
 CellID->385841835]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10914, 355, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[11336, 369, 169, 3, 70, "Tutorials",
 CellID->341631938],
Cell[11508, 374, 160, 3, 70, "Tutorials",
 CellID->182133350]
}, Open  ]],
Cell[CellGroupData[{
Cell[11705, 382, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[12127, 396, 168, 3, 70, "MoreAbout",
 CellID->692903178]
}, Open  ]],
Cell[12310, 402, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

