(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     42400,       1126]
NotebookOptionsPosition[     36527,        955]
NotebookOutlinePosition[     39345,       1014]
CellTagsIndexPosition[     39302,       1011]
WindowTitle->1.3 Airfoils From Thickness And Camber Properties - Wolfram \
Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.2 Airfoils From Data Files\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"], "\<\"1.4 \
Airfoils From Conformal Mapping\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"], \
"\<\"Table Of Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"AirfoilGeometry\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/guide/AirfoilGeometry"], "\<\"Aerodynamics\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/Aerodynamics"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/\
AirfoilsFromThicknessAndCamberProperties\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
             "Aerodynamics/tutorial/AirfoilsFromThicknessAndCamberProperties"]\
}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/AirfoilsFromThicknessAndCamberProperties.html"], StandardForm]], 
              "Input", TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/AirfoilsFromThicknessAndCamberProperties",
              ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["1.3 Airfoils From Thickness And Camber Properties", "Title",
 CellID->509267359],

Cell[TextData[{
 "During the 1930s and 1940s, the National Advisory Committee for Aeronautics \
(NACA) developed and tested families of airfoils based on systematic \
variations of thickness and camber.  Algebraic equations were used to \
prescribe the thickness and camber of an airfoil, and the upper and lower \
surfaces of the airfoil were established by wrapping a thickness envelope \
around a camber line.  See Section 4.3 of ",
 ButtonBox["Anderson (1984)",
  BaseStyle->"Hyperlink",
  ButtonData->{"References.nb", "anderson1984"}],
 " or Chapter 6 of ",
 ButtonBox["Abbott and von Doenhoff (1959)",
  BaseStyle->"Hyperlink",
  ButtonData->{"References.nb", "abbott1959"}],
 " for more details."
}], "Text",
 CellID->237225321],

Cell[TextData[{
 "The example used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " for airfoils specified by thickness and camber properties is the NACA \
four-digit family of airfoils.  If the four-digit identification is written \
as ",
 Cell[BoxData[
  RowBox[{
   StyleBox["id", "TI"], "=", 
   StyleBox["ijkl", "TI"]}]], "InlineFormula"],
 ", then ",
 Cell[BoxData[
  StyleBox["i", "TI"]], "InlineFormula"],
 " specifies maximum camber in percent chord, ",
 Cell[BoxData[
  StyleBox["j", "TI"]], "InlineFormula"],
 " specifies location of maximum camber in tenths chord and ",
 Cell[BoxData[
  StyleBox["kl", "TI"]], "InlineFormula"],
 " specifies maximum thickness in percent chord. "
}], "Text",
 CellID->3719437],

Cell[TextData[{
 "The input arguments for the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["NACA4DigitAirfoil",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/NACA4DigitAirfoil"]], "InlineFormula"],
 " are the airfoil identification number and a list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " values at which thickness and camber properties are to be computed.  The \
output of the function is the list ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    StyleBox["x", "TI"], ",", 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["t", "TI"]], ",", 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["t", "TI"]], ",", " ", 
    SubscriptBox[
     StyleBox["z", "TI"], 
     StyleBox["c", "TI"]], ",", 
    SubscriptBox[
     StyleBox["\[Theta]", "TR"], 
     StyleBox["c", "TI"]]}], "}"}]], "InlineFormula"],
 ", where ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " is the list of values input to the function, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["z", "TI"], 
   StyleBox["t", "TI"]]], "InlineFormula"],
 " is the list of thickness values, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["\[Theta]", "TR"], 
   StyleBox["t", "TI"]]], "InlineFormula"],
 " is the list of angles that the thickness line makes with the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " axis, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["z", "TI"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " is the list of camber values and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["\[Theta]", "TR"], 
   StyleBox["c", "TI"]]], "InlineFormula"],
 " is the list of angles that the camber line makes with the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis."
}], "Text",
 CellID->193521988],

Cell[TextData[{
 "The list of thickness and camber values are input to ",
 Cell[BoxData[
  ButtonBox["AirfoilSurfacePoints",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"]], 
  "InlineFormula"],
 " to compute a collection of vectors locating points on the airfoil surface. \
 Note that this function is not limited to the NACA four-digit airfoil, but \
could be used for any airfoil defined by a list of thickness and camber \
proprieties of the same form."
}], "Text",
 CellID->119120002],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->278144368],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->2058623809],

Cell[CellGroupData[{

Cell["1.3.1 NACA 4412 airfoil", "Section",
 CellID->780127955],

Cell[TextData[{
 "The input list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values for the function NACA4DigitAirfoil controls the number of points \
computed on the airfoil surface.  In this example, a relatively small \
discretization number is used.  The ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["NDiscretizeUnitSegment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/NDiscretizeUnitSegment"]], 
  "InlineFormula"],
 " is used as a convenience to generate the list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values.  The value HalfCosineSpacing for the option Layout concentrates \
points near the leading edge."
}], "Text",
 CellID->78760192],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xList", "=", 
  RowBox[{"NDiscretizeUnitSegment", "[", 
   RowBox[{"4", ",", 
    RowBox[{"Layout", "\[Rule]", "HalfCosineSpacing"}]}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->36949950],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.07612046748871326`", ",", "0.2928932188134524`", ",", 
   "0.6173165676349102`", ",", "0.9999999999999999`"}], "}"}]], "Output",
 ImageSize->{265, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->876142913]
}, Open  ]],

Cell[TextData[{
 "Use the list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values and the identification number for the airfoil to compute lists of \
thickness and camber properties."
}], "Text",
 CellID->158135470],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"properties", "=", 
  RowBox[{"NACA4DigitAirfoil", "[", 
   RowBox[{"4412", ",", "xList"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->136038124],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.07612046748871326`", ",", "0.2928932188134524`", ",", 
     "0.6173165676349102`", ",", "0.9999999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.04224482966144003`", ",", "0.060006295329734644`", ",", 
     "0.044186384497731004`", ",", "0.0012599999999999944`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.5707963267948966`", ",", "0.21461900569014944`", ",", 
     "0.0031819755314542327`", ",", 
     RowBox[{"-", "0.08478225618956567`"}], ",", 
     RowBox[{"-", "0.13939996933185558`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.013775512105067588`", ",", "0.037132034355964245`", ",", 
     "0.034752612159042386`", ",", "1.2335811384723961`*^-17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.19739555984988075`", ",", "0.16054603550811242`", ",", 
     "0.05350228208284681`", ",", 
     RowBox[{"-", "0.04825508083145211`"}], ",", 
     RowBox[{"-", "0.132551532296674`"}]}], "}"}]}], "}"}]], "Output",
 ImageSize->{387, 90},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->252736694]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["AirfoilSurfacePoints",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"]], 
  "InlineFormula"],
 " to compute a collection of vectors locating points on the surface of the \
airfoil from these lists of thickness and camber properties."
}], "Text",
 CellID->89603494],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rP", "=", 
  RowBox[{"AirfoilSurfacePoints", "[", "properties", "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->175130362],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.9998334737126852`", ",", "0.6151851774798535`", ",", 
     "0.29610216111173066`", ",", "0.08287360953113432`", ",", "0.`", ",", 
     "0.0693673254462922`", ",", "0.2896842765151742`", ",", 
     "0.6194479577899669`", ",", "1.0001665262873145`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.0012489471548601018`"}], ",", 
     RowBox[{"-", "0.009382337155398324`"}], ",", 
     RowBox[{"-", "0.02278839762283289`"}], ",", 
     RowBox[{"-", "0.027926055079859263`"}], ",", "0.`", ",", 
     "0.055477079289994444`", ",", "0.09705246633476139`", ",", 
     "0.0788875614734831`", ",", "0.0012489471548601265`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.9998334737126852, 
    0.6151851774798535, 0.29610216111173066`, 0.08287360953113432, 0., 
    0.0693673254462922, 0.2896842765151742, 0.6194479577899669, 
    1.0001665262873145`}, {-0.0012489471548601018`, -0.009382337155398324, \
-0.02278839762283289, -0.027926055079859263`, 0., 0.055477079289994444`, 
    0.09705246633476139, 0.0788875614734831, 0.0012489471548601265`}], 
   "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{583, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->72223849]
}, Open  ]],

Cell[TextData[{
 "To approximate the geometry of the airfoil, use a relatively large list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values, and note that the functions can be nested."
}], "Text",
 CellID->49184558],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"NACA4DigitAirfoil", "[", 
     RowBox[{"4412", ",", 
      RowBox[{"NDiscretizeUnitSegment", "[", "500", "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->100398123],

Cell["\<\
Prepare and show graphics.  The coarsely discretized airfoil is plotted using \
a red line.\
\>", "Text",
 CellID->154464187],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gr", "=", 
   RowBox[{"PlotAirfoil", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grP", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"PlotStyle", "\[Rule]", " ", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gr", ",", "grP"}], "]"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->11328373],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3Q2UlNV9x/Ftq8AxNWKKSo0Wi5G3FoJoIlmL4CGkIEkAhSwGsQTosqRE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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->462734487]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3.2 NACA four-digit family of airfoils", "Section",
 CellID->257533491],

Cell["\<\
The effect of the three parameters making up the identification number for a \
NACA four-digit airfoil on the shape of the airfoil can be seen using the \
following dynamic example.  Use the sliders to control the three components \
of the identification number.\
\>", "Text",
 CellID->205773740],

Cell[TextData[{
 "Note:  If graphic does not show properly, quit the kernel and evaluate as \
you would for any ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook."
}], "Text",
 CellID->583385869],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"idS", "=", 
     RowBox[{
      RowBox[{"ToString", "[", "c1", "]"}], "<>", 
      RowBox[{"ToString", "[", "c2", "]"}], "<>", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"c3", ">", "9"}], ",", 
        RowBox[{"ToString", "[", "c3", "]"}], ",", 
        RowBox[{"\"\<0\>\"", "<>", 
         RowBox[{"ToString", "[", "c3", "]"}]}]}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"id", "=", 
     RowBox[{"ToExpression", "[", "idS", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"rP", "=", 
     RowBox[{"AirfoilSurfacePoints", "[", 
      RowBox[{"NACA4DigitAirfoil", "[", 
       RowBox[{"id", ",", 
        RowBox[{"NDiscretizeUnitSegment", "[", 
         RowBox[{"100", ",", 
          RowBox[{"Layout", "\[Rule]", "HalfCosineSpacing"}]}], "]"}]}], 
       "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"PlotAirfoil", "[", 
     RowBox[{"rP", ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"7", " ", "72"}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"\"\<NACA \>\"", "<>", "idS", "<>", "\"\< Airfoil\>\""}]}], 
      ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.05"}], ",", "1.05"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.2"}], ",", "0.301"}], "}"}]}], "}"}]}]}], "]"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c1", ",", "3", ",", 
       RowBox[{"Dynamic", "[", "c1", "]"}]}], "}"}], ",", "0", ",", "9", ",", 
     "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c2", ",", "4", ",", 
       RowBox[{"Dynamic", "[", "c2", "]"}]}], "}"}], ",", "0", ",", "9", ",", 
     "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c3", ",", "15", ",", 
       RowBox[{"Dynamic", "[", "c3", "]"}]}], "}"}], ",", "0", ",", "99", ",",
      "1"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->26946],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c1$$ = 3, $CellContext`c2$$ = 
    4, $CellContext`c3$$ = 15, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c1$$], 3, 
       Dynamic[$CellContext`c1$$]}, 0, 9, 1}, {{
       Hold[$CellContext`c2$$], 4, 
       Dynamic[$CellContext`c2$$]}, 0, 9, 1}, {{
       Hold[$CellContext`c3$$], 15, 
       Dynamic[$CellContext`c3$$]}, 0, 99, 1}}, Typeset`size$$ = {
    504., {127., 131.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`c1$208$$ = 
    0, $CellContext`c2$213$$ = 0, $CellContext`c3$214$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c1$$ = 3, $CellContext`c2$$ = 
        4, $CellContext`c3$$ = 15}, "ControllerVariables" :> {
        Hold[$CellContext`c1$$, $CellContext`c1$208$$, 0], 
        Hold[$CellContext`c2$$, $CellContext`c2$213$$, 0], 
        Hold[$CellContext`c3$$, $CellContext`c3$214$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`idS = StringJoin[
          ToString[$CellContext`c1$$], 
          ToString[$CellContext`c2$$], 
          If[$CellContext`c3$$ > 9, 
           ToString[$CellContext`c3$$], 
           StringJoin["0", 
            ToString[$CellContext`c3$$]]]]; $CellContext`id = 
        ToExpression[$CellContext`idS]; $CellContext`rP = 
        Aerodynamics`AirfoilGeometry`AirfoilSurfacePoints[
          Aerodynamics`AirfoilGeometry`NACA4DigitAirfoil[$CellContext`id, 
           Aerodynamics`AirfoilGeometry`NDiscretizeUnitSegment[
           100, Aerodynamics`AirfoilGeometry`Layout -> 
            Aerodynamics`AirfoilGeometry`HalfCosineSpacing]]]; 
       Aerodynamics`Graphics`PlotAirfoil[$CellContext`rP, ImageSize -> {7 72},
          PlotLabel -> StringJoin["NACA ", $CellContext`idS, " Airfoil"], 
         PlotRange -> {{-0.05, 1.05}, {-0.2, 0.301}}]), 
      "Specifications" :> {{{$CellContext`c1$$, 3, 
          Dynamic[$CellContext`c1$$]}, 0, 9, 1}, {{$CellContext`c2$$, 4, 
          Dynamic[$CellContext`c2$$]}, 0, 9, 1}, {{$CellContext`c3$$, 15, 
          Dynamic[$CellContext`c3$$]}, 0, 99, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{553., {200., 205.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`idS = "3415", $CellContext`id = 
       3415, $CellContext`rP = 
       Aerodynamics`CartesianVectors`CartesianVectors[{0.9998334737126852, 
         0.6151851774798535, 0.29610216111173066`, 0.08287360953113432, 0., 
         0.0693673254462922, 0.2896842765151742, 0.6194479577899669, 
         1.0001665262873145`}, {-0.0012489471548601018`, \
-0.009382337155398324, -0.02278839762283289, -0.027926055079859263`, 0., 
         0.055477079289994444`, 0.09705246633476139, 0.0788875614734831, 
         0.0012489471548601265`}]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 ImageSize->{557, 407},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->495630756]
}, Open  ]]
}, Open  ]],

Cell["", "Section",
 CellID->794950467],

Cell[CellGroupData[{

Cell["1.3.3 Trailing-edge of NACA four-digit airfoils", "Section",
 CellID->140735501],

Cell[TextData[{
 "A characteristic of the NACA four-digit airfoils is that there is a small \
gap at the trailing edge.  This can cause problems for some panel methods.  \
Specify a discretized airfoil with 100 panels and cosine spacing for the \
layout to provide relatively fine discretization near the trailing edge.  \
Note the first and last vectors in the collection do not coincide, but that \
the mean of the two vectors is ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"1", ",", "0"}], "}"}]], "InlineFormula"],
 " as expected for a normalized airfoil."
}], "Text",
 CellID->48076094],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"NACA4DigitAirfoil", "[", 
     RowBox[{"4412", ",", 
      RowBox[{"NDiscretizeUnitSegment", "[", 
       RowBox[{"50", ",", 
        RowBox[{"Layout", "\[Rule]", "CosineSpacing"}]}], "]"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"First", "[", "rP", "]"}], ",", 
   RowBox[{"Last", "[", "rP", "]"}], ",", 
   RowBox[{"Chop", "[", 
    RowBox[{"Mean", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"First", "[", "rP", "]"}], ",", 
       RowBox[{"Last", "[", "rP", "]"}]}], "}"}], "]"}], "]"}]}], 
  "}"}]}], "Input",
 CellLabel->"In[9]:=",
 CellID->508498224],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9998334737126853`", ",", 
     RowBox[{"-", "0.001248947154860081`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0001665262873147`", ",", "0.001248947154860081`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0"}], "}"}]}], "}"}]], "Output",
 ImageSize->{389, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->39441523]
}, Open  ]],

Cell["\<\
By magnifying the region near the trailing edge, the small gap at the \
trailing edge is  noticeable.\
\>", "Text",
 CellID->440842507],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotAirfoil", "[", 
  RowBox[{"rP", ",", 
   RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.75", ",", "1.02"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.06"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->62089316],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c1rVFkaB+AM85f0vyGIC3EhLpoeEBfiJkKY2ehGN7pJNrpRCLppQTqL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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->287171945]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["AirfoilGeometry",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/guide/AirfoilGeometry"]], "TutorialMoreAbout",
 CellID->1567025153],

Cell[TextData[ButtonBox["Aerodynamics",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"]], "TutorialMoreAbout",
 CellID->325103336]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["1.2 Airfoils From Data Files",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromDataFiles"]], "RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["1.4 Airfoils From Conformal Mapping",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"]], \
"RelatedTutorials",
 CellID->610993246],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->554434694]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"1.3 Airfoils From Thickness And Camber Properties - Wolfram \
Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 59, 22.6014000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "During the 1930s and 1940s, the National Advisory Committee for \
Aeronautics (NACA) developed and tested families of airfoils based on \
systematic variations of thickness and camber. Algebraic equations were used \
to prescribe the thickness and camber of an airfoil, and the upper and lower \
surfaces of the airfoil were established by wrapping a thickness envelope \
around a camber line. See Section 4.3 of Anderson (1984) or Chapter 6 of \
Abbott and von Doenhoff (1959) for more details. The example used in \
Aerodynamics for airfoils specified by thickness and camber properties is the \
NACA four-digit family of airfoils. If the four-digit identification is \
written as id=ijkl, then i specifies maximum camber in percent chord, j \
specifies location of maximum camber in tenths chord and kl specifies maximum \
thickness in percent chord. The input arguments for the Aerodynamics function \
NACA4DigitAirfoil are the airfoil identification number and a list of x \
values at which thickness and camber properties are to be computed. The \
output of the function is the list {x,z_t,\\[Theta]_t, z_c,\\[Theta]_c}, \
where x is the list of values input to the function, z_t is the list of \
thickness values, \\[Theta]_t is the list of angles that the thickness line \
makes with the x axis, z_c is the list of camber values and \\[Theta]_c is \
the list of angles that the camber line makes with the x-axis.", 
    "synonyms" -> {}, "title" -> 
    "1.3 Airfoils From Thickness And Camber Properties", "type" -> "Tutorial",
     "uri" -> 
    "Aerodynamics/tutorial/AirfoilsFromThicknessAndCamberProperties"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[632, 22, 78, 1, 70, "TutorialColorBar"],
Cell[713, 25, 191, 5, 70, "LinkTrail"],
Cell[907, 32, 3171, 71, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4103, 107, 86, 1, 70, "Title",
 CellID->509267359],
Cell[4192, 110, 736, 16, 70, "Text",
 CellID->237225321],
Cell[4931, 128, 731, 22, 70, "Text",
 CellID->3719437],
Cell[5665, 152, 1833, 61, 70, "Text",
 CellID->193521988],
Cell[7501, 215, 527, 12, 70, "Text",
 CellID->119120002],
Cell[8031, 229, 125, 6, 70, "Text",
 CellID->278144368],
Cell[8159, 237, 101, 3, 70, "Input",
 CellID->2058623809],
Cell[CellGroupData[{
Cell[8285, 244, 62, 1, 70, "Section",
 CellID->780127955],
Cell[8350, 247, 762, 21, 70, "Text",
 CellID->78760192],
Cell[CellGroupData[{
Cell[9137, 272, 220, 6, 70, "Input",
 CellID->36949950],
Cell[9360, 280, 316, 9, 36, "Output",
 CellID->876142913]
}, Open  ]],
Cell[9691, 292, 237, 7, 70, "Text",
 CellID->158135470],
Cell[CellGroupData[{
Cell[9953, 303, 176, 5, 70, "Input",
 CellID->136038124],
Cell[10132, 310, 1199, 31, 111, "Output",
 CellID->252736694]
}, Open  ]],
Cell[11346, 344, 423, 13, 70, "Text",
 CellID->89603494],
Cell[CellGroupData[{
Cell[11794, 361, 149, 4, 70, "Input",
 CellID->175130362],
Cell[11946, 367, 1354, 30, 71, "Output",
 CellID->72223849]
}, Open  ]],
Cell[13315, 400, 238, 6, 70, "Text",
 CellID->49184558],
Cell[13556, 408, 291, 9, 70, "Input",
 CellID->100398123],
Cell[13850, 419, 135, 4, 70, "Text",
 CellID->154464187],
Cell[CellGroupData[{
Cell[14010, 427, 420, 13, 65, "Input",
 CellID->11328373],
Cell[14433, 442, 7710, 134, 201, "Output",
 CellID->462734487]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22192, 582, 79, 1, 70, "Section",
 CellID->257533491],
Cell[22274, 585, 306, 6, 70, "Text",
 CellID->205773740],
Cell[22583, 593, 209, 7, 70, "Text",
 CellID->583385869],
Cell[CellGroupData[{
Cell[22817, 604, 2266, 63, 70, "Input",
 CellID->26946],
Cell[25086, 669, 3714, 72, 70, "Output",
 CellID->495630756]
}, Open  ]]
}, Open  ]],
Cell[28827, 745, 39, 1, 70, "Section",
 CellID->794950467],
Cell[CellGroupData[{
Cell[28891, 750, 86, 1, 70, "Section",
 CellID->140735501],
Cell[28980, 753, 592, 12, 70, "Text",
 CellID->48076094],
Cell[CellGroupData[{
Cell[29597, 769, 721, 22, 70, "Input",
 CellID->508498224],
Cell[30321, 793, 460, 14, 36, "Output",
 CellID->39441523]
}, Open  ]],
Cell[30796, 810, 145, 4, 70, "Text",
 CellID->440842507],
Cell[CellGroupData[{
Cell[30966, 818, 421, 14, 28, "Input",
 CellID->62089316],
Cell[31390, 834, 3961, 72, 201, "Output",
 CellID->287171945]
}, Open  ]],
Cell[CellGroupData[{
Cell[35388, 911, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[35456, 914, 167, 4, 70, "TutorialMoreAbout",
 CellID->1567025153],
Cell[35626, 920, 157, 3, 70, "TutorialMoreAbout",
 CellID->325103336]
}, Open  ]],
Cell[CellGroupData[{
Cell[35820, 928, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[35895, 931, 187, 4, 70, "RelatedTutorials",
 CellID->806871991],
Cell[36085, 937, 203, 5, 70, "RelatedTutorials",
 CellID->610993246],
Cell[36291, 944, 170, 4, 70, "RelatedTutorials",
 CellID->554434694]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[36500, 953, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

