(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    376530,       6951]
NotebookOptionsPosition[    369202,       6717]
NotebookOutlinePosition[    371505,       6767]
CellTagsIndexPosition[    371462,       6764]
WindowTitle->3.7 Analysis of an Airfoil - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:guide/Mathematica"],
  FontSlant->"Italic"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.6 Aerodynamic Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"], "\<\"A1 \
CartesianVectors\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/CartesianVectors"], "\<\"References\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/References"], "\<\"Table Of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/Analysis of an Airfoil\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/Analysis of an Airfoil"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/Analysis of an Airfoil.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/Analysis of an Airfoil", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["3.7 Analysis of an Airfoil", "Title",
 CellID->509267359],

Cell["\<\
The individual functions available in Aerodynamics are synthesized in this \
section to determine the aerodynamic properties of a general-aviation airfoil \
as computed by a panel method.  After determining the geometry of the \
discretized airfoil as specified by a data file, a numerical solution is \
obtained at a specified angle of attack.  Flow visualization is used to \
verify that the solution is plausible, and aerodynamic characteristics of the \
airfoil are computed in the linear range of the lift curve.  Properties of \
the flow field are presented as a color-coded density plot for pressure \
coefficient superimposed on a streamline plot.  A plot of surface pressure \
coefficient using the same color scheme provides a key to the pressure \
distribution in the flow field.\
\>", "Text",
 CellID->1534169418],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->124449903],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->196209460],

Cell[CellGroupData[{

Cell["3.7.1 Airfoil geometry", "Section",
 CellID->265027215],

Cell[TextData[{
 "Import the file from the ",
 ButtonBox["UIUC Airfoil Coordinates Database",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.ae.uiuc.edu/m-selig/ads/coord_database.html"], None}],
 ", and display a few lines of the data file to identify the numbering \
convention used as fore-to-aft."
}], "Text",
 CellID->836781195],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
   "Import", "[", 
    "\"\<http://www.ae.uiuc.edu/m-selig/ads/coord/ls417.dat\>\"", "]"}], ",", 
   "5"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->2058623809],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NASA/LANGLEY\"\>", ",", "\<\"LS(1)-0417\"\>", 
      ",", "\<\"(GA(W)-1)\"\>", ",", "\<\"AIRFOIL\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"38.`", ",", "38.`"}], "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.002`", ",", "0.013`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.005`", ",", "0.02035`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0125`", ",", "0.03069`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.025`", ",", "0.04165`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "65", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.85`", ",", 
      RowBox[{"-", "0.00852`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.875`", ",", 
      RowBox[{"-", "0.00565`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.9`", ",", 
      RowBox[{"-", "0.00352`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.925`", ",", 
      RowBox[{"-", "0.00248`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.95`", ",", 
      RowBox[{"-", "0.00257`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.975`", ",", 
      RowBox[{"-", "0.00396`"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", 
      RowBox[{"-", "0.00783`"}]}], "}"}]}], "}"}],
  Short[#, 5]& ]], "Output",
 ImageSize->{498, 67},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]//Short=",
 CellID->67713472]
}, Open  ]],

Cell["\<\
Use AirfoilFromDataFile to import the data file and compute the collection of \
vectors locating panel endpoints for the discretized airfoil.\
\>", "Text",
 CellID->245057279],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rP", "=", 
  RowBox[{"AirfoilFromDataFile", "[", 
   RowBox[{"\"\<http://www.ae.uiuc.edu/m-selig/ads/coord/ls417.dat\>\"", ",", 
    RowBox[{"NumberingConvention", "\[Rule]", "ForeToAft"}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->322575182],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1.`", ",", "0.975`", ",", "0.95`", ",", "0.925`", ",", "0.9`", ",", 
     "0.875`", ",", "0.85`", ",", "0.825`", ",", "0.8`", ",", "0.775`", ",", 
     "0.75`", ",", "0.725`", ",", "0.7`", ",", "0.675`", ",", "0.65`", ",", 
     "0.625`", ",", "0.6`", ",", "0.575`", ",", "0.55`", ",", "0.5`", ",", 
     "0.45`", ",", "0.4`", ",", "0.35`", ",", "0.3`", ",", "0.25`", ",", 
     "0.2`", ",", "0.175`", ",", "0.15`", ",", "0.125`", ",", "0.1`", ",", 
     "0.075`", ",", "0.05`", ",", "0.0375`", ",", "0.025`", ",", "0.0125`", 
     ",", "0.005`", ",", "0.002`", ",", "0.`", ",", "0.002`", ",", "0.005`", 
     ",", "0.0125`", ",", "0.025`", ",", "0.0375`", ",", "0.05`", ",", 
     "0.075`", ",", "0.1`", ",", "0.125`", ",", "0.15`", ",", "0.175`", ",", 
     "0.2`", ",", "0.25`", ",", "0.3`", ",", "0.35`", ",", "0.4`", ",", 
     "0.45`", ",", "0.5`", ",", "0.55`", ",", "0.575`", ",", "0.6`", ",", 
     "0.625`", ",", "0.65`", ",", "0.675`", ",", "0.7`", ",", "0.725`", ",", 
     "0.75`", ",", "0.775`", ",", "0.8`", ",", "0.825`", ",", "0.85`", ",", 
     "0.875`", ",", "0.9`", ",", "0.925`", ",", "0.95`", ",", "0.975`", ",", 
     "1.`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.00783`"}], ",", 
     RowBox[{"-", "0.00396`"}], ",", 
     RowBox[{"-", "0.00257`"}], ",", 
     RowBox[{"-", "0.00248`"}], ",", 
     RowBox[{"-", "0.00352`"}], ",", 
     RowBox[{"-", "0.00565`"}], ",", 
     RowBox[{"-", "0.00852`"}], ",", 
     RowBox[{"-", "0.01191`"}], ",", 
     RowBox[{"-", "0.01587`"}], ",", 
     RowBox[{"-", "0.0203`"}], ",", 
     RowBox[{"-", "0.02461`"}], ",", 
     RowBox[{"-", "0.0293`"}], ",", 
     RowBox[{"-", "0.03383`"}], ",", 
     RowBox[{"-", "0.0383`"}], ",", 
     RowBox[{"-", "0.04265`"}], ",", 
     RowBox[{"-", "0.04678`"}], ",", 
     RowBox[{"-", "0.05061`"}], ",", 
     RowBox[{"-", "0.05396`"}], ",", 
     RowBox[{"-", "0.05683`"}], ",", 
     RowBox[{"-", "0.06091`"}], ",", 
     RowBox[{"-", "0.06344`"}], ",", 
     RowBox[{"-", "0.06483`"}], ",", 
     RowBox[{"-", "0.06517`"}], ",", 
     RowBox[{"-", "0.06448`"}], ",", 
     RowBox[{"-", "0.06265`"}], ",", 
     RowBox[{"-", "0.05926`"}], ",", 
     RowBox[{"-", "0.057`"}], ",", 
     RowBox[{"-", "0.05426`"}], ",", 
     RowBox[{"-", "0.05087`"}], ",", 
     RowBox[{"-", "0.047`"}], ",", 
     RowBox[{"-", "0.04209`"}], ",", 
     RowBox[{"-", "0.03569`"}], ",", 
     RowBox[{"-", "0.03191`"}], ",", 
     RowBox[{"-", "0.02691`"}], ",", 
     RowBox[{"-", "0.02052`"}], ",", 
     RowBox[{"-", "0.01444`"}], ",", 
     RowBox[{"-", "0.00974`"}], ",", "0.`", ",", "0.013`", ",", "0.02035`", 
     ",", "0.03069`", ",", "0.04165`", ",", "0.04974`", ",", "0.056`", ",", 
     "0.06561`", ",", "0.07309`", ",", "0.07909`", ",", "0.08413`", ",", 
     "0.08848`", ",", "0.09209`", ",", "0.09778`", ",", "0.10169`", ",", 
     "0.10409`", ",", "0.105`", ",", "0.10456`", ",", "0.10269`", ",", 
     "0.09917`", ",", "0.09674`", ",", "0.09374`", ",", "0.09013`", ",", 
     "0.08604`", ",", "0.08144`", ",", "0.07639`", ",", "0.07096`", ",", 
     "0.06517`", ",", "0.05913`", ",", "0.05291`", ",", "0.04644`", ",", 
     "0.03983`", ",", "0.03313`", ",", "0.02639`", ",", "0.01965`", ",", 
     "0.01287`", ",", "0.00604`", ",", 
     RowBox[{"-", "0.00074`"}]}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[CompressedData["
1:eJxdkj0KwkAQhdc7eAHP4AG2tBAbTyABbW2s9AQeIbZWaWys0gmCICiIgiBY
GI0aNf71FpL4PkGnCbPz7Wbmvck59XI1Y4wpGuJh82ncbS2Nm+24SVztdJJE
bD9cLO4i7izuJC4SF4k7ijuI24sLxYXiduK24gLVN+LXOl+JW+reQtxM9bHq
I9WHqg9U93XeV+4p7yp39W3bVrZXCJoN+/Ke85JTsShFTh2e+7/veX//87/9
0B/90j/zMB/zMj96oA96oR96oi96oz9+4A9+4R9+4i9+4z/7wH6wL+wP+/QG
Mkj8GA==
    "], CompressedData["
1:eJwBZQKa/SFib1JlAQAAAEsAAAB+42vPLAmAvyrj32dcOHC/WUxsPq4NZb+p
TZzc71Bkv0uwOJz51Wy/TfOOU3Qkd79QNuUK73KBv05/9iNFZIi/cTjzqzlA
kL9EaW/whcmUv/pEniRdM5m/4lgXt9EAnr/8Uj9vKlKhv0Ck374OnKO/9UpZ
hjjWpb/6uDZUjPOnv5p8s82N6am//5WVJqWgq78pBd1e0hitvx2s/3OYL6+/
BBxClZo9sL/Ut8zpspiwv3Qprir7rrC/Gf8+48KBsL+ZKhiV1Amwv/MC7KNT
V66/yXa+nxovrb9kQPZ698ervyTusfShC6q/qvHSTWIQqL8GL/oK0oylv6Cm
lq31RaK/EarU7IFWoL8Dz72HS46bv6Xap+MxA5W/+64I/reSjb9RTrSrkPKD
vwAAAAAAAAAAObTIdr6fij9m9+RhodaUPyHIQQkzbZ8/pb3BFyZTpT8PKJty
hXepP3npJjEIrKw/JGJKJNHLsD/ZJaq3BrayP8jNcAM+P7Q/fcucLouJtT/Y
nlkSoKa2P1DkSdI1k7c/8u8zLhwIuT+cilQYWwi6Py8012mkpbo/4XoUrkfh
uj8xQni0ccS6P0RRoE/kSbo/wYu+gjRjuT/dDDfg88O4P+W4UzpY/7c/bXNj
esIStz/Y2CWqtwa2P9MTlnhA2bQ/A8+9h0uOsz8m/FI/byqyP3Qprir7rrA/
LspskElGrj+eQUP/BBerP7vVc9L7xqc/26LMBplkpD8RcAhVavagP9kIxOv6
BZs/kDF3LSEflD8k0csolluKP8xFfCdmvXg/VvFG5pE/SL85SzQJ
    "]], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{567, 254},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->565679034]
}, Open  ]],

Cell[TextData[{
 "This is a good place to inspect the data carefully to insure that there are \
no surprises.  Look at the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-components of the data; they go from expected value for trailing edge to \
expected value for leading edge and back to trailing edge in an ordered \
manner.  Look at the ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 "-components of the data; they traverse the lower surface, pass through the \
leading edge and then traverse the upper surface.  Note that the airfoil is \
not closed at the trailing edge."
}], "Text",
 CellID->627557896],

Cell["\<\
The number of panels describing the discretized airfoil is one less than the \
number of panel endpoints.\
\>", "Text",
 CellID->6171103],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"NumberOfVectors", "[", "rP", "]"}], "-", "1"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->583105778],

Cell[BoxData["74"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->171731451]
}, Open  ]],

Cell["Compute the angle between trailing-edge panels in degrees.", "Text",
 CellID->182804906],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TrailingEdgeAngle", "[", "rP", "]"}], "/", "Degree"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->13794719],

Cell[BoxData["6.374096676031951`"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->87133865]
}, Open  ]],

Cell["Plot the discretized airfoil.", "Text",
 CellID->603324995],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gA", "=", 
  RowBox[{"PlotAirfoil", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->172065563],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c9rFNkaxvFc7l9y/w1huIthFuJimAviQtwk0OhGN7rRTbLRjUKjGwPD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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->13919548]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.2 Potential-flow solution", "Section",
 CellID->6058915],

Cell[TextData[{
 "The panel method ",
 Cell[BoxData[
  ButtonBox["PMVortexLinearNeumann",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"]], 
  "InlineFormula"],
 ", using vortex panels of linearly varying strength and Neumann boundary \
conditions, is selected to solve the problem.  This model is chosen because \
it does not require alterations to the airfoil geometry to close the trailing \
edge as do the two doublet models implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  "
}], "Text",
 CellID->702507737],

Cell[CellGroupData[{

Cell["Solution at a specified angle of attack", "Subsection",
 CellID->198401933],

Cell["Specify an angle of attack in degrees.", "Text",
 CellID->124929276],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"4.", " ", "Degree"}]}], ";"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->174803283],

Cell[TextData[{
 "Solve the model for the strength parameters in the model, locations of \
collocation points and fluid speed at collocation points.  Compute the lift \
and pitching moment coefficients about the leading edge using the function ",
 Cell[BoxData[
  ButtonBox["ForceAndMoment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"]], "InlineFormula"],
 "."
}], "Text",
 CellID->234527805],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rP", ",", "\[Alpha]", ",", 
     "rC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"cl", ",", "cm"}], "}"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->195944851],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0222417592664566`", ",", 
   RowBox[{"-", "0.3819788899288332`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->360895096]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.3 Flow visualization", "Section",
 CellID->550601939],

Cell[TextData[{
 "Plotting streamlines provides a computationally inexpensive flow \
visualization to check plausibility  of the flow field.  Specify an arbitrary \
field point, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 ", as a collection of one vector of the data type CartesianVectors using the \
constructor ",
 Cell[BoxData[
  ButtonBox["MakeCartesianVectors",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/MakeCartesianVectors"]], 
  "InlineFormula"],
 ".  This provides expected input for computing influence coefficients in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " and yields results that are functions of position instead of numerical \
values."
}], "Text",
 CellID->22156770],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rF", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "x", "}"}], ",", 
     RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[10]:=",
 CellID->11362066],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "x", "}"}], "\[UpArrow]", 
   RowBox[{"{", "z", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{$CellContext`x}, \
{$CellContext`z}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->64288410]
}, Open  ]],

Cell[TextData[{
 "Use the stream-function influence coefficients and the strength parameters \
from the model solution to compute the stream function for the flow at a \
field point ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 ".  Extraneous list brackets are removed from contributions to the stream \
function.  In the resulting streamline plot, look primarily for evidence that \
the flow leaves the trailing edge smoothly (Kutta condition), that \
streamlines are smooth near the surface of the airfoil, and that there are no \
streamlines inside the airfoil."
}], "Text",
 CellID->52332134],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[Psi]\[Infinity]", "}"}], "=", 
   RowBox[{"UniformFlow\[Psi]", "[", 
    RowBox[{"rF", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ic\[Psi]A", ",", "ic\[Psi]B"}], "}"}], "=", 
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rF", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "\[Psi]A", "}"}], ",", 
     RowBox[{"{", "\[Psi]B", "}"}]}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ic\[Psi]A", ".", "a"}], ",", 
     RowBox[{"ic\[Psi]B", ".", "b"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]", "=", 
   RowBox[{"\[Psi]\[Infinity]", "+", "\[Psi]A", "+", "\[Psi]B"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "xMin", ",", "xMax", ",", "zMin", ",", "zMax", ",", "\[CapitalDelta]"}], 
    "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5"}], ",", "1.5", ",", 
     RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.07"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g\[Psi]", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "25"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"g\[Psi]", ",", "gA", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7.9", " ", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[11]:=",
 CellID->17324249],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx0nQd45lWZ9hEb7uqKLjYW7K7oYtddC3J0LQi6rgWwsq6KHQuLggVlbNgQ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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{7196, 10529, 9489, 7550, 8634, 8633, 8666, 7547, 8742, 7674,
           9142, 9143, 8363, 11443, 8362, 11444, 11446, 11445, 7215, 8495, 
          8321, 11520, 7355, 9087, 7356, 10848, 10849, 10846, 7615, 10847, 
          7238, 8503, 8050, 10670, 10671, 10672, 8992, 7329, 10669, 10668, 
          11586, 7569, 10804, 10566, 8230, 7240, 9066, 9067, 8229, 10280, 
          8228, 10281, 10284, 10283}]},
        "0.546`"],
       Annotation[#, 0.546, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{8709, 8560, 7198, 9713, 9714, 9711, 9856, 9855, 10385, 
          10748, 7548, 11585, 9854, 11530, 9853, 9191, 7386, 9858, 9859, 9857,
           7551, 9343, 9342, 9706, 9341, 9484, 11570, 11572, 11571, 7192, 
          9866, 7193, 7919, 7918, 8933, 10692, 11226, 11227, 10878, 10877, 
          7683, 10879, 7684, 9952, 7531, 9826, 9828, 9827, 7237, 8950, 7236, 
          10565, 9529, 11082, 7939, 11547, 9530, 10567}]},
        "0.504`"],
       Annotation[#, 0.504, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{7199, 10532, 9496, 7553, 8639, 8638, 8936, 6976, 8402, 8109,
           8935, 8934, 7675, 10070, 10071, 10982, 10981, 7810, 10980, 10141, 
          7920, 10140, 10143, 10142, 7388, 9347, 7387, 9603, 7552, 9350, 9349,
           9712, 9344, 9486, 9485, 7194, 8559, 7195, 9488, 9487, 7549, 8453, 
          7085, 9836, 7536, 9835, 9838, 9837, 7451, 9676, 7450, 11600, 9705, 
          10178, 11594, 10179, 11595, 7940, 11083, 7941, 10180, 7642, 9935, 
          10868, 10867, 8552, 7181, 8609, 8610, 8949, 8948, 7439, 8608, 
          9173}], LineBox[{7200, 8641, 7201, 9500, 9501, 9192, 10148, 10387, 
          6977, 10386, 10149, 10150, 10080, 10082, 10081, 7676, 8937, 8938, 
          8110, 8403, 6978, 11061, 10156, 10157, 10085, 10984, 7819, 10086, 
          7677, 8940, 7922, 9019, 8404, 8405, 7923, 11357, 8223, 10568, 10569,
           10570, 8952, 10573, 10572, 10571, 7948, 11095, 7951, 11359, 8231, 
          9531, 10574, 10575, 8751, 7686, 10880, 7687, 10881, 7252, 10580, 
          7400, 10708, 10407, 10408, 7612, 10411, 10410, 10409, 7401, 10709, 
          7688}]},
        "0.462`"],
       Annotation[#, 0.462, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0UlLlWEYxvFbqG1gapJ6FI85t/RL5MbSXWqaq8LQlSbuHBMEhyCNjChF
HAK1ReCibxCO7ZzaBFHpQvAcVw6/Fn+u576f6x7e5y1u66zvyIiIN7hVEPGh
OCJ9LyKFM7xIuJCbz49oLYt4it7SiG3eJvc7tEXuOV8zfUaf0FRlRKZzmn7n
38QGMvnb9euqiujGLu8+3w9aQNfdDVVEHJbIy+0hId9nVrfzS3SJe+iKnQbl
+3Gi9zEO5L/pkTAnS3wbp4URozyr/OXJiI/lEZ8wIjdHa6ojZmk2b9K+OTSN
C+dLpJwneCf/zzJ7UHyo/xA9ondoCV8uvaLhuzJwKZ5SM40BdcPiEfxU84pu
8W5iA3fFpfS3ujKaJ87HW7XvsGb3Crsv2nMJC/iMZST1K+Qtwgzve3zhr+T/
h1WeNazgzFssyy3hHA99+yPUoQH1uMlz4z7FlH8xjQf6/fKutfSvf/MHjeY9
xlfzJ737a4xhAuNYwDVM3maK
          "]]},
        "0.42000000000000004`"],
       Annotation[#, 0.42000000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNkLsvg3EUht9q4ppYdEPbr1WXMLCJWWJBaDCQkrhXQgdDKRtabVyi7UfM
Eve/gNVtMpBUTTYJpQmViITEMzx5+p7z/g6tMRzwzlgkxaCpXHqvl7Yd0hve
wVlchPtwCe7BxbgXt1VIHbiA3I4LcSfOxxls4hecxK+4kftmgxR1Sl21/E3c
jU/Zt7jJdunEJf1USqM19MhevIpHcITuAfswuZl+BB+Sv+l7cJr9bpW0wnyI
foK7fx7JzT7BPAkmhMiL1dICxMku8i+9OP1B3i3zfp35BmyCm9sP3E7BGnmJ
vY/eFv0v3hm8jzCPQgyC5Hluz+EQduIUPQfO4TB3MthOzuJnvosV54GN3/Tc
kMqwhSyYpXfM7AgmuDdNHsd+mIR7uml2d9iPA+wf8T6/txVPkT/4vz4hB3vM
bnl3ze0bGGDmg1Zm/XSf+Gyrk67YlZLP8CVcwBidf3x+Wro=
          "]]},
        "0.378`"],
       Annotation[#, 0.378, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkbsvQ2EYxp9qSTBoiIi4tHVXwWAQE6vBfXEpwShx6lITIYwmkSBhMLgs
/gQhFsQl2grRui0lQWIw0Nvid4Zfnu99z/Nevu+4Rr3dhkXSMgSLpNMK6RzO
IJX4p1pKQw/LpWzOOWAtkWwQIO8vRSEI2y7JXSBd4L2EY7DjaafXINqGetAU
fBYYIzaI42VSAuyF5MhnoVHiGAzBLX2G0RHw4Z+mbgZ8cIf3ndlezum10gTa
gk7ii7LrShVnclNwT58whCCXunFmGfCC95EeT/AMR+TquEdfpdQPveCBAfjF
u8fd9+HAIe2iO1CPP0bfOEQhCQnIY84J/ULMD8MDvNLjxik1U9NQI63Rdx06
oAs64Q9PhL6fxVIjO/nxB+CLeIPvrdxxnnPELS2gPeRi1LxR803cZP4T/Jvk
tyCDXRy8R6a5F5qEfPwfxLO86xysEi+a78POS+Zbodf4rsDGPCs4Of8D+4th
6w==
          "]]},
        "0.336`"],
       Annotation[#, 0.336, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkDsvg2EYhm/SOowkSkIrrTrXwMDGL2hCMZFIOmiCqDOtU4UFCUYmlRAJ
/oNVLbS03bSaOCTKYCKO1zdcuZ/z+zyv3ev3jOZI2oKdSqm3VlqxSXNOKQBB
sDukeJ10C7P4IfI91G1T/1QtlVmlaeIzcFYu9ddIp2jMJfVhTxF/pO4B/ugL
M+8AsszZxX9B99AMMSec0DtJzwQU0lMAlgrJVi/lYy9DBPsSQthJcktogD3G
6RmDFH4p/ic1H5CHb2b/VnZqg+ZGqQWeedtexR3oPW87YJj+IXCzU5B4poEc
mJlhZZYJXYAL7ARvL2LH0Xl0hjd99A5CEt+LfsMXFFMzYucPsH/hx7iRehOx
Y2728Ffd0AWdMGD0kL/GjkKCPVe5YQ0O6TmCG/IRcjHUz44+YibesbDbufF3
xN+Nf0PXuSfFPXfMLSKWy61XxDeJp4lvoE38iQvC7NPB3H00yn+1Y7vpe6Xv
DbKQxi9B/wExYV/K
          "]]},
        "0.29400000000000004`"],
       Annotation[#, 0.29400000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0U1vzHEUxfHTRG0supB0Q0c7qGexoBthp0QbkjahSCy0hIQ2saqnBSsS
bCrKhlCh+gKK96ChpkRrhk6LdEdS8ZAgPhbfnHvv3Ht+93+n6UhfR29NkgE0
L0kGm5Li2qSjIdnanHTS22q3ULM0qVuTTK5Inq1Mvoi/4ql4gb6fq5Jf+I5r
y5IfNEVzmCkkV+VVunFdcs9bbfzbcdr8c957+Y7RnWq7sAOH+LbSIXqfPqBD
9DCd1f8Jn/HQfrVmH9FhFLzZgHHeL/ECg+uTm+hcnbxdnpR5TPBaTLt57BPv
R4+8iw7b8ah6DybMl/BafYq+w3H1y/Jxfo/1XhGXxK9wwm9zbrBQ3E+L3jtL
u+Rn6JxbvNFf5lOxU4WeNHNA7SCO2aFP3otTqJe/13Pd7G+zf/EH59yzlZ6n
e+j8/zv57gvyzd7cgrvyO9hgxyqPGUzjI2axyN1G3ewJJs2XzFy05yVsM7PJ
/zXA+wZ2ox1t+Kb3A99pjNhrrDHZrr/F/D9Jt2fY
          "]]},
        "0.252`"],
       Annotation[#, 0.252, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0T1szXEUxvFHDEJIDEy9aL20t73dLEiNUu2AyBUqEdHFxkSJvZaWBDFa
GIi3XhSJl6EdiBaD0jS3xGub1PvLqOFzh2+ec87vnPN7fv9/Q/fB7QfmJDmP
hYWk0ppcrE8G6CV6g56jb1Ymr1GPC3XJ7tVJF37gOxaY/Uq/4eia5FFzcoQ+
V++h+5clu5ztxLB8kfyPnt/4olagn+nU8uRUUzLqzrWrkk/ySXf+0t+ufkj+
tiXZJD6B/poWkzaeHvJ6UjxbSv5i3MxIY/KKjtLBhmQ+PzfpLbSs8D5aQav5
MTOH1abs7KHTdJivIRyTTzifUevi/56dd+0siQfML5XP8rmEXpdP8F6ys8xP
n7fsof20V/2nnmt6qvxepfN4ukwn5Vdot/Nxffto2R1ncBpj7n6JEXueoKKn
na+Ce+tQ5KUJjbitbxDTvulH7LVra82v7zdDO9CJd87eYy4PL/Q/Vrtv/gG2
qG/DcfVJc1XxYt/iH4/P7OtVr6oXfZdmPK39N5wVb7Bnnff3efd68QdeR9yx
UbzDbBst0047O7AZd2q+MeTsP3BXdoI=
          "]]},
        "0.21000000000000002`"],
       Annotation[#, 0.21000000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0t9PzXEcx/F3F35s/AFMJAqlji0OLqpzzmL9sDZF5Y5KcdGPCyrF/LpQ
d9hsWXEjNzYzd3FjuOCCkqKaK8xN3LgwFzLzOBfPvd7v9+f96/P5fvPbeht7
ciJiBs0bI27lM+j6rRE5dN+2iP1I4jB/Lx3fEPFvc0QDf74gYgGL6MzW5kZ8
ZKfyIqoLIwaLIoZQvyViSW0aGXySM73dqNKId7SeptWM7oy4jfdiM3hjxix9
a58pjJlxaUfERXQVR/SgG3Vm1eKK+SecteKRHdvpSbThaUnEExRvijjN78Qp
dOCx3GN2bMGA+83aJU/uHD1PLyCT7SVviH3VnEN2qXP+iz/C72MP0zn730ct
f4LW0OP6Js1dpn9Roc8PdS3yX7nfF2/yFU1od+cl7zMpXq6+AkXuVoyE/Dz1
K7xFgb4PaI/zbnThob6T+qbtlmLnetdCeb3yKsQqs4jvcpcEyvVc5/y1WQln
Y+aPmp8STyODZ/yzdNrsM7QffWjnr9R3Far1zKhvFUtm35vO8xdw0PkBdOhT
5l/4bL/dNGXfSuxhJ7O+eyX0LUUJfnuv795htV5jzsbxTey6XW/iBu75VlV2
nqCNchvwQu1zTIkvmvmSvYYecXZNbBgj/GZ+E45iLf+PfsuYtetld6hh95tX
RQdoLf0p7649Bvll8s7RO/wP7P8uT38x
          "]]},
        "0.168`"],
       Annotation[#, 0.168, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV00lszVEUgPHDRkklCFrzrIa+iGAhhig2JG2RtlJjY5aYag5aEouaaZNW
xwUbJIi2ErRFYkWlXbEStdCdadGSGILfW3z97rm9Z7j3nzdhy/41+/pERIo/
d8ZFvBof8RKzJ0V0jY14NzHi25iI5RkRh8UfZkQc4uGJiHP20vi9+PfMiNvy
f/It/sUj5I7EXnGHeA8nRkc8tl5n/YjX8xMu5FZuQwtKMyNKsNMsC0ZFZKBV
3G2uTnSYqWFCRD36qvl+ckSd9QD7PXr25/apEW/5oJnf8AEuxtbpEdtQJG+x
s5fspbtDt/Mj+IL+F3Ee88w1XN80DMUL8TA+aa4C/fLRYp78ZIx9at7TK9W7
3OeH4lXqr0Y2cpGDE/JS5BW5V7e8q9ZXkFA/y0xLsE1utZlqUInrqEKX3AJ5
n5x/7vxcZ+dgoNkX8iJcU7PWnBVczeVcwxvlHXSvqfKKOYMP8V29jvFxHMZR
HEGB/e3ydiAxLWJX8pvgmbxUfsr5ajbrmcfv9Gmz1yRuRKqZHnAF15q3nGep
+5HTfIN03BDfTL659SVky/+u9nm917prE9fJrccP9Y/r02u/B5/xBfeSff3/
pjfP8/Zf7ZWptcRbZ6HVugUP1Cp1rpGfittQKvevfmU4h3rnG1CHTHMWmv+s
8/+m+KF4/wH2+2OGXv04BSfVOZWs5dwQ9U8n1yhBlvvUuN8KM63EMnGteDnX
8VIeq28nj+GO5Ddxx0HqDEav+XqQY73Y/3LNk4MSvX6r9webfZtNaHfmNSrt
VeGVGXeZbzea/V6bMF/Pf+p/sN6gXhdv5HR5abhq5iu4jDPmOY1m/f8D7veq
oA==
          "]]},
        "0.126`"],
       Annotation[#, 0.126, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV011szmcYx/GrXkoiO5kgWmr0TfVhmMhWb2E4aY+EsJXVcDA1jO7A5i1Z
NjNvq0h0yTx9b50R7fO0yOolFk4cOFhJvBwtQmK0hkSIxOd/8H1+/+u+rut3
X/f9/P+TN2xfsS0nIhb4efNRxFtkJ0asnhbRQ9fQgQkRd8sintGK6RGXpkZc
xt78iH8mR/xSArU/0wN0mZ7l+Byd4qW0RG9K7VeTIup5HcdRa3mFEUdoZXFE
FXJ5jFI/nLYVRTSVRzTjoPrfcAjrpvDBrIKIXnOcxwXMFjfpnUOf6f+E7rHf
Rf5nxV1mOUPP0VXqDljvEncna8gik8TW0+ZqxGv3sd85V3neR5tS5kEjWtGC
TjW15tmMZfbs4d2LbmSRwVBn+F5/tzm78Ie1BhSrHyLXTYN20Rxa566G0Yx4
RykfWs3/S/xnxuniJ3QGfUqf83zI/5L8ZfRaH66/h+bSn+Te8ay15xb8reem
e+iUq3JHHbSS3rHXbQyRL5fPoSm6UM8iLECzuMl/04g0hqkZin/xI5+pfH6g
ZXQ3HWeGD93TaLSZsx015rmXvA+0VdyCw7wPYT3/8f7nPOTjOx7bket/men9
m4WP8djezWhBL5/Zzp1BFg3+k077nU72RAfacUHdSHtdpP3iEZ5b9Z8w4zXz
3rC2Qe6+2b6m18X5cnnYZ4aUmj20nO6l1erWIm3mQbVbzFgn97tzFOg5Ro+j
Hn+qmU9PJffnruqcbav6D7xb39Kd4h1YafZdvF5af4VH/B/jG76t8m1Iq1/u
nI20XdyRfE/OslFfhbk30fl8plmrcldj9NaYdywtsVaKtWqqUaCuWLxCXRH9
1Hd41TtwBffdzRKzrjZzkdkLMUX+iLW56lP2P+q5Xr7YehEK8au4hHcp/uLZ
h//VVbiT53QefUE7+H3mecDzIN4471vsdoYHzjyAQfRjDc8+uS9oxlmyOJd8
O8l3gwfmXYwlqDT3LXum+YxL7olWJe+rszaIT6KM13tExMtB
          "]]},
        "0.084`"],
       Annotation[#, 0.084, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1Els1VUUgPFDqyJlMHEBLR1foQMg2tJqQlJAaY0K0iolbReYMMpQBDFQ
IDExCkQKqKHvVSgS0AAFFhgS4DEYQWVIAF1JXBkFWtBEcYGiwgL9vcXHd4dz
zzn38v5NzFsxc/mAiJjrn+L8iGQionBsRBGeLI+YVhhxhI9xi7Wj3PRExCto
xNCSiAWjIobwVvN3uJO3YDM+wFTnHsg9aExEiXExGuWZPD4ix9pgJKw1WZti
rdv8w4KIA9YOoheTiiLmlEbckufw6IjPsbks4nuxnfy7HgaOizgp7k5lxJ/4
C1858zVOWz8q5hQ/rsY+fd7FStzT4w711trv4fvmb1kv8xavGg8zHqLOUAxD
hbhNxRH96nXyTT4r7wlxLXKnuVLMGWvfqH3O+zVzhXmP9XKeaX7P+JIaT7v3
DuNn+LL5RjUedabWfCDX8Ahv0OzueTwSuShAPvqtz5YvoddSlOCqvi7IdR5p
73Acx9Cgv6fU3+1cFS+qiFiM2+IH2U9ZS8t1Rs4cZ1dZP66fNE7gxUwdMV3O
p5DEbv19qs89/BmvEbfaOz7mTh2ZMVahTq5t3upH77Ms87vg2dZfQ4jNsz/P
fj7P4ZE8l8fKtcT4ivFS/pb/UGu/8ZfyTNTrOb02YxbWydvoLk2Yjhl4GW3y
PGdviTPtWIpnzWvs1aIKE1CNVjnr7b0hpoGXc4F6C9Uu4vlcyAt4nLzj1W03
73WXAziIXG/1t/1e63f5X/yDCr0/5N0ewcPocP4lsaXetdt8FH/MO8XlqXvB
+Vw+z9PEjc7EyTPJvItTSOIFe8/jot773WG/b2Sv2P/0v8tatZwfyVnFNZiA
bPPf9JrFdX4bPc7txCe44U59+CLz21B/MHJQrUaznjcar5Z7A3fwFP+HkzHA
PO1McDayUCZ/lnrlnM31zt+RZyr32S90/rpa1/C2Xr+z9oMcdfpvk7PPOKG/
fl7mXDseiH1P3Apn3+U3eT3/JKbFmZ+5xJlrfEjdWns3jGv4OreK2a7+Hvdv
9TekwZ3r8bq9y95zUeYb922kjVsz34H4Nh7OLfyr9a18i7fwL1yp9y75N+ll
G6eQxPvmST134Xbme+ce7HOum1MY4+z/ch7TYw==
          "]]},
        "0.042`"],
       Annotation[#, 0.042, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1FtMl3Ucx/EfuqZBUKTZFqRSKSACdgNoQSiKmriJKQHSQZRmtYk2Tdu4
SG3qpqXzwI2graVgqUDTRgc3aOnI3LLlxFlqZwUU8MapLfX1XLz5/L7f3/f4
PM+flOra+ctjQghv+DM+JYSWiSE0jQ1hXAYbqWh6OoQLo/FUCKMw85kQilGY
GsKlCSFcxG84y3eUb4qc5zApPYRnkZ4cQpm8NJrNThnHxkLU8yWpn4yaMSF0
yVtKf6B/Jeml7p+0Py2E6xjEABaY8yVcRqJ5J6qbiSzUqJWqbobzdHN/oUaH
nGVmmMZuYxfRI7QVLYjXr0SfaeoVYSrumGM6bRX7rdxeNQ7acYUdazGU/aJe
3fL6nD9z95+cBOc2OcflzEEJWth39TlC79EM/SbgNbO/I/+UPqflzlWvBHXm
f9VdrPgN4uPoB/SjJ+1Js5GFqeKy1I9xX8ceQrdHz1+tbXQK7VbnHDapuxml
3vM8rJE7m52kdzKewEnxve568La5Dqn3v7qH6Tf6fI0e+13FFXzOP1fc93L/
Vu875zwxI/jjM0MYSbv4DtJEdjPNdd/Jd07OPvZwvdrZs8wbo/9MOoTOpoF+
SPPoVppL4+V10N/tdBlb7ZATPXeaoF6feetpD91Ne+lKPQZpI3uA7qU3aCLd
SB+le+2zDx/jAHu5d9xE9+NT5Ji7w5wNzsPUm2GeYhRF3xkK7V9pthdoBU0y
W3n0bGkDbUSV2p+w9zgvcn4I8VE/304TmlFlj1dw206x7m7ROFqhd9x4Objh
fhADuKLfw3Z4BAnRd+EbuST+YlQ7+m3SMvMtjBB7xx4VzuV4GY+r/xN+NNPq
6Fu227v0NPtn/jMoUGOJuZ+n1TSfPqb3PLVK0SfmGs7K+VJuC98xWhA9D+Tj
ZvRu5RRjFpapk+mbeJOWRrWi35KY89hth7X8+81bx3+ATuYbLj6P9vNdxxb/
Q/519wB/ufNX9mlHq5gFdv81esY0k50vptLdIuSLHcbO5X/Q84zFIc/+DzMf
dl7lGazGW2bYIX4ndmG+nml2afDeG/E+3zqsxwh3I7FYzntiXqf/qPELctQ9
wV7ivhqnzFzDHyPvjL5zzJGtb6FzAY6Z7yg6+e4DktPcTw==
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1G1MlmUYxvFTJbNVighpqfnyQIJoQ2trggs3RXFWtqfalLbKli4tNVlm
C1ltoR+yL6UWZsvUUhIU3PRDb7OlBaJBWpavpTZdmVbCpr2I9rs//Dmu47jO
67zO+3nuh2FPLkwv6BYRi/25b3BE0R0RYzEG1wZFlOZGFFqPQrn90bR2YETX
0IipfJv9dvwne2pYxL/0mcKI4UMi5tEULR4eMQ4lyLk94j15mfzVgogavOye
h+1l5Efcpf/dOKDnQaTU5qK7uh7IwD/JPWhxf5UzS1GNVn6nuXagJhWxDLnq
UvjUXNfLU6MjetEMTBkV0ZOW0evoZDpDXXPSGxWy5802gy6ii/WrpDP5Ynpa
/evuLEk+J3ONp/fk6YM73TNHrxflL8m3mW8rGrBPfkb2lfMPWvd2VxvdoH+t
3pl8Hzwt+9BnsQn382udaVTzLn2An44V6tN6npSfwojkbJLpnUlnyZ7Acb2u
+cz/th6s5if+A+sTdBDfad2BmXrfa/6D8pX873qcx3f8Ofob3pQf4G9x7rT6
AfQw/5b8bVxUs4AfKF9IO/hVuI2/FZXoiyyslP+KuerK+HwUYJ2skI5Eu71+
njFkWbQbzaYtnmdvgmddpKaH/CTdJ2vFNLP8zHeXV5izv16H+NXyP2V/4Qf+
D3ohmVH+Pf+L2t16TrOudc8Rep4epfXeyb7WV/U/xj/mzOPo4vvIr9BMmrY3
1ruRPdLnhBycS74/e03YjodkacxTm222HKwxx0b9vk2emc+jn5hll7Nbccne
Fu9DPRr1b6Dz1VyW36D+c+t11p/RYr4E6/Wsk011fhxfRev5BpTzU/CN+kf5
/fSs2c7gsmeZ4O5c93yppohmmXcM7Ufr9GlyZjNN2//ILHV4To+b+JuTu+2/
j2bZjcn362xPv40CutG5Knsb6BIzdti/iGfVtri32f1b/L84Yt0q+9j/iL3J
+yT/UbbbusL5PfQw3yk/q89sfohzvd0zlF51V6O9XWom2vvaHZPoF/x2eRPG
61NkjlOyLD2K1Myhnfwy+Qv2a2gHPzt5d6yP+W2fwHGs4KerOaRXSk1e8rlh
vbuXqr9ivU1NtZpG2sVXy5fTd3yWBeZcQ/PpI57zFTXL9S33W5zguyjFZL1L
R3jX1Uz0HrbJ2pGjvoyfhAq+0v4bstfU/w9aDOw8
          "]]},
        RowBox[{"-", "0.042`"}]],
       Annotation[#, -0.042, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV08lvjmEUxuFj2EmoqYjOUtpqqamtOYiphlILibY6SMxTEFFLC1RTSsSC
DdoNLYkpIUiQ4F9AgqiZVtSwscD1Ln7f/ZzznHM/0/tlN+yq3NknIlL8pI+O
2J8XMbMo4k9axLv8iPe4khvRid/mN2RHbCyIeJwe8WBsxBN6Su4kno4RY+P4
iMzMiPV6a1HFq698Nc2S32I+m/aX64cGNfWow2ZzmzC4MGKBuct6bsrfwMGs
iLnWqZHrtG65fSzHMnTItajvUvMWZ8x/UFtlz2/EC9HNc7263epqaY94kfxU
dXfkmvW8Ni4zt1k8nZY49yK5RuPLcgdonp53esuNt8sto+/F+fKz1I6nH8Ur
5HeYX04/iAvkX6DCnqqSM7qDdXQIraYpyZ3RYbSGDqWz9aZ7kwykIQuZuG7u
Bh7yXZz48Z2Esd5uMi1OzoVx4il0JZ8ymi+eTqehFHniErqaRxHNFU+ghajn
3YA6TBTP4ZFj7ZHG2XQUHUNv2sctPFK3hE910s+nhs7AZ/lVene6i9X0i3hm
sqY3XYUS7zcNh1CcE1GpZo18Ja7jGtrlTnufT3orkrcwHmCNDnpJ3Mz7Jc9X
+MfjL76jF1dxIiPirppWWiQuxO2kxr5z+PTS+ebn4aHxQOukYBB28d8nv5v2
itdaI8t3kSsexqOPO+iLwAW9P73defqDnrNet3N9Qw/OireP811gC7ZhK6rd
W6q5I2qacBRfnO2l/9grdFm/iX+pukbf2BL7WIrhciOQirv69/G6T/fQe3Qv
PainjV+p+CIto+30a/K9885w/ov2+8t+j/FpxjPnasFxHHbe1uQO0a3nOX3O
ozj5v5t7ijb9/wE5pKKA
          "]]},
        RowBox[{"-", "0.084`"}]],
       Annotation[#, -0.084, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV009Mz3Ecx/F3B8mfDbOx+VOi/zJ/C4eMsmHKwZ/5s7lw6CDlFG6MDvLn
4M9Bi9XB5iAzOpDRASujjUL/pDriYLNR+FUeHZ57fd7/35/Pd9/0I1W7K5Mi
4juylkVcWBpRi/olEcUZEXULI+ayb9KOnIgtfJuyI/asiCiiPejHZ/ShF11y
yhZH5ORF5CIT2cjCg+URp/V6qlcLGvkaUJgaMUNsJlIwHdNwVm6PeC+60Y8+
nJD/kX5CJz6gCz9xSM0tvesxhEG08hW4xyx1NXJm0380gVH8xR+cSo9YL38D
ClHqHTbSnfRkfsQuWk3LaKHcAuxnL2BvzvU+KEaRtxy3/wTm6LvSewzr88oe
neLDiyLe0SH6nl4Wz5fXLN4nrxfJ/FOQ4Ou2+xhNYU9Fj/2TzX7I1yT2iHbZ
41taxFccNH+LnHKxo+xi/SrtuDfT26i/jb1yBsRWqVuD1bhrj898ab5vP90j
54YdR8WOq6/h++UbD7nXIM6xB+h5+oVeMvOemVdos9rLdJZed9SO4Bh+63VN
z5Pi1+kIu4K/1H2a+O7joPMBVOOwd6mT12jnBuxgb8dzvjPqJtQ/di5XN4+d
Yd58+sxdWrIinqDAvWvZF53X6tnqDhN2W8u/Dj/snGBvdYdxWkzH6D69SpxL
6BJv3G7Ga7xCuR1e0hdo03tU35FJ5L3xD1xxHrNXkniC5pq9TV6bWML3qDK3
jb+CVuI48uRcVZ9qZtrku07+T/bosN9bvFbbjv+xZKPl
          "]]},
        RowBox[{"-", "0.126`"}]],
       Annotation[#, -0.126, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klIlWEUgOHTtjbtggbzem3SigoCG5YtKir1mrUuJKpFoRato9QmyibN
RRMFDU7hIndqFCka5CK1rYpDBFrklSIann/x8nq+70zff00dPZ05tSAiBrFk
WcT5VMS+9RH7sXRtxMLciIG8iH78Ev9ET37E6LqIMYyjeZW75RHdqyPerYjo
4rfc5vy3843y084+6nnbjHx/3+HcwohPORE1ayKGeN7sLObd/TGnX92k/lOY
Rod+m5xtxmX9h9QPo8tdN16blU5HdPIbcQ8+ux9BSt8xc8ZRqk+Tu5vyjnhX
S0FEK+bsNY8sbrnLyCvDFvPe2+euvSrkN3CfuBd96npRpO9wMg8jeKWmHVNy
n+o3zTl2aPc9P/AAjul1KOnrrJwb+DBPrlSHQd+rUd1WnhB/8477PMsP+Dt/
tec5vebEO+RleSc/Sr6nvR7zD84m70OFfjfk12OReX/N+5f8rs6Hkt+Yq9RX
oxJncQa75e5FwYaIPZySV8yF4hKu8t0rcdw+peJd+pfxrNqTzqrdneAZccb5
BJ5gsfp7duxw38Sddmjk7fJmvaWIZ3gb55n53JuLxc+4hF/wAW7hDL/kUm7m
K+a18UFxK5dzO5fxONfxKNfyGKeTb2PORXtd5xqu5wtca68afPF/d5Wv4aG6
S1yHfLX/AdWYnA8=
          "]]},
        RowBox[{"-", "0.168`"}]],
       Annotation[#, -0.168, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0btPlFEQxuHBP8CCSoUFFlHY5daxi3dEaomlDboIXgqByktlpCaxAqNW
BjBqvBBaMAEBRUHFAoKFUUm4BRItDDFR4kPxy3tmzpx35psvmes4czUvIp6j
NBnxrMoZyUoxFooiBvdHzNP50oh8HC2LOLJDeUSH/Fw64hNm5SIVkVcdsQuT
zlOYLozoOhDxlnbSgUREVm0Gw+Jt+XV1a5iRG+Kb0TuLlFwaZWoa9a5wLked
u99679GniUen3OrBiITcCi2kPWY65c1SRcQP9PN+KP+nJOJWQcQH95fFs/QK
/Ugv0hl6iU7T93iHLbR6M8hnAPX6bphpUd9Nesj9YWRQjyzO2uekOacwgVxx
xBt6nPeWGU/Qv3b7D9uYU/8ZX9TV+AeLtJa2+YYH+tzHPZyXf8VnVN9Rek7c
K9+Hu2hVf4z3YzM8xRM8svMqXtVIoRJp5NTe4dNsh6fx3e6/oYVnt7t2Pmvi
WrvbLV7mkxG3ySfoBVpHb9jJTVzDdbzgNYSX+GVvPb7rJ33NZxxNfLrlbqPI
LhrEiZ3/hq92MWamEudG+WJ6khZ4tw970ce3FyPu/gPfiXQN
          "]]},
        RowBox[{"-", "0.21000000000000002`"}]],
       Annotation[#, -0.21000000000000002`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0D1PE1AUxvHH1aDEBU3USpEX34JKgYR2A1Yd3IwuGtuqQOvgLFB56eag
DgT1QzALSEmML8hXcMLNCeNgHPw5/PPkOee55557i/ebtxpHkrzE9Nlkvpgc
nkl2+5Jf9Phg0o1jqOif6k9OogevB5JX+DmUPJXfVtvCJvYKyd/epH06KTrb
h5psx8wq3aV1+udCsiM/b8Yz3HHu46XkLi3wB+7cN/sbP3zebDO3sM8v2/W3
OQvqLbVVfgUv1G6YfRPf9Qbc/f5KUrJL232D/BDW9d/iDQ717jn7wN1VbOp3
3N25bFdsYwcfUJBdoFfP2Zteo4t0mD6nI7RFr9MpMyexxJf4hxeTR3iMo3ar
0xqqeGLHJja8ZVl+BTPqs//73tQlX6MNfg5t/VV88k9T3rBm33f2/oEDTPq3
unxTdlq/4u1ljNpjwpkZf1jy95/VvqBbfpwfwyhm9ctyi/IVOsdPqH+V3cMJ
+Qpfxm2+ob+k1pL/ByY4W6U=
          "]]},
        RowBox[{"-", "0.252`"}]],
       Annotation[#, -0.252, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkL0vA3Ecxh9jI0HiJaovd8ddW6nEoB0tBgObCQupxUvCZJXesbT8AdWW
zR/AKuFa166tMGMjBm+JkFh8Onzy3O+55/vy+1m5nYXtLkkHcG5K9pjkQJnv
M9SwJBNCnMMpaRgubKkWl+YmpHn4xnuNSD5eT1rqg17wY9JlQrqizzXk6TNE
biQpRSAMi9RE0Ueyu6PSMuc02SX0Hf8D3mDPkEoOs6Lkmd9P3wGYpm4QLdA3
jh+DMrlj+KTOBgcM/Dp7FsmFmHPY2YMdW8zJ87+NrrLfCnzxLyDfABMsOMJL
MWeDvpuwDgG7bKF/9G2SeRjnHvAEp/gJvCSU2LFC7QlUoUFdqPMmvKkPs/wv
MPcHvxv/Fy1ynqFHDm1ydvFrZOtw29mZO6yhHv4+eJxdeKZXC21DhTe7IZ9h
9wh3dbmnB1OQhQy8kL8jew9V8gH5LPlJev4DbbpUMQ==
          "]]},
        RowBox[{"-", "0.29400000000000004`"}]],
       Annotation[#, -0.29400000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TtMk2EUxvFjMDIQEw2LUAq05VpooGyyw8jgznVgbCOE+wCJbipgIgmJ
A0QXbgtbYVLA0aKMxsGQMJgwKQls8GP45/nec55zed8vNVZ8UXgQEeu4SkRs
d0bsYAt72MXHxoizdMRPPMF7vrqOiCRetcrVR7xNRbzBlXMePehsishhlf+x
uhX6rS2iQ6xbvgv/8ak54jPaxbNY5ku0RLyjZfNrfbeJb/Js4J+apQZ+OmZ2
Rq4Jzagy58SMY6SdR+UnfA/kIhbV/LbzpPM837BcLhMxQhecz5Pm6Dnk3EIH
aSt9yV9jl2meGazrM0dn8UdNmieDBqTQiGf8r73Hkf5f8eVeeYfEBnEpv+Iu
q1jGtJopPLXfsbkH3ryErLoj50qzHuGhO1XgxpscZvlQwr7Yhfpf3uuv3qf6
FOxZpkX6g/aaP6ffPMp2+I7++3+iro+uuecHzOo3g1v+G7NrvN017eHPI8FT
bbduez9vF6+LGNczT7vEJuW2xXewi6TchtwdE/teQA==
          "]]},
        RowBox[{"-", "0.336`"}]],
       Annotation[#, -0.336, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0btvzmEYxvGrGKpJqdbUFq06tm8NElRi6GYRDQlRqqQdhEQNJQ7RGiwI
xchE4rw6vO2rhKTUq/9ALRIhMTQqFkktfAzfXL/7cN3P/Ty/5r4TuwcqktxB
Y0PS3ZoUlyUv1iSjtEjHGpMe+ZJ4Px2jB2iL/Kb25PHq5HMheUIf4BEeosG8
8yuTIdxekVygw/jG37422YBWFNCGev0n1yWncJf/Pu7hp/yl5mSWllY5H51m
DMsNoWzmRrXxpuSWcz6IJ/FVz2Jzu+xYQ9/a+Q26lifb5c7JlX2/5Cuh0MIr
nuD9wltFq521QN8O+de8r/Bc7rcd68xYiro2ikk9Z/W+p2doJf9CvZWYJx7n
nU+fiZ9ixs6H3O8wetCLg6j15hfVas2cMOs0zzs6YN5xzIiv6ruGmFPxfz62
2XkJbw3+ussv/6fPmf04at9j2OM/7cXm9ckWdOCHmbvcY5b+cc5l3jlaLzfi
XabRKVf0tqO0w5v3mtEkv8+O3ZjjXaR+Rb2aXlf7hJ3uMaK+Va5s7yl8xKDd
bui9ie/6juj7B5S+ZWk=
          "]]},
        RowBox[{"-", "0.378`"}]],
       Annotation[#, -0.378, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0L1OwmAUxvGHQUmAoAOVElHECGobRzUB/GDg0807ENg0oCNWNtQZvBc0
wUEDOOjAjcjiQlBR/w6/POnpec9522ipdlx1SapiGJUcBBalz7j0hQmm+EZ2
Wfoh82TXknJkZks63ZDOoHWpQO2XniJ5virV4F6TZjGDI+ou+hoRqRWTPsKS
h/oCZ4I4WJJMsskdfNS9uKOvjXfOeeCFn/ozO6/pu2DHDWnYzIHD+1f2vFAf
YMS7Dv33mMM8bqmF2FNibhkneOIuFXLM3Ad6enxjHwOYzAxQM+Bj5hXPb+xo
kCF2mgii+9/DP3kkD3lOI7EpJbHNfIuz4lydmQ4u0eSbLdJGir497NC7T+6S
xgq7kedeBWSQQxZF/AGkVDz1
          "]]},
        RowBox[{"-", "0.42000000000000004`"}]],
       Annotation[#, -0.42000000000000004`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNkDtOAlEYRg+FPBIxAUQLngMaiWghkGhlSWxURMDezgJQtGQXbIBlMOOD
xBWo26HxFCfn5vv+/97JBI/T/iQG3MplCX4CmEu+APEjSMiWpCQp12VI6x3Z
lvUx3Jh1T2HcgIlkze/MMrqvc7qnd/VAf7tzr6/cmTr/LHt2Q7O8HunXGswk
d+B9kpEH8337jV7pUM4OoSXtIjSdfzf7kEi+5Nw3PvWF7jjz1/S9CvzqF12p
Q1mWdpsTeKvCwv+Q9Bzax/VKJ3RgV5eaPLmT8juWniP7f4BiKEU=
          "]]},
        RowBox[{"-", "0.462`"}]],
       Annotation[#, -0.462, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdlH1MzHEcx2+VduUxbMWYNSdp1FoeYtM7VCTRk9TCSLLIepySx1goDwtd
c3WrS51cV+fU6Sqrn6dRquFKCo3cRRHhVFPmdPX9/OOz3W6/fb6f1/f7eXh/
bMNjAvaa8Hg8n9Gf8X/cvuO49sCzxRYnOZcx64eD9t2+7a6xXOSYfUPopmg3
xeS9XI7IaF8h8xW/7feL4JqbjNYHH6Wr+PfLaG6c1wdf/aXAREES432B3/Ju
y/74VMb7jM0nBud7RpxjvF7EuerlK90zGa8HHlEx39MashivB8MeeYIdLiLG
+4QPIdbqF7w8xvuIPwGIcQgoYLxuuBe9q5siLmQ8HQY2hp5xbZMyng7DVcuD
LuiLGU+LnKMVzRd7ZYz3AQah0E4qkTNeFxZN6NypsSlj8e8xt9SQcM3pFuO/
hdmctcKc1Up2vgOt6qbe8mtKxmtD4iKFw4hCye5rwSyDm/ZBqpLxnkPkYCNs
taD4BuhN+goDtylY/GM0HKrLn+1UxuIfIsJ9MGXoiZzF34Pg2+1fBRNLWHw1
Sn5ofMOn3WTnK2DuNGypuSBlfhkkN7LLBjyvM38hrEpa+1KDJcwvgumz2rM+
l3LZdzqkr4u1zqZC7shMxfqulESMKPh/1Vcucn9kxot2wX+zSp758zTH+8/I
v1JVP5pBBig+cki3u6AtC8S3rV9j4XIwH3S/tPa+tV2gFPS+qfa58WlJMtD7
D/faOfNLS0H5CcI3Cl40KkH5dywoUZtXloPqU98ca+oGFah+xxrFjufT74Dq
254XOl1yoxJUfz+dt2bZVTWoPz/7XRzn8KtB/RNnBNmE8WtA/XVa+iqqSFoD
6n9XijHRGtB8OK9NVsU9qgHNj4e/ZIvOm8534f75ulNL91SD5q9z0or3+odV
oPnsrgpcFWKg9+hwMGFPyoPpatB8t7ePJQya/5YZ2cnuHSqQPsb7WQHSj92Y
YKg+PTSfIP05Po3O9PZSgPSZt2adwcxaDtLv3ZcJmpHHxSB9v7neZC6KKALp
3yqWv3X/oAS0Hzr4j74MT8gF7Y9M56QltvOyQPtltHn22WEZoP3T5Hl0YWRt
Mmg/Bf/w+ngZG7h/vuUuPQ==
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->568.8000000000001,
  PlotRange->{{-0.5, 1.5}, {-0.5, 0.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{573, 301},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->437338274]
}, Open  ]],

Cell["\<\
These conditions are important enough to look more closely at the region near \
the airfoil.\
\>", "Text",
 CellID->206472012],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g\[Psi]N", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.02"}], ",", "1.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", ".1"}], ",", ".14"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.02"}], ",", 
        RowBox[{"-", ".03"}], ",", 
        RowBox[{"-", "0.04"}], ",", 
        RowBox[{"-", "0.05"}], ",", 
        RowBox[{"-", "0.06"}], ",", 
        RowBox[{"-", "0.07"}]}], "}"}]}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "3"}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"g\[Psi]N", ",", "gA", ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7.9", " ", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[18]:=",
 CellID->176178541],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxs3QXYVcXWB3AVxU7sxG7lGtiMce1ujCuK3d2FmCgKCAiKIN310n0IA1Rs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    "], {{{}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1W1Ml1UYx/GbDBG05cNUfEhBrN60ske10rJlS23NuWlm0HwIy83slU4t
rXCIurQtpwlo0iYgSEtTt+qFmAqYhgywRoCC+NQqRKNAUaTPefH1d/2uc53r
XOe+7z8mL/xg1rKYKIqq/NM0OIo6RkdRJ/7DlGFRlDIiisagMTGKnsLcIVHU
MDyK3qBP8sOHRtGLSOZX0DF0Ci3DC0jil9PRdDJNoZ3ITHIWnSXX7NxUfrB4
D3aPiqI8nHhAHwxTd4RPpMf5Y8ji12OE+rnmG0lnm+uY+IZ+vWmBOxTiwsgo
uogW3LTWRJvRiPM4h39QZ63BnfPxmP2Pok7cZu06DvAbnH1a3TjxKbqffosY
+QgxZryPP+DZfE730360L2pRg+rg9e0Jc9FO2osely/WYx/ixHvNvtv+q9bz
6B+0xNoV+hV/ie6il+m/aMfvZmrUqwBP6PF4eB7yE/EsDvE76AnP+4zabHEl
PSj/HSbw43Gve6ziY+kNvc6Ke4lLPfN76CFzHEQP7iJd7nmzLArvyHs4gcl8
pV6T6Bm6Vd0XyPSutjt/m1ytfjXoL/cxvZ9upY/QLHNNV5djfzbq1e+gDWE+
85Q76yW1Wfxq9Zl0FV1P05yzPdyVP69mLC2U24sipPKH5ducUcDnYyO/AZus
teq90Nmt1ufw1+giPkX8ZfjOsYD/W36p+C86n08Wb8Q2+2fy++Rn83FmqkKq
+bdbu+b5tOEt/iPveR5dQ3ep36xuC3aaPxc56LGn3GwVKMMaPTep2YgkXLL+
pvxFGusuvdFk3090qNxEcQsuoBmJ3uk51Duvj5rh4jg6gsaH3xy9jS7kqhnr
jAdRzL9i7qk4q28HraXTnT0NGe6xTi4Dv4W76LUFn9ibgU/xp/olZkgRj0Fy
uKu+C+yZj77qb8l1hd8r7uA24tTUeEa1qEaf8F064661eHE3TaDP6P00Fnv+
6Tgp/oWeRmX47lGFxPBsECu+Y+5uzBP/qmeaOd7GDP366DvA3Qbidb2Wm3+Q
eIn8a97De3QGPaq2FNP4h/lytRXo0G+ZXCeN1zMBRerWht+bXpfCPvEV6yto
IX8Vl7FHrlUunx4P31v47mkFyjDE/n56r6N5NNtzycEO7EQuSq21O/MoHUfv
6rVSn2563Rlp8gPlq/n6cCYG8P0xE/vctQSnPKufcRKT3O+m3C2s5j/Ej/av
DfXh7xiK8IO6fHN9H9RasbNWmvt9z7pRPMra1/xSvlpcg0EosrZH/S104bCZ
7tDbuGDtOXta6Bznzw7/F9g/wVqV3LvOPUPH84vF6SixnkC/oS97Jkn0ipmv
ok7daL40fI/0SPgm6VR17eF3z7+DhViMdDzkPq/Szc7+DP8DfuIv6Q==
          "]]},
        RowBox[{"-", "0.02`"}]],
       Annotation[#, -0.02, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1nd0kNUZx/FXQWpbESdTikqgrLBkhGCLlqWiRAGBMCtEmYG2CSJgCTJk
BFBOUxDQsKFixbL0VEDAhpHAKRwrhCm251SwhikKFKj9PH98z+8+4z73ee87
7vvQoNHdRt2SJElKuSQ5VjNJvq2RJAMfSJIB6MLuigzcXz1J7sNs8VNVk+RL
9HwwSbbenyR5/Fvo8+wv+E8ixXh8tSR5mI6jtWlmZapWCh5GXdRBX/HG4k2Q
iinsVDX3qLmvVpLsRwkuqHuMHset5pVHOVTSUzPzmqMpWuARXJL/LXob71Vr
kprFNJP9Hf9lpJs/zXppdCptQxfRunJeo3XoZPpz+rX8htb6D/2A/Q3NrZIk
Z+g69mnaQPyM65zCXmzeVePf809k7zK+rIei8LFf5e9u/ntYyF5LF4u/JZ7D
7i9ejm/Uz1wrHU1XiF2Us5Lmyhkmpy57Kp0U+89/lX2S5rH/qIctGIEx7FX8
mXpcTV9mj4xrk59Nx7LX8PcR74v6/PVQYM/q2ZdBkUsH0/r0BVrFnBdpZZpF
3zb/l2KzjH9B82k7OpNuj/ui3hNxr+i0uCfoGH3qvwBXsJ79Pd0vVtG8zew7
6R0ode+P4HMcxiEslPc7z2sOfosxyMUFvTxlnS54z9wnY22M5N/A/kTdjXQ9
TvF/gTfiHpj7B9dfEO8CX0/Msvcn5efTTuKdsZddgmJkq5mI3YL7XG/leGcw
3HXM0mM+mrKb4AH58/Xc0LgRGqAxUvGSXqqJV0dVDGG/o/bjYr/CY+iA9pgt
tkPOTjwZz70+X1f3NXRiL7D2fFzDBvZVekDsHvM+Yt9LK+FufMi+i+5CEWbr
d4T8lq6nFVrjkvrptA3SMFfOHBy0F/fgVUzASqyQ+6W+e8irxX5Cv53jXYv7
yz5vn0vs7/t8/9XTp/Kvx/vO105OeTm3oQJOimXFvZRbGPeRLolnWu5wnBfr
LGeymgesN4UepKk0w/zn8CxmoIR/k3XGqjHeeBwqyutOT6nTjeaxi2l7FGEC
+6j96WDcEcXyBls3C/P00VqsDdIwUeyMXvJodbnVkGuPclBB/Fn504yHuMba
Yimog6HxrTEvBb3UnSg+l28OWpnXEq/jmrqHaD9zzhlvoaP09zHNpkP5stXv
aP5I2omOoh3oWrqcvkuX0TfjWTEeHN8OmkUn00F0Kn2JTqEv0sL4duttinHN
2E/rPYcrfBm0K55BgX7T9VdHLyvNXRVrYUWsjenxXVdrvdwN+At6yD1LV9My
uoq+JW8hMq033rzedALN4Mu3/ux4LuzTCRxHC3M2mdubbqS9aC195OqnLftR
DJCXw36I/2X6IB1DM/RzVN2u9KznoizeS+uViK22R8Ot9Yx6S81fgkLcyl4e
deky2pb2kZeJxexCvIO34/nimxffMFoJ4+K9dC3j6QK629wf5O2hb1j7TcyL
b4eebjfvx/gRfoqfoEe8t/G+4o6oi4r4tf5vqHcT1+O9wjWkx3fVnLvEC6IH
esw1HMWFeH/i/ORrQZvTS/RifP/NOYdr9qCfealojEZoiiYYKL8ZbY6hrmEI
rvNN1093vrlxrruuUnoEc9CNv1j9hvwjjbMxIvaOfZiWohqqo0bk2ocSvOI6
jrDH0qM0sc5o+hscVO8A/o6mcZ7qYxEW4JF4nuL+xzlsbwbSPLqIv9DchXQJ
7WONXDW7GD+Np1BPbAX9IO43XUc70pr0E2vtwGn70z+eEfOvxn7hq/hui52L
ftRcJl6Gs+iNdPN70Y/QUi+t4kxzrw7FGSF/jlrfxL8Gvsadev5Y7ha0kZuG
e/mO288TOIa/ig1zncORGP9gXj+1Nqm1Ob6v8mfG2YzP4p7y/YPmx1mCEnP2
Yx/Kyy2Otegemkb30rXy98f/GfuG+jfxP3ym1kU1LuA8eurveRRjg9hGtDan
f1wrHUAvq7Wd/zuapf/y6pbZlz/HeR3/HvEMxhlhvJ1/J71Nzia5FeLZjO9G
zIlzUOwse5ced6Ov+n3Q0lq76R78DbtQhEfjfDTvMfPaYa51DsutRefz77OH
k+IexTcF8+KbaE6Z/ZxhvNx4Oi3V+xrxP8X3C2vxLgbJO6HuC/Sm/biBtvLX
qL85/kHFPqTj+F/BFXO+j7PJmp/qP0XuDlqb7owzLP7D4hxhfx7/N/QQLZK/
Xuzf7Pf19BXNib3CIvYOuk78tD4ms2eK3x7/CfEtRkNrNsJS8aX82/i2sreh
PhpgBt/M+H8xboZlci/IbWLcOM5ZDLNnNdQ/EHsqt6p1/um6/oVSuVXY2+Kd
plvj/aaPy2sf55n4YTSNfzz5Z/nL8H9N8enk
          "]]},
        RowBox[{"-", "0.03`"}]],
       Annotation[#, -0.03, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1nuUyGUex/Ff2bQIaRu3GWPsOeu+zsklxQgjjPu9PYdiXMJ2GTPjmru0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          "]]},
        RowBox[{"-", "0.04`"}]],
       Annotation[#, -0.04, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1F1M1XUcx/HfQb3Qq3hKSg6Y080S8E6v7EEJLgTRw3xIc0FrGeXUtTUa
oJtohqCRJvNCWy3XAuHg5MJ4iJIypXyozfnYMlbZZqyHOSndynr9Lt58ft/v
7/P7fH//P+ecR57fnNqUCCGs9achN4RvC0OYyA/hLxxFD7qRRseMEHrp5zND
aOU9Zt1GD+WFcGB6CJ0Ph9CF3odCeJLnKSzCE3gcJ3kvOjNC07J6cPPBEM4X
hHAB57BdTqNefjKESjkz6DKapF3mHEWFrH0ydsU5znzM3+ve3fa6aRo9mCr/
Nt8pOt+9hviarQfpT7w9cn6ks/XmoEneAnMa6UJax1ehX4lyvQR/Gc2gmfa+
N+MGPuEdwiDuuf+gzEqe98yuN/cFvT6+Af3jtJ8+IPOSjKXuX4Fa1GC5jHGe
YnNuWP+AMSzhL43PoT8ou4T+Kb9VfhsOy1yqv1dvjfot2mHuNZnf4Tr2qC/T
K6iWWc7fzJfiT8g7b+43uIAx3kI6E/koQBLt/Hn2tsvYgWa86Dl2ynhT/5K6
hda6z/vya2ijM6vkD6tX05VY4VlanFtjXejsSr5W9W/Wu2lCRht/oM/wvGr9
tn62c5/yfoYqvU7ZW535iGa43yQkcM65yfRresL+Ac8b1GfVP8fPHX5BSnaB
vep4D7oi1vxJvIbjcj/kG7euMnOL9XL6q/oW+qz/kVnnLtnud1Yvh76s/ld/
k/20zIuoR7e95+Jnn76uzuYvpRvUGfqT8I4zpc5vNfuI97kt/o/i3ZBU56ON
P5M3C8P8y/g/4GuQd4Qm9Io973yU4L67BL13+f6zbuG5Y+4EcuLnXc6A/H7k
qq/Fd0X7fF8n+K/Yv4pp5p4xYyq9rF7M87czd7FOr0ivGI+a8xjmogjz8Lv5
f2C19Wnzm+S8JHtW/Lw6m3KunS7Ua+dZQL+SP4q12Gevmmd/fL/2Onjq6IjM
zvj7QnPs58Z3yP+0O+2nZbTCjCyeZ9WZdH189/SUM9P5v4y/LfFe9BWZo/G3
RH2G5tk/aGaXfkov7e69/gdV6nT8ztJj9AueN8zZFZ9Hb6Nz/eYMxO8sdjo3
Re9/fMrQ0A==
          "]]},
        RowBox[{"-", "0.05`"}]],
       Annotation[#, -0.05, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klQz2Ecx/EnS5ayRYVsIQfMUMaMSw0HB46ksswg42QbY2wzDmYsY4tk
zyCaoQ5OlFT/rEeksmSZiJJtmME4MJbX7/D5v5/v/n2e/y+9cN28tXEhhBF+
2pJDSBkdwovUEJLxJabiM6wbHsL5kSEMYT9ntzhPTgnh66gQKthf8BKWypvE
3yzeRFnyM+nNsBCScDCd4y+jTvNq5Z91PkOxtBBa9eg+lG9MCN2wii46X8X+
4ldwH+6nn3ommDXDORG79M7ge4cTMIc/myaKNer/kOLFetIx5+N0zfwaemBu
L/772Bsr7bYMZ5m3FAtpOc1k/8Ngp78425zc6G3kLxgRQh7l0nR9arzJdaqm
lexrmGyXAnVT9MnHqbgQa8Uv6pPJvqM+C+/iDztewvoojnX4K3pruXl6fRf/
Rqv5VtEfvjX4F6fJvyeW4fxA/oSI7PvUW/+p5t7GSne5g/HRe6vphdXYEzvl
jHPHDhyLq/SZTzvcN1efEu9bZKet4vnyt2AenhYrpVO0yz476YrYcbU3+W5Q
A/1We4zvKJVQkh1j/G36/hK7ao82cyvwKbuWv46uy33EHqTnExyAj3Egvscl
eiymRdGO7FbzD2Na9C3iMGzH4dF37i79sJmdiC3YHxsxAZuwDz7EvtiFC/Ut
oHwqZu+1zx4qZ1+gW3Z8xV9p72rnKspxzqZS2hztYe5JuScoVe52O17A91iO
H3AFbpK/Jaqh3d7nszm7ME18kz4bab43z2Zf5t/q/1zHLqE4c2/zbePb4x0z
1d5iHxI7p64Yy/AAHqRyeUV4wm7r5c5R04NvLnayO2iD+gw1n+w2Hj9iTLye
1phXhg3yYnREbGz0DVE6vWW3i7+m/xzItL4=
          "]]},
        RowBox[{"-", "0.06`"}]],
       Annotation[#, -0.06, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ktQzWEYx/GnQskluZxThJoxKnYMm3LrWFiw0Ng1ZYpumm4WBoVNbmNT
w7AxRmrGxs6MMlrZWliZQRPqmBGtFFv5/Bff+T3P7/29z/v+33MqWnrre3Ii
4i1ubIkY2RZxaGvE51TETfU0PawvK4uopZ/0Q/yPtEY/rF4sjcjXX1UX0CX9
M/UYqvUnt0ecQq58Dqp472klnZf5gV32FMrUpSManHUUx3AEGdThu/vtl83S
x7JT6n8lEWl7J8sjUvSptcEdEdcwgPXmXacLzvqLjNygzD7+B/snzNlr9h9r
Z+WW6CP9Levd1l7InrbnIW9U/iA9gAWkknvLv5PLqiuc/xUz9hy3XmrGa/5k
cg42638ld0GnPRfQhcve4gqmfMtzZ72h9/W3ze7Xn9EvqqvM3INq9OuzMhfp
BvOK0LXTTKT5HbQTa/nrknfAHH8NLcRqZMxtl5lw5zznnKAr+CuxCrPyfeYX
qPPRJtuKFP8cPY9cfh565b7xe+hu96tEE78Rv3n1zupzxpB6WG4Eo96jzfe3
owOXeE+8Xau61v6N1mvoJtqCB/Y302mZBnWx+h4GzJ7lNSb/Af2Yflw9Tmf0
Je75hYbve8lf5v9Uz+OO3+UuAsvOf8X7D26SbTs=
          "]]},
        RowBox[{"-", "0.07`"}]],
       Annotation[#, -0.07, "Tooltip"]& ], {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdlH1MzHEcx2+VduUxbMWYNSdp1FoeYtM7VCTRk9TCSLLIepySx1goDwtd
c3WrS51cV+fU6Sqrn6dRquFKCo3cRRHhVFPmdPX9/OOz3W6/fb6f1/f7eXh/
bMNjAvaa8Hg8n9Gf8X/cvuO49sCzxRYnOZcx64eD9t2+7a6xXOSYfUPopmg3
xeS9XI7IaF8h8xW/7feL4JqbjNYHH6Wr+PfLaG6c1wdf/aXAREES432B3/Ju
y/74VMb7jM0nBud7RpxjvF7EuerlK90zGa8HHlEx39MashivB8MeeYIdLiLG
+4QPIdbqF7w8xvuIPwGIcQgoYLxuuBe9q5siLmQ8HQY2hp5xbZMyng7DVcuD
LuiLGU+LnKMVzRd7ZYz3AQah0E4qkTNeFxZN6NypsSlj8e8xt9SQcM3pFuO/
hdmctcKc1Up2vgOt6qbe8mtKxmtD4iKFw4hCye5rwSyDm/ZBqpLxnkPkYCNs
taD4BuhN+goDtylY/GM0HKrLn+1UxuIfIsJ9MGXoiZzF34Pg2+1fBRNLWHw1
Sn5ofMOn3WTnK2DuNGypuSBlfhkkN7LLBjyvM38hrEpa+1KDJcwvgumz2rM+
l3LZdzqkr4u1zqZC7shMxfqulESMKPh/1Vcucn9kxot2wX+zSp758zTH+8/I
v1JVP5pBBig+cki3u6AtC8S3rV9j4XIwH3S/tPa+tV2gFPS+qfa58WlJMtD7
D/faOfNLS0H5CcI3Cl40KkH5dywoUZtXloPqU98ca+oGFah+xxrFjufT74Dq
254XOl1yoxJUfz+dt2bZVTWoPz/7XRzn8KtB/RNnBNmE8WtA/XVa+iqqSFoD
6n9XijHRGtB8OK9NVsU9qgHNj4e/ZIvOm8534f75ulNL91SD5q9z0or3+odV
oPnsrgpcFWKg9+hwMGFPyoPpatB8t7ePJQya/5YZ2cnuHSqQPsb7WQHSj92Y
YKg+PTSfIP05Po3O9PZSgPSZt2adwcxaDtLv3ZcJmpHHxSB9v7neZC6KKALp
3yqWv3X/oAS0Hzr4j74MT8gF7Y9M56QltvOyQPtltHn22WEZoP3T5Hl0YWRt
Mmg/Bf/w+ngZG7h/vuUuPQ==
     "]]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  ImageSize->568.8000000000001,
  PlotRange->{{-0.02, 1.05}, {-0.1, 0.14}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{573, 153},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[19]=",
 CellID->95979302]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.4 Linear aerodynamic properties", "Section",
 CellID->92614445],

Cell["\<\
Sometimes, it is useful to express the aerodynamic properties of an airfoil \
in the linear range of the lift curve as of slope of the lift curve, angle of \
attack at zero lift, location of aerodynamic center and pitching moment at \
zero lift. \
\>", "Text",
 CellID->95510791],

Cell[TextData[{
 "If a list of angles of attack is input to the model function, lists of \
strength parameters are output.  For this case, ForceAndMoment fits a \
straight line to results, and computes aerodynamic characteristics of the \
airfoil in terms the linear fit, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["l", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["l\[Alpha]", "TI"]], 
    RowBox[{"(", 
     RowBox[{
      StyleBox["\[Alpha]", "TR"], "-", 
      SubscriptBox[
       StyleBox["\[Alpha]", "TR"], 
       StyleBox["0", "TR"]]}], ")"}]}]}]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["m", "TI"]], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["m0", "TI"]], "-", 
    RowBox[{
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["ac", "TI"]], " ", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["l", "TI"]]}]}]}]], "InlineFormula"],
 ".  The validity of this approach depends on appropriate selection of angles \
of attack."
}], "Text",
 CellID->8061801],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]L", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6."}], ",", 
      RowBox[{"-", "2."}]}], "}"}], "Degree"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aL", ",", "bL", ",", "rC", ",", "un"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]L"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"cl\[Alpha]", ",", "\[Alpha]0", ",", "xac", ",", "cm0"}], "}"}], 
  "=", 
  RowBox[{"ForceAndMoment", "[", 
   RowBox[{
   "\"\<Vortex\>\"", ",", "aL", ",", "bL", ",", "rP", ",", "\[Alpha]L", ",", 
    "rC"}], "]"}]}]}], "Input",
 CellLabel->"In[20]:=",
 CellID->683198910],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7.136462028403815`", ",", 
   RowBox[{"-", "0.073891120135118`"}], ",", "0.2698461086858004`", ",", 
   RowBox[{"-", "0.10614919348506457`"}]}], "}"}]], "Output",
 ImageSize->{291, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[22]=",
 CellID->297998300]
}, Open  ]],

Cell[TextData[{
 "Recall that results for thin-airfoil theory are that the lift-curve slope \
is ",
 Cell[BoxData[
  RowBox[{"2", 
   StyleBox["\[Pi]", "TR"]}]], "InlineFormula"],
 ", and that the aerodynamic center is at the quarter-chord point of the \
airfoil.  Normalize the lift-curve slope by the thin-airfoil result and \
display the angle of attack at zero lift in degrees."
}], "Text",
 CellID->21443967],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", "/", 
    RowBox[{"(", 
     RowBox[{"2", "Pi"}], ")"}]}], ",", 
   RowBox[{"\[Alpha]0", "/", "Degree"}]}], "}"}]], "Input",
 CellLabel->"In[23]:=",
 CellID->595815551],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.1358032080080813`", ",", 
   RowBox[{"-", "4.233649327236399`"}]}], "}"}]], "Output",
 ImageSize->{128, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->411973265]
}, Open  ]],

Cell["\<\
A check for self-consistency is to compute the lift and moment coefficients \
at the angle of attack used for flow visualization by using the linear \
characteristics computed from the list of angles of attack.\
\>", "Text",
 CellID->263220017],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cl\[Alpha]", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}], ",", 
   RowBox[{"cm0", "-", 
    RowBox[{"xac", " ", "cl\[Alpha]", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", "\[Alpha]0"}], " ", ")"}]}]}]}], 
  "}"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->4822966],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0255402104372928`", ",", 
   RowBox[{"-", "0.3828872285723849`"}]}], "}"}]], "Output",
 ImageSize->{142, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]=",
 CellID->515659122]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7.5 Flow field and surface pressure coefficient", "Section",
 CellID->38592037],

Cell["\<\
In addition to the aerodynamic properties computed above, more information of \
possible interest can be presented in a plot of the flow field and surface \
pressure coefficient.  Compute the list of surface pressure coefficients \
using Bernoulli's equation and record the minimum pressure coefficient for \
use in color coding.  In the color function, Hue is used to specify color, \
saturation and brightness.  Positive pressure coefficients are shown in \
orange and negative pressure coefficients are shown in a shade of blue.  \
Minimum and maximum values of pressure coefficient have maximum saturation \
and a pressure coefficient of 0 has a saturation value of 0.  The same color \
function is used for pressure in the flow field, so the graph of surface \
pressure coefficient serves as a color key for the pressure coefficient in \
the flow field.  Prepare graphic for surface pressure coefficient.\
\>", "Text",
 CellID->39871541],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cpC", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpCMin", "=", 
   RowBox[{"Min", "[", "cpC", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"colorFunction", "[", 
    RowBox[{"c_", ",", "cMin_"}], "]"}], ":=", 
   RowBox[{"Hue", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", ".0483667", ",", 
       "0.633338"}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", "c", ",", 
       RowBox[{"c", "/", "cMin"}]}], "]"}], ",", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"cMin", "\[LessEqual]", "c", "<", 
        RowBox[{"-", "1"}]}], ",", "0.6472", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "\[LessEqual]", "c", "<", "0"}], ",", 
       RowBox[{"1", "+", 
        RowBox[{".3528", "c"}]}], ",", 
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", "1"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpSurfaceColor", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xC", ",", "cpC", ",", "rP", ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xC", ",", "cpC"}], "}"}], ",", 
        RowBox[{"colorFunction", "[", 
         RowBox[{"cpC", ",", "cpCMin"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", "0.015", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpSurfaceLine", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xC", ",", "cpC", ",", "rP", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpSurface", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gCpSurfaceColor", ",", "gCpSurfaceLine"}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[25]:=",
 CellID->460900760],

Cell[TextData[{
 "Use the velocity influence coefficients and the strength parameters from \
the model solution to compute the velocity at an arbitrary field point ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 ", induced by the panels representing the discretized airfoil, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["p", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->128602679],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icA", ",", "icB"}], "}"}], "=", 
   RowBox[{"ICVortexLinear", "[", 
    RowBox[{"rF", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"velA", ",", "velB"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"icA", ".", "a"}], ",", 
     RowBox[{"icB", ".", "b"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vel\[Infinity]", "=", 
   RowBox[{"UniformFlow", "[", 
    RowBox[{"1", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vel", "=", 
   RowBox[{"vel\[Infinity]", "+", "velA", "+", "velB"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "u", "}"}], ",", 
     RowBox[{"{", "w", "}"}]}], "}"}], "=", 
   RowBox[{"Components", "[", "vel", "]"}]}], ";"}]}], "Input",
 CellLabel->"In[32]:=",
 CellID->20343141],

Cell["\<\
Locate a collection of points through which flow lines must pass.\
\>", "Text",
 CellID->599562155],

Cell[BoxData[{
 RowBox[{
  RowBox[{"z0", "=", 
   RowBox[{"Range", "[", 
    RowBox[{
     RowBox[{"zMin", "+", "\[CapitalDelta]"}], ",", 
     RowBox[{"zMax", "-", "\[CapitalDelta]"}], ",", "\[CapitalDelta]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"xMin", "+", "\[CapitalDelta]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "z0", "]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tuples", "=", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"x0", ",", "z0"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xMax", "-", "\[CapitalDelta]"}], ",", "0"}], "}"}]}], "]"}]}],
   ";"}]}], "Input",
 CellLabel->"In[37]:=",
 CellID->826808409],

Cell["\<\
Compute the scalar field for pressure coefficient from Bernouilli's equation \
and prepare the graphic.  The preparation of this graphic requires much more \
time than the others because more recursion are needed to reduce numerical \
artifacts near the surface of the airfoil.\
\>", "Text",
 CellID->76766512],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vel", ".", "vel"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSDP", "=", "\[IndentingNewLine]", 
   RowBox[{"StreamDensityPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "w"}], "}"}], ",", "cp"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"colorFunction", "[", 
         RowBox[{"#", ",", "cpCMin"}], "]"}], "&"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "6"}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
     RowBox[{"StreamPoints", "\[Rule]", 
      RowBox[{"{", "tuples", "}"}]}], ",", 
     RowBox[{"StreamScale", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Full", ",", "All", ",", "0.015"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gField", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gSDP", ",", "gA"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[40]:=",
 CellID->146745562],

Cell["\<\
Display the graphics for a combined flow field and pressure field, with a \
plot of surface pressure coefficient serving as a key to color coding used in \
the pressure field.\
\>", "Text",
 CellID->42228577],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gField", ",", "gCpSurface"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7.9", " ", "72"}]}]}], "]"}]], "Input",
 CellLabel->"In[43]:=",
 CellID->448653773],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQeYXddx56kde3c2jGe+2V3PNzNrj2fkHXvXYbzyWLIsK1jBlEiKpCRK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    "], {{0, 676}, {569, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{569, 676},
  PlotRange->{{0, 569}, {0, 676}}]], "Output",
 ImageSize->{573, 676},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[43]=",
 CellID->113373074]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["3.6 Aerodynamic Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"]], "RelatedTutorials",
 CellID->59868671],

Cell[TextData[ButtonBox["A1 CartesianVectors",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/CartesianVectors"]], "RelatedTutorials",
 CellID->474440930],

Cell[TextData[ButtonBox["References",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/tutorial/References"]], "RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"3.7 Analysis of an Airfoil - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 59, 31.9770000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "The individual functions available in Aerodynamics are synthesized in \
this section to determine the aerodynamic properties of a general-aviation \
airfoil as computed by a panel method. After determining the geometry of the \
discretized airfoil as specified by a data file, a numerical solution is \
obtained at a specified angle of attack. Flow visualization is used to verify \
that the solution is plausible, and aerodynamic characteristics of the \
airfoil are computed in the linear range of the lift curve. Properties of the \
flow field are presented as a color-coded density plot for pressure \
coefficient superimposed on a streamline plot. A plot of surface pressure \
coefficient using the same color scheme provides a key to the pressure \
distribution in the flow field. Load the Aerodynamics packages. Import the \
file from the UIUC Airfoil Coordinates Database, and display a few lines of \
the data file to identify the numbering convention used as fore-to-aft.", 
    "synonyms" -> {}, "title" -> "3.7 Analysis of an Airfoil", "type" -> 
    "Tutorial", "uri" -> "Aerodynamics/tutorial/Analysis of an Airfoil"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[607, 21, 78, 1, 70, "TutorialColorBar"],
Cell[688, 24, 209, 6, 70, "LinkTrail"],
Cell[900, 32, 3060, 69, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3985, 105, 63, 1, 70, "Title",
 CellID->509267359],
Cell[4051, 108, 835, 13, 70, "Text",
 CellID->1534169418],
Cell[4889, 123, 125, 6, 70, "Text",
 CellID->124449903],
Cell[5017, 131, 100, 3, 70, "Input",
 CellID->196209460],
Cell[CellGroupData[{
Cell[5142, 138, 61, 1, 70, "Section",
 CellID->265027215],
Cell[5206, 141, 348, 9, 70, "Text",
 CellID->836781195],
Cell[CellGroupData[{
Cell[5579, 154, 229, 8, 70, "Input",
 CellID->2058623809],
Cell[5811, 164, 1549, 47, 88, "Output",
 CellID->67713472]
}, Open  ]],
Cell[7375, 214, 185, 4, 70, "Text",
 CellID->245057279],
Cell[CellGroupData[{
Cell[7585, 222, 281, 7, 70, "Input",
 CellID->322575182],
Cell[7869, 231, 4847, 99, 275, "Output",
 CellID->565679034]
}, Open  ]],
Cell[12731, 333, 638, 14, 70, "Text",
 CellID->627557896],
Cell[13372, 349, 147, 4, 70, "Text",
 CellID->6171103],
Cell[CellGroupData[{
Cell[13544, 357, 135, 4, 70, "Input",
 CellID->583105778],
Cell[13682, 363, 159, 5, 36, "Output",
 CellID->171731451]
}, Open  ]],
Cell[13856, 371, 94, 1, 70, "Text",
 CellID->182804906],
Cell[CellGroupData[{
Cell[13975, 376, 141, 4, 70, "Input",
 CellID->13794719],
Cell[14119, 382, 174, 5, 36, "Output",
 CellID->87133865]
}, Open  ]],
Cell[14308, 390, 65, 1, 70, "Text",
 CellID->603324995],
Cell[CellGroupData[{
Cell[14398, 395, 132, 4, 28, "Input",
 CellID->172065563],
Cell[14533, 401, 5936, 105, 201, "Output",
 CellID->13919548]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20518, 512, 66, 1, 70, "Section",
 CellID->6058915],
Cell[20587, 515, 573, 15, 70, "Text",
 CellID->702507737],
Cell[CellGroupData[{
Cell[21185, 534, 81, 1, 70, "Subsection",
 CellID->198401933],
Cell[21269, 537, 74, 1, 70, "Text",
 CellID->124929276],
Cell[21346, 540, 147, 5, 70, "Input",
 CellID->174803283],
Cell[21496, 547, 427, 10, 70, "Text",
 CellID->234527805],
Cell[CellGroupData[{
Cell[21948, 561, 661, 20, 70, "Input",
 CellID->195944851],
Cell[22612, 583, 259, 8, 36, "Output",
 CellID->360895096]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22932, 598, 63, 1, 70, "Section",
 CellID->550601939],
Cell[22998, 601, 777, 21, 70, "Text",
 CellID->22156770],
Cell[CellGroupData[{
Cell[23800, 626, 241, 8, 70, "Input",
 CellID->11362066],
Cell[24044, 636, 391, 13, 36, "Output",
 CellID->64288410]
}, Open  ]],
Cell[24450, 652, 654, 14, 70, "Text",
 CellID->52332134],
Cell[CellGroupData[{
Cell[25129, 670, 2117, 60, 70, "Input",
 CellID->17324249],
Cell[27249, 732, 138660, 2360, 70, "Output",
 CellID->437338274]
}, Open  ]],
Cell[165924, 3095, 136, 4, 70, "Text",
 CellID->206472012],
Cell[CellGroupData[{
Cell[166085, 3103, 1270, 34, 70, "Input",
 CellID->176178541],
Cell[167358, 3139, 91459, 1530, 70, "Output",
 CellID->95979302]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[258866, 4675, 73, 1, 70, "Section",
 CellID->92614445],
Cell[258942, 4678, 289, 6, 70, "Text",
 CellID->95510791],
Cell[259234, 4686, 1176, 40, 70, "Text",
 CellID->8061801],
Cell[CellGroupData[{
Cell[260435, 4730, 749, 24, 70, "Input",
 CellID->683198910],
Cell[261187, 4756, 334, 9, 36, "Output",
 CellID->297998300]
}, Open  ]],
Cell[261536, 4768, 413, 10, 70, "Text",
 CellID->21443967],
Cell[CellGroupData[{
Cell[261974, 4782, 233, 8, 70, "Input",
 CellID->595815551],
Cell[262210, 4792, 259, 8, 36, "Output",
 CellID->411973265]
}, Open  ]],
Cell[262484, 4803, 254, 5, 70, "Text",
 CellID->263220017],
Cell[CellGroupData[{
Cell[262763, 4812, 356, 12, 70, "Input",
 CellID->4822966],
Cell[263122, 4826, 260, 8, 36, "Output",
 CellID->515659122]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[263431, 4840, 87, 1, 70, "Section",
 CellID->38592037],
Cell[263521, 4843, 952, 14, 70, "Text",
 CellID->39871541],
Cell[264476, 4859, 2324, 65, 70, "Input",
 CellID->460900760],
Cell[266803, 4926, 470, 14, 70, "Text",
 CellID->128602679],
Cell[267276, 4942, 949, 31, 70, "Input",
 CellID->20343141],
Cell[268228, 4975, 109, 3, 70, "Text",
 CellID->599562155],
Cell[268340, 4980, 853, 28, 70, "Input",
 CellID->826808409],
Cell[269196, 5010, 320, 6, 70, "Text",
 CellID->76766512],
Cell[269519, 5018, 1508, 41, 70, "Input",
 CellID->146745562],
Cell[271030, 5061, 218, 5, 70, "Text",
 CellID->42228577],
Cell[CellGroupData[{
Cell[271273, 5070, 263, 8, 28, "Input",
 CellID->448653773],
Cell[271539, 5080, 96527, 1590, 643, "Output",
 CellID->113373074]
}, Open  ]],
Cell[CellGroupData[{
Cell[368103, 6675, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[368171, 6678, 158, 3, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[368366, 6686, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[368441, 6689, 188, 4, 70, "RelatedTutorials",
 CellID->59868671],
Cell[368632, 6695, 173, 4, 70, "RelatedTutorials",
 CellID->474440930],
Cell[368808, 6701, 155, 3, 70, "RelatedTutorials",
 CellID->806871991],
Cell[368966, 6706, 170, 4, 70, "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[369175, 6715, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

