(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    108613,       2626]
NotebookOptionsPosition[    101563,       2398]
NotebookOutlinePosition[    103689,       2446]
CellTagsIndexPosition[    103646,       2443]
WindowTitle->3.5  Convergence And Timing - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.4 Flow Visualization\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/FlowVisualization"], "\<\"3.6 \
Aerodynamic Coefficients\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"], "\<\"Table Of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/ConvergenceAndTiming\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/ConvergenceAndTiming"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/ConvergenceAndTiming.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/ConvergenceAndTiming", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["3.5  Convergence And Timing", "Title",
 CellID->509267359],

Cell["\<\
The example used in this chapter is the Eppler-205 airfoil at an angle of \
attack of 6 degrees.  Lift coefficient and pitching-moment coefficient for \
the airfoil are used as measures of convergence.  These coefficients are \
plotted versus the reciprocal of the number of panels describing the \
discretized airfoil for constant spacing.  If this curve has a linear region \
for large discretization numbers, it is tempting to extrapolate the line to \
the coefficient axis to obtain a reference value for the coefficient.\
\>", "Text",
 CellID->163863731],

Cell["\<\
Computational times for models are plotted versus number of panels describing \
the discretized airfoil.  Since implementation of models result in a full \
system of linear algebraic equations to be solved, this curve is expected to \
be quadratic.\
\>", "Text",
 CellID->133626429],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->836781195],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->2058623809],

Cell[CellGroupData[{

Cell["3.5.1 Eppler-205 airfoil", "Section",
 CellID->627174914],

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  ButtonBox["AirfoilFromDataFile",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"]], 
  "InlineFormula"],
 " to import data from the file for the Eppler-205 airfoil which is located \
in the folder Airfoil Data.  The data file for the Eppler-205 airfoil uses a \
counterclockwise numbering convention, and this is the default value for the \
option NumberingConvention.  "
}], "Text",
 CellID->24014087],

Cell[BoxData[
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->543466123],

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  ButtonBox["FitAirfoil",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/FitAirfoil"]], "InlineFormula"],
 " to fit a B-spline to the data."
}], "Text",
 CellID->193395042],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spline", "=", 
  RowBox[{"FitAirfoil", "[", "rD", "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->199940495],

Cell[BoxData[
 TagBox[
  RowBox[{"BSplineFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.0000000000000004`"}], "}"}], "}"}], 
    ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 ImageSize->{215, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->349215460]
}, Open  ]],

Cell["Visually check that the spline fits the data. ", "Text",
 CellID->107920476],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSpline", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"spline", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gD", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->88849844],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PFPUdx/Fr+pf037hEueMOFAk9D4vYWmrhZAtt1Wo0MagRalsIQrrx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->608318569]
}, Open  ]],

Cell["\<\
Specify angle of attack and a list of discretization numbers.\
\>", "Text",
 CellID->797728430],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"6.", " ", "Degree"}]}], ";", 
  RowBox[{"n", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{"10", ",", "20", ",", "5"}], "]"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"25", ",", "250", ",", "25"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->124450942],

Cell["\<\
Compute a list of collections of vectors locating panel endpoints for the \
list of discretizations numbers.  Display the list of numbers of panels for \
discretized airfoils.\
\>", "Text",
 CellID->728508869],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AirfoilSurfacePoints", "[", 
       RowBox[{"spline", ",", 
        RowBox[{"NDiscretizeUnitSegment", "[", 
         RowBox[{"#", ",", 
          RowBox[{"Layout", "\[Rule]", "ConstantSpacing"}]}], "]"}]}], "]"}], 
      "&"}], ",", "n"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"nP", "=", 
  RowBox[{"Length", "/@", 
   RowBox[{"PanelLengths", "/@", "rP"}]}]}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->207596273],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "30", ",", "40", ",", "50", ",", "100", ",", "150", ",", "200", 
   ",", "250", ",", "300", ",", "350", ",", "400", ",", "450", ",", "500"}], 
  "}"}]], "Output",
 ImageSize->{395, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->121956668]
}, Open  ]],

Cell[TextData[{
 "The last ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["n", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 " values in the list of panel numbers are used to determine a straight-line \
fit to the convergence data.  Specify ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["n", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->329689094],

Cell[BoxData[
 RowBox[{
  RowBox[{"nF", "=", "5"}], ";"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->3218154]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5.2  Solve models", "Section",
 CellID->186435948],

Cell[TextData[{
 "A given model is solved and aerodynamics coefficients computed for the list \
of discretized airfoils.  The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function Timing is used to return the computational time in seconds for \
the solution for each discretization.  Results for aerodynamic coefficients \
are grouped by type rather than by iteration number.  Finally, convergence \
plots are generated but not displayed for each model."
}], "Text",
 CellID->109828650],

Cell[CellGroupData[{

Cell["PMVortexLinearNeumann", "Subsection",
 CellID->276154793],

Cell[TextData[{
 "Compute information for generating convergence and timing plots for the \
model using vortex panels of linearly varying strength and external Neumann \
boundary conditions.  Map the model ",
 Cell[BoxData[
  ButtonBox["PMVortexLinearNeumann",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"]], 
  "InlineFormula"],
 " to each collection of vectors describing a discretized airfoil, arranging \
the result to collect like terms together.  Maximum computational time is \
labeled for later use. "
}], "Text",
 CellID->114624859],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tV2", ",", "a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Timing", "[", 
          RowBox[{"PMVortexLinearNeumann", "[", 
           RowBox[{"#", ",", "\[Alpha]"}], "]"}], "]"}], ",", "1"}], "]"}], 
       "&"}], ",", "rP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tMax", "=", 
   RowBox[{"Max", "[", "tV2", "]"}]}], ";"}]}], "Input",
 CellLabel->"In[10]:=",
 CellID->261387464],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["ForceAndMoment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"]], "InlineFormula"],
 " to compute lift and moment coefficients, recording minimum and maximum \
values for later use."
}], "Text",
 CellID->318823208],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Apply", "[", 
     RowBox[{"ForceAndMoment", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Vortex\>\"", ",", "a", ",", "b", ",", "rP", ",", "\[Alpha]", ",",
          "rC"}], "}"}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clMin", ",", "clMax", ",", "cmMin", ",", "cmMax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", "cl", "]"}], ",", 
     RowBox[{"Max", "[", "cl", "]"}], ",", 
     RowBox[{"Min", "[", "cm", "]"}], ",", 
     RowBox[{"Max", "[", "cm", "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellLabel->"In[12]:=",
 CellID->685483094],

Cell[TextData[{
 "Generate preliminary graphics for convergence plots using the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["PlotConvergence",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PlotConvergence"]], "InlineFormula"],
 "."
}], "Text",
 CellID->147033675],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clV2Ref", ",", "gClV2"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cl"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cmV2Ref", ",", "gCmV2"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cm"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"slopeClV2", ",", "slopeCmV2"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cl", "]"}], "<", 
        RowBox[{"First", "[", "cl", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cm", "]"}], "<", 
        RowBox[{"First", "[", "cm", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[14]:=",
 CellID->314455783],

Cell["\<\
Clear significant variables which are reused in computations for the next \
model.\
\>", "Text",
 CellID->716293580],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "cl", ",", "cm"}], "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->215445822]
}, Open  ]],

Cell[CellGroupData[{

Cell["PMDoubletConstantDirichlet", "Subsection",
 CellID->502776918],

Cell[TextData[{
 "Compute information for generating convergence and timing plots for the \
model using doublet panels of constant strength and internal Dirichlet \
boundary conditions.  This is accomplished by repeating the procedure of the \
previous section using the function ",
 Cell[BoxData[
  ButtonBox["PMDoubletConstantDirichlet",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"]], 
  "InlineFormula"],
 "."
}], "Text",
 CellID->826207730],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tD1", ",", "a", ",", "aW", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Timing", "[", 
          RowBox[{"PMDoubletConstantDirichlet", "[", 
           RowBox[{"#", ",", "\[Alpha]"}], "]"}], "]"}], ",", "1"}], "]"}], 
       "&"}], ",", "rP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tMax", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"tMax", ",", "tD1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Apply", "[", 
     RowBox[{"ForceAndMoment", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Doublet\>\"", ",", "a", ",", "rP", ",", "\[Alpha]", ",", "rC"}], 
        "}"}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clMin", ",", "clMax", ",", "cmMin", ",", "cmMax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"clMin", ",", "cl"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"clMax", ",", "cl"}], "]"}], ",", 
     RowBox[{"Min", "[", 
      RowBox[{"cmMin", ",", "cm"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"cmMax", ",", "cm"}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[18]:=",
 CellID->30890011],

Cell["Generate preliminary graphics for convergence plots.", "Text",
 CellID->694186779],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clD1Ref", ",", "gClD1"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cl"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cmD1Ref", ",", "gCmD1"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cm"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"slopeClD1", ",", "slopeCmD1"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cl", "]"}], "<", 
        RowBox[{"First", "[", "cl", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cm", "]"}], "<", 
        RowBox[{"First", "[", "cm", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[22]:=",
 CellID->319310269],

Cell["\<\
Clear significant variables reused in computations for the next model.\
\>", "Text",
 CellID->84964916],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "cl", ",", "cm"}], "]"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->106005035]
}, Open  ]],

Cell[CellGroupData[{

Cell["PMDoubletQuadraticDirichlet", "Subsection",
 CellID->118691814],

Cell[TextData[{
 "Compute information for generating convergence and timing plots for the \
model using doublet panels of quadratically varying strength and internal \
Dirichlet boundary conditions.  This is accomplished by repeating the \
procedure of the previous section using the function ",
 Cell[BoxData[
  ButtonBox["PMDoubletQuadraticDirichlet",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"]], 
  "InlineFormula"],
 "."
}], "Text",
 CellID->60685572],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "tD3", ",", "a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], 
    "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Timing", "[", 
          RowBox[{"PMDoubletQuadraticDirichlet", "[", 
           RowBox[{"#", ",", "\[Alpha]"}], "]"}], "]"}], ",", "1"}], "]"}], 
       "&"}], ",", "rP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tMax", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"tMax", ",", "tD3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cl", ",", "cm", ",", "\[CapitalDelta]cl", ",", "\[CapitalDelta]cm"}], 
    "}"}], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Apply", "[", 
     RowBox[{"ForceAndMoment", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Doublet\>\"", ",", "a", ",", "b", ",", "c", ",", "rP", ",", 
         "\[Alpha]", ",", "rC"}], "}"}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clMin", ",", "clMax", ",", "cmMin", ",", "cmMax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"clMin", ",", "cl"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"clMax", ",", "cl"}], "]"}], ",", 
     RowBox[{"Min", "[", 
      RowBox[{"cmMin", ",", "cm"}], "]"}], ",", 
     RowBox[{"Max", "[", 
      RowBox[{"cmMax", ",", "cm"}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[26]:=",
 CellID->135262774],

Cell["Generate preliminary graphics for convergence plots.", "Text",
 CellID->435374246],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clD3Ref", ",", "gClD3"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cl"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cmD3Ref", ",", "gCmD3"}], "}"}], "=", 
   RowBox[{"PlotConvergence", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nP", ",", "cm"}], "}"}], ",", "nF"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"slopeClD3", ",", "slopeCmD3"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cl", "]"}], "<", 
        RowBox[{"First", "[", "cl", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Last", "[", "cm", "]"}], "<", 
        RowBox[{"First", "[", "cm", "]"}]}], ",", "\"\<positive\>\"", ",", 
       "\"\<negative\>\""}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[30]:=",
 CellID->378144234]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5.3  Convergence properties", "Section",
 CellID->227129737],

Cell[TextData[{
 "Final convergence graphs are presented in this section.  Preliminary graphs \
generated in the previous section are given appropriate titles and labels.  \
Also, common plotting ranges are used among common graphs for the models to \
facilitate comparison.  Routine ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " coding to add these finishing touches to the convergence graphs detracts \
from the narrative and is in closed cells."
}], "Text",
 CellID->74633868],

Cell["\<\
In each graph, a straight line is fit to data points for relatively fine \
discretization, and both data and line are shown in blue.  Data points for \
coarser discretization, not used to determine the line, are shown in red.  \
Extrapolation of the line beyond the range of data used to determine the \
equation for the line is shown as dashed.  The extrapolated reference value \
corresponding to an infinite number of panels is displayed on the graph.\
\>", "Text",
 CellID->98070734],

Cell[CellGroupData[{

Cell["Lift Coefficient", "Subsection",
 CellID->869225247],

Cell["\<\
The following series of graphs present the convergence properties of the lift \
coefficient for the three models.\
\>", "Text",
 CellID->2960992],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"clMin", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Floor", "[", 
      RowBox[{"100", "clMin"}], "]"}], "/", "100"}], "-", "0.05"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cmMin", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Floor", "[", 
      RowBox[{"100", "cmMin"}], "]"}], "/", "100"}], "-", "0.01"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"clMax", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Ceiling", "[", 
      RowBox[{"100", "clMax"}], "]"}], "/", "100"}], "+", "0.05"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cmMax", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Ceiling", "[", 
      RowBox[{"100", "cmMax"}], "]"}], "/", "100"}], "+", "0.01"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gClV2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gClV2", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"clV2Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "clV2Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeClV2", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeClV2", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMVortexLinearNeumann\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"clMin", ",", "clMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gClD1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gClD1", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"clD1Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "clD1Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeClD1", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeClD1", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMDoubletConstantDirichlet\>\""}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"clMin", ",", "clMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gClD3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gClD3", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"clD3Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "clD3Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeClD3", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeClD3", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMDoubletQuadraticDirichlet\>\""}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"clMin", ",", "clMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"GraphicsColumn", "[", 
    RowBox[{"{", 
     RowBox[{"gClV2", ",", "gClD1", ",", "gClD3"}], "}"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", " ", "72"}]}]}], "]"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[33]:=",
 CellID->228822420],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, 0.9897711520439691}, {0.0022222222222222222`, 
         0.9896214395067449}, {0.0025, 0.9894311090452481}, {
         0.002857142857142857, 0.9891822786083211}, {0.0033333333333333335`, 
         0.9888448165504262}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, 0.9883744876132636}, {0.005, 0.9876872778029462}, {
         0.006666666666666667, 0.9865689490418403}, {0.01, 
         0.9844981599700706}, {0.02, 0.9790145434607962}, {0.025, 
         0.9764192981740645}, {0.03333333333333333, 0.9724211193147836}, {
         0.05, 0.9649551596371126}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz3s41XccB3DRRm5n57gT1XqS+6VTUen5YE3CsTaFYvU793N857Io8zxE
6LYu2xAzt6N1yHFNRGhnJqQjnppO6NnykKflslN0jKL2OX+8n/fz+uP9x3sD
J/4rvraWlhYLo+kntHoli0OBp+2mcZ8aFbyZ/pntyKUgKvLMPo0Z9zJnVvMo
OJ37omEXOjQjXLuDT8HIGln6TnTPqxVXJzEFGQtutt7opochpz9OoGBw0DuS
ic7JnWLK0yiIzQwZcESzLOx/8iikoOpFYps5Wi697nRjiAJW0+avZ6tVwO94
HuZryIalkoI7Pejhw5LUVn820F6/eyZB780QZg+ksSEsoLs/GT3l+o/NfBMb
SluDkr9En+ck5TS/YoO567aZzeg3dhl6bGcOLOqbbvwgU0Ee93NjGw4Hxj+q
txhBe7ibzx8r4cCSdr2yHq2VJRGODHHA0paEnUeXHJE9dTDggkRik8NFb++U
u5kHcCHc3rNoJ1qn5jKdkcYF0z5tjim631b8Z3UrFz7E7pifqlIBx6Irz22e
C2GpvIA/0C6Fykm5Iw8aKoMjitFz5WozFY8HOx4XbElEz24ZeOxSzAPFOoki
BP08qDFJb5gH339j5L4RXTllZvKAwYfGT+MPvL2ugjIG00+yjw/j6oteQ+jc
zqhQ+mk++CpokzJ0++Lu6R87+CC9E7o/G13fUnZ2aY4PSVaZaUc0+xVDHS03
ASQkWx/fhr6rYBqb8QWQNBfnRENPrhcs9koEII13kE1WquDRisU496kAfMOV
0x3oN5ysKGOGECYO+U7noxlfvL0ZzhLCzaO05lg0r8upuDZbCBcyf/HZi86S
j2bNtgmh39j6zAZ0qX9+kEIthF0l7wsXK/A/y6C8xUUEjYFl5BHae+yC0k8k
goML13Sr0K1vu4tGy0SwqlPAzkSvLkmnopUiMFevTYtGh/TsWZ1KF8MhZ28u
E92X3OUlCxTDrydpukZo/wZW0IlsMdgMBR+fkKrgbEJEtLNcDMs5qdI2tNZt
6/f/qsUwGSfOzUMfP/fy5H7PGFgOaQ8m6HVj3/7wuygGrAP7Ovegr8hTyqzK
YuBqjWLJDq1rf+nyJ6MxEGHCXFZfU0Gd6WEjczoB04LwjkG0Z8TLdgMGgZz/
LtA1bir8LmaVCQF6ZKdgAN1mV9A7Y0rA2MqF/gDd6zB0qsuSgF7RKsF99JhP
6ELCegLvSmto3Wg63/+Zwp3ARIU2tw2dV/nwUqcHAbaud+tttOUU5dPiSWBM
GGuksV18euFVJoG/HIZbWtBOKR1hKV4EnshqDZvR/pe237MHAvfrIm/Vo7sH
u0+s9SWwj3bZQONAxsFNDD8CvfFdVB06tCAxc8WfwF0PN4NadFR5g89QAIHf
GnUoGfrvCZju20tgt8mO5io0x36wUB5IoD0xTl9jUfXsgiyIQOvWkaZK9PRs
qlQSTMDrirG+xnEehgfyQwg0qz87WoF+faxI+yKLwNbwlCYpOqnZ6capUAKN
t+rWaPw/nMVdHA==
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0n881HccB3BlEyG/ojLFeshvZedHJXdvxCbuRCcujvss4xJRKOyaSErk
sYrvZH6Gh4vOb3drrBpK09Q8dPthdTLOj0fRt9Va17Hauz9ej9fj+d/rj9fH
+1P2xC3X0NDgYN63QPO2dezhQeavHorG2u9oAMGWVgHVwCo1oPtq0FLThHsM
qpvFndNQVKOfP/8w2oK6xRoptzapQhfHyK2NKDnr56XEE+VoPtVboEspWf39
6oiL6AGXth5t6h9Wa/BanVPojLdXuCuoD6AgnpsoRJe47U6tTTWFE+s+F9ij
+9JKnDMVlrBMpX2YltFQW0rm3ulsgrr0mnoZetkavXrDUgc4k35PKwvNibH4
PfvmFlDVUKcBXdVopX4kYYAk+JX7MrRY1HJyJskdTlTs1L4lpcG2a/5O9X9b
YdzE6XUhOpMly71+2xNyDSSmHDTLiaEqjGFCm8dgiAm6POPKAb8nAEuL91v/
7KZhf5HcpjPcB875pXhVoV31WjPKa32h6VrTTCx6Xja83E3LD3TaRT9uQqec
nyv0i/OHAn+v63NdNDhXRB+RSD6FEq2y39rQD35Zc/GOQQD8FXjWMhXd7e5o
5Bm1C3p7TPO3ob+6nXdX0B8IYy3bzdWdNBieGstZ3MgGM2CP/oAeTyugniVy
YHxR1ZiHpoqPK0tHguHJDuZVf/TOeWXA0KoQOCn+aFgXbWW/coNmZwhs75gz
eNBBw9/q0PNmsaHgyuLkUWgSN9ixV3sPfP9vkAkfPfBF9OHk3j2Qx5gcXY8u
Wkx19k3kQqKeUDrRjn9wkJb7GITBY6PT3WJ0IL2u3rwvDMq+9ZpKQPuwr0ZZ
CvfCw+DizS7oKu9e48c64cC8PFz5uo2GhaGF+MyecFAeq/fsQT98yj7IFESA
aebqVzno63X3Vz4y4kHRksVjX7TXi+ORjdd4UCy5Oa2NthpruuLI3wct6hCD
kVYaVGFvSgr1I8FwOOvARXRywtHNpl2RoDHkNc5D/2G8Oj4rPgpcd5XlmaPF
3E8qL5nxIV84EaRoocHEWZQ71cOH2I4BlwZ0WsWspvahaMjPZvnHo4/U5bjz
TGKAkcE95oSWe1+Ki5XFwFv9iLsvJTQ4po8yAoQC0Ld7wZGhDWsrI5y0CDQd
sn12HC3PS1NUriAgzH69IEKXCwNj9XUIWH99Z+FL9MYtquRnugRq24ULmWi3
G9zT7UYEyl6K59PR+x6tlLqtJ3Aqy+5pErpubZYx042AIN9+jo+OX9p9qcWd
wPpv3sxGvd8zYbNhw1YCDxuHZiPR3WK5/bvtBMJ/SpjloQc9XHz6gABHt3km
DP0kbDbFP4jAjgsO02x067Ybr6RsAqrLamUQOs2CEtkEE5B13lUGopemfM+s
CCXAkB9UBqBXpVVXD4UTsFtzdcoPPRp+1NqTR2DGVjS1E13myW5u3kegYVvQ
lC/aarlaWsQnYBn5dNIbPT09smMpmoDiYO8koJuHxH1JAgIVoqJJFjq5Jfsz
BSHAOxc1yUS7Xth7j7OfgFmV46QX+n/lPmM+
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0H841HcAB/DDrK6oKL+62oNE0o+F/Fjj3SqnPCQiRLJqSRe6GXNlsvKr
E91Fic45Dtc3K8XULZMe5Vg/NE2iuiyle0LfD/IjI9t3f7yf9/P68/222BPr
/502i8XyYfJ/b5v50Pn4Vh5kX/ixy8sI9pmr1qYf4iFkrcROxFjg0uAgFPJg
6K3xOcq49MC11WdUPKQJfjrjx3ik5axNqfshHGynONNygvyT4SaNq6LhKNRe
FcT45azBMa25sWgerfFnlxJcT2c/vx3JB3lgLIkuJji2MSFktiAe0c2Vz5oK
CNSPDCoDPAT49NtHdnIeQY1Vb1zWdBJYxlfrt50m6DHTSuampmDNLafFNScJ
nNiKStX+40gIj4+OTyVQPBly+YWfij6vE1HNyQQB6Z0/z4xLxyPZ5DsHAcED
6Q7HN36ZaKbtQlk/EOzJE3CXhghBMu0Sw2II7gw5NPa6nYIt53WaaRRBhINw
YpFZDtqNdU3JXgJ9akNL2BwRqsLHAgPDCXwHslr6pkUokhanckIIzKWKxEqd
M7i53HQ3fzvB3A3idIVOLraYT9a/8iF4U8Ddsnc4F/365/SrNxN4RrTW+Y3m
4XdPFttwI4HomcXrf9+eRbHAcrTNjeDAHc+bfw+cQ/X4/GwLF4Jw6Toy9T4f
zt2xVJY9gevKyc5O9Xm03jpxPXAlgXx59veaVwXI69sfW2VDMPy873ZteyGi
52ibRVkS7D5mHN3QeAHKCzM83RYThIoX/DF5VwL7+BfmJSYEbkEvu8Zri9DA
jerfZ0hwOetIoXWdFEn7mr5V6hGsq36jFNUV41J/Vpj1DIIgrj53V6AMfQdn
bR7RIug6KM6Y/VSGnU7B3X5TNLZGHZWbbSuBemJX5NxxGo8jvGOaVCVos26N
0wzRKDr9uVjoWYqRYv0VvgM0Qs9b51Q1lMLOQPeJsYZGROfq1++/kUPUet82
5hWN4GGp4ak6OdipXrFLX9DYrTs62GxfhuFSB9fxDhqXfR1tFv9aBr05A1eC
22jQcV3Oj1eUw4UfZrTwAY2ER5EyWVU5cs0lNjwVDX0r9Q29LysQ4cq91XGb
Rr6/kupUVGC910WP0joaUcqkD/W2CvgquhI/1dJY+bHCREeuAH+qUaK8SoO1
RtnXa3YRn9UZe+RU0uCUVBv1FF6Eqsm14EM5jWX9hhz3+RQkLQteKmU0KrwH
MoOMKLydiEgtYbz0StPYYRMKa+wuLxcytuQnPpZzKKiyPX4MZbxoXH2SbUVh
0D9h3nQxjXk61Md2Rwqb1E83bGQ8sRAdvB0U+ocKFQ+LaCQmmW5KC6bgtETj
c53xmHromnQnhZQAhxEp4xFZWXZbOAWjG/fXH2ZMW8/ycI6kgKSpLkPGPfZP
arQTKeR+Hq4XLGH+z7tisegIBbXzper1jLtHM06vTaKwLGos2JbxC+VXvAMp
FOrv55T/c4FGh7vMsjWTgkbU4F7EOEAmEGmEzL7G2b1pjP/S2j7NyqaQ9CEo
K4bxn3d1nzmIKRjsGHwKxlutuz19cimEZnydvIzxwwxl7f6zFCqUmVYGjL3f
iZek5DN/vGu/N1FI454XT1xQQGEdx4Lfw/g/uBZvsQ==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"0.991\\\"\\)\"", 
           StringForm["\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``", 
            NumberForm[
            0.9911654719698267, {4, 3}, NumberPadding -> {"", "0"}]], 
           Editable -> False], TraditionalForm]], {0, 0.9911654719698267}, {
        Left, Bottom}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)\"", 
         TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMVortexLinearNeumann\"", TraditionalForm],
      PlotRange->{0.7899999999999999, 1.04},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -167.4254075523465}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}], InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, 0.9511004233284324}, {0.0022222222222222222`, 
         0.9497922835451513}, {0.0025, 0.9483278611966914}, {
         0.002857142857142857, 0.9466666879252428}, {0.0033333333333333335`, 
         0.9447479123490954}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, 0.9424716210237221}, {0.005, 0.9396404571458992}, {
         0.006666666666666667, 0.935775493793839}, {0.01, 
         0.9291009298824124}, {0.02, 0.9081646891096811}, {0.025, 
         0.89655937617214}, {0.03333333333333333, 0.8781398383441088}, {0.05, 
         0.8455771685297873}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0n9czHccB/BDkhXT1RVplm2lzpXIJKqXjn64upuVQom77/2+7/QL4bFC
CjVqqaijH9emWDZCHooeu3EkD8ajqaQ8JpY96qrPotUsyj774/14P55/vP94
vd/v+UxipHIyh8MR0/q/P/7wQruYkWJ5dmTB+W0Ef/eXyDzkUjjt3Z5RQ81t
PjBgoZDi3faipGpqyf6YyY1KKYxb2yXl1E1D4558rRQhvrHWedR1LREHLZOk
iPpTlrWNuqDQ7GNMlyJhTXKqgFrs6HbMWy/F95z82JqvCIxVZ/kXW6XgvU1G
PkugbOyJWmUjQ2Mlvz1bR9ARa0irF8rwbOUPxYe0BKH71VkP0mWw2nh/Z4KG
wOzZO3e4TgaNS9NUrZogh9lRcGVIhgc6xSWxiuaZt99KtpDBhbPNOb5KgiJ5
8My5DIOmgil2SxUE3oschlPKGPRMvKh3khNwMg3qJ60MljvqZ9kzBGVbarrc
reWw/JRXyJURLLth9HIIkeNp7edL3m4lmPJjni03XY5esyBzdAvB/Y+0j87V
yzFW3TzUFU/AOJqKvIblyI7h5zRtJhDo218aPRQIv8Q8MsURvK4c4f2lUICX
jxXnYgkGlzxoE5RSOw1HVm0i6BFd2mHVoYCzW3h2zkaCM2ae3a9cJcpdtb0p
GwgquD5BhrVKRLfEjyXEEBTeiJPYHlTC/v2oe3Q0wfU3Af35jUpYPVFNl6wn
uHC14vC/r5XYXV1qHxFF58dtpnC8VCAjqf5LIwlu3fOZyVOqcPLVAodFXxK8
dFG9uWNQQZyYbmO/juC3cccX8i4Vvu4u8ZyQ0P0ymXEzuWo8G/+G81ZM/+WL
scsxYjVEZfOHnkcQKEz80p+y1DD35h3rCifINHZmDl5Tw9L9ZnyniKBceEJ0
b0QNjz59iGktzS+2rrwq0CAjJuz5z2EEy7uPtAdpNOgOPlVyOpSgfuz2qc4K
DXY+vzWpLITAomyfdHO7BgeT6o6fDCaIaFpjkWarRWlGWMiBNQR3d5l8a8K0
6Au8fDZtNYGwVixKzdIiYO/NBTIhweGkDZsXGrWwuVjcIgqi929wmiAjWszK
X+0ZuopgZ3bf3nWLdXB+VVjlCYKPu5O//UWjQ/zEtYdugQTHjXsq5lToMOf9
mc9cAwimueXmzerU4WmG34kZ/gTn7WNnONiyaKutbLBaSbB4Q991ay4L7Uir
wIK6Tr9bN8mOxTs/K8P7FQTX5hXfGbBn8Ykp4dAo9R331gzTbBaJbSujeqi7
/SWjSS4spo+1DRipbZXCZ/cWsQhc/YHLLuqiMy25N7xZtBwOKEyhnm2W+l9d
zEJxP8kygXpe4j79dz4sjkQ/HlBQ8/c0Ru3xZdGhPt0QSS3MXdbsBhYpRwOj
vKhvP7yd6ryKxdSW5CYP6jButCs3iEUJr8rPlVpSvP3AuJCFsdzaxZk6rrLW
vzWEpfvsGJhO/fsf6L8byqJixFo6lZpxe6g3hrFYsgKPONSac4OjNSIWm0xV
Df/4EfQPplUZwlkMTHsiGKZO8LZZfyKCxb4IGwOhfpVyavJRMQu7Y7AzU++4
wr+YIWFR3ZZy6CX1f0UARAg=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0ns01HkYBnCriwghUi1RjUpDLpHSmsd1Q8hlTGSYX+zQdWhk0QjRbA6p
Fr/NLeuYXBJTqrFiu6iltVtSq1VbqTaqY/XdklpJ2W9/vOc9n3Pef97zPAuj
44PF6mpqav50Pm/RlA5OTEKny19xARxhGwFENkoRe5zXeHdSS0CtMtp6w549
x8vwaXq9gfrVq2mRJuwvPA7X8JIHdX5UL0ef7eVJyL1wLrWQbcuZyQ7w1JPE
h8dbCa7anmqdwY7ylmeljRdTJ3+qC9Fgp2JPeX3PnfMEhQ4bpJVSI1gUfaxd
0ULQnlhonfLQDOaHDHIVzQSVRcyLSU0L8JMCrcxVBF8Yayv0ipajwEz+XnaW
wD/KpC/9kg0WXpfdetNEcKzGfPxBgz1a127t9T1NUCtrzHq2wxEHizOOnlAS
LD07fK3ioxOU/20UcxoJUnjN+y50OOP+vKVR6ScJeFb2Y7lRLgjntWwePUFQ
kly3xXMImBUotZDWEUTn9S45I3BDD2ex4c0agpXayuSSSnc8+cDqeFcTDDdf
V3eY7okJdtKuUkEQf+RFrqfYC0GmBXPUqgisyyJ3NTR8jXc1z6alVRL8cdO4
4Nosb1S/sTPvqyA458jVd47wQbU7vAKOEeztyP5NdMUXp/ge7PEyAr399zI/
LPLDSEhCtXopQX9iDku2+0MeKrqcVkzA5qcNFPUEYPF8r+l//kDgMTzg3aUb
CP0nw4L1LIG5pdaCKWcCsYa9EPdrIcHr8aAjc2KCsE1bruAUEDDizqbQGcEY
lusOlR+h+X0TmSBpC0bqlUMRo4cI8j5Ird23h4A37JQfkk/7sFxV4jaLD/5c
RVd3HoHvv/MU89v52K0xzc4yl8DN72SEWVwoBseWKX7Mofm4thk80hTgcF/S
HdMDBC+7XsamtArgkXreXiYnuP+P3zYX0UasM71UOppNcKGqW+uBfhgE+9us
/bMIvhpJ21TTEgbVy9Tf2zPpP/dO1HGF4fD33GzJyyAY478vzNXZhFeROFOy
l0CyNWmF0dlNeJr6yEs/jeCugWFsamwEHod9O3XLHtqPELvy4jlCGFusyu5M
IZhtLdv3tFWIijc/abslEySWPZ8yY2ckbOS27aVJBLuqMh3DZkdBb972TL3d
BL2uxeKY5ihwS7sn86UE3N237b3jRAjsX1Y/lEDzqizfaDWdQQfHSxQTT++z
Ex+WazCommlwUEhdEucbo6PJIGOkvyWUepHNmITMZLDmcoqBN7XDxZDvTusz
aIho6LCiDn+gpXIwZVBYMNvqnYSgam6qgYsDg2i1v8dyqGMnNhQ3OjLAc6VF
FjX38ZIFC5wYmHTLgmXU52p7LSfXMLhTZtSwk7pzla1bOxj4OPmIgqmH+M/j
vdYzsJWc7viSWrn64luVHwOd0L0jhtSJJqxsSQCDobW+ZrrUE0/dD2gEMTiu
OZCiRq2bWFHRJWBgXG1sNbiT4LYgieMcxmA0byCsn/qos199fTiDW9ImeR+1
ufq4Kk/IIM91/aMu6sHBnrUTkQy2LJ2rfZW6vqu2fYeIgafu4OqfqSWN6ese
MgwWvm0Sq6hXfh96wz+awaf76QVK6v8BfktIWg==
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0Hk41AkYB3DH1nbQ4UjM1JNiHJEtx7CV74MaaoVaR8UyT2xoSqxNxnpi
baSRGEeuTMPI+D2kJ10yKyJDtZXVhZLNzPjNrWzSte3O/vE+7/P54/s+3+e1
3nd4148Genp6O3Tz/w6Zd5+eE8RCR+7b32ReWsStErvnHWShbE2ae4TObM8u
Vw6HhaRbs5MDnlrUJ1xyKRGzsOafj9ta6Fq8HSi3q/c+iMKf9ZekumtRcTLa
omfdITBjF53VW6/FywWv3+kvPoy5PvZXKPZaXMub/7w7PgW7PkdKdy7TIssv
bc9C9hGMefm4dE9pMPZwaXPoVjZEBtl3f7+nwWUbWWrBl0wcNX/ondSkwYSl
/jHG8WzQpmpqrXM08JgvbBbvz4FdaE9gbLQGwidvPFtSjoOavX+yka5BaN7w
r/NS8zA1Y7Xn3FIN/uCFu0l35sN01p5K06qxr4zNsN3DgVPXlTut/Wr0vnHt
kW0+hQqT6v4+gRpMV84HquVpjF8s4nGz1TAmfAeiFhWDYmbIjNmrRrC6YED5
pRiE4WCKyEONVTxherNhCdZ2WCVZLlFjsS83T2hYCk7HET8npQrSKsa22OlS
bGI4Jt4Xq+DPfCDaOVOGV5VR7GS+CsWj1pJ/J8sxkiYfqctUIaHXv+Mv9Rnc
pkzbPAlTIZq3ceqzpgKFC4y2dbqo4OX8aXh4rBJNx7M6XY1UEDgW/kS+qsL1
vmRqi0yJ6efK7quPq7G8RHSv7ZYSMVnLDnX11CC8aVloEk+JSK7ZnU+3zyI/
d0q8Nl2JzREvR2av1sJYa805GqrEhYKMapqIh9wVQ/Q+ZyU2tknbi0XnMHqm
5Gb/10pEMIwZP4TxkVPTUr5bqsDIAe6Jhc/4WBm/JULVqUBQ4i8Cy5A6GN10
TzSqVmCIGZjUJ67D02h66ESaArVFc7kc/3qUi685dIQoEFlJO32xqx6NN4qC
VzkrwBx2kWh8BGhOnYzJn6vA7mmeySmRAAY3znQfm5AjZs7M6/4NDaAHRHx0
6JLjQrCb3YorDYjhla98VimHNnWEPuR0HqNZzqUmR+RIexjP5188jwB7v+ng
IDmMbcauG33TiDKrREdfezkqdrUTw8JGbKiUt/V8JUdie+bfnQ5C9L6Q2W59
ScL5faOFoUAIYcsmRVgHCb317UqZZRMSxIJcSgUJSl2b+UR1E1YI840kySTs
VSYUb1MCtqb9Es8dJBoD1fkR5gT8U+8IqgJJ2Lb2vUu2IJD46F7sx+9IrE5J
HxJQCLSWDkpE20lQZ8dOzrch4GE2KvEOILHEkHj/2E2XN9dItviR+GCFp6xw
Xd7CVBriRSI9c/mW3N0ECo6aN1zyJPFu7M0l3l7dvWcWcSY6v+U3FP4ZTWC6
gip95EFCS1uwlR5PIGM5TRruRmJiw5PLBukETll6SaNcSDDLWq2pGbo8e2ND
5zoS4zMnitwzCQyObI5bqfOL9m9ZCdkEzKp9peNOJJ5681c/yCdQaxUo3edI
IpTPLiY5BLoyghp6HUg80v/+i14hgVejIXE2Og/enjPqytX9pyZMKrMjEUQb
999RSiDgU0QDQ+f7J9qv7i8ncCByb5yQRiJQwV2TXaHrJ4qymafz3e0sblWV
rh8lRppgS+I/EEJhoQ==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"0.960\\\"\\)\"", 
           StringForm["\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``", 
            NumberForm[
            0.9603710852752703, {4, 3}, NumberPadding -> {"", "0"}]], 
           Editable -> False], TraditionalForm]], {0, 0.9603710852752703}, {
        Left, Bottom}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)\"", 
         TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMDoubletConstantDirichlet\"", TraditionalForm],
      PlotRange->{0.7899999999999999, 1.04},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -502.2762226570395}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}], InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, 0.9831945218660683}, {0.0022222222222222222`, 
         0.9825632028726639}, {0.0025, 0.9817745191652536}, {
         0.002857142857142857, 0.980770311087138}, {0.0033333333333333335`, 
         0.9794395443113051}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, 0.9776577475319064}, {0.005, 0.9751254189083709}, {
         0.006666666666666667, 0.9709763188909919}, {0.01, 
         0.9628313052379318}, {0.02, 0.9394680831794164}, {0.025, 
         0.9279928573311895}, {0.03333333333333333, 0.9089910493150095}, {
         0.05, 0.8711135638734682}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0n9czHccB/CbGgnRJYU0ttW4VJebH7Ps5a6Nims9NIqk+/W9X9/0S5nC
QiW0awnpFJUtv7IieSTKzU4l5cclhxgxzSr50A9iru2zP96P9+P5x/v9eLwf
79c0WcwyZhiHwxHT+r/fGVtuFsskaP43Kt9/PUF/d550hlwCxtXDZxE198q2
59YKCYZ8O+v9qIO2rBhWw0jgncz0fkVd/9LiydNIkNMfETCbutK0NH14rARh
nUFvplHn7OkSGDZL0NHCD/knkUDs5L6br6f7Svpty6gNJcd4p1slsOUJkodT
MzVPQxaOlmKw/BNrbQLB3VVFm86JpIgzNxTeXEeweIsq7fpmKYxtH3/Jo+7y
/HtyX6UUb9q9X2XFE+yUJeScfSnFh3V9R/6Ko/e4brGReshwKICNFlLvlX9j
N1kmg/PNvcFHYwn43hP64g/KsPbzxFkcak5qkepeqww/HxjhrYghOLjmxP3p
o+RQFIsXNEUTzLlk8JqwSI6h9MAlbtRWJ7PsuZvl2Bj1dt2utQTNUzS3Ss/J
0cKPLHgSRSBzMu716pOjYt8G8wLqmXpzh2GGAonv/Tx+YQl6iwcciUIBrrA+
xaIl6Jl1/fbMAgV2Z7x7IaV+GliRYHNXga7SjohqDcHRLkeHa1wGzbFpDx2o
C7kCYVEAg5y5t5OS1AR7LoUH2acz4D94ML5FRXBhcEF3dg2Dim25V2dTl1cV
ZrztZVDbaJVToKTzltFWHC8lDr/4bOVrhuByk8DOkVFC4zg0P5y6Y6pysKFI
CdtJmS5nFAQtFqcn8vtKzDE0jbWj7pelhttxVfBTXpySIKd5+fbdmRViFXjd
Ko9rMgKFkVfwa5oK/XHGEB/qVENbas95Ffz1Lbo8KcEhUW5g04AKiYfyGnol
9H7xqOKqmWqkl4xzCaOe155pFqrViN6F2FORBOfe1eW3FaoxP27qIwdq64Mp
ktVmNbIHKyOT1xAsrf/aepO9BoYITvutCILG741zT/hrYLpsSZ5HLTolDlyf
pkHtyArH7NUEGbGhqz0MGgjIxN+7wun/qycNvRjQINMs2BlMnbij84dgHy1q
862Dj68i+Kg97qff1FqYZBk+Y6j3GZIKJxZqEXO19tOElQQj3HVZ49q0eDa2
1Ol6GEHZ+FVjJtizEIYGugmofUI7L4zissi2iorjU1fqN2g/cGDxsFxX60l9
3nV/w/PxLJJtTMunUzdMb91qdGZxpjp0+xTqdt+g17FTWbi5MM9GUNszokdN
3ixGPk45/iCU5vuoSXeJzyJMVzxwj9q5S+Jb5cPiyBdG4R1q15gU/WEBC1HO
8DYTNS+pJiRpLouNfjrbBmqRbs4Vd7DoKTnAnqauu1G33mUhC99lNVVl1P7c
5W5cIYtdQ39YnaQO2r9um0XEwj10WsER6vDiU76ti1hE2hxrzqd++Ce6Gxez
KKtsdNZTy9xv6A3+LN5LuhW51OrSntcnAlnkVXtZsqm7ezaVFC1h8YwJDsii
juaP/i53KYvZ3Ph9mdSv4vOH/ShmkXpxz+Md1Alneae3BrEwac96bqf+D3HY
UN8=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0ns0FGgYBvBQuRUJlU5ZOWgLqWlk05oHJZNIGJM0Y76TW2J1meSazaXc
Um5TLKNZtaioNo1alpDL6rKVtVsW3VNH6SttJ6uR/faP97znd877z3ueZ9H2
Xb6h6lOmTPFi8/+WaHRYBO/udDpZN9856jQFJHbnJbLTvPQnVxQ7mJXGEbc5
ssu8nfr+aqHM795NEy+QtfO4kcfaxMy5Qb0WBrJeXrf5VDdvZpGsMVNX9pw3
mj+ygcN8ffmFBi3ZPzy33S1+Y6coYr9U+2nKpmLYJiw8nbmQ671XsdcYqtG1
elkVFK3SQtu4wa/wtNFGXP4jhaKIvJrUtsTxjxXrryoo1ObOODWraCkMks5d
aD5J4RW04H7yNTuQadda/iynkFeajQ/UcBDTH+LTJ6eoSqxNHYqyR6B5cdKT
MorFdW+6yiccYBD1l/d4KUUcrz6lqcMReepVFZM/UPBsOGPZQU54WpoqN2Yu
ia3esW4Y0Kh8zVleQrE9p9fqktAFr1VD7g7FFCtnnI8tUbiiUjgy1fsExZv6
W+rc6evw9cQhF7/jFLvyXmWvC3VDvFHNPJGMwrZUvKemZj3kywZPxBRR/HFn
bkGXPh+ZMsXxxEKKy/bWBo7bNmD9ZLRTQQHFgY60G5I2D9xS3gmW5VPMSu87
+NncE2aDTRbyPIqH0kzZ20gv8DWv5CqPUchyk54X3d2EVcmu+xuOUqx985zf
rbcZY58eTL+bS2G2RMdU49JmZD1VrRg+QvF+3CdvTrAPHpvUDbzLoSChnT/7
a/lCV7DPTov5eoh4d3SjLyb+7lKbkU2R83mvrWukH5p7qqONslgflipLXPQF
8L1dlGabSeFBTU7NbxWg1shw3soMChfPc9u+CvdHf1CZYMNhlo9z4+xH2kL0
mdRZhxyiGOkeCYtrEEK+SJQamU7R/9pzp5NkC7g2s1LS0iiaKn7XGTAIQEGa
cDIjleLb0aTAyqsBaB+sspSnsH/6zlRbi7aio/rwUP1BijHBv4XZMwNxpOWT
VdP3FNERMcuM6wKxuF+q35tM8WC2UVh82DZkuabG3j/A+uG3oqx4jgi/zDdN
eJREYWibmPKsQYTmj+0WY4kU0tKXGlrfiZG58MumiQSKPRUH7QMMg2DFd11k
yNzrXBwaXB+EomeGR23jKaz39XD44RL8djM2gRvH8lKUbbGZTnCnfkjPM5bd
p0kHyzQJ3FabqPGZS8I9gmdqEzQ0bvywltncbiz6rS7BTy0X769h5jb7Hb5o
QJBwI0Fhzbx1QEfJXUhg+VCPo8tcMS9+thOXIHGag/+N/RRhKu/iWnuC9xkR
7p3M1o+tTE0dCMJ0yla3MV+u6l0yuZrAR1/NtIG5c9Vyl1YQWJncHDrDPCx4
ucttI8E9G0lcFvP5b5o/Kj0J3C/k7zzELF0gS7TaRPDrinZRCrPqmWuGpg9B
1aolLvHMetLy8m4hQZLzB+0I5h5hjIVjAMFom6UqhPmEo+fZs1sJwt0C3hJm
M/VxZY6IwNejqSeA+cWLu2tUYoKuW7RdwHy2u6o1SkLg5G1+ZTNzdG2y+yAh
uHRPcMaTeWW+/22v7QSLBRmlfOb/APo2TWY=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0G00VAkAxvFB2iKVNk0WnQhpRS8IY/NsbdiKvGSNsmpOW6RBScpEu70O
RsWgUNuYMZjuipaWZlN0pElO0ioiZL2ts+69M0OIU2nvfnjOc35f/5b7Dgcd
0GWxWH7M/v+AOc2uZ3fwUe7FWS3karB/ucpFGM2H+Jhb8TrGArc6J5GIjwT5
hmU9IRoUHqxYk6Xiw0PHaaEz4/HGKysLPaPx9L79eF+wBrlpe9j1jjEYdLK4
vzFIg7cG2kmdBYdhZsXynfDVoFo4t+thZBxSZx7z92/W4Jfvju8yFCTAYV6Q
LMleg54W49JgLwFqw5xPsZdocMd6KD59JhlrJcUNy3Q06DfV+dn7/GnwXdi6
e0fU2DBXUaqKOIuc+b1DK9rUULSNut2KOw/hN4o6y1o1goUdZ+bECxEaPjMr
XaHGM0mI82BgKpY+LNUmZqmxL0fgbbNLBNmJXa0FSWo8GnWqH9p4Eey48N3b
I9TgOYmmzU0vIyZc67cvUA0jYnPjj/MzcVlyzrWSo4Y/ld44MpOJ65YxT4Q2
aiyXKBJL9bJwdDrEL2e+Ggs2i4UKvWysamjxNJqiMZjvvfWnsWw0v5C0GwzQ
8OE9rwmcyIHH+tj9m57RyHxjOfD5nyu42pad97GaxsFHPvf+pq7iXvOf9doC
GnskHpqPdC7qlLGhAWk03B0+dHT05KFiSJDjfIyG/OtLR4f78hEdeUEVGE5j
rGvkYdWra1hsPyx550Nj7y9LYurqr+NG3+t+lhONMPHipx8afoWWajT3Maex
kfu2833VDazhLPxk/AWNsvST12xrJHDr5r400VLwqBxUZtYUwCrO0eRCJwWu
t5F3+A9STPmEfUpsoNB5SJxi+FqKvPjUruIyCjuikuSmATLY9BnyuHkUWnm+
sY9VMmRtWhZw7ByFGxmzxSKfQjRNrt3QFE0hLM/28u26QtB0fn0RlwKvY80A
vUmOLnc9L+W3FELHJIsu1shR9aQ+JsCewl79Ce2T9UU48r2xbvASCmX+zist
/ijChAXvYuZnEur4TtfW1cWIcNF/EDhC4nhLpFR6uxgy2W8D21+SMLLuuTtv
bQlqWb0JFfdJ5AYpiQ5FCVSyqPLrChJRyuR3D1YpkJc73l2bScJhqoStJ1eA
29JWEZFEgrVOOTJkehPvp73GBBEkzGSVJv3XboInqLZT+ZOwIxeZeX5J4C7n
lH4uh0SJL5XKNSFw6Ck71o2xTfnjySNsAuahle2d7iTTNbFVbkbgbMKwwpyx
+fuetLnWBPx+D9xW6EpioR4x9cqZwKCNbUaZM4npr9DODyFgbNyytMGRRGLy
0i0XQgk0FESdOcB4sme0QrKbwAnHWSOzGY9Liy79tYdA93b3mq0OTB9bAy/X
SAI3hfLwFnsS/evb7ugmEvD8eKLwjR0JXk65pflJAqOiRYbJjHsnUjJckgkU
mZbFWzDuVnL4B08TMHDt38JbSaLdU2r1PJVAW5zv8JANiWCpIHNYRCCVNeyf
wvilzs4Z1iUCnIwzSjvGLxr03ziJCUhvVafxrUnssO318csmsNMjcGwe4+YU
ZVXEFQKzm8jd5StI+P4rXnE6l4AyVPjIn3HTNr44P59A9PDy1aNWJP4DSkdi
yg==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"0.989\\\"\\)\"", 
           StringForm["\!\(\*SubscriptBox[\(C\), \(\[ScriptL]\)]\)(0) = ``", 
            NumberForm[
            0.988821149181599, {4, 3}, NumberPadding -> {"", "0"}]], Editable -> 
           False], TraditionalForm]], {0, 0.988821149181599}, {Left, Bottom}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(\[ScriptL]\\)]\\)\"", 
         TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMDoubletQuadraticDirichlet\"", TraditionalForm],
      PlotRange->{0.7899999999999999, 1.04},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -837.1270377617325}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}]}, {}},
  ContentSelectable->True,
  ImageSize->504,
  PlotRangePadding->{6, 5}]], "Output",
 ImageSize->{508, 913},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[40]=",
 CellID->771433077]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pitching-moment coefficient", "Subsection",
 CellID->870013475],

Cell["\<\
The following series of graphs present the convergence properties of the \
pitching-moment coefficient for the three models.\
\>", "Text",
 CellID->438634265],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gCmV2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gCmV2", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\"C\", 
StyleBox[\"m\",
FontSlant->\"Italic\"]]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"cmV2Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "cmV2Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeCmV2", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeCmV2", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\"C\", 
StyleBox[\"m\",
FontSlant->\"Italic\"]]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMVortexLinearNeumann\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"cmMin", ",", "cmMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCmD1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gCmD1", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\"C\", 
StyleBox[\"m\",
FontSlant->\"Italic\"]]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"cmD1Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "cmD1Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeCmD1", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeCmD1", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(C\), \(m\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMDoubletConstantDirichlet\>\""}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"cmMin", ",", "cmMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCmD3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gCmD3", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\"C\", 
StyleBox[\"m\",
FontSlant->\"Italic\"]]\)(0) = ``\>\"", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"cmD3Ref", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "3"}], "}"}], ",", 
            RowBox[{"NumberPadding", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<\>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "cmD3Ref"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Left", ",", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"slopeCmD3", "\[Equal]", "\"\<positive\>\""}], ",", "Top",
             ",", 
            RowBox[{"slopeCmD3", "\[Equal]", "\"\<negative\>\""}], ",", 
            "Bottom"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<reciprocal of number of panels\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\"C\", 
StyleBox[\"m\",
FontSlant->\"Italic\"]]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<PMDoubletQuadraticDirichlet\>\""}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"cmMin", ",", "cmMax"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"GraphicsColumn", "[", 
    RowBox[{"{", 
     RowBox[{"gCmV2", ",", "gCmD1", ",", "gCmD3"}], "}"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", " ", "72"}]}]}], "]"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[41]:=",
 CellID->236745322],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, -0.3030799885049016}, {
         0.0022222222222222222`, -0.3030245888433609}, {
         0.0025, -0.30295338813335526`}, {
         0.002857142857142857, -0.30285918275941803`}, {
         0.0033333333333333335`, -0.3027304067949217}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, -0.30255033565778633`}, {
         0.005, -0.3022869506514747}, {
         0.006666666666666667, -0.3018615090008967}, {
         0.01, -0.30112789172966004`}, {0.02, -0.2994506097235059}, {
         0.025, -0.2987216831002686}, {
         0.03333333333333333, -0.29777117591801894`}, {
         0.05, -0.2963055615838363}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz2lQUwcUBWC2gh0ETdhUFLVFRgNCkKqdFuZKqmCRUAZUpoDy8pKX7RWl
yFJUBA0MdQkVQTahAS2DVaoQsbhEnzQiUFxGQ5HFaSmLhk0oENkEe/PjzJnv
3zlryYNhlJmJiQkfY+yXS6638UkC3lPqphuUjpkcKhRsEBLwiozfYzS76cSw
hYgATcymHjU6JH2vmYYi4Mi36rka9KOx+Y0cGQFzwWrPanTt8+BMyzi0jzqv
Cn0ud9CHSSVg1lRNVKD5Tm453CICpktrpvPRTMVlTk0rAcW9PE0ymtL0hW9b
LIC0tfdyItHtkWVHb/EEcOjjazN+6MB0ScbTVAFYf+AaXNCDG/XOE7UCeDNc
YmaGPkkmnLs5JgCpvvhSjwj/uKQvEriTMKVc8lKLzhPusHUmSWh2j11ZieZ6
OU7El5Lg/zLakIU2UZRJOlpJeH94c7ccXbr/Std6ayE0NGXsC0FvqWc8HQOE
8Jmr+IAX2rwqm8VOFUJ/MjeHjX68Sqa7eksIvh1nAieEOoZ00uZ5TgihvC/m
bCvao6itn9kggiC981Aderzc4DAqEkHBjKyjED2y6elfHiUiWG9e3nEE3Rek
TljULoL9K+Sx0ejKQQe7J2wKLnb9muuHVrF9/Mu+poBz/kXLGnRufVQIK5OC
vdHKAlP03Wm/obMaCh45eyf2kTrmep0qa2acgh2Zu/ob0ar5xeYmnmKQvp/S
X0Y/bPGxdaDE8IxWLpxG968RTzeWiaFTX1v5HfrFvFOPsEsMk0vCe/noSVIR
ZcuWQJhXJ9cbzf5m9sZevgR2R0+w2GiRllPyW4YEio8bLAwCHaNgOhUjdyQw
GnrgVDv6Z15+UItBAvqNKZduo0f41uV1HlJwNY99WoL+vPt0m79UCpavx8+k
om/NNlzoVEnBvV6wj0BblKYR0W1S2B8Q+OArdPCj7RZHWTLY2nH/d1d0c7J2
65WdMggTrWas0LxqflBShgzs5llRekLHZMVFRLszMuiBIyeb0Sa3Vyy8NcjA
cPhJcxU68ceBY6HecqjS1pQq0au7v//pgVQOlRZpijj0eSZFtVwlh+rRP+bC
0VZuyuylnXKI0RdabUZfs4+0cWTRENoRsW4Z2jti4K41m4brH8X84oSuLfpB
bmpHg80m8adG33EpaBy2p6HlVMJaR3Tj+tbj2mU07PDNWWWP7vYNeRe3hoYv
VH86LEWzKN4/LV40uFJ+lovQeZXPlfVcGhQ52zOt0MsGCd86bxr+vbfLwmiX
g2lFF31oUDlGmlmiOSma8JStNCxvSlowR/OUW5rcgAZb9+p3H2J0TMOzhqSV
22iIjahLNHone886tj/uU9yfXECHFBw6Mc+j4eSrx+Pz6Kjyat/WABrMswfe
zqH/7oWh5kAayDtjsUaTbs+KmJ00PHg9NTyLll4deXcliIZjYDk0gx4aOVpR
touGV7SN3OgD3MW784Np+LLQfmAa/V/8BbMzfBqKHzpLjU64yak5HkLD9Ngn
b6bQ/wNm5XeV
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwVynk81Hkcx3Gb3UEywmK3lWQdjxyRRkqZTzOrVgxyNDnm+K5xTa40zlSP
bD3KY0Ql88A6HpZdJOlgsCy/VTlDHs3so+SoXSyl0Nbuitm1H3+8H6/H8/F4
bw1L8I9Yp6am5o1bq1C9y0J0vNtt5TS92DteQYHQoV4o+4Hplb59noOWG4oH
nWSNzOIkH9aaFxc/4ZvIHjD3xuTOeKJzBEoLPZmSeTKIzvBA82RtWdqyKeay
E32Qjb7veKtVU/ae+WFGZ9UFnfpfTYCG7GP4209HZI6+xvA9UX7CEMSuUVnv
4hRUp+Safdr4FthfUNbbgy7PJ7OrWpZg/+7iVAn6I+MNlRvzbSBPNMCPR3sL
TJ6coRyA5zH/lo0urTJbHqtzglJWzKQBujrj5rd/xDrD+z3f3Z6OVVDWDa97
yv51gdtVVYWt6DRmU2Z7lytMWtMnstFMO6clqcANMjYHMAm6KLUm2v0VgI2+
50lndFi20uoulwW+X5QYaKB3bqhPLSpnw7PChz2jMQrqddPAOgbNHcZsuCN1
6IQrs1L3iAPwri2v+wzavpifWFd3EI531g0FoBWPjPN6dD0gfHQrwxLd6Gyr
5xp6CDrESY0fjimo013n+oX3PCF3g3leP3rj+ZGzK+YcSK7P9CpBT0iyZPMx
3vDLg44tiWhZzqmp/GEfOLfA9WOjv3o95dFHPww3cgdKjdBm29abqt89DLN2
77vmxArq7bLfFSORH5Q+T/FqR5OI7jtHNP2hmfZk7ir6fjj/eHybPxxi570M
Q2evnLBnxwTA4qnVewz0oo28iKUbCCpbz2YttOfC55WbOgPh7MKC5mi0gmJx
boRuiToCYmtJ8i106f42/edaXIgS1LSfR7/pexOZ1sqF8eu7RVz06BznmJvw
KLSIq760RbdXDK0f0wsCbWYCSxWloPb9eSqkqiUI7l0wPDmMNhu5XmPLC4bL
Q3G5P6KXAj9ck+qEgNJmq1oqOl6cvN2wIQROr9y55IV+qv9pZHpkKJS9KE0x
QVcH7CgpNOLBrw/27puPVFAG9hmZk608SNzcbHIfLSmeUdeM48N5aU5IPjqx
4qxzkIEAVDGshmi0cn9hhKhJAFJO9Ywb2jbpsZNHlBAus6LTddEby0uO2tEI
LNfSrKYi8H9OMl6iQSAr7mr4JLooylOko0XAyNGk8ne0ucNS/Lw2ASf5DrPf
0IyOgAu39QiIKd6mCXTw2Ho5YzOBEcVd+lN0xWfp+m4MAi0qwT8P0ZEq38Kb
zgQOUi+d12z7wsrU1IWAMjMpqR/dWK3ctrqHwCJN+rYX3b3LkdUJBKz15HNd
6FeBMwkHvAgUWGq/oND1uzv+knMIWM7KTNcsMZFlWPkQaKg143egVZPsixp+
BB457Hr2M5ouKSvr4xKguX6j/An9mJts4RpEIF81p7/mAldObW0wAXMqxa8F
bbZuWZ7NI8B0vzTUhJ6eHt6r4hMYoBnrrLm2r7ozVkggpO97Lzk6/uaZr8cJ
gdlsO2kjeufVI4PeYQRSfJp7G9D/A/WFa2U=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwVz3tUzGkcBvBJGwa5tEilVckglzBd0Oq7KqXdZFQruVRbKA2b0dlOl0Ec
WxlmzFCmC9NomPFuK6qNWcO+c7ptQnjfsoOmbCkrhYmJZLO//eM5z/n89zzO
cclhO0axWKx1TP5v3ti73odD+VDp39bzPobi7U4Nntm7+cB76DDnH8bpyzFX
JOLDq8Qt8QbGpYkV7icb+OAmedyhZfyuMX9uqe9uUBkMhnTG8qPRtjWL90D+
ntam4WiK28e9GbSYlAxp8ubyz9sovprNfqJPEAC81KeO2UrxQf/UqPHpP8Gm
vWe5NZEUG+9NKYtYkw6anvD4+nCKq1y7U46NCOHtGf/CtvUUd9pZHAg8kgVN
SxZ8UnxHsRdbU9aw8zAYqvseoCCKNa2m5b8KjoBghrolxp/iiGzDobEp2TBG
V2CcDxTfUWz0eLYhF1pCd0R97UNxXF564JwoESzQzx/10YviWhO3pnvVcfjd
pdGRxaU4lisammkngYD6ErB3p9ga+TVunSiFzWuSJR1uFK/vO9bYOyIFzdUZ
vH4OxU4KTVqZ5Uk4aHXdV+1C8SQ/WbbG8hRE5OVxU76i+FlhYHD8wCmImRpc
nGtPcVBss26DOQ/MArN78HSKpY+duz735EONPtM7zIbixNqg60/7ToN9/xB/
9ESKoxU+rz/1yyE5qkLdzKZ4xaJhg8FYAB+v+kV0WFGschPve/53IUwZuL24
2ILigSe9+uqWIoj+yl1Y8i/BMQen78E1xaAR3b53bYjgLbKpt4brzsD+lhhe
ppngVZHtj95Xn4XcSc3+OSaCLx3LKOLoFDBrnsd2336CfSqfaaW6EqjKoiL2
C4IjA60Dt32vhP1NIa6O3QQ/SpLljP9LCcR0s/fJU4JDd2Wq7HjnIHoc27Wr
jWASG/JjfcM56IkTx48YCD57YrRMFFQKHwvY9+tamD0FHMllXAoB+pjL9D7B
sQb3rv7VKrCvv6QT3yF404DC5rhOBRxd60ppI/PHyvzmz2XnYbHJS6+uY/au
95jr+Nt5qP1Cui9RT/CrlEfeZOEFELNr5ftuEJx6L0GpvHwBul72v5irJdja
1XhtwhI1eE0M8zNVESwP0yKDRg1/OEutLa8QvEsrfHtzvgaoTYOVvozgRR/U
tpYqDTiaW/fWawhmLdX2dttdhB22szrbVQQ7nKuc1ll0EZbbxmapSgie99LG
wfdLBKvHZsquFBOsDunLjZyGYKld6msF4znl9YN7bRE4uQnWiRm7CNKIygEB
KySBncR45nvjUbYrAv2J8EOzGU+2RB9aPBCA7ULB6SKCh+zhIX8jglUcI09Y
SHCacEbAz5sQLPI2lCcxHjSaKhSbETiupROiGL9Tnhc/iEbwadetRk/Grzjj
1ngnILhxqfqb1wUEdy5rrRqVhsDHU7IkjnFsXrnzzAwECwKPSniMO8w5JzyF
CBwij/T5Mm7TruQnZiEYTsu46MD4oa/SpTkXwfUbO51a5QRHKNOlz0UIfrn7
w4FaxtQifIQlRlDUvrWtgvH9OqvHXBmCDFZ4gYRxKKcjaN0pBElTQgeFjO/m
aKt35iPY7BIcwWcc8kI2O0uOIJgbUBnFuOlbvqywEMGKAJi8lvF/5NaNbA==

          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\\"C\\\", \\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"-0.304\\\"\\)\"", 
           StringForm[
           "\!\(\*SubscriptBox[\"C\", \n StyleBox[\"m\",\nFontSlant->\"Italic\
\"]]\)(0) = ``", 
            
            NumberForm[-0.30360736983652525`, {4, 3}, 
             NumberPadding -> {"", "0"}]], Editable -> False], 
          TraditionalForm]], {0, -0.30360736983652525`}, {Left, Top}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\\"C\\\", \\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]]\\)\"", TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMVortexLinearNeumann\"", TraditionalForm],
      PlotRange->{-0.33, -0.22},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -167.4254075523465}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}], InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, -0.2844107311178482}, {
         0.0022222222222222222`, -0.2837962200705145}, {
         0.0025, -0.2831095035923028}, {
         0.002857142857142857, -0.2823317311420813}, {
         0.0033333333333333335`, -0.281434698358656}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, -0.2803701466298594}, {
         0.005, -0.2790390455507654}, {
         0.006666666666666667, -0.27720889131318094`}, {
         0.01, -0.27404490527579295`}, {0.02, -0.2640414766465009}, {
         0.025, -0.25844346585075983`}, {
         0.03333333333333333, -0.249585957024972}, {
         0.05, -0.23355077579306815`}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0ns0FHgUB3BvE0NmPEaR9CDkMbJbndaeyySE0YO0Rc48zYxfZ5P0cBaZ
6LlYydaKjMcWKy2VNow9N+TR0eP4JRW1dVo6Im0lnbRHZ3/7xz33fP64f3zv
vYtkuzYrjQwMDMSs/u8P5zYMimUSKDR/M7pkBcUPE79IPeUSuB3e6+DKzO89
9NpEIQHOiaowZ+bo7DijNqUEtNytv9kxd7+d9fHSSGA378ZOU+am/qjDZikS
2OxUNPXSn2LRqfEAzJSArd9KwzpmscD9pLBEAqfjspyFzHi+1uvygAT+iM3p
XyakqGwbiQniSqG3ycfC34/io+0VGc0iKQyPCuaDL8WwbFXu3UwpcLr31a72
oTjuM+Y01SSFZZwfWtd6UzwuSyu69lYK0pmpiDXLWR6XbI50uQxK9fVXvvai
WCxfZ+0kk0HPM4tykSdFoZ/DVOo5GVhffWr+jQdFg5wK1eMBGYSPbZkOWUbx
XGLdsIelHLRvrFpj3CmubEdfh1A5PKheMyt2o2hcX8DjZ8rBSc+9uW0pxdsL
NPcvNsshQxszZ9MSijJBZ7HvlByeOA65iRdT9C4ZHEVPBQj5Zt3bF1F8Xzlt
/49CAeWtF0ZiXClOrrj7wLtMAV9uvj6SuJDiSMSVNM4jBaRn1dTEulCsGbe3
vcNXwhSnSrdhAUUdPyC4Yr0SpNPBTgnOFE+1x0fzDithrDDOPtaJov7TtxOF
bUqQF9ic2jGfYsN13dGZ90p4mmAxRuax+VmusYFvEqQOHdArHSne7Auwtlcm
wUxLHn+3gOKoa9KnnookKA23H1M5UKSzghfy4SQIrH1aLLdn+5XlxFvzVdCv
iexKsWP/suHz1TixCg4O+aRpbCkqOr3KLuWqwPXStQt7+BRzcChnslUFHRsz
Gw/xKJaLTkf0Tasgs7pldaYNyy+2rLzurQbv70pDjs+luPr5j4PBajV80L+7
m21NsflzV+mQTg0N2sknx60ompw7KEkYVANx9Ow4w6UY1R1iksHTQFDiY7eT
lhRv7e9cVReuAY6Zn1WZBUVRozhiX64GJhJmUovmUDyasjVhOWrgTq5xYz6H
3b9l/pc30xqotr6actac4t5jr7I2+idDUdjDhiIziguf7/7phjoZ0l5UpJaZ
UvwZ03XzdMkQF13HvWhC0dw9v8BmKBliNB5u540p/m633cqBR0D0MrK90Yii
/9ZXeks+gaXNlln1zE0lB5INbQmYnuhbU8vc6nKm57UdgV6fyCYdc4/HgLbT
kcCGvRE1BczPA6M/prgSiDdZn7+TmacUPevzI5C2OHSbB3NxTX9+u5BA3AdT
h6XMjuOSwOv+BFZ1d9GFzC67DpZUBRD4V7MuSsDsld4Wk76KgPZyCJgxi/JX
9roDgYKgtW4jhhS77nXtcw4isItv/OIZczh/ixs/mMCmkY7yYeboM3sOzYoI
2B0TOd5njq9sDBwIJXD2XrBlB/Nff8PErTACGZWGvX8yy9zvlWA4gR172nNb
mNUXJz/WRRBwFQR/aWSemMw4XxFJwOiVgb6e+XshN/Z0FIGR1hv7a5nfpZYa
5YkJdOVlf/Urc9o1r8vaaAI1iUHvdMz/AT6ISoc=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0ns01GkYB3BRueQSJSkN27pLMQ1C5nErk8Z9jMuYmbfkVkImJJcjnG0i
rcVvI1aWyqxSrYZjk961u9jZrbRvanVR7aHrKmrbEql994/nPOdzzvPPc77f
z7anhyeoq6mpBdH5f0s1+i3jMwa81uia3Xy2n2CQrjsrZU5wF6bFs8apO41T
rrIZJffhUFvSfeqpqQViM+YXbk21+wyhrpAMWxoyw9y5FVHml6jjmB75Imac
e82uKuUI9c9O5y5qMW+4GQFaH9nUOR8VEZrMfFAWv7HOzyW4mhOS2ZRpDOOf
8romcwjuk1U77hs1B7XKvPKCbIKbatDTT9pW0HA7tsUoi+B5Jroti2vs4YHd
s2m5jOAgidmfhXgd6FdMVptmEvzNKYuZe2fY8OjtidTyDIJb89qLH6e6gOcK
D/n8dIJtLkwMNs65QWFowLOjuwnex+060NvvAckVGnLdVIK5a9jTZRIvgFG3
1PqdBNflKJL9nwMwj7dWO6cQvL182LpD6ANVb/WnFUkEr9c9m1PX5Av5poHN
HokET3RdUecs9Ac9P05Z+w6C0yuflvknbAKW9UelTTzBjvXiPWfObIaVZt5W
l7YRfGPIpGrQgAc/Lne+4YwIVro4GHqItkCo7bGBPgnBBf0lv0l/CgQ5t+Md
W0zw4tLbRbOr+eCt37brtIjg+zI583JXEIxPmVpxYwlmKvLHa64Hg9OdDWYd
0QT7TYzzVPqhkHxrKNo7imALOx2WRkcomB/ePHIzkuBXM2GVy+LDoJCXyvAF
BKOEge8jtcJBZaJTOxpO89shzkjrCYeeF8KRkDCCy2czHX13RcDaghKRKoT2
wb6zzsdAAIfNbS3FwQQHTpq2rOgTQNWvefaET7AP/7TIPCkSSksDsrdtpfl4
9xg90BbC2/ev509vIfiF6kXivotCMMgO+iOdR/Ddv/k7vaRRYLzAYmxeAMG9
zdd07hlGQ9+xb9lZmwje+Do/9lR3NMT61Q+q+9N/bn+ncIiLAdnJvceP+hI8
LXhfXaYXCxz9OaWeD8FpKVlrjS/EwsNDcwaNQPCI0dLE3EQRcHTbFQZc2o8I
54baZXGgydtYKt9I8BLHvANjF+Ng8Gu/kys9CZbVP9HQ2i2GtRPvNSrdCd7T
XOQSvUQCxQJbBWsDwcPetQnxXRKIzHb9UulKsMNewuYlSWGo8Z8LDi40r6aG
qDULEbjesWX1rqf3JbLRBk0E2gzvhy7quqTAeD1tBHdDkgXnqVevm057uQhB
UX9rWQs153LEF+cNEajOW787RB1zT6eTswpB3EHL60Lq5uW5Rl4cBMUci+Ip
NsGJH0Jq210QCCZh1XNqh4fWLJYbAps2afcYtbJ12O6TO4LfzY+/vEU94Ork
0wcIjBexRL3UzwVP0jdtRaD4ayWnjPrshsv/dvIR7G/wHCqhlpkxedbBCPhR
op0F1B/GfA9qhiF4deVYUwa1vqyxUSVE4NltqhdFTYRZlh7RCPRk7opQ6qMe
/La2GAQPHGP8Aqkt1Gc6y+MQlLbU5npRP3p03fODGIFQ0r3UjbpN1dqXKkVg
Zzpyzok6rb0wYBQhmL3xLtCeev1XkVeDtiO4esTk8efU/wFAaFM/
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwVx3k41HkcwHFHdlOuWFmTFDuxumtUqtWHVqNypFCo0IUalKKoeVJWpkaH
ydjBahqGmb6r6GIt6eOo34xrDsmS1eHYWk2OClml2j/ez/t52ew+uGWfjpaW
ltfX/r/P5KYVSd4sUOzo67+q3Yx7Z1PLUiJZoLe+Oof21QlOyOByWeDMyNyY
odWMeRG3Fl2mWFCoz5RwP6vxvTzDPm9NJHBKc3fGfVKj4FywRc3CKHAxCWzc
OKbGp1MGR7SND8KtWhkZHlRjaYp+R1V4DPDnFuz1eK7GxJ+PBk5NiAPNK1+6
wz01diqnFfqtS4CEqVe7WdlqvEPvPZI6wYZJ1WKTgAQ1dllqn2QmnwLb8BzO
UX81LteXFlJhSRAbs2RijKFG6eMhp+sxyRAYWX6/2FiNfiltpycfSYGf/vuo
MdKosFG41bFn81nw03TQHtWrcDc/gTknkAsTiqLLdRIV1g4xanqdz0OnufWU
OWdUGMrgjllZXoSKAeaAw14VGpK18h1GaTCvfI/1LhcVbtKkyvsm0kD5ysrr
k7UKZwul8YW6l8HQhJ8qGFai8VpeilQ3HeJjdwVwipTYk8XcsOdtOnjlhtNd
I5XoHqqo2DzMB2axf3IIXYlpT2y6P/+TAeQMu9v9hQIjat3Ln2t+hcXOqa38
TAUGC1cPfHwjgBKaYYHjZgWuXDDe1taZCeIq2WGhkQLFcy8cfvkiC0rdD7RE
Uk34tqOvqqQlG5YK1i3T+6UJQxKnR2HNb1BowI8ZdGnC7bzv6sYf5MCGPfWu
LmON6LztaftoyRXwSVo5Lai0EW+kHs+2qxACOyktti2qEVff7ilLq7gKkmtB
d4hdI25jGjJ3+ovASbBzyK2nAdsP8DhT/xLBQNj6WrecBvTef0Js6ZMLxp9Z
fKPABmwO9Yx+SOXC/Eod13kWDXjl0jc8rnseRO84ffq6sh63Z9pdLMY8oD1w
qh49X4+hbYu637iKoc+gjS91q8eAt0LT8xVioFvfDLfRrscQveFB2dJ8CPIf
N++/X4c3Njnaz7ybD6VRCwNmHavD/iPtK5rnF8AJ7+wsmmMdHlWGi0TFBRBm
0h99/LUcDemdfxgsloDnh7uzFuTLUbCljLRJJZBz7a6S7JLj/jL2u0oHKZiu
yjFLtZTjgg8SC12xFAbT721d3ipDrSVlfb2W16DBzCfOkS/DGbm3zbuyvzq2
wV7gKcMfX5vOWGNGwFGY2F6rL0OJp+bsNnMC3drv4rImy3BO0cORQxYEePvC
TA9+K0PbmPhm8QwC/fO9PGh6MrQa7TynTycgraBVHtKSoYku+dDiSMCyvUQ0
c5TCMRq0srYS+GSmCT/WQ2E8+3u3MwEECo+FTPLqpnCkc+iWMIhAUEezyLaL
wvei/AvqYAKleX+2Nz2jsN9uyroV4QSil3A86B0Udi19fEcnnsBzb9tFajWF
ofwiG6vjBC7dzmiQqCh8Nsy5tIxNwHm6fgRbSeHfZatYEacIZHcOiOybKGxd
I7JVnCXgG1lpelJOoZ8oIe0ll4COanGxr4zCR9q+E1oXCNxk5Hs4UBSqHug9
YfAIGIxzk1tqKfS2e+bulU6gPHhi9u81FDZxykrCMghE1MRUJlZT6Pkv74dT
AgLT7XoD/asorN/I4mVlEXh4LmBkLlL4BVbmiU8=
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\\"C\\\", \\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"-0.289\\\"\\)\"", 
           StringForm[
           "\!\(\*SubscriptBox[\"C\", \n StyleBox[\"m\",\nFontSlant->\"Italic\
\"]]\)(0) = ``", 
            
            NumberForm[-0.2887520391558228, {4, 3}, 
             NumberPadding -> {"", "0"}]], Editable -> False], 
          TraditionalForm]], {0, -0.2887520391558228}, {Left, Top}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(m\\)]\\)\"", TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMDoubletConstantDirichlet\"", TraditionalForm],
      PlotRange->{-0.33, -0.22},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -502.2762226570395}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}], InsetBox[
     GraphicsBox[{
       {RGBColor[0, 0, 1], AbsolutePointSize[5], 
        PointBox[{{0.002, -0.3040605351062051}, {
         0.0022222222222222222`, -0.30413146191109797`}, {
         0.0025, -0.30421952833033705`}, {
         0.002857142857142857, -0.30433197072743523`}, {
         0.0033333333333333335`, -0.30448090876709843`}}]}, 
       {RGBColor[1, 0, 0], AbsolutePointSize[5], 
        PointBox[{{0.004, -0.30468680875955445`}, {
         0.005, -0.30499146755338424`}, {
         0.006666666666666667, -0.30549395797770384`}, {
         0.01, -0.30653130760423464`}, {0.02, -0.30946590445292077`}, {
         0.025, -0.31068817275777105`}, {
         0.03333333333333333, -0.3125264682329867}, {
         0.05, -0.31518930879525164`}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzH801Xccx/Eb1Ygyt6JmpE7d+R3Z1NnhvLmTzNy7nTU5dUv396/PaSlS
fgt32urGxfyYH5eQXytlfoX2DUNFwvVrsljjnLp+lOgHpbP3/eN1nufxz2s7
/+T3Ij0ajcbC6TpsUjXE4nOht7tdcPuMhlqczuLZCrggVNnP6Uy/Gz+zWsiF
NwGqc3+i2XGH9JpFXLAaP6qk0B0vVhztZFw4Mb9Q14Ku6fNXrA3mwjqzHes6
0KlpWlcqmgtfHY+50YNmmTNUztlcqJt3WxlHUyVldjcH8I9THbsmTEOJmicP
ehrzoLtySGGDHjlSENXA5EHsta1jfugDcZLEnmge1CyILYLRWsenFgs1PNi9
/djjVPTP/NDU2hc8sE879ksDetEqzoBnzweHuqif/kGnC/ZvsODzIfSO91ra
WQ3lvNts4XQeHzxMzE/uQtMSCiR/D/CBtT+V44vOC6p4ZGMkAJ6DQ5Yc7dZC
OZn5COBNYO/tZLT+75dN6dEC0MgtJdXobkuZprJBAC6toUvDaL55W7rTggDS
72sfvUc7ZA9NUbZC8Gg0ZG47p6FeFr7a/FwoBMncHpU3enZPz6BDrhBGDNcI
JehJv+pQgxEhdMn+3aZEl2o3b3xAF0FrxJh9NVpNd/Uq+FoEtJC4pgF0WguH
baoQAVXl9Pkyuumtx3RKswjaNQpny3ANVVWvTlp6KYKHZe+iAK1eMdanOYmB
0xpZLUT/1eW6YbNIDE5txSQJPWUtfttZIIZ4g5H119D9K+ZPBI/EMPrBltaP
XuQncDbQJRAxtjNsEU3/dvmPQywJ/PbBdnBrhIYSttnlXkuUwCqDkXp3dAI1
mjDbKIETrcXaIHQ+M8Ov65UEOC2RaxPRsyyjwnoHKSSXviu5it43cXHISyoF
736FUze6Ybk9Z1QtBc/Jhi+fo1fnxXKPDknBq3RdpmmkhvLv8F4dZSqDtuvi
MTf0vbNteyt8ZXAxj5QcRjNvsPzCEmUw2BsRGItOCg48ak/JYGdt2eFiNO3W
Jx/mXsngVlzseAf6zIVnMd+5yKE3hcueQW+bOJV8RyoHxwtaT5MoDfUrFa7e
qpZDinNaggv6I4by8sejcgix9Kk6hL6+6ch6M1MCefOFQeFol8BnTUZ0AsdN
4pd0rsk+J1+1kYC1Iz89At1oldk5s4lAkXTH/Uh0p83A+bYtBMrHr3wRg55w
Z78OtiZQ86DIOAFtKmKOd+0m0FVe0ngJnV7ap2xxJqDsVAQo0Vu0XPd6FwLs
KdELna1OxmZfcSXQZ81gJKPtwpsPhu8lMJx5VaVCM5VudxlA4ImiVJqBbn/Y
HvapJ4HioiT9TLQvPWAX3YuAqEWSrzM7MyR+hUng6fvPBrLQnMIb7gM+BOZC
yiAH/fg/mL53gECV6sKoznzGw2zKl8CpKumZXLS0cvZ1hR+BRa1NZR56ejaq
pOAbArUGhj756B+djX/I8CdwlvFsQuf50zl6l1gE9nnfi1SjQ2vtbp5nE1ji
lZsVoP8HhUB7nQ==
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0ns0FHgUB3Cv9Zj0QKhWqGZRskoj1mNupNZqxvsxHmN+x+T9NlmkB6Fk
Yr2mzUnl0YkkSkZlVnO0i6bdlmOm0mloW0RFSxsxadvrj3vu+fz3ved7N0Uk
+0aqKCkpMXGWN0e1h8pN6XV2KowLio2XioFj3cIRXKZvsFY1j0ML9WMf2Qja
6R8fn59f9szMV2wjwW/0ti2PBAno4nAZVUcgo5uLrWXJ6DCBqHCFYIyuN//B
+0f0rztaOzUFH+ivucc98tAZ/zX6aQjU4CxUOl9AV9C80mrS9OEmm5n7GN3N
q7DKHDaBjid5FEqCVFxTSSa/aH0De4Mn+c5oZUPt+jWV26DcVR6XjmaGGz09
JraGhyeZP11FX7hiqpA320DPTk+dv9EN2ddPvEqwhf2vjvDXJ0rF5rem+i5+
toO2OYsDTHQmvSO3q8cBXsQfjClA07fbLBSFO8NHp42/30VXZTTGuL0BOGuo
ZjaNjuDLzNoCXWCedXiEmiQV79JuyaiqcQWXuUQ5Cz3V8YcKTd0NPBdm7MrQ
yaWTRW6R++ClWh3/AdrqPDu1uXk/cBIGqEtoab9hed9qd7jkUPI1LVkqbre1
1HEI/QEkXElQDPpoT95Dzn0PaP+3YrYGvSb/Wc6nzQwwLz6TN4Qe4RUK3sUz
IT9XJVQ7RSoWFB8ZqxzwhHq5Rqkbeu/UmLtklTdcKy+iZKFNt1KMVdu8wdHX
8WgzelbhU2rA9YHizGzmGJpE9t4M0PQFyaI9d10q9neQnZIk8oW+lwVPvNH8
T2lWrvF+wJAquRaiZ7YJq1xW+4PIZPG9CO3xz/r6Dd3+8HYwR/kD2oVxLdQk
OgDUXxYEWKRhP3tEui+0AqFx4U5tKHpaMh2V2RkI2hnZByrQz98y4pw5QRDi
LXLoQ3fV/UmR67AgrrTo1Be00/sjIVfusOCg5dP1NB7e8+xqo2VYMIz3+1yO
Ri/4L1YUrQwBi+ehZy6hk2LTv9W/FQIBLqN3pegh3bVRWVGh4LZK4aZ9CP/D
b2f1OYMw6ByjP9iL1rPKzh3tDIMNBsplGWje+QlVzUQ2OLX43m5Fp9bl2LL0
wsG9dtOWMbRsz7lIbkc4PL9gfMowXSq2PDRo4x7NgZ3K19y90GtqqoO2qxNI
Ebd75aFlebzhag0CulNq9vnoqmgP7kotAu3rAkwL0JutF5LerSCwkDo3cxJN
u+d38oYOgVzq7vIidLCcIqRtJFB++rasDF23LkvXmUZA6NcZXIOOWvI6d92W
QFAOxbV2Oc9fZsbGdgQWm0O21aHbG2Rbv3xHgK7+SVGP7t29w6UbCPTecaxu
QL/xn0jed4DA0MaukRZ0i/29OSGDwGGPlX2taJ6RINvMk4BRBrv1Bnpp1PWU
hg8BMvD5eBt6Fe/iRUkggdcn6Js60IOB6VQHFgF+a4nWbfTPDoympmACVvKR
2WWbqiiE/DACabbH799Fj48POC6xCayN6G/qRDdJGroTOAQ6SkwqROik68e+
HyYEWKLk7F/Qu8oCHjEjCCgmxNwu9P8hTmnm
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJwV0Hs01HkYBvCZlFBSdiehGya6rNpFO21Wb6lmsqELQorZqDDa0kVoXHKs
y0hMsRpb02QwfrVdKMuS3q7W1iK+X61RdNNWwmJjOEX72z+e85zPf895rHbs
3bxzHIfD8WDzf280qBckeUpg6aqx6SopwZC5tUtTIiQQbPVm3FXWMcvQUSaT
gJzb3HuPdUFo6ZITtRLouVVU+471+7pcu4IVEVDk6hEliCOYlx5odnvxHuCt
Od3SwLrDqG+Ia7IX3guX54zGE/w1xfDxzd2RUOYeNS3gKMGE1VH+k2IOQXu5
z5sjKQTbG6dd8F4bA5dr3HFtBsGr/FcHMsaksGjkkEyXRfCFOTdemJwI3if0
HUxyCX5tqLlQuysJ+PcvaRsVBDUt/ct+iUwGddCN7UNKgt4prUcNDqTAg/mc
R+MLCf6p3OLUuSkN8rP9Pa+XENyREyOc5y8Dsy0Wau1Fgnf6HW+/cjkGzlUD
urNlBMWOspGZ5sfBYPPoSs8KgsaMa922KdmQLNq7a8d1ghu6M+q6xrJB83g4
Y84tgnOVmugLeifgcP3bTNdagiau8hSN3knoH5ic7PGAYKdC6BY8cBJMK0Sx
3IcEReKG6k2DOfC89a27ZQvB7Darl5/+zgVfhXpOh5Zg6B1R1bPun+BIxd0G
/acEA5XO/3zsyQM3wxn7zToJfmP/obW1/RTcGEniNb0hqF6Yuf/1cwU8E/nk
9vUQHHjcdbOc5sN5J+D9NkAwKGH6Hrz9M8z2CUgP0xEMkH/+x4e7pwFIhzbh
I0EX3w6trvwMTOyLWQhcihczYvNtq5UQFy71DdGn6FzWWZldfRbOzCiNjpxE
0VdoLNzuo4KQnaMKu6kUteHy1El/qUBrUpq3mkfRM+yI2nzjORj0k+YaWFBs
Frv/cK/2HFS1xKSWz6Z4JktfLhMVwOIrHT51NhQDTtkev4wFsG5BAD95PkVx
65KXPavUMI0DjUX2FP0GlKbHqtWQeGh57D4HikETBvt+dyiE/Nmh5jYCdu8G
J7tZ1wpBPG80x/lbir0HtILmL4qg8T4zdXQlxajG3SrV5SLoqq8J5QspGvPb
KyZ/WQxXxo8vd1xPMW9zJdOqKYZZbd9zuzdQDKuU/luzQAMCY7uFRj4U7YeL
zfTUGhjp0PNq8qfI+aqy65V5CYR0mu5LDKRoea6M9yK/BOJE6WG5wRTnvzO1
XPEZAy5uZsFeoRSL3bvTfHkMXNlanRXKet6le0P7zBiwjgi6HsfaOjK6WW3J
wMQsDa+E9Uxde7ohn4EmKqj7yHqqHjNMnRjYKfazLw6jOGIBjyRbGMg8rNAN
h1OMls5Y86MfA5/SXPhTJBSH2vtLlVsZ2J//fKMN6/eqwsymQAZ8axac92Dd
a2u0VrCbASu9qm0FrF84tFwdF83AteNtt9ZHsP/nXLKaGcuAnSq+V8z66WBq
1lIpA4pSa8so1k8ql0tCExmIp+EHVawfrVBZN6QxsM7ig+0ga29VTPZrGQPV
i856Ge2hSLheY5xMBuxdVifOYf3w7oQ2RzkDpuIMrRtrT9unIo+TDCRHLtEP
Yl2fWlm+K5cBXRJxOMja/a3cJjGPgfCcw0HprO9/J5ErFAw8KbI8pmT9H9Fq
hNI=
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->None,
      Epilog->InsetBox[
        BoxData[
         FormBox[
          InterpretationBox[
          "\"\\!\\(\\*SubscriptBox[\\\"C\\\", \\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]]\\)(0) = \
\\!\\(TraditionalForm\\`\\\"-0.303\\\"\\)\"", 
           StringForm[
           "\!\(\*SubscriptBox[\"C\", \n StyleBox[\"m\",\nFontSlant->\"Italic\
\"]]\)(0) = ``", 
            
            NumberForm[-0.3034308770693163, {4, 3}, 
             NumberPadding -> {"", "0"}]], Editable -> False], 
          TraditionalForm]], {0, -0.3034308770693163}, {Left, Bottom}],
      Frame->True,
      FrameLabel->{
        FormBox["\"reciprocal of number of panels\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\\"C\\\", \\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]]\\)\"", TraditionalForm]},
      ImageSize->504,
      PlotLabel->FormBox["\"PMDoubletQuadraticDirichlet\"", TraditionalForm],
      PlotRange->{-0.33, -0.22},
      PlotRangeClipping->True,
      RotateLabel->False], {264.6, -837.1270377617325}, 
     ImageScaled[{0.5, 0.5}], {504, 311.489130329947}]}, {}},
  ContentSelectable->True,
  ImageSize->504,
  PlotRangePadding->{6, 5}]], "Output",
 ImageSize->{508, 913},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[44]=",
 CellID->294381282]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5.4 Timing properties", "Section",
 CellID->32786706],

Cell["\<\
Computational times for executing the three models has been recorded and is \
used in the graphics displaying CPU time in seconds versus number of panels \
for discretized airfoils.\
\>", "Text",
 CellID->469986439],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tMax", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Ceiling", "[", 
      RowBox[{"100", "tMax"}], "]"}], "/", "100"}], "+", "0.01"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotTiming", "[", 
   RowBox[{"nP_List", ",", "t_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "data", ",", "fit", ",", "gData", ",", "gExtrapolate", ",", "gFit"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"nP", ",", "t"}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fit", "=", 
      RowBox[{"LinearModelFit", "[", 
       RowBox[{"data", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"x", "^", "2"}]}], "}"}], ",", "x"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gData", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"data", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"AbsolutePointSize", "[", "5", "]"}], "}"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"gFit", "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"fit", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"First", "[", "nP", "]"}], ",", 
          RowBox[{"Last", "[", "nP", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"gData", ",", "gFit", ",", 
       RowBox[{"AspectRatio", "\[Rule]", "0.35"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gTV2", ",", "gTD1", ",", "gTD3"}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"plotTiming", "[", 
       RowBox[{"nP", ",", "#"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"tV2", ",", "tD1", ",", "tD3"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{"gTV2", ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<time\>\"", ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<number of panels\>\"", ",", "\"\<PMVortexLinearNeumann\>\""}],
            "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "Automatic"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.01"}], ",", "tMax"}], "}"}]}], "}"}]}]}], "]"}], 
     ",", 
     RowBox[{"Show", "[", 
      RowBox[{"gTD1", ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<time\>\"", ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<number of panels\>\"", ",", 
            "\"\<PMDoubletConstantDirichlet\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "Automatic"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.01"}], ",", "tMax"}], "}"}]}], "}"}]}]}], "]"}], 
     ",", 
     RowBox[{"Show", "[", 
      RowBox[{"gTD3", ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<time\>\"", ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<number of panels\>\"", ",", 
            "\"\<PMDoubletQuadraticDirichlet\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "Automatic"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.01"}], ",", "tMax"}], "}"}]}], "}"}]}]}], "]"}]}],
     "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", " ", "72"}]}]}], "]"}]}], "Input",
 CellLabel->"In[45]:=",
 CellID->53565918],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {Hue[0.67, 0.6, 0.6], AbsolutePointSize[5], 
        PointBox[{{20., 0.015000000000000013`}, {30., 0.}, {40., 
         0.01599999999999996}, {50., 0.}, {100., 0.031000000000000028`}, {
         150., 0.030999999999999972`}, {200., 0.04700000000000004}, {250., 
         0.09400000000000003}, {300., 0.125}, {350., 0.15599999999999992`}, {
         400., 0.2490000000000001}, {450., 0.2809999999999999}, {500., 
         0.3899999999999999}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk4lV0XxpGQInmTIaSBBjQREtbCcY5jnjNUJLwUGkwlHJXnHBEqEpKQ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          "]]}}},
      AspectRatio->0.35,
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"time\"", TraditionalForm], None}, {
         FormBox["\"number of panels\"", TraditionalForm], 
         FormBox["\"PMVortexLinearNeumann\"", TraditionalForm]}},
      PlotRange->{{0, Automatic}, {-0.01, 0.4}},
      PlotRangeClipping->True], {189., -67.72499999999998}, 
     ImageScaled[{0.5, 0.5}], {360., 125.99999999999997`}], InsetBox[
     GraphicsBox[{
       {Hue[0.67, 0.6, 0.6], AbsolutePointSize[5], 
        PointBox[{{20., 0.}, {30., 0.016000000000000014`}, {40., 0.}, {50., 
         0.}, {100., 0.015000000000000568`}, {150., 0.016000000000000014`}, {
         200., 0.01499999999999968}, {250., 0.04699999999999971}, {300., 
         0.0470000000000006}, {350., 0.0779999999999994}, {400., 
         0.06200000000000028}, {450., 0.11000000000000032`}, {500., 
         0.10899999999999999`}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz30w1AkcBvCtpst15Ta52yWhRG82K0vev98shdZNpRTXrre1kbewLFv2
J7SW6PJy6yUJoRcqL3ltf7ita1LXFHnL1E5pujvHIbEr3Zxzfzzz/PPMZ+bZ
FBR9OGQ5hULxWsr/bWbmW0WhsFBZkCNcyRKAs+VMar0pC8N1u8upHAEcdbwQ
GHCAhbMf1geY8AWQfpg07JazsEJiVORfIIB3kk3FBMMaQ6WP/t49J4DSobGc
f/1ssGnK28Kt7SSsyxSL/mm2xb3bI76hu4bBP+OXPefDnZBhm7dVFBsBoxXe
faG9bBz1ncszeRsDP02diLOUu2Pu69OC4Mx40I3wv7WK7YWv4jfoy04kQQ/9
Gvf6jkM41KcyNHuUDBEc+ttEmTduTozRU607BxeqiOfL9XzQOffpw8+5aUAr
eJ+Zf+U48t5yWH7bpZBxxMO5T+2HtQcg3K9JBnF2Ff49qVwMUja+t5dfANep
BXHUe3+cyM0aWDh5EbDsBnOtQSBytdpEXVWXwGCI49flH4SePJq0wi0PTs1/
THmcE4w9v8dquCP5oNlJVTEG+Dhrs9XRpfJnsK+tK5d/L8C4p0bjzLhCmNLx
DPBxOYm/FWYJf2AVw2h2gE9sRijarLLSHDe/DPunRB4fWsJwb4Y6rUnnCvwV
rBV3b/EUbmhfw/3K6iq4bqEtz3CJwH7X6t4zt8uB+szsYn10JB5yby992FIB
+rK7B21aotAm7bn7pKoS5DvtqOv/iEYTYexV0ZdrwM8pL/ksO43UU8OWU3rV
YKAd+Ji2Mwa1nUNCjX1rYO2KSmGgMgapFoXPP2Rdh43njBx9BbE43eQUPaa6
AVqmJ1oOr4pDba5ta7T1LWA46d0VXYnDzkxpWdPZWohR6TzwRCGiz+oten/W
weSn7KMew0LkqV4kcNh3YJ/FoxKPyHjsX+h5tvnqXSA/OXzRaCdg2a+p9KRL
9RBpvnuktzoBp2UNxUHuDeA4ye/39RDh8fnMgNW6jUv/6V5rR0VoJOekOQw2
wtaUrESlKBFr1hhNBBc1wfYQuy5T/SRs7S0I2RN9D/idoen3GpKw6JaYdseh
GTrL+/kfj4pRemYwKW9jC3y6saix0Ihx3xg7qW2xBYJMa78uyTmD6w7OLJMP
tsL0jnybRuZZXJnOO/byQRu0Vn15N/f4LL5ppNIPVreDr6sJOvCSEVNVdobS
DtCPzGjfRZHg/NCQu63kPuiujmjwKpTgiCjFrS5MAZXsZPF0sQRHzS3YLyIV
wEy+yM4vlWCeqjt7NkYBnOn6geEKCc7uyVnhLFbA+cG5z8F1EqxX9hD9WQpQ
VxIu4l8kqGXb1/htnQJeOeS/rBmXoHul8YquSQWExleVekxKMH9iV/LEzNL+
TnPIxLQEpVbGbH2NAnQ2D2ss1RIMb61tTFhUgKfWRgOSQiCjUGBsRSVB0V/D
f/kdgUUt4TYdliR4arcxEugEpj29GTVhTcLw/h41fQOBtDdPZgztSZjtGJfx
jAl0Ujer0l1IYFQwb4/tIPA8hel2xHvJG9mbkM0gULlw/rXs2JKn6w0WTAJr
PnZ2kT+SIMiI7xVaExg18CpsG3/J65aW0GwJPKS8z+SFkpC6UBjcYU+gqjaF
XRBBApV105zrRKBu3rbKJ6dJKIvsmFsEAtXCJs6yeBL+AwrsPfk=
          "]]}}},
      AspectRatio->0.35,
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"time\"", TraditionalForm], None}, {
         FormBox["\"number of panels\"", TraditionalForm], 
         FormBox["\"PMDoubletConstantDirichlet\"", TraditionalForm]}},
      PlotRange->{{0, Automatic}, {-0.01, 0.4}},
      PlotRangeClipping->True], {189., -203.17499999999993`}, 
     ImageScaled[{0.5, 0.5}], {360., 125.99999999999994`}], InsetBox[
     GraphicsBox[{
       {Hue[0.67, 0.6, 0.6], AbsolutePointSize[5], 
        PointBox[{{20., 0.}, {30., 0.}, {40., 0.015000000000000568`}, {50., 
         0.016000000000000014`}, {100., 0.030999999999999694`}, {150., 
         0.031000000000000583`}, {200., 0.0779999999999994}, {250., 
         0.07800000000000029}, {300., 0.10999999999999943`}, {350., 
         0.17100000000000026`}, {400., 0.25}, {450., 0.2649999999999997}, {
         500., 0.34299999999999997`}}]}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj3s01AkfxofdTbQ0G+VaqTW2MhPKtoP4fsNixG4Rm5JcB4WSy2iG3292
3LKizs4smkVuzdZSLi8qksvmGm+5/Er1ptzWa1lNSSKbd94/nvOc5zzP+Zzz
bAk45R6sTKPRghT6vxsbe5fSaBYYxbceGtYhwNb8jaiSYYHyojvlK1sI8Nyb
4e+33wK3mk0sm5oQkOzeuKk52wJLhUx6kw0BI8SWSyTrazR4I1bOCSQg7/FU
5scje3B8Q/uGndUEfJHO5y3XsrEn5Oby+yMkbJNoepU/Y+OTYIajKpcEvFxu
4aNkidJuqzXbo0iIrB1+3eBqiZadR1fnpJHQM2IXLhizxBlx3L+ZtSSkWq3x
X6Jbo6ROpe2yqhCWp391eX/SBgnNkBfCCCEc1f20ckBig5IEmXpmjBDqHcPX
VzTaYNckw7NYIIT4or0vg9faouTeuOl/04Uw7/U8dqDaFmU5AVojMiHMtmwq
urEI2FzieyltVAjy+w8F1fb7sNvjsPg3vx9htMijP7TPHtma7k6740Wg2/H4
rWDcHt+acH+YFIrgwMxR7QsL9rjvpa1XSboIGvcE+dRudMBcfVvD3b+KIPd+
zJ9KJxxw5/Poiaq7InCb/2VJqvwtrmTcsWCqJMEt56GtvbsdkZ3b+qdmQRJc
eOUTbZ7tjJ+dLMqtGEsG0SK7Z/yqM/5CM83bPpsMMZ+sZ+Q2OONiSD6UvU+G
w9q9jz6+dEbLcgNum3oKGIKNVY8JB6+oXTH3ZKdAZdZGpZAWDm7a/Lx1NCsF
+lnDWXkzLiiT/dVbuy8VtMKP/65i74ZLpoJU67tp0KVTcuy3HQexLcxEUOKX
AeGuOi/jz3lgqM/+P6IdL0BGKflAWdcLc7+fIxNW/QzakrF0cf5hLJjqaf5M
JoG0Qxzb/ndH8GTpdOU3h3Mg2rLoeJfoGG4bfZrL/kkKDq+W+JFjx3GMs8j5
piMfsOCqmbqBP3oON4SKcwvB4LHrkabjAfigJHXpg6QYTrx/LezMDMTimqYf
Ll4ohQUT+jCLCsKCwLUHOx7LwKqsvDB7Axd3qXZHDrKvwat1Ln5ediHI56tP
nr9YBqPn/bzOpIWi/tqOjjybG+D0iseZqAvDSC0rWWtkJfwVuDq6ZuUEPtzW
oEPOVIGDkbZyml04Fi8W5O2K/RfQe42zKk9F4AaVJnnmXA3onas4sKcuEr/T
PmR/saQOsk0s6ZqTp1Bww2TwO6dbEJRZKF08dxpbss+4s97cBgMN/05tkyi8
Os346mx/A6h/Uhzj3xqFv+/nqj0qboSNP27e6809g80Cj/T6siZYzfCpc1eJ
xrk1akzecDOwbHQrePnRuENrspz9vAWihtf94YIxuOzEWMVcaoXZufOenKEY
/L6T9uLg5/fA0bRdyomIRe6XKsxawzZonLP+sKARh/+MPzBkerZDBHPX074r
cVjJPH1AKbED9s4GDXpzeMhN0jeNa+9U/NdxUx/lYVhYiKaHcjd8JfwpvpUX
j3Sn9KUauA/bgy2bGHpnUd5tJJEW9kDQ3dDkmqqzWFYz3/XFm164WzgY9NqT
jxlj/yRJQx/A3NWVBdMFPgbUxOsVnn4IAYwyVWmmAOM0/EZcjPpAvkO8p9os
AdWG/Z/FTvfBzdIPI/OdCeggvEcjrvWDt8OXaO2biJ87JOlfDhkAvYi02ztp
BE5ltN8xtxoELbXwKrccAuMz4WOdMgXF9ol8+SUCn4yIzWEVBWaJWfbiPEWe
i6vuUKXAVV5JDRURePPAVN4TOgUpj+YXA8sVvL8JLaXNFLwrJu34LQQa10Vk
+VpT8MRaPCCbJvBTwvu6RwwFobGleZxZAl1TU36e4Cn2N2qDZ+QEmrtiG09A
wbqtQwvm7wh8Rg/QzBdR4LJ6o0EjjcSSRC/36YsU3BmUBQ2sJ1FjQvlo9nVF
r3GLFadDIqdDT5dVRcGQU9c7HX0St4S0GN2roeBt/fQ5X0MSK17UG801UMAq
Mrs+tYPEb2t8Ow51K3hP98WdZ5F4Nmnm9d+9Cp6WB5iakbifrnoirY8Cblps
X8zXJPYGzNo1DCl4zalSbTaJCdtulnj+hwLRUk5gvRWJ98s03OUvKKBbXGMe
syHx9sxbt4wxCgoi6udXgETH6bAc40kK/gf7SfIK
          "]]}}},
      AspectRatio->0.35,
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"time\"", TraditionalForm], None}, {
         FormBox["\"number of panels\"", TraditionalForm], 
         FormBox["\"PMDoubletQuadraticDirichlet\"", TraditionalForm]}},
      PlotRange->{{0, Automatic}, {-0.01, 0.4}},
      PlotRangeClipping->True], {189., -338.6249999999999}, 
     ImageScaled[{0.5, 0.5}], {360., 125.99999999999994`}]}, {}},
  AspectRatio->1,
  ContentSelectable->True,
  ImageSize->504,
  PlotRangePadding->{6, 5}]], "Output",
 ImageSize->{508, 712},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[48]=",
 CellID->59140639]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5.5  Summary", "Section",
 CellID->154697233],

Cell["\<\
The following observations are based on the results of the example studied, \
and should not be generalized without further study. \
\>", "Text",
 CellID->277145952],

Cell["\<\
Convergence properties for PMDoubletConstantDirichlet are more nonlinear than \
for the higher-order models.  For lift coefficient, results are fairly close \
to those of PMDoubletQuadraticDirichlet.  However, for pitching moment, the \
trend is different, pitching moment decreases with finer discretization for \
PMDoubletConstantDirichlet and increases, for PMDoubletQuadraticDirichlet, so \
noticeable differences occur at coarser discretizations.  As expected \
PMDoubletConstantDirichlet is noticeably faster than the higher-order models.\
\>", "Text",
 CellID->8518968],

Cell["\<\
Convergence properties are much more linear for the two higher-order models.  \
For lift coefficient, the trend of increasing lift coefficient for finer \
discretizations is the same for both models, but PMVortexLinearNeumann has \
the flattest convergence.  For pitching moment the two models have opposite \
trends with PMVortexLinearNeumann computing decreasing moments with finer \
discretizations, and PMDoubletQuadraticDirichlet, increasing moments.  The \
slopes of both convergence curves are small enough, however, that there are \
not unreasonable differences in results even for relatively coarse \
discretizations. \
\>", "Text",
 CellID->389877127],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["3.4 Flow Visualization",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/FlowVisualization"]], "RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["3.6 Aerodynamic Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AerodynamicCoefficients"]], "RelatedTutorials",
 CellID->334470709],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->2248688]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"3.5  Convergence And Timing - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 10, 59, 46.2666000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "The example used in this chapter is the Eppler-205 airfoil at an angle \
of attack of 6 degrees. Lift coefficient and pitching-moment coefficient for \
the airfoil are used as measures of convergence. These coefficients are \
plotted versus the reciprocal of the number of panels describing the \
discretized airfoil for constant spacing. If this curve has a linear region \
for large discretization numbers, it is tempting to extrapolate the line to \
the coefficient axis to obtain a reference value for the coefficient. \
Computational times for models are plotted versus number of panels describing \
the discretized airfoil. Since implementation of models result in a full \
system of linear algebraic equations to be solved, this curve is expected to \
be quadratic. Load the Aerodynamics packages.", "synonyms" -> {}, "title" -> 
    "3.5  Convergence And Timing", "type" -> "Tutorial", "uri" -> 
    "Aerodynamics/tutorial/ConvergenceAndTiming"}, "SearchTextTranslated" -> 
  ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[608, 21, 78, 1, 70, "TutorialColorBar"],
Cell[689, 24, 191, 5, 70, "LinkTrail"],
Cell[883, 31, 2949, 67, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3857, 102, 64, 1, 70, "Title",
 CellID->509267359],
Cell[3924, 105, 569, 9, 70, "Text",
 CellID->163863731],
Cell[4496, 116, 292, 6, 70, "Text",
 CellID->133626429],
Cell[4791, 124, 125, 6, 70, "Text",
 CellID->836781195],
Cell[4919, 132, 101, 3, 70, "Input",
 CellID->2058623809],
Cell[CellGroupData[{
Cell[5045, 139, 63, 1, 70, "Section",
 CellID->627174914],
Cell[5111, 142, 479, 12, 70, "Text",
 CellID->24014087],
Cell[5593, 156, 217, 8, 70, "Input",
 CellID->543466123],
Cell[5813, 166, 227, 8, 70, "Text",
 CellID->193395042],
Cell[CellGroupData[{
Cell[6065, 178, 135, 4, 70, "Input",
 CellID->199940495],
Cell[6203, 184, 375, 14, 36, "Output",
 CellID->349215460]
}, Open  ]],
Cell[6593, 201, 82, 1, 70, "Text",
 CellID->107920476],
Cell[CellGroupData[{
Cell[6700, 206, 552, 18, 65, "Input",
 CellID->88849844],
Cell[7255, 226, 5843, 103, 201, "Output",
 CellID->608318569]
}, Open  ]],
Cell[13113, 332, 105, 3, 70, "Text",
 CellID->797728430],
Cell[13221, 337, 387, 12, 70, "Input",
 CellID->124450942],
Cell[13611, 351, 219, 5, 70, "Text",
 CellID->728508869],
Cell[CellGroupData[{
Cell[13855, 360, 539, 16, 70, "Input",
 CellID->207596273],
Cell[14397, 378, 346, 10, 36, "Output",
 CellID->121956668]
}, Open  ]],
Cell[14758, 391, 386, 14, 70, "Text",
 CellID->329689094],
Cell[15147, 407, 109, 4, 70, "Input",
 CellID->3218154]
}, Open  ]],
Cell[CellGroupData[{
Cell[15293, 416, 58, 1, 70, "Section",
 CellID->186435948],
Cell[15354, 419, 496, 10, 70, "Text",
 CellID->109828650],
Cell[CellGroupData[{
Cell[15875, 433, 63, 1, 70, "Subsection",
 CellID->276154793],
Cell[15941, 436, 581, 13, 70, "Text",
 CellID->114624859],
Cell[16525, 451, 629, 19, 70, "Input",
 CellID->261387464],
Cell[17157, 472, 368, 12, 70, "Text",
 CellID->318823208],
Cell[17528, 486, 932, 28, 70, "Input",
 CellID->685483094],
Cell[18463, 516, 330, 11, 70, "Text",
 CellID->147033675],
Cell[18796, 529, 1159, 38, 70, "Input",
 CellID->314455783],
Cell[19958, 569, 126, 4, 70, "Text",
 CellID->716293580],
Cell[20087, 575, 147, 4, 70, "Input",
 CellID->215445822]
}, Open  ]],
Cell[CellGroupData[{
Cell[20271, 584, 68, 1, 70, "Subsection",
 CellID->502776918],
Cell[20342, 587, 490, 12, 70, "Text",
 CellID->826207730],
Cell[20835, 601, 1637, 49, 70, "Input",
 CellID->30890011],
Cell[22475, 652, 88, 1, 70, "Text",
 CellID->694186779],
Cell[22566, 655, 1159, 38, 70, "Input",
 CellID->319310269],
Cell[23728, 695, 113, 3, 70, "Text",
 CellID->84964916],
Cell[23844, 700, 137, 4, 70, "Input",
 CellID->106005035]
}, Open  ]],
Cell[CellGroupData[{
Cell[24018, 709, 69, 1, 70, "Subsection",
 CellID->118691814],
Cell[24090, 712, 504, 12, 70, "Text",
 CellID->60685572],
Cell[24597, 726, 1690, 51, 70, "Input",
 CellID->135262774],
Cell[26290, 779, 88, 1, 70, "Text",
 CellID->435374246],
Cell[26381, 782, 1159, 38, 70, "Input",
 CellID->378144234]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27589, 826, 68, 1, 70, "Section",
 CellID->227129737],
Cell[27660, 829, 488, 10, 70, "Text",
 CellID->74633868],
Cell[28151, 841, 497, 8, 70, "Text",
 CellID->98070734],
Cell[CellGroupData[{
Cell[28673, 853, 58, 1, 70, "Subsection",
 CellID->869225247],
Cell[28734, 856, 155, 4, 70, "Text",
 CellID->2960992],
Cell[CellGroupData[{
Cell[28914, 864, 5702, 157, 19, "Input",
 CellOpen->False,
 CellID->228822420],
Cell[34619, 1023, 20954, 380, 934, "Output",
 CellID->771433077]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55622, 1409, 69, 1, 70, "Subsection",
 CellID->870013475],
Cell[55694, 1412, 168, 4, 70, "Text",
 CellID->438634265],
Cell[CellGroupData[{
Cell[55887, 1420, 5016, 136, 19, "Input",
 CellOpen->False,
 CellID->236745322],
Cell[60906, 1558, 21357, 397, 934, "Output",
 CellID->294381282]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82324, 1962, 61, 1, 70, "Section",
 CellID->32786706],
Cell[82388, 1965, 225, 5, 70, "Text",
 CellID->469986439],
Cell[CellGroupData[{
Cell[82638, 1974, 4386, 130, 70, "Input",
 CellID->53565918],
Cell[87027, 2106, 12024, 214, 733, "Output",
 CellID->59140639]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99100, 2326, 53, 1, 70, "Section",
 CellID->154697233],
Cell[99156, 2329, 175, 4, 70, "Text",
 CellID->277145952],
Cell[99334, 2335, 586, 9, 70, "Text",
 CellID->8518968],
Cell[99923, 2346, 671, 11, 70, "Text",
 CellID->389877127],
Cell[CellGroupData[{
Cell[100619, 2361, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[100687, 2364, 158, 3, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[100882, 2372, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[100957, 2375, 177, 4, 70, "RelatedTutorials",
 CellID->806871991],
Cell[101137, 2381, 189, 4, 70, "RelatedTutorials",
 CellID->334470709],
Cell[101329, 2387, 168, 4, 70, "RelatedTutorials",
 CellID->2248688]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[101536, 2396, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

