(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    148334,       5156]
NotebookOptionsPosition[    126963,       4400]
NotebookOutlinePosition[    129087,       4448]
CellTagsIndexPosition[    129044,       4445]
WindowTitle->3.3  Implementation - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.2 Validation Example\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ValidationExample"], "\<\"3.4 Flow \
Visualization\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/FlowVisualization"], "\<\"Table Of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/tutorial/Implementation\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/Implementation"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/Implementation.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/Implementation", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["3.3  Implementation", "Title",
 CellID->509267359],

Cell[TextData[{
 "This section provides details for the implementation of the three \
panel-method functions implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " for a coarsely discretized Eppler-205 airfoil.  In addition to \
illustrating the common steps used in constructing a model, some of the \
choices that must be made are pointed out.  Also, the display of intermediate \
results may aid those constructing their own panel methods."
}], "Text",
 CellID->1534169418],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->585195885],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->20779588],

Cell[CellGroupData[{

Cell["3.3.1  Eppler-205 Airfoil", "Section",
 CellID->491421075],

Cell[TextData[{
 "The data file for the Eppler-205 airfoil has been downloaded from the UIUC \
Airfoil Data Base to the Airfoil Data folder in the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " software.  Use ",
 Cell[BoxData[
  ButtonBox["AirfoilFromDataFile",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilFromDataFile"]], 
  "InlineFormula"],
 " to import data from the file and rearrange the data to the form used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  This data file uses the counterclockwise numbering convention, which is \
the default value for the option NumberingConvention."
}], "Text",
 CellID->323137],

Cell[BoxData[
 RowBox[{
  RowBox[{"rD", "=", 
   RowBox[{
   "AirfoilFromDataFile", "[", 
    "\"\<Aerodynamics\\\\Airfoil Data\\\\e205.dat\>\"", "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->543466123],

Cell["Count the number of vectors in the file.", "Text",
 CellID->173149258],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberOfVectors", "[", "rD", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->416922631],

Cell[BoxData["61"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->104749150]
}, Open  ]],

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  ButtonBox["FitAirfoil",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/FitAirfoil"]], "InlineFormula"],
 " to fit a B-spline to the data and check visually that the spline fits the \
data."
}], "Text",
 CellID->193395042],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"spline", "=", 
  RowBox[{"FitAirfoil", "[", "rD", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gD", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rD", ",", 
     RowBox[{"Joined", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gSpline", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"spline", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gD", ",", "gSpline"}], "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->88849844],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3f+PFPUdx/Fr+pf037hEueMOFAk9D4vYWmrhZAtt1Wo0MagRalsIQrrx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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->393419389]
}, Open  ]],

Cell[TextData[{
 "Specify an angle of attack and discretization parameters.  Compute panel \
endpoints using ",
 Cell[BoxData[
  ButtonBox["AirfoilSurfacePoints",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"]], 
  "InlineFormula"],
 ", and plot the discretized airfoil."
}], "Text",
 CellID->135072324],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"6.", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "3"}], ";", 
  RowBox[{"layout", "=", "HalfCosineSpacing"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"spline", ",", 
     RowBox[{"NDiscretizeUnitSegment", "[", 
      RowBox[{"n", ",", 
       RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotAirfoil", "[", "rP", "]"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->25651006],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3c+rXOUZB/Bb+pf03wiULsSFuBALIQtxE2HQTd0km3bTbnSjMOjGgDQL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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->169311790]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.3.2  Panel method using vortex panels of linearly varying strength and \
exterior Neumann boundary conditions\
\>", "Section",
 CellID->336729780],

Cell[TextData[{
 "The discretized airfoil is specified by ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " straight-line panels, where the circulation density for each panel varies \
linearly with distance from the beginning of the panel.  The clockwise \
numbering convention is used to determine the beginning of a panel."
}], "Text",
 CellID->479438142],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Gamma]", "TR"], 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], ")"}]}], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["i", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], " "}]}]}]], "InlineFormula"],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["i", "TI"], "=", "1"}], ",", "2", ",", "3", ",", 
   StyleBox["\[Ellipsis]", "TR"], ",", 
   StyleBox[
    ButtonBox["N",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/N"],
    FontSlant->"Italic"]}]], "InlineFormula"]
}], "Text",
 CellID->111507038],

Cell[TextData[{
 "Strength parameters are denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["b", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 " and the panel-local coordinate is denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["x", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ".  Strength parameters for the discretized airfoil are grouped as lists."
}], "Text",
 CellID->101991089],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"]
}], "Text",
 CellID->104238284],

Cell[TextData[{
 "There are ",
 Cell[BoxData[
  RowBox[{"2", 
   StyleBox["N",
    FontSlant->"Italic"]}]], "InlineFormula"],
 " unknown strength parameters in the formulation of this model."
}], "Text",
 CellID->547624004],

Cell[TextData[{
 "Boundary conditions at collocation points provide ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " equations, continuity of circulation density between panels (except at \
trailing edge) provide ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "-", "1"}]], "InlineFormula"],
 " equations, and the Kutta condition (zero circulation density at trailing \
edge) provides the final equation for a system of ",
 Cell[BoxData[
  RowBox[{"2", 
   StyleBox["N",
    FontSlant->"Italic"]}]], "InlineFormula"],
 " linear algebraic equations involving the unknown strength parameters.  The \
system of equations is solved using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Text",
 CellID->375367223],

Cell[CellGroupData[{

Cell["Step-by-step implementation", "Subsection",
 CellID->725608851],

Cell[CellGroupData[{

Cell["Airfoil geometry", "Subsubsection",
 CellID->225787759],

Cell["\<\
Geometric quantities for the discretized airfoil are determined from panel \
endpoints.\
\>", "Text",
 CellID->472269960],

Cell["Compute panel lengths.", "Text",
 CellID->74064168],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]", "=", 
  RowBox[{"PanelLengths", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->106567359],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.5002885392353387`", ",", "0.36607906794806605`", ",", 
   "0.1362110722318475`", ",", "0.14784225044636182`", ",", 
   "0.36612761798854254`", ",", "0.5050815775453544`"}], "}"}]], "Output",
 ImageSize->{409, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->5087492]
}, Open  ]],

Cell["Count the panels.", "Text",
 CellID->10851564],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nP", "=", 
  RowBox[{"Length", "[", "\[Delta]", "]"}]}]], "Input",
 CellLabel->"In[14]:=",
 CellID->152897124],

Cell[BoxData["6"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->510270591]
}, Open  ]],

Cell["\<\
Compute unit vectors normal normal to panels, directed outward.\
\>", "Text",
 CellID->162262132],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"un", "=", 
  RowBox[{"PanelNormals", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[15]:=",
 CellID->691393489],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.0345027900632578`", ",", "0.018161718177544042`", ",", 
     RowBox[{"-", "0.18056985639311346`"}], ",", 
     RowBox[{"-", "0.42303444756106034`"}], ",", 
     RowBox[{"-", "0.02275423631690169`"}], ",", "0.1416780193852656`"}], 
    "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.999404601489232`"}], ",", 
     RowBox[{"-", "0.9998350623942129`"}], ",", 
     RowBox[{"-", "0.9835621622257387`"}], ",", "0.9061136000395913`", ",", 
     "0.999741088847325`", ",", "0.9899127935444962`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.0345027900632578, 
    0.018161718177544042`, -0.18056985639311346`, -0.42303444756106034`, \
-0.02275423631690169, 
    0.1416780193852656}, {-0.999404601489232, -0.9998350623942129, \
-0.9835621622257387, 0.9061136000395913, 0.999741088847325, 
    0.9899127935444962}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{455, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->136121080]
}, Open  ]],

Cell["\<\
Compute locations of collocations points, placing them just outside of panel \
centers.\
\>", "Text",
 CellID->11573225],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rC", "=", 
  RowBox[{
   RowBox[{"PanelPoints", "[", "rP", "]"}], "+", 
   RowBox[{
    RowBox[{"10.", "^", 
     RowBox[{"-", "10"}]}], " ", "un"}]}]}]], "Input",
 CellLabel->"In[16]:=",
 CellID->92036532],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.7500046659113888`", ",", "0.3169999879461579`", ",", 
     "0.06700461569302872`", ",", "0.06699952420201506`", ",", 
     "0.3169968728694684`", ",", "0.7500066423162746`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008630675320085856`"}], ",", 
     RowBox[{"-", "0.02058566297165969`"}], ",", 
     RowBox[{"-", "0.01161216852538943`"}], ",", "0.0319568209114868`", ",", 
     "0.06739348046365765`", ",", "0.03577947886629698`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.7500046659113888, 
    0.3169999879461579, 0.06700461569302872, 0.06699952420201506, 
    0.3169968728694684, 
    0.7500066423162746}, {-0.008630675320085856, -0.02058566297165969, \
-0.01161216852538943, 0.0319568209114868, 0.06739348046365765, 
    0.03577947886629698}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{490, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->94250242]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions at collocation points", "Subsubsection",
 CellID->15365561],

Cell["\<\
The equations applying tangent-flow boundary condition at each collocation \
point can be written in matrix form.\
\>", "Text",
 CellID->412123985],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["va", "TI"]], ".", 
     StyleBox["a", "TI"]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["vb", "TI"]], ".", 
     StyleBox["b", "TI"]}]}], "=", 
   RowBox[{"-", 
    SubscriptBox[
     StyleBox["v", "TI"], 
     StyleBox[
      RowBox[{"\[Infinity]", ",", "n"}], "TI"]]}]}]], "InlineFormula"]
}], "Text",
 CellID->9417412],

Cell[TextData[{
 "The matrices ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["va", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["vb", "TI"]]], "InlineFormula"],
 " are of dimension ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " by ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 ", and consist of the components of velocity influence coefficients at \
collocation points normal to the panels associated with those collocation \
points, and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox[
    RowBox[{"\[Infinity]", ".", "n"}], "TI"]]], "InlineFormula"],
 " is the list of components of free-stream velocities normal to panels.  \
Each row of the system generates the equation for the tangent-flow boundary \
condition at one of the collocation points.  This matrix equation represents \
a system of ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " linear algebraic equations and ",
 Cell[BoxData[
  RowBox[{"2", 
   StyleBox[
    ButtonBox["N",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/N"],
    FontSlant->"Italic"]}]], "InlineFormula"],
 " unknowns."
}], "Text",
 CellID->173755935],

Cell["\<\
Compute the velocity influence coefficients at collocation points due to \
vortex panels representing the discretized airfoil.  The output of this \
computation is suppressed because of its length, but its dimensions are \
displayed.\
\>", "Text",
 CellID->23730492],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"icA", ",", "icB"}], "}"}], "=", 
   RowBox[{"ICVortexLinear", "[", 
    RowBox[{"rC", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{"icA", ",", "icB"}], "}"}]}]}], "Input",
 CellLabel->"In[17]:=",
 CellID->42090444],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "6"}], "}"}]}], "}"}]], "Output",
 ImageSize->{143, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->283650381]
}, Open  ]],

Cell["\<\
Compute the normal-component velocity influence coefficients and display in \
matrix form.  Chop is used to replace real numbers that are close to zero by \
the integer 0 to yield a compact display of the result.\
\>", "Text",
 CellID->407869361],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mVA", "=", 
   RowBox[{"icA", ".", "un"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Chop", "[", "mVA", "]"}], "//", "MatrixForm"}]}], "Input",
 CellLabel->"In[19]:=",
 CellID->151960291],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0.14349054705701622`", "0.031825225561479244`", 
      "0.03430025715116066`", "0.1364445330142508`", 
      RowBox[{"-", "0.07065016751805961`"}]},
     {
      RowBox[{"-", "0.209649452692794`"}], "0", "0.0887008353112518`", 
      "0.08980076407306763`", 
      RowBox[{"-", "0.001181844302595359`"}], 
      RowBox[{"-", "0.20031626344354492`"}]},
     {
      RowBox[{"-", "0.12020316318673128`"}], 
      RowBox[{"-", "0.29386965448222363`"}], "0", "0.14515006194726182`", 
      RowBox[{"-", "0.20952926880841855`"}], 
      RowBox[{"-", "0.11809884336227774`"}]},
     {"0.10664821495105566`", "0.19626605611761289`", 
      RowBox[{"-", "0.1639508174879371`"}], "0", "0.28031136151015834`", 
      "0.11271041332979455`"},
     {"0.19555295724804822`", 
      RowBox[{"-", "0.0038946150822851775`"}], 
      RowBox[{"-", "0.07991041060288702`"}], 
      RowBox[{"-", "0.09497420342903388`"}], "0", "0.21063553658538386`"},
     {"0.0761867929576533`", 
      RowBox[{"-", "0.13610671456333523`"}], 
      RowBox[{"-", "0.03103822088435744`"}], 
      RowBox[{"-", "0.034176028026357226`"}], 
      RowBox[{"-", "0.14270214580900453`"}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{497, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[20]//MatrixForm=",
 CellID->97378443]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mVB", "=", 
    RowBox[{"icB", ".", "un"}]}], ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[21]:=",
 CellID->49864735],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.07962339394152783`", "0.022370237624797656`", 
      "0.002096121991101305`", "0.0026115732494333627`", 
      "0.02833386897983458`", 
      RowBox[{"-", "0.07809862871203899`"}]},
     {
      RowBox[{"-", "0.06363691885856679`"}], "0.058263293176408534`", 
      "0.005484528292589147`", "0.007041887107460456`", 
      RowBox[{"-", "0.02704648870819142`"}], 
      RowBox[{"-", "0.04123424465704046`"}]},
     {
      RowBox[{"-", "0.03390087533584536`"}], 
      RowBox[{"-", "0.06965671067115602`"}], "0.021678665399545747`", 
      "0.0011475893060461412`", 
      RowBox[{"-", "0.03173402713324312`"}], 
      RowBox[{"-", "0.02636637677005869`"}]},
     {"0.029844549372037763`", "0.04233309816960869`", 
      RowBox[{"-", "0.018298239931666953`"}], "0.023529824906368447`", 
      "0.03625384290775606`", "0.024615733024160653`"},
     {"0.058048548442896995`", 
      RowBox[{"-", "0.027532620694403438`"}], 
      RowBox[{"-", "0.005096977581238277`"}], 
      RowBox[{"-", "0.007707425120822561`"}], "0.05827102015533772`", 
      "0.04172526708180758`"},
     {
      RowBox[{"-", "0.04002446233016957`"}], 
      RowBox[{"-", "0.02141776947075815`"}], 
      RowBox[{"-", "0.0020496309513599485`"}], 
      RowBox[{"-", "0.0026147979127629627`"}], 
      RowBox[{"-", "0.0299843716580853`"}], "0.08038622968099558`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{504, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]//MatrixForm=",
 CellID->230765848]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Panel-to-panel continuity of circulation density and the Kutta condition\
\>", "Subsubsection",
 CellID->103764251],

Cell["\<\
Continuity of circulation density from one panel to the next can be written \
in terms of the the strength parameters and panel lengths.  At the trailing \
edge, a Kutta condition is applied that the circulation density be zero.\
\>", "Text",
 CellID->386586113],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["j", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["j", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["j", "TI"]]}]}], "=", 
   SubscriptBox[
    StyleBox["a", "TI"], 
    StyleBox[
     RowBox[{"j", 
      StyleBox["+",
       FontSlant->"Plain"], 
      StyleBox["1",
       FontSlant->"Plain"]}], "TI"]]}]], "InlineFormula"],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["j", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   ButtonBox[
    RowBox[{
     StyleBox["N",
      FontSlant->"Italic"], "-", "1"}],
    BaseStyle->"Link"]}]], "InlineFormula"]
}], "Text",
 CellID->750004683],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["N", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["N", "TI"]]}], "+", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->123989520],

Cell["These equations can be written in matrix form.", "Text",
 CellID->503495065],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Gamma]a", "TI"]], ".", 
     StyleBox["a", "TI"]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Gamma]b", "TI"]], ".", 
     StyleBox["b", "TI"]}]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->179254913],

Cell[TextData[{
 "Compute the matrix of coefficients for ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " in the continuity of value equation, including continuity from last panel \
to first, which will be replaced by a Kutta condition."
}], "Text",
 CellID->531359183],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"im", "=", 
   RowBox[{"IdentityMatrix", "[", "nP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mD2", "=", 
    RowBox[{"im", "-", 
     RowBox[{"RotateLeft", "[", "im", "]"}]}]}], ")"}], "//", 
  "MatrixForm"}]}], "Input",
 CellLabel->"In[22]:=",
 CellID->23909254],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{154, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]//MatrixForm=",
 CellID->352287606]
}, Open  ]],

Cell["\<\
Modify the last row of the matrix to apply the Kutta condition.\
\>", "Text",
 CellID->78370612],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalGamma]A", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"mD2", ",", "1", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->49331538],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}]},
     {"1", "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{146, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]//MatrixForm=",
 CellID->439898199]
}, Open  ]],

Cell[TextData[{
 "Compute the matrix of coefficients for ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " in the continuity of value equation."
}], "Text",
 CellID->126776796],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalGamma]B", "=", 
    RowBox[{"DiagonalMatrix", "[", "\[Delta]", "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->31347865],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.5002885392353387`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.36607906794806605`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.1362110722318475`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.14784225044636182`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.36612761798854254`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.5050815775453544`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{400, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[25]//MatrixForm=",
 CellID->60914246]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution procedure", "Subsubsection",
 CellID->298127402],

Cell[TextData[{
 "Solve the continuity of value equations for ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " in terms of ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->122106569],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["\[Gamma]b", "TI"]], 
       RowBox[{"-", "1"}]], ".", 
      SubscriptBox[
       StyleBox["m", "TI"], 
       StyleBox["\[Gamma]a", "TI"]], ".", 
      StyleBox["a", "TI"]}]}], "=", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["ba", "TI"]], ".", 
     StyleBox["a", "TI"]}]}]}]], "InlineFormula"]
}], "Text",
 CellID->148715506],

Cell[TextData[{
 "Substitute into the system of equations for boundary conditions to \
eliminate ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->27432560],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       StyleBox["m", "TI"], 
       StyleBox["va", "TI"]], "+", 
      RowBox[{
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["vb", "TI"]], ".", 
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["ba", "TI"]]}]}], ")"}], ".", 
    StyleBox["a", "TI"]}], "=", 
   RowBox[{"-", 
    SubscriptBox[
     StyleBox["v", "TI"], 
     StyleBox[
      RowBox[{"\[Infinity]", ",", "n"}], "TI"]]}]}]], "InlineFormula"]
}], "Text",
 CellID->347230142],

Cell[TextData[{
 "Solve this system of ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " equations and ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " unknowns for ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ", then, solve for ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " using ",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["m", "TI"], 
     StyleBox["ba", "TI"]], ".", 
    StyleBox["a", "TI"]}]}]], "InlineFormula"],
 "."
}], "Text",
 CellID->44848813],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["ba", "TI"]]], "InlineFormula"],
 ", noting that ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["\[Gamma]b", "TI"]]], "InlineFormula"],
 " is a diagonal matrix so its inverse is simple."
}], "Text",
 CellID->517009306],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mBA", "=", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"DiagonalMatrix", "[", 
       RowBox[{"1", "/", "\[Delta]"}], "]"}], ".", "m\[CapitalGamma]A"}]}]}], 
   ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->319384963],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1.998846508713633`"}], "1.998846508713633`", "0.`", "0.`",
       "0.`", "0.`"},
     {"0.`", 
      RowBox[{"-", "2.7316503115164874`"}], "2.7316503115164874`", "0.`", 
      "0.`", "0.`"},
     {"0.`", "0.`", 
      RowBox[{"-", "7.3415470828823715`"}], "7.3415470828823715`", "0.`", 
      "0.`"},
     {"0.`", "0.`", "0.`", 
      RowBox[{"-", "6.763966301790075`"}], "6.763966301790075`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", 
      RowBox[{"-", "2.7312880833570268`"}], "2.7312880833570268`"},
     {
      RowBox[{"-", "1.9798781908853205`"}], "0.`", "0.`", "0.`", "0.`", 
      RowBox[{"-", "1.9798781908853205`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{406, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]//MatrixForm=",
 CellID->1394338]
}, Open  ]],

Cell["Compute the uniform flow normal to panels.", "Text",
 CellID->31359196],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v\[Infinity]N", "=", 
  RowBox[{
   RowBox[{"UniformFlow", "[", 
    RowBox[{"nP", ",", "\[Alpha]"}], "]"}], ".", "un"}]}]], "Input",
 CellLabel->"In[27]:=",
 CellID->211953321],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.07015244700708628`"}], ",", 
   RowBox[{"-", "0.08644899620810997`"}], ",", 
   RowBox[{"-", "0.28239091717212306`"}], ",", 
   RowBox[{"-", "0.3260023584364365`"}], ",", "0.08187181345319883`", ",", 
   "0.24437595544925345`"}], "}"}]], "Output",
 ImageSize->{455, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]=",
 CellID->769261126]
}, Open  ]],

Cell[TextData[{
 "Solve the boundary-conditions equation for ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->388832003],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{
    RowBox[{"mVA", "+", 
     RowBox[{"mVB", ".", "mBA"}]}], ",", 
    RowBox[{"-", "v\[Infinity]N"}]}], "]"}]}]], "Input",
 CellLabel->"In[28]:=",
 CellID->367664505],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.2435494755986378`"}], ",", 
   RowBox[{"-", "0.9088440472222541`"}], ",", 
   RowBox[{"-", "0.8222846153481761`"}], ",", "0.7132996637720699`", ",", 
   "1.5332593308472093`", ",", "1.284845658670144`"}], "}"}]], "Output",
 ImageSize->{398, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->748911096]
}, Open  ]],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " from ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->535259082],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"b", "=", 
  RowBox[{"mBA", ".", "a"}]}]], "Input",
 CellLabel->"In[29]:=",
 CellID->28035240],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6690247769576354`", ",", "0.23645009904351522`", ",", 
   "11.27356428489527`", ",", "5.546179556923252`", ",", 
   RowBox[{"-", "0.6784893025601781`"}], ",", 
   RowBox[{"-", "0.08176141223008271`"}]}], "}"}]], "Output",
 ImageSize->{411, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->174816235]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compare with results using function PMVortexLinearNeumann", "Subsection",
 CellID->611074881],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["PMVortexLinearNeumann",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"]], 
  "InlineFormula"],
 " to solve the model for this example.  Use the suffix VLN to denote results \
computed from the programmed model function."
}], "Text",
 CellID->19519575],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aVLN", ",", "bVLN", ",", "rCVLN", ",", "vCVLN"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->50303841],

Cell["\<\
Verify that the results of the step-by-step implementation are the same as \
those from the model PMVortexLinearNeumann.\
\>", "Text",
 CellID->68346340],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "==", "aVLN"}], ",", 
   RowBox[{"b", "==", "bVLN"}]}], "}"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->514967147],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->270348639]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.3.3 Panel method using doublet panels of constant strength and interior \
Dirichlet boundary conditions\
\>", "Section",
 CellID->577981106],

Cell[TextData[{
 "The discretized airfoil is specified by ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " straight-line panels, where the doublet density for each panel is constant."
}], "Text",
 CellID->3302604],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Mu]", "TR"], 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], ")"}]}], "=", 
   SubscriptBox[
    StyleBox["a", "TI"], 
    StyleBox["i", "TI"]]}]], "InlineFormula"],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["i", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   StyleBox["N", "TI"]}]], "InlineFormula"]
}], "Text",
 CellID->181147249],

Cell[TextData[{
 "Strength parameters are denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", and the collection of strength parameters for the discretized airfoil are \
grouped as a list."
}], "Text",
 CellID->260469098],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["N", "TI"]]}], ")"}]}]], "InlineFormula"]
}], "Text",
 CellID->295014137],

Cell[TextData[{
 "A wake panel of strength ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 " that extends from the trailing edge of the airfoil far downstream along \
the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis is appended to ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ".  There are thus ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " unknown strength parameters in the formulation of this model."
}], "Text",
 CellID->409613708],

Cell[TextData[{
 "Boundary conditions at collocation points provide ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " equations, and the Kutta condition (zero circulation at trailing edge) \
provides the final equation for a system of ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " linear algebraic equations involving the unknown strength parameters.  The \
system of equations is solved using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Text",
 CellID->191057130],

Cell[CellGroupData[{

Cell["Step-by-step implementation", "Subsection",
 CellID->104432088],

Cell[CellGroupData[{

Cell["Airfoil geometry", "Subsubsection",
 CellID->80757491],

Cell["\<\
Compute geometric quantities for the discretized airfoil that are determined \
from panel endpoints.\
\>", "Text",
 CellID->217356065],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]", "=", 
  RowBox[{"PanelLengths", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[32]:=",
 CellID->446124998],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.5002885392353387`", ",", "0.36607906794806605`", ",", 
   "0.1362110722318475`", ",", "0.14784225044636182`", ",", 
   "0.36612761798854254`", ",", "0.5050815775453544`"}], "}"}]], "Output",
 ImageSize->{409, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]=",
 CellID->317520761]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nP", "=", 
  RowBox[{"Length", "[", "\[Delta]", "]"}]}]], "Input",
 CellLabel->"In[33]:=",
 CellID->7807257],

Cell[BoxData["6"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[33]=",
 CellID->585340433]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"un", "=", 
  RowBox[{"PanelNormals", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[34]:=",
 CellID->201019853],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.0345027900632578`", ",", "0.018161718177544042`", ",", 
     RowBox[{"-", "0.18056985639311346`"}], ",", 
     RowBox[{"-", "0.42303444756106034`"}], ",", 
     RowBox[{"-", "0.02275423631690169`"}], ",", "0.1416780193852656`"}], 
    "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.999404601489232`"}], ",", 
     RowBox[{"-", "0.9998350623942129`"}], ",", 
     RowBox[{"-", "0.9835621622257387`"}], ",", "0.9061136000395913`", ",", 
     "0.999741088847325`", ",", "0.9899127935444962`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.0345027900632578, 
    0.018161718177544042`, -0.18056985639311346`, -0.42303444756106034`, \
-0.02275423631690169, 
    0.1416780193852656}, {-0.999404601489232, -0.9998350623942129, \
-0.9835621622257387, 0.9061136000395913, 0.999741088847325, 
    0.9899127935444962}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{455, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->83752]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rC", "=", 
  RowBox[{
   RowBox[{"PanelPoints", "[", "rP", "]"}], "-", 
   RowBox[{
    RowBox[{"10.", "^", 
     RowBox[{"-", "10"}]}], " ", "un"}]}]}]], "Input",
 CellLabel->"In[35]:=",
 CellID->5240558],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.7500046659044883`", ",", "0.3169999879425256`", ",", 
     "0.0670046157291427`", ",", "0.06699952428662194`", ",", 
     "0.31699687287401923`", ",", "0.750006642287939`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008630675120204935`"}], ",", 
     RowBox[{"-", "0.020585662771692676`"}], ",", 
     RowBox[{"-", "0.011612168328677`"}], ",", "0.03195682073026408`", ",", 
     "0.06739348026370942`", ",", "0.03577947866831442`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.7500046659044883, 
    0.3169999879425256, 0.0670046157291427, 0.06699952428662194, 
    0.31699687287401923`, 
    0.750006642287939}, {-0.008630675120204935, -0.020585662771692676`, \
-0.011612168328677, 0.03195682073026408, 0.06739348026370942, 
    0.03577947866831442}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{490, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[35]=",
 CellID->363823630]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Boundary conditions at collocation points, and Kutta condition\
\>", "Subsubsection",
 CellID->292614508],

Cell[TextData[{
 "Apply the boundary condition that the velocity potential is zero at each \
collocation point and include an additional equation for the Kutta condition. \
 This system of equations can be written in matrix form.  In the following \
equation, the strength parameter for the wake panel is appended to the list ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " and renamed as the double-struck character ",
 Cell[BoxData[
  StyleBox["\[DoubleStruckA]",
   FontSize->14]], "InlineFormula"],
 "."
}], "Text",
 CellID->104611666],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"m", ".", 
    StyleBox["\[DoubleStruckA]",
     FontSize->14]}], "=", 
   StyleBox["rhs",
    FontSlant->"Italic"]}]], "InlineFormula"]
}], "Text",
 CellID->794714778],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], 
   StyleBox["+",
    FontSlant->"Plain"], 
   StyleBox["1",
    FontSlant->"Plain"]}]], "InlineFormula"],
 " by ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], 
   StyleBox["+",
    FontSlant->"Plain"], 
   StyleBox["1",
    FontSlant->"Plain"]}]], "InlineFormula"],
 " matrix ",
 Cell[BoxData[
  StyleBox["m", "TI"]], "InlineFormula"],
 " is the matrix of velocity-potential influence coefficients to which a row \
has been appended for the Kutta condition, ",
 Cell[BoxData[
  StyleBox["\[DoubleStruckA]", "TI",
   FontSize->14]], "InlineFormula"],
 " is the list of unknown strength parameters and ",
 Cell[BoxData[
  StyleBox["rhs",
   FontSlant->"Italic"]], "InlineFormula"],
 " denotes the right-hand-side of the system of equations and consists of a \
zero appended to the list of free stream velocity potentials at collocation \
points multiplied by -1."
}], "Text",
 CellID->177985028],

Cell[TextData[{
 "The Kutta condition imposed is based on the equivalence of a \
constant-strength doublet panel with a pair of contra-rotating point vortices \
at panel endpoints.  The relationship between circulation density and doublet \
density is discussed in more detail in ",
 ButtonBox["Section 2.1",
  BaseStyle->"Hyperlink",
  ButtonData->{"IntroductionToInfluenceCoefficients.nb", "relation"}],
 "."
}], "Text",
 CellID->317018286],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["N", "TI"]], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["w", "TI"]], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->452776010],

Cell["\<\
Compute the velocity-potential influence coefficients at collocation points \
due to the doublet panels representing the discretized airfoil and the wake \
panel.  Display the dimensions of this matrix.\
\>", "Text",
 CellID->128200992],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ic\[Phi]", "=", 
   RowBox[{"IC\[Phi]DoubletConstant", "[", 
    RowBox[{"rC", ",", 
     RowBox[{"Append", "[", 
      RowBox[{"rP", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"10.", "^", "10"}], ",", "0.0"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "ic\[Phi]", "]"}]}], "Input",
 CellLabel->"In[36]:=",
 CellID->9956353],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "7"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[37]=",
 CellID->34436041]
}, Open  ]],

Cell["Compute the coefficients for the Kutta condition.", "Text",
 CellID->790473042],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kutta", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1."}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0.", ",", 
       RowBox[{"{", 
        RowBox[{"nP", "-", "2"}], "}"}]}], "]"}], ",", "1.", ",", 
     RowBox[{"-", "1."}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[38]:=",
 CellID->167614302],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "1.`", ",", 
   RowBox[{"-", "1.`"}]}], "}"}]], "Output",
 ImageSize->{198, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[38]=",
 CellID->12200932]
}, Open  ]],

Cell["\<\
Append the row expressing the Kutta condition to the matrix of influence \
coefficients, and display the result in matrix form.\
\>", "Text",
 CellID->54865923],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m", "=", 
    RowBox[{"Append", "[", 
     RowBox[{"ic\[Phi]", ",", "kutta"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[39]:=",
 CellID->87445909],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.49999999987274946`", "0.0015455902883346497`", 
      "0.005923707618673844`", "0.016504839930439916`", 
      "0.03092007818335357`", "0.4451057841064485`", "0.005492379620102115`"},
     {"0.0019048020419853374`", "0.4999999998260977`", 
      "0.013554922888940672`", "0.05768403819334981`", "0.35741669280338834`",
       "0.06943954424623798`", "0.004795488107070001`"},
     {"0.004057050586950482`", "0.026820802845579937`", 
      "0.49999999953262264`", "0.3372860896294977`", "0.10361460625757114`", 
      "0.028221451147778145`", "0.0019807585337395044`"},
     {"0.012563886285040859`", "0.09261522905682568`", "0.3198541553449522`", 
      "0.4999999995693926`", "0.05500208647035182`", "0.019964643273436833`", 
      RowBox[{"-", "0.005449191673949274`"}]},
     {"0.053300724196137836`", "0.35739292598749606`", "0.04064053368295844`",
       "0.029390543089924073`", "0.49999999982612076`", 
      "0.019275273217362925`", 
      RowBox[{"-", "0.01565351136633488`"}]},
     {"0.4441013230066497`", "0.017900318746378333`", "0.007931641394619956`",
       "0.014528677413945916`", "0.015538039564449184`", 
      "0.49999999987395705`", 
      RowBox[{"-", "0.022624882283626427`"}]},
     {
      RowBox[{"-", "1.`"}], "0.`", "0.`", "0.`", "0.`", "1.`", 
      RowBox[{"-", "1.`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{549, 102},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[39]//MatrixForm=",
 CellID->166239599]
}, Open  ]],

Cell["\<\
Compute the free stream velocity potential at collocation points and append a \
zero for the Kutta condition equation.\
\>", "Text",
 CellID->134373867],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhs", "=", 
  RowBox[{"-", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"UniformFlow\[Phi]", "[", 
      RowBox[{"rC", ",", "\[Alpha]"}], "]"}], ",", "0.0"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[40]:=",
 CellID->134984038],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.7449939106631028`"}], ",", 
   RowBox[{"-", "0.31311164114544915`"}], ",", 
   RowBox[{"-", "0.0654237553227679`"}], ",", 
   RowBox[{"-", "0.06997289124415831`"}], ",", 
   RowBox[{"-", "0.32230486776270967`"}], ",", 
   RowBox[{"-", "0.7496380013487123`"}], ",", "0.`"}], "}"}]], "Output",
 ImageSize->{496, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[40]=",
 CellID->93986948]
}, Open  ]],

Cell["Solve the system of equations.", "Text",
 CellID->6313767],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{"m", ",", "rhs"}], "]"}]}]], "Input",
 CellLabel->"In[41]:=",
 CellID->173842100],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6108118179608026`"}], ",", 
   RowBox[{"-", "0.1785390391669687`"}], ",", "0.060338529923743604`", ",", 
   RowBox[{"-", "0.04875947697623317`"}], ",", 
   RowBox[{"-", "0.4278985308985351`"}], ",", 
   RowBox[{"-", "0.9520430904670153`"}], ",", 
   RowBox[{"-", "0.34123127250621266`"}]}], "}"}]], "Output",
 ImageSize->{538, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[41]=",
 CellID->154187580]
}, Open  ]],

Cell["\<\
Separate the strength parameters for the discretized airfoil from the \
strength parameter for the wake panel.\
\>", "Text",
 CellID->201664465],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "aW"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Most", "[", "soln", "]"}], ",", 
    RowBox[{"Last", "[", "soln", "]"}]}], "}"}]}]], "Input",
 CellLabel->"In[42]:=",
 CellID->51826491],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.6108118179608026`"}], ",", 
     RowBox[{"-", "0.1785390391669687`"}], ",", "0.060338529923743604`", ",", 
     RowBox[{"-", "0.04875947697623317`"}], ",", 
     RowBox[{"-", "0.4278985308985351`"}], ",", 
     RowBox[{"-", "0.9520430904670153`"}]}], "}"}], ",", 
   RowBox[{"-", "0.34123127250621266`"}]}], "}"}]], "Output",
 ImageSize->{552, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[42]=",
 CellID->253364607]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compare with results using function PMDoubletConstantDirichlet\
\>", "Subsection",
 CellID->37612957],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["PMDoubletConstantDirichlet",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"]], 
  "InlineFormula"],
 " to solve the model for this example.  Use the suffix DCD to denote results \
computed from the programmed model function.  "
}], "Text",
 CellID->756079987],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aDCD", ",", "aWDCD", ",", "rCDCD", ",", "vCDCD"}], "}"}], "=", 
   RowBox[{"PMDoubletConstantDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->178842356],

Cell["\<\
Verify that the results of the step-by-step implementation are the same as \
those from the model PMDoubletConstantDirichlet.\
\>", "Text",
 CellID->289996779],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "==", "aDCD"}], ",", 
   RowBox[{"aW", "==", "aWDCD"}]}], "}"}]], "Input",
 CellLabel->"In[43]:=",
 CellID->229212092],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[43]=",
 CellID->15448748]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.3.4 Panel method using doublet panels of quadratically varying strength and \
interior Dirichlet boundary conditions\
\>", "Section",
 CellID->106827055],

Cell[TextData[{
 "The discretized airfoil is specified by ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " straight-line panels, where the doublet density for each panel varies \
quadratically with distance from the beginning of the panel.  The clockwise \
numbering convention is used to determine the beginning of a panel."
}], "Text",
 CellID->784000936],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Mu]", 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]], ")"}]}], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["i", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["i", "TI"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["i", "TI"]], " ", 
     SuperscriptBox[
      SubscriptBox[
       StyleBox["x", "TI"], 
       StyleBox["i", "TI"]], "2"], " "}]}]}]], "InlineFormula"],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["i", "TI"], "=", "1"}], ",", "2", ",", "3", ",", 
   StyleBox["\[Ellipsis]", "TR"], ",", 
   StyleBox["N",
    FontSlant->"Italic"]}]], "InlineFormula"]
}], "Text",
 CellID->20572744],

Cell[TextData[{
 "Strength parameters are denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["b", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["c", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 " and the panel-local coordinate is denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["x", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula"],
 ".  Strength parameters for the discretized airfoil are grouped as lists."
}], "Text",
 CellID->321938409],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "TI"], "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["a", "TI"], 
      StyleBox["N", "TI"]]}], "}"}]}]], "InlineFormula"],
 ",  ",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]]}], "}"}]}]], "InlineFormula"],
 ",  ",
 Cell[BoxData[
  RowBox[{
   StyleBox["c", "TI"], "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["2", "TR"]], ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["3", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], ",", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]]}], "}"}]}]], "InlineFormula"]
}], "Text",
 CellID->206580932],

Cell[TextData[{
 "A wake panel of strength ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["a", "TI"], 
   StyleBox["w", "TI"]]], "InlineFormula"],
 " that extends from the trailing edge of the airfoil far downstream along \
the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis is appended to ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ".",
 "  There are thus ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{"3", "N"}],
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " unknown strength parameters in the formulation of this model."
}], "Text",
 CellID->63853891],

Cell[TextData[{
 "Boundary conditions at collocation points provide ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["N",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/N"],
   FontSlant->"Italic"]], "InlineFormula"],
 " equations, continuity of value and slope of the doublet density between \
panels (except at trailing edge) provide ",
 Cell[BoxData[
  RowBox[{"2", 
   RowBox[{"(", 
    RowBox[{
     StyleBox[
      ButtonBox["N",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/N"],
      FontSlant->"Italic"], "-", "1"}], ")"}]}]], "InlineFormula"],
 " equations, and the Kutta condition provides 2 equations (zero circulation \
and zero circulation density at trailing edge).  This makes a total of ",
 Cell[BoxData[
  RowBox[{"3", 
   StyleBox["N",
    FontSlant->"Italic"]}]], "InlineFormula"],
 " equations.  An additional equation is generated by adding a collocation \
point interior to the airfoil near the trailing edge.  The resulting system \
of linear algebraic equations is solved using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Text",
 CellID->24556244],

Cell[CellGroupData[{

Cell["Step-by-step implementation", "Subsection",
 CellID->97066759],

Cell[CellGroupData[{

Cell["Airfoil geometry", "Subsubsection",
 CellID->135427747],

Cell["\<\
Compute geometric quantities for the discretized airfoil that are determined \
from panel endpoints.\
\>", "Text",
 CellID->181155074],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]", "=", 
  RowBox[{"PanelLengths", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[45]:=",
 CellID->536239764],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.5002885392353387`", ",", "0.36607906794806605`", ",", 
   "0.1362110722318475`", ",", "0.14784225044636182`", ",", 
   "0.36612761798854254`", ",", "0.5050815775453544`"}], "}"}]], "Output",
 ImageSize->{409, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[45]=",
 CellID->182606370]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nP", "=", 
  RowBox[{"Length", "[", "\[Delta]", "]"}]}]], "Input",
 CellLabel->"In[46]:=",
 CellID->677970246],

Cell[BoxData["6"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[46]=",
 CellID->45611920]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"un", "=", 
  RowBox[{"PanelNormals", "[", "rP", "]"}]}]], "Input",
 CellLabel->"In[47]:=",
 CellID->191192788],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.0345027900632578`", ",", "0.018161718177544042`", ",", 
     RowBox[{"-", "0.18056985639311346`"}], ",", 
     RowBox[{"-", "0.42303444756106034`"}], ",", 
     RowBox[{"-", "0.02275423631690169`"}], ",", "0.1416780193852656`"}], 
    "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.999404601489232`"}], ",", 
     RowBox[{"-", "0.9998350623942129`"}], ",", 
     RowBox[{"-", "0.9835621622257387`"}], ",", "0.9061136000395913`", ",", 
     "0.999741088847325`", ",", "0.9899127935444962`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.0345027900632578, 
    0.018161718177544042`, -0.18056985639311346`, -0.42303444756106034`, \
-0.02275423631690169, 
    0.1416780193852656}, {-0.999404601489232, -0.9998350623942129, \
-0.9835621622257387, 0.9061136000395913, 0.999741088847325, 
    0.9899127935444962}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{455, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[47]=",
 CellID->53980787]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rC", "=", 
  RowBox[{
   RowBox[{"PanelPoints", "[", "rP", "]"}], "-", 
   RowBox[{
    RowBox[{"10.", "^", 
     RowBox[{"-", "10"}]}], " ", "un"}]}]}]], "Input",
 CellLabel->"In[48]:=",
 CellID->308931740],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.7500046659044883`", ",", "0.3169999879425256`", ",", 
     "0.0670046157291427`", ",", "0.06699952428662194`", ",", 
     "0.31699687287401923`", ",", "0.750006642287939`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008630675120204935`"}], ",", 
     RowBox[{"-", "0.020585662771692676`"}], ",", 
     RowBox[{"-", "0.011612168328677`"}], ",", "0.03195682073026408`", ",", 
     "0.06739348026370942`", ",", "0.03577947866831442`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.7500046659044883, 
    0.3169999879425256, 0.0670046157291427, 0.06699952428662194, 
    0.31699687287401923`, 
    0.750006642287939}, {-0.008630675120204935, -0.020585662771692676`, \
-0.011612168328677, 0.03195682073026408, 0.06739348026370942, 
    0.03577947866831442}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{490, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[48]=",
 CellID->399907175]
}, Open  ]],

Cell["\<\
Locate an extra collocation point at the mean location of the collocation \
points for the first and last panels.  Append it to the list of collocation \
points for the discretized airfoil.\
\>", "Text",
 CellID->412865955],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xCExtra", ",", "zCExtra"}], "}"}], "=", 
   RowBox[{"Mean", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"First", "[", "rC", "]"}], ",", 
      RowBox[{"Last", "[", "rC", "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"rCAll", "=", 
  RowBox[{"Append", "[", 
   RowBox[{"rC", ",", 
    RowBox[{"{", 
     RowBox[{"xCExtra", ",", "zCExtra"}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[49]:=",
 CellID->164764330],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.7500046659044883`", ",", "0.3169999879425256`", ",", 
     "0.0670046157291427`", ",", "0.06699952428662194`", ",", 
     "0.31699687287401923`", ",", "0.750006642287939`", ",", 
     "0.7500056540962137`"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.008630675120204935`"}], ",", 
     RowBox[{"-", "0.020585662771692676`"}], ",", 
     RowBox[{"-", "0.011612168328677`"}], ",", "0.03195682073026408`", ",", 
     "0.06739348026370942`", ",", "0.03577947866831442`", ",", 
     "0.013574401774054744`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.7500046659044883, 
    0.3169999879425256, 0.0670046157291427, 0.06699952428662194, 
    0.31699687287401923`, 0.750006642287939, 
    0.7500056540962137}, {-0.008630675120204935, -0.020585662771692676`, \
-0.011612168328677, 0.03195682073026408, 0.06739348026370942, 
    0.03577947866831442, 0.013574401774054744`}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{564, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[50]=",
 CellID->152351051]
}, Open  ]],

Cell["\<\
Write the location of the extra collocation point in the form of the data \
type CartesianVectors in preparation for using it as input for computing \
influence coefficients at the extra collocation point.\
\>", "Text",
 CellID->708988792],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rCExtra", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "xCExtra", "}"}], ",", 
     RowBox[{"{", "zCExtra", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[51]:=",
 CellID->707799138],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "0.7500056540962137`", "}"}], "\[UpArrow]", 
   RowBox[{"{", "0.013574401774054744`", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.7500056540962137}, {
    0.013574401774054744`}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{160, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[51]=",
 CellID->786176867]
}, Open  ]],

Cell["Compute the locations of the endpoints for the wake panel.", "Text",
 CellID->829104254],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rPWake", "=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"Append", "[", 
     RowBox[{"rP", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10.", "^", "10"}], ",", "0."}], "}"}]}], "]"}], ",", 
    RowBox[{"-", "2"}]}], "]"}]}]], "Input",
 CellLabel->"In[52]:=",
 CellID->240976878],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9999999999999982`", ",", "1.`*^10"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"7.631757509490455`*^-17", ",", "0.`"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0.9999999999999982, 
    1.*^10}, {7.631757509490455*^-17, 0.}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{231, 19},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[52]=",
 CellID->315967782]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Boundary conditions at collocation points\
\>", "Subsubsection",
 CellID->306855904],

Cell[TextData[{
 "Apply the boundary condition that the velocity potential is zero at each \
collocation point due to all doublet panels.  This collection of equations \
can be written in matrix form.  In the following equation, the strength \
parameter for the wake panel is appended to to the list ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " and renamed as the double-struck character ",
 Cell[BoxData[
  StyleBox["\[DoubleStruckA]",
   FontSize->14]], "InlineFormula"],
 "."
}], "Text",
 CellID->1539757],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox[
       RowBox[{
        StyleBox["\[Phi]", "TI"], "\[DoubleStruckA]"}]]], ".", 
     StyleBox["\[DoubleStruckA]",
      FontSize->14]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Phi]b", "TI"]], ".", 
     StyleBox["b", "TI"]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Phi]c", "TI"]], ".", 
     StyleBox["c", "TI"]}]}], "=", 
   RowBox[{"-", 
    SubscriptBox["\[Phi]", "\[Infinity]"]}]}]], "InlineFormula"]
}], "Text",
 CellID->202532084],

Cell[TextData[{
 "The dimensions of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["\[Phi]\[DoubleStruckA]", "TI"]]], "InlineFormula"],
 " are ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " by ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 ", and the dimensions of ",
 Cell[BoxData[
  SubscriptBox["m", "\[Phi]b"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox["m", "\[Phi]c"]], "InlineFormula"],
 " are ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " by ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 ".",
 Cell[BoxData[Cell["", "InlineFormula"]], "InlineFormula"],
 "  The list of ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " free-stream velocity potentials at collocation points is denoted by ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["\[Phi]", "TR"], 
   StyleBox["\[Infinity]", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->207590312],

Cell["\<\
Compute the velocity-potential influence coefficients and display their \
dimensions.\
\>", "Text",
 CellID->48064062],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "m\[CapitalPhi]A", ",", "m\[CapitalPhi]B", ",", "m\[CapitalPhi]C"}], 
    "}"}], "=", 
   RowBox[{"IC\[Phi]DoubletQuadratic", "[", 
    RowBox[{"rCAll", ",", "rP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{
   "m\[CapitalPhi]A", ",", "m\[CapitalPhi]B", ",", "m\[CapitalPhi]C"}], 
   "}"}]}]}], "Input",
 CellLabel->"In[53]:=",
 CellID->388039116],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"7", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "6"}], "}"}]}], "}"}]], "Output",
 ImageSize->{157, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[54]=",
 CellID->434498979]
}, Open  ]],

Cell["\<\
Append the influence coefficients at collocation points due to the \
constant-strength wake panel.\
\>", "Text",
 CellID->65240430],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"m\[CapitalPhi]", 
     StyleBox["\[DoubleStruckCapitalA]",
      FontSize->14]}]], "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Append", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "m\[CapitalPhi]A", "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"IC\[Phi]DoubletConstant", "[", 
        RowBox[{"rCAll", ",", "rPWake"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "m\[CapitalPhi]\[DoubleStruckCapitalA]", 
  "]"}]}], "Input",
 CellLabel->"In[55]:=",
 CellID->24538656],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", "7"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[56]=",
 CellID->267931135]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kutta conditions", "Subsubsection",
 CellID->94585002],

Cell[TextData[{
 "The relationship between circulation density and doublet density is \
discussed in more detail in ",
 ButtonBox["Section 2.1",
  BaseStyle->"Hyperlink",
  ButtonData->{"IntroductionToInfluenceCoefficients.nb", "relation"}],
 ".  Write this relationship for a quadratically varying doublet panel."
}], "Text",
 CellID->349121839],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[Gamma]", "TR"], 
    RowBox[{"(", 
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["j", "TI"]], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"\[DifferentialD]", 
        StyleBox["\[Mu]", "TR"]}], 
       RowBox[{"(", 
        SubscriptBox[
         StyleBox["x", "TI"], 
         StyleBox["j", "TI"]], ")"}]}], 
      RowBox[{"\[DifferentialD]", 
       SubscriptBox[
        StyleBox["x", "TI"], 
        StyleBox["j", "TI"]]}]]}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox[
       StyleBox["b", "TI"], 
       StyleBox["j", "TI"]]}], "-", 
     RowBox[{"2", 
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["j", "TI"]], " ", 
      SubscriptBox[
       StyleBox["x", "TI"], 
       StyleBox["j", "TI"]]}]}]}]}]], "InlineFormula"]
}], "Text",
 CellID->55333495],

Cell["\<\
Using the relation between the circulation density function and the doublet \
density function, write the condition that the circulation density at the \
trailing edge be zero.\
\>", "Text",
 CellID->291362026],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["b", "TI"], 
     StyleBox["N", "TI"]], "+", 
    RowBox[{"2", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["N", "TI"]]}], "+", 
    SubscriptBox[
     StyleBox["b", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->404054939],

Cell["\<\
Requiring that the value of the doublet density at the trailing edge be zero \
implies that there is no point vortex singularity at the trailing edge.\
\>", "Text",
 CellID->226623022],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["N", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]], 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["N", "TI"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]], " ", 
     SuperscriptBox[
      SubscriptBox[
       StyleBox["\[Delta]", "TR"], 
       StyleBox["N", "TI"]], "2"]}], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["w", "TI"]], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->335859064],

Cell["\<\
These two conditions at the trailing edge are applied to require the flow to \
leave the trailing edge smoothly.  These Kutta conditions are implemented by \
modifying the continuity equations in the following two sections.\
\>", "Text",
 CellID->880967397]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Panel-to-panel continuity of value of doublet density, and a Kutta condition\
\>", "Subsubsection",
 CellID->102303559],

Cell["\<\
Continuity of the value of the doublet density function from one panel to the \
next is required, except at the trailing edge, where a Kutta condition is \
imposed.\
\>", "Text",
 CellID->54578817],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["j", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["j", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["j", "TI"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["j", "TI"]], " ", 
     SuperscriptBox[
      SubscriptBox[
       StyleBox["\[Delta]", "TR"], 
       StyleBox["j", "TI"]], "2"]}]}], "=", 
   SubscriptBox[
    StyleBox["a", "TI"], 
    StyleBox[
     RowBox[{"j", 
      StyleBox["+",
       FontSlant->"Plain"], 
      StyleBox["1",
       FontSlant->"Plain"]}], "TI"]]}]], "InlineFormula"],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["j", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   StyleBox["N",
    FontSlant->"Italic"]}]], "InlineFormula"]
}], "Text",
 CellID->329538159],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["N", "TI"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["b", "TI"], 
      StyleBox["N", "TI"]], 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["N", "TI"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]], " ", 
     SuperscriptBox[
      SubscriptBox[
       StyleBox["\[Delta]", "TR"], 
       StyleBox["N", "TI"]], "2"]}], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["w", "TI"]], "-", 
    SubscriptBox[
     StyleBox["a", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->39977282],

Cell["These equations can be written in matrix form.", "Text",
 CellID->397767550],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox[
       RowBox[{"\[Mu]", 
        StyleBox["\[DoubleStruckA]", "TI"]}]]], ".", 
     StyleBox["\[DoubleStruckA]",
      FontSize->14]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox[
       RowBox[{"\[Mu]", 
        StyleBox["b", "TI"]}]]], ".", 
     StyleBox["b", "TI"]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox[
       RowBox[{"\[Mu]", 
        StyleBox["c", "TI"]}]]], ".", 
     StyleBox["c", "TI"]}]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->643737613],

Cell[TextData[{
 "The dimensions of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["\[Mu]\[DoubleStruckA]", "TI"]]], "InlineFormula"],
 " are ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " by ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 ",  and the dimensions of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["\[Mu]b", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["\[Mu]c", "TI"]]], "InlineFormula"],
 " are ",
 Cell[BoxData[
  StyleBox["N",
   FontSlant->"Italic"]], "InlineFormula"],
 " by ",
 Cell[BoxData["N"], "InlineFormula",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellID->856713082],

Cell["\<\
Compute matrices for panel-to-panel continuity of doublet density function.  \
The first matrix includes coefficients for continuity of value from last \
panel to first, which will be replaced by a Kutta condition\
\>", "Text",
 CellID->756125371],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"im", "=", 
   RowBox[{"IdentityMatrix", "[", "nP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalMu]A", "=", 
    RowBox[{"im", "-", 
     RowBox[{"RotateLeft", "[", "im", "]"}]}]}], ")"}], "//", 
  "MatrixForm"}]}], "Input",
 CellLabel->"In[57]:=",
 CellID->615129277],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{154, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[58]//MatrixForm=",
 CellID->200252758]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalMu]B", "=", 
    RowBox[{"DiagonalMatrix", "[", "\[Delta]", "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[59]:=",
 CellID->16413054],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.5002885392353387`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.36607906794806605`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.1362110722318475`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.14784225044636182`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.36612761798854254`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.5050815775453544`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{400, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[59]//MatrixForm=",
 CellID->506272189]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalMu]C", "=", 
    RowBox[{"DiagonalMatrix", "[", 
     RowBox[{"\[Delta]", "^", "2"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[60]:=",
 CellID->741221869],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.250288622490229`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.13401388398972475`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.01855345619854958`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.021857331017044773`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.13404943265396413`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.25510739997570386`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{414, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[60]//MatrixForm=",
 CellID->85676179]
}, Open  ]],

Cell["\<\
Modify the first matrix by adding a column of zeros to accommodate the \
strength parameter for the wake panel, and modify the last row to be the \
Kutta condition. \
\>", "Text",
 CellID->92270313],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"kutta\[CapitalMu]", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"nP", "-", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m\[CapitalMu]\[DoubleStruckCapitalA]", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", "m\[CapitalMu]A", "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "nP", "}"}]}], "]"}]}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "\[Rule]", "kutta\[CapitalMu]"}]}], "]"}]}], ")"}],
   "//", "MatrixForm"}]}], "Input",
 CellLabel->"In[61]:=",
 CellID->599743264],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0"},
     {
      RowBox[{"-", "1"}], "0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{177, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[62]//MatrixForm=",
 CellID->147518915]
}, Open  ]],

Cell[TextData[{
 "Display the dimensions of the matrices ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], "\[Mu]\[DoubleStruckCapitalA]"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], "\[Mu]B"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], "\[Mu]C"]], "InlineFormula"],
 "."
}], "Text",
 CellID->526156131],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{
   "m\[CapitalMu]\[DoubleStruckCapitalA]", ",", "m\[CapitalMu]B", ",", 
    "m\[CapitalMu]C"}], "}"}]}]], "Input",
 CellLabel->"In[63]:=",
 CellID->92044694],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "6"}], "}"}]}], "}"}]], "Output",
 ImageSize->{157, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[63]=",
 CellID->327786406]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Panel-to-panel continuity of slope of doublet density function, and a Kutta \
condition\
\>", "Subsubsection",
 CellID->89512504],

Cell["\<\
Continuity of the slope of the doublet density function from one panel to the \
next is required, except at the trailing edge.  At the trailing edge, the \
slope of the doublet density is required to be zero as part of the Kutta \
condition.\
\>", "Text",
 CellID->126141448],

Cell["\<\
Continuity of slope of the doublet density function from one panel to the \
next can be written in terms of the the strength parameters and panel lengths.\
\>", "Text",
 CellID->61776658],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["b", "TI"], 
     StyleBox["j", "TI"]], "+", 
    RowBox[{"2", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["j", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["j", "TI"]]}]}], "=", 
   SubscriptBox[
    StyleBox["b", "TI"], 
    StyleBox[
     RowBox[{"j", 
      StyleBox["+",
       FontSlant->"Plain"], 
      StyleBox["1",
       FontSlant->"Plain"]}], "TI"]]}]], "InlineFormula"],
 "   for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["j", "TI"], "=", "1"}], ",", "2", ",", "3", ",", "...", ",", 
   Cell["", "InlineFormula"]}]], "InlineFormula"],
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "-", "1"}]], "InlineFormula"]
}], "Text",
 CellID->72666099],

Cell["\<\
Write the Kutta condition that the circulation density at the trailing edge \
be zero.\
\>", "Text",
 CellID->26705995],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["b", "TI"], 
     StyleBox["N", "TI"]], "+", 
    RowBox[{"2", 
     SubscriptBox[
      StyleBox["c", "TI"], 
      StyleBox["N", "TI"]], " ", 
     SubscriptBox[
      StyleBox["\[Delta]", "TR"], 
      StyleBox["N", "TI"]]}], "+", 
    SubscriptBox[
     StyleBox["b", "TI"], 
     StyleBox["1", "TR"]]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->44996651],

Cell["These equations can be written in matrix form.", "Text",
 CellID->112301587],

Cell[TextData[{
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], "sb"], ".", 
     StyleBox["b", "TI"]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], "sc"], ".", 
     StyleBox["c", "TI"]}]}], "=", "0"}]], "InlineFormula"]
}], "Text",
 CellID->47088591],

Cell[TextData[{
 "The dimensions of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["sb", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["sc", "TI"]]], "InlineFormula"],
 " are ",
 Cell[BoxData["N"], "InlineFormula",
  FontSlant->"Italic"],
 " by ",
 Cell[BoxData["N"], "InlineFormula",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellID->454274171],

Cell[TextData[{
 "Compute the matrix of coefficients for ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 ", replacing the last row of the continuity matrix with coefficients for the \
Kutta condition on slope of the doublet density function."
}], "Text",
 CellID->31540012],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mSB", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"m\[CapitalMu]A", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], "\[Rule]", "1"}]}], "]"}]}], 
   ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[64]:=",
 CellID->262110288],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "1", 
      RowBox[{"-", "1"}]},
     {"1", "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{146, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[64]//MatrixForm=",
 CellID->496316663]
}, Open  ]],

Cell[TextData[{
 "The matrix ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["sc", "TI"]]], "InlineFormula"],
 " is just twice ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], "\[Mu]b"]], "InlineFormula"],
 "."
}], "Text",
 CellID->278147230],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mSC", "=", 
    RowBox[{"2", "m\[CapitalMu]B"}]}], ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[65]:=",
 CellID->97230909],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.0005770784706773`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.7321581358961321`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.272422144463695`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.29568450089272363`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.7322552359770851`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "1.0101631550907089`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{386, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[65]//MatrixForm=",
 CellID->52717624]
}, Open  ]],

Cell[TextData[{
 "Display the dimensions of ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["sb", "TI"]]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["sc", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->727079737],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{"mSB", ",", "mSC"}], "}"}]}]], "Input",
 CellLabel->"In[66]:=",
 CellID->19263021],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "6"}], "}"}]}], "}"}]], "Output",
 ImageSize->{107, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[66]=",
 CellID->168315440]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution procedure", "Subsubsection",
 CellID->165742176],

Cell[TextData[{
 "Solve the equations for panel-to-panel continuity of slope and a Kutta \
condition on circulation density for ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 " in terms of ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->12866520],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["c", "TI"], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["sc", "TI"]], 
       RowBox[{"-", "1"}]], ".", 
      SubscriptBox[
       StyleBox["m", "TI"], 
       StyleBox["sb", "TI"]]}]}], "=", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["cb", "TI"]], ".", 
     StyleBox["b", "TI"]}]}]}]], "InlineFormula"]
}], "Text",
 CellID->446515824],

Cell[TextData[{
 "Eliminate ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 " from the system of equations."
}], "Text",
 CellID->111227654],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Phi]\[DoubleStruckA]", "TI"]], ".", "\[DoubleStruckA]"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["\[Phi]b", "TI"]], "+", 
       RowBox[{
        SubscriptBox[
         StyleBox["m", "TI"], 
         StyleBox["\[Phi]c", "TI"]], ".", 
        SubscriptBox[
         StyleBox["m", "TI"], 
         StyleBox["cb", "TI"]]}]}], ")"}], ".", 
     StyleBox["b", "TI"]}]}], "=", 
   RowBox[{"-", 
    SubscriptBox[
     StyleBox["\[Phi]", "TR"], 
     StyleBox["\[Infinity]", "TI"]]}]}]], "InlineFormula"],
 "\t(boundary conditions)"
}], "Text",
 CellID->430827873],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], 
      StyleBox["\[Mu]\[DoubleStruckA]", "TI"]], ".", "\[DoubleStruckA]"}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["\[Mu]b", "TI"]], "+", 
       RowBox[{
        SubscriptBox[
         StyleBox["m", "TI"], 
         StyleBox["\[Mu]c", "TI"]], ".", 
        SubscriptBox[
         StyleBox["m", "TI"], 
         StyleBox["cb", "TI"]]}]}], ")"}], ".", 
     StyleBox["b", "TI"]}]}], "=", "0"}]], "InlineFormula"],
 "\t(continuity of ",
 Cell[BoxData[
  StyleBox["\[Mu]", "TR"]], "InlineFormula"],
 " and Kutta)"
}], "Text",
 CellID->19233526],

Cell[TextData[{
 "Solve the continuity/Kutta system of equations for ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " in terms of ",
 Cell[BoxData["\[DoubleStruckA]"], "InlineFormula"],
 "."
}], "Text",
 CellID->358389442],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox["b", "TI"], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox[
         StyleBox["m", "TI"], 
         StyleBox["\[Mu]b", "TI"]], "+", 
        RowBox[{
         SubscriptBox[
          StyleBox["m", "TI"], 
          StyleBox["\[Mu]c", "TI"]], ".", 
         SubscriptBox[
          StyleBox["m", "TI"], 
          StyleBox["cb", "TI"]]}]}], ")"}], ".", 
      SubscriptBox[
       StyleBox["m", "TI"], 
       StyleBox["\[Mu]a", "TI"]], ".", "\[DoubleStruckA]"}]}], "=", 
    RowBox[{
     SubscriptBox[
      StyleBox["m", "TI"], "b\[DoubleStruckA]"], ".", 
     "\[DoubleStruckA]"}]}]}]], "InlineFormula"]
}], "Text",
 CellID->268860931],

Cell[TextData[{
 "Eliminate ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 " from the boundary-condition equations."
}], "Text",
 CellID->187237148],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       StyleBox["m", "TI"], 
       StyleBox["\[Phi]\[DoubleStruckA]", "TI"]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox[
          StyleBox["m", "TI"], 
          StyleBox["\[Phi]b", "TI"]], "+", 
         RowBox[{
          SubscriptBox[
           StyleBox["m", "TI"], 
           StyleBox["\[Phi]c", "TI"]], ".", 
          SubscriptBox[
           StyleBox["m", "TI"], 
           StyleBox["cb", "TI"]]}]}], ")"}], ".", 
       SubscriptBox[
        StyleBox["m", "TI"], 
        StyleBox["b\[DoubleStruckA]", "TI"]]}]}], ")"}], ".", 
    "\[DoubleStruckA]"}], "=", 
   RowBox[{"-", 
    SubscriptBox[
     StyleBox["\[Phi]", "TR"], 
     StyleBox["\[Infinity]", "TI"]]}]}]], "InlineFormula"]
}], "Text",
 CellID->710384853],

Cell[TextData[{
 "Write this  system of ",
 Cell[BoxData[
  RowBox[{
   StyleBox["N",
    FontSlant->"Italic"], "+", "1"}]], "InlineFormula"],
 " equations for the list of ",
 Cell[BoxData[
  RowBox[{"N", "+", "1"}]], "InlineFormula"],
 " unknown strength parameters ",
 Cell[BoxData["\[DoubleStruckA]"], "InlineFormula"],
 " in the following form."
}], "Text",
 CellID->621887025],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["m", "TI"], ".", "\[DoubleStruckA]"}], "=", 
   RowBox[{"-", 
    SubscriptBox[
     StyleBox["\[Phi]", "TR"], 
     StyleBox["\[Infinity]", "TI"]]}]}]], "InlineFormula"]
}], "Text",
 CellID->947573354],

Cell[TextData[{
 "Solve the resulting system of linear algebraic equations using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function LinearSolve."
}], "Text",
 CellID->242166576],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox["cb", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->159109476],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mCB", "=", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"Inverse", "[", "mSC", "]"}], ".", "mSB"}]}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[67]:=",
 CellID->588459847],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.9994232543568164`"}], "0.9994232543568164`", "0.`", 
      "0.`", "0.`", "0.`"},
     {"0.`", 
      RowBox[{"-", "1.3658251557582437`"}], "1.3658251557582437`", "0.`", 
      "0.`", "0.`"},
     {"0.`", "0.`", 
      RowBox[{"-", "3.6707735414411857`"}], "3.6707735414411857`", "0.`", 
      "0.`"},
     {"0.`", "0.`", "0.`", 
      RowBox[{"-", "3.3819831508950373`"}], "3.3819831508950373`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", 
      RowBox[{"-", "1.3656440416785134`"}], "1.3656440416785134`"},
     {
      RowBox[{"-", "0.9899390954426602`"}], "0.`", "0.`", "0.`", "0.`", 
      RowBox[{"-", "0.9899390954426602`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{420, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[67]//MatrixForm=",
 CellID->631633575]
}, Open  ]],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["m", "TI"], 
   StyleBox[
    RowBox[{
     StyleBox["b", "TI"], "\[DoubleStruckA]"}]]]], "InlineFormula"],
 "."
}], "Text",
 CellID->167905182],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mB\[DoubleStruckCapitalA]", "=", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"m\[CapitalMu]B", "+", 
        RowBox[{"m\[CapitalMu]C", ".", "mCB"}]}], "]"}], ".", 
      "m\[CapitalMu]\[DoubleStruckCapitalA]"}]}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[68]:=",
 CellID->119869274],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "3.978724699598953`"}], "4.730496820230121`", 
      RowBox[{"-", "10.073197394398857`"}], "14.105513384672443`", 
      RowBox[{"-", "9.4952543851471`"}], "4.711166274242346`", 
      RowBox[{"-", "1.97987819088532`"}]},
     {
      RowBox[{"-", "0.01896831782831221`"}], 
      RowBox[{"-", "0.7328038028028547`"}], "10.073197394398857`", 
      RowBox[{"-", "14.105513384672443`"}], "9.4952543851471`", 
      RowBox[{"-", "4.711166274242347`"}], "1.9798781908853205`"},
     {"0.01896831782831221`", 
      RowBox[{"-", "4.730496820230121`"}], 
      RowBox[{"-", "4.609896771365884`"}], "14.105513384672445`", 
      RowBox[{"-", "9.495254385147101`"}], "4.711166274242348`", 
      RowBox[{"-", "1.9798781908853211`"}]},
     {
      RowBox[{"-", "0.01896831782831221`"}], "4.730496820230121`", 
      RowBox[{"-", "10.073197394398857`"}], "0.5775807810922942`", 
      "9.495254385147103`", 
      RowBox[{"-", "4.711166274242348`"}], "1.979878190885321`"},
     {"0.01896831782831221`", 
      RowBox[{"-", "4.730496820230121`"}], "10.073197394398857`", 
      RowBox[{"-", "14.105513384672443`"}], "4.0326782184330465`", 
      "4.711166274242348`", 
      RowBox[{"-", "1.979878190885321`"}]},
     {
      RowBox[{"-", "0.01896831782831221`"}], "4.730496820230121`", 
      RowBox[{"-", "10.073197394398857`"}], "14.105513384672443`", 
      RowBox[{"-", "9.4952543851471`"}], "0.751409892471705`", 
      "1.979878190885321`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{492, 87},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[68]//MatrixForm=",
 CellID->55077927]
}, Open  ]],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  StyleBox["m", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->597170703],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"m", "=", 
    RowBox[{"m\[CapitalPhi]\[DoubleStruckCapitalA]", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"m\[CapitalPhi]B", "+", 
        RowBox[{"m\[CapitalPhi]C", ".", "mCB"}]}], ")"}], ".", 
      "mB\[DoubleStruckCapitalA]"}]}]}], ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[69]:=",
 CellID->284020968],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.25193027797083456`", "0.6556856356536203`", 
      RowBox[{"-", "1.124195802830467`"}], "1.5882394279680538`", 
      RowBox[{"-", "1.0445101284132645`"}], "0.6728505896512234`", 
      "0.10633940266660691`"},
     {"0.011079777187541828`", "0.24818644259815564`", "0.7927003366626837`", 
      RowBox[{"-", "0.9000471546657861`"}], "0.7767826605227269`", 
      "0.07129793769467763`", "0.06664599713794604`"},
     {"0.007255959664391043`", 
      RowBox[{"-", "0.0371902978203922`"}], "0.2554350387526026`", 
      "0.5768020149877041`", "0.10502087614010103`", "0.09267640827559344`", 
      RowBox[{"-", "0.01060692048701354`"}]},
     {"0.006845988084618333`", "0.08620981855425787`", "0.0871928888412421`", 
      "0.5516138147849928`", "0.2974304531418364`", 
      RowBox[{"-", "0.02929296340694744`"}], "0.023924466556613684`"},
     {"0.011909254820922588`", "0.06875823037712814`", "0.7978445205714115`", 
      RowBox[{"-", "0.9020905971837635`"}], "0.7702466135845378`", 
      "0.2533319778297634`", 
      RowBox[{"-", "0.05665596035065028`"}]},
     {"0.24759603559984564`", "0.6669597375176765`", 
      RowBox[{"-", "1.1181854967441685`"}], "1.5867566129591095`", 
      RowBox[{"-", "1.0483582965230094`"}], "0.6652314071905465`", 
      "0.12854753514741113`"},
     {"0.25167752797729837`", "0.6580178676487459`", 
      RowBox[{"-", "1.112368926934308`"}], "1.5751859470452951`", 
      RowBox[{"-", "1.0380984313762158`"}], "0.6655860156391846`", 
      "0.11846783515128871`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{532, 102},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[69]//MatrixForm=",
 CellID->234747518]
}, Open  ]],

Cell["\<\
Compute the list of free stream velocity potentials at collocation points.\
\>", "Text",
 CellID->328797457],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Phi]\[Infinity]", "=", 
  RowBox[{"UniformFlow\[Phi]", "[", 
   RowBox[{"rCAll", ",", "\[Alpha]"}], "]"}]}]], "Input",
 CellLabel->"In[70]:=",
 CellID->244118140],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7449939106631028`", ",", "0.31311164114544915`", ",", 
   "0.0654237553227679`", ",", "0.06997289124415831`", ",", 
   "0.32230486776270967`", ",", "0.7496380013487123`", ",", 
   "0.7473159560059076`"}], "}"}]], "Output",
 ImageSize->{490, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[70]=",
 CellID->493201908]
}, Open  ]],

Cell[TextData[{
 "Solve the system of equations for the list of strength parameters ",
 Cell[BoxData["\[DoubleStruckA]"], "InlineFormula"],
 "."
}], "Text",
 CellID->190811117],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[DoubleStruckA]", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{"m", ",", 
    RowBox[{"-", "\[Phi]\[Infinity]"}]}], "]"}]}]], "Input",
 CellLabel->"In[71]:=",
 CellID->446810411],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.7913951699608313`"}], ",", 
   RowBox[{"-", "0.3369762229021142`"}], ",", 
   RowBox[{"-", "0.0015843939653637348`"}], ",", "0.009523536820030676`", ",", 
   RowBox[{"-", "0.16817322801969964`"}], ",", 
   RowBox[{"-", "0.6961132264612991`"}], ",", 
   RowBox[{"-", "0.45939986678997774`"}]}], "}"}]], "Output",
 ImageSize->{538, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[71]=",
 CellID->36496744]
}, Open  ]],

Cell[TextData[{
 "Compute the list of strength parameters ",
 Cell[BoxData[
  StyleBox["b", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->253484638],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"b", "=", 
  RowBox[{"mB\[DoubleStruckCapitalA]", ".", "\[DoubleStruckA]"}]}]], "Input",
 CellLabel->"In[72]:=",
 CellID->215094552],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9318710505958281`", ",", "0.8847564010474565`", ",", 
   "0.947589986942861`", ",", 
   RowBox[{"-", "0.7844911932341179`"}], ",", 
   RowBox[{"-", "1.6193786653919846`"}], ",", 
   RowBox[{"-", "1.2645337875501514`"}]}], "}"}]], "Output",
 ImageSize->{412, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[72]=",
 CellID->47862118]
}, Open  ]],

Cell[TextData[{
 "Compute the list of strength parameters ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->203098661],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "=", 
  RowBox[{"mCB", ".", "b"}]}]], "Input",
 CellLabel->"In[73]:=",
 CellID->156425214],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.04708747637951449`"}], ",", "0.0858196922424399`", ",", 
   RowBox[{"-", "6.358077767821877`"}], ",", 
   RowBox[{"-", "2.823575363731255`"}], ",", "0.48459179314483936`", ",", 
   "0.32931584890804244`"}], "}"}]], "Output",
 ImageSize->{433, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[73]=",
 CellID->407262288]
}, Open  ]],

Cell["\<\
Separate the strength of the wake panel from the panels specifying the \
discretized airfoil.\
\>", "Text",
 CellID->64776907],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "aW"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Most", "[", "\[DoubleStruckA]", "]"}], ",", 
    RowBox[{"Last", "[", "\[DoubleStruckA]", "]"}]}], "}"}]}]], "Input",
 CellLabel->"In[74]:=",
 CellID->57059381],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7913951699608313`"}], ",", 
     RowBox[{"-", "0.3369762229021142`"}], ",", 
     RowBox[{"-", "0.0015843939653637348`"}], ",", "0.009523536820030676`", 
     ",", 
     RowBox[{"-", "0.16817322801969964`"}], ",", 
     RowBox[{"-", "0.6961132264612991`"}]}], "}"}], ",", 
   RowBox[{"-", "0.45939986678997774`"}]}], "}"}]], "Output",
 ImageSize->{552, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[74]=",
 CellID->747573472]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results using function PMDoubletQuadraticDirichlet", "Subsection",
 CellID->913638886],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["PMDoubletQuadraticDirichlet",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"]], 
  "InlineFormula"],
 " to solve the model for the example discretized airfoil at the specified \
angle of attack."
}], "Text",
 CellID->213089269],

Cell["\<\
Compute the strength parameters, locations of collocation points and surface \
speeds near collocation points using the suffix DQD to denote results \
computed from the programmed model function.  \
\>", "Text",
 CellID->525928298],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "aDQD", ",", "bDQD", ",", "cDQD", ",", "aWDQD", ",", "rC", ",", "vCDQD"}],
     "}"}], "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[44]:=",
 CellID->239185265],

Cell["\<\
Verify that the results of the step-by-step implementation are the same as \
those from the model PMDoubletQuadraticDirichlet.\
\>", "Text",
 CellID->476901211],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "==", "aDQD"}], ",", 
   RowBox[{"b", "==", "bDQD"}], ",", 
   RowBox[{"c", "==", "cDQD"}], ",", 
   RowBox[{"aW", "==", "aWDQD"}]}], "}"}]], "Input",
 CellLabel->"In[75]:=",
 CellID->1385341],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 ImageSize->{163, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[75]=",
 CellID->6699110]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.5 Comments", "Section",
 CellID->273428036],

Cell["\<\
The model PMVortexLinearNeumann is the most straightforward to implement.  \
Both doublet models require a constant-strength wake panel to accommodate a \
Kutta condition, which complicates implementation.  Additionally, \
PMDoubletQuadraticDirichlet, has the complication that an additional point \
must be placed inside the airfoil where the boundary condition is applied.\
\>", "Text",
 CellID->107864109],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[Cell[BoxData[
 ButtonBox["PanelMethods",
  BaseStyle->"Link",
  ButtonData->
   "paclet:Aerodynamics/guide/PanelMethods"]], "InlineFormula"]], \
"TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["3.2 Validation Example",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/ValidationExample"]], "RelatedTutorials",
 CellID->17795993],

Cell[TextData[ButtonBox["3.4 Flow Visualization",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/FlowVisualization"]], "RelatedTutorials",
 CellID->14999323],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"3.3  Implementation - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 11, 0, 12.2250000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "This section provides details for the implementation of the three \
panel-method functions implemented in Aerodynamics for a coarsely discretized \
Eppler-205 airfoil. In addition to illustrating the common steps used in \
constructing a model, some of the choices that must be made are pointed out. \
Also, the display of intermediate results may aid those constructing their \
own panel methods. Load the Aerodynamics packages. The data file for the \
Eppler-205 airfoil has been downloaded from the UIUC Airfoil Data Base to the \
Airfoil Data folder in the Aerodynamics software. Use AirfoilFromDataFile to \
import data from the file and rearrange the data to the form used in \
Aerodynamics. This data file uses the counterclockwise numbering convention, \
which is the default value for the option NumberingConvention.", 
    "synonyms" -> {}, "title" -> "3.3  Implementation", "type" -> "Tutorial", 
    "uri" -> "Aerodynamics/tutorial/Implementation"}, "SearchTextTranslated" -> 
  ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[600, 21, 78, 1, 70, "TutorialColorBar"],
Cell[681, 24, 191, 5, 70, "LinkTrail"],
Cell[875, 31, 2891, 65, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3791, 100, 56, 1, 70, "Title",
 CellID->509267359],
Cell[3850, 103, 492, 10, 70, "Text",
 CellID->1534169418],
Cell[4345, 115, 125, 6, 70, "Text",
 CellID->585195885],
Cell[4473, 123, 99, 3, 70, "Input",
 CellID->20779588],
Cell[CellGroupData[{
Cell[4597, 130, 64, 1, 70, "Section",
 CellID->491421075],
Cell[4664, 133, 668, 17, 70, "Text",
 CellID->323137],
Cell[5335, 152, 217, 8, 70, "Input",
 CellID->543466123],
Cell[5555, 162, 76, 1, 70, "Text",
 CellID->173149258],
Cell[CellGroupData[{
Cell[5656, 167, 112, 3, 70, "Input",
 CellID->416922631],
Cell[5771, 172, 159, 5, 36, "Output",
 CellID->104749150]
}, Open  ]],
Cell[5945, 180, 278, 9, 70, "Text",
 CellID->193395042],
Cell[CellGroupData[{
Cell[6248, 193, 645, 20, 83, "Input",
 CellID->88849844],
Cell[6896, 215, 5843, 103, 201, "Output",
 CellID->393419389]
}, Open  ]],
Cell[12754, 321, 341, 10, 70, "Text",
 CellID->135072324],
Cell[CellGroupData[{
Cell[13120, 335, 604, 17, 83, "Input",
 CellID->25651006],
Cell[13727, 354, 4396, 80, 201, "Output",
 CellID->169311790]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18172, 440, 158, 4, 70, "Section",
 CellID->336729780],
Cell[18333, 446, 388, 9, 70, "Text",
 CellID->479438142],
Cell[18724, 457, 815, 33, 70, "Text",
 CellID->111507038],
Cell[19542, 492, 521, 18, 70, "Text",
 CellID->101991089],
Cell[20066, 512, 1016, 40, 70, "Text",
 CellID->104238284],
Cell[21085, 554, 223, 8, 70, "Text",
 CellID->547624004],
Cell[21311, 564, 803, 23, 70, "Text",
 CellID->375367223],
Cell[CellGroupData[{
Cell[22139, 591, 69, 1, 70, "Subsection",
 CellID->725608851],
Cell[CellGroupData[{
Cell[22233, 596, 61, 1, 70, "Subsubsection",
 CellID->225787759],
Cell[22297, 599, 131, 4, 70, "Text",
 CellID->472269960],
Cell[22431, 605, 57, 1, 70, "Text",
 CellID->74064168],
Cell[CellGroupData[{
Cell[22513, 610, 140, 4, 70, "Input",
 CellID->106567359],
Cell[22656, 616, 365, 10, 36, "Output",
 CellID->5087492]
}, Open  ]],
Cell[23036, 629, 52, 1, 70, "Text",
 CellID->10851564],
Cell[CellGroupData[{
Cell[23113, 634, 134, 4, 70, "Input",
 CellID->152897124],
Cell[23250, 640, 159, 5, 36, "Output",
 CellID->510270591]
}, Open  ]],
Cell[23424, 648, 107, 3, 70, "Text",
 CellID->162262132],
Cell[CellGroupData[{
Cell[23556, 655, 134, 4, 70, "Input",
 CellID->691393489],
Cell[23693, 661, 1116, 27, 54, "Output",
 CellID->136121080]
}, Open  ]],
Cell[24824, 691, 130, 4, 70, "Text",
 CellID->11573225],
Cell[CellGroupData[{
Cell[24979, 699, 230, 8, 70, "Input",
 CellID->92036532],
Cell[25212, 709, 1071, 26, 54, "Output",
 CellID->94250242]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26332, 741, 85, 1, 70, "Subsubsection",
 CellID->15365561],
Cell[26420, 744, 157, 4, 70, "Text",
 CellID->412123985],
Cell[26580, 750, 504, 21, 70, "Text",
 CellID->9417412],
Cell[27087, 773, 1301, 44, 70, "Text",
 CellID->173755935],
Cell[28391, 819, 276, 6, 70, "Text",
 CellID->23730492],
Cell[CellGroupData[{
Cell[28692, 829, 345, 11, 70, "Input",
 CellID->42090444],
Cell[29040, 842, 323, 11, 36, "Output",
 CellID->283650381]
}, Open  ]],
Cell[29378, 856, 256, 5, 70, "Text",
 CellID->407869361],
Cell[CellGroupData[{
Cell[29659, 865, 235, 7, 70, "Input",
 CellID->151960291],
Cell[29897, 874, 1858, 45, 122, "Output",
 CellID->97378443]
}, Open  ]],
Cell[CellGroupData[{
Cell[31792, 924, 179, 6, 70, "Input",
 CellID->49864735],
Cell[31974, 932, 2038, 49, 122, "Output",
 CellID->230765848]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34061, 987, 125, 3, 70, "Subsubsection",
 CellID->103764251],
Cell[34189, 992, 272, 5, 70, "Text",
 CellID->386586113],
Cell[34464, 999, 817, 34, 70, "Text",
 CellID->750004683],
Cell[35284, 1035, 464, 19, 70, "Text",
 CellID->123989520],
Cell[35751, 1056, 82, 1, 70, "Text",
 CellID->503495065],
Cell[35836, 1059, 396, 16, 70, "Text",
 CellID->179254913],
Cell[36235, 1077, 283, 7, 70, "Text",
 CellID->531359183],
Cell[CellGroupData[{
Cell[36543, 1088, 335, 11, 70, "Input",
 CellID->23909254],
Cell[36881, 1101, 1049, 32, 122, "Output",
 CellID->352287606]
}, Open  ]],
Cell[37945, 1136, 106, 3, 70, "Text",
 CellID->78370612],
Cell[CellGroupData[{
Cell[38076, 1143, 325, 11, 70, "Input",
 CellID->49331538],
Cell[38404, 1156, 1027, 31, 122, "Output",
 CellID->439898199]
}, Open  ]],
Cell[39446, 1190, 189, 6, 70, "Text",
 CellID->126776796],
Cell[CellGroupData[{
Cell[39660, 1200, 218, 7, 70, "Input",
 CellID->31347865],
Cell[39881, 1209, 1087, 26, 122, "Output",
 CellID->60914246]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41017, 1241, 63, 1, 70, "Subsubsection",
 CellID->298127402],
Cell[41083, 1244, 233, 9, 70, "Text",
 CellID->122106569],
Cell[41319, 1255, 580, 23, 70, "Text",
 CellID->148715506],
Cell[41902, 1280, 192, 7, 70, "Text",
 CellID->27432560],
Cell[42097, 1289, 598, 24, 70, "Text",
 CellID->347230142],
Cell[42698, 1315, 610, 26, 70, "Text",
 CellID->44848813],
Cell[43311, 1343, 339, 13, 70, "Text",
 CellID->517009306],
Cell[CellGroupData[{
Cell[43675, 1360, 298, 10, 70, "Input",
 CellID->319384963],
Cell[43976, 1372, 1350, 36, 122, "Output",
 CellID->1394338]
}, Open  ]],
Cell[45341, 1411, 77, 1, 70, "Text",
 CellID->31359196],
Cell[CellGroupData[{
Cell[45443, 1416, 201, 6, 70, "Input",
 CellID->211953321],
Cell[45647, 1424, 438, 12, 36, "Output",
 CellID->769261126]
}, Open  ]],
Cell[46100, 1439, 157, 6, 70, "Text",
 CellID->388832003],
Cell[CellGroupData[{
Cell[46282, 1449, 244, 8, 70, "Input",
 CellID->367664505],
Cell[46529, 1459, 413, 11, 36, "Output",
 CellID->748911096]
}, Open  ]],
Cell[46957, 1473, 190, 9, 70, "Text",
 CellID->535259082],
Cell[CellGroupData[{
Cell[47172, 1486, 117, 4, 70, "Input",
 CellID->28035240],
Cell[47292, 1492, 398, 11, 36, "Output",
 CellID->174816235]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47751, 1510, 99, 1, 70, "Subsection",
 CellID->611074881],
Cell[47853, 1513, 411, 13, 70, "Text",
 CellID->19519575],
Cell[48267, 1528, 275, 8, 70, "Input",
 CellID->50303841],
Cell[48545, 1538, 163, 4, 70, "Text",
 CellID->68346340],
Cell[CellGroupData[{
Cell[48733, 1546, 172, 6, 70, "Input",
 CellID->514967147],
Cell[48908, 1554, 210, 7, 36, "Output",
 CellID->270348639]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49179, 1568, 152, 4, 70, "Section",
 CellID->577981106],
Cell[49334, 1574, 245, 7, 70, "Text",
 CellID->3302604],
Cell[49582, 1583, 491, 20, 70, "Text",
 CellID->181147249],
Cell[50076, 1605, 287, 9, 70, "Text",
 CellID->260469098],
Cell[50366, 1616, 533, 21, 70, "Text",
 CellID->295014137],
Cell[50902, 1639, 590, 20, 70, "Text",
 CellID->409613708],
Cell[51495, 1661, 598, 17, 70, "Text",
 CellID->191057130],
Cell[CellGroupData[{
Cell[52118, 1682, 69, 1, 70, "Subsection",
 CellID->104432088],
Cell[CellGroupData[{
Cell[52212, 1687, 60, 1, 70, "Subsubsection",
 CellID->80757491],
Cell[52275, 1690, 144, 4, 70, "Text",
 CellID->217356065],
Cell[CellGroupData[{
Cell[52444, 1698, 140, 4, 70, "Input",
 CellID->446124998],
Cell[52587, 1704, 367, 10, 36, "Output",
 CellID->317520761]
}, Open  ]],
Cell[CellGroupData[{
Cell[52991, 1719, 132, 4, 70, "Input",
 CellID->7807257],
Cell[53126, 1725, 159, 5, 36, "Output",
 CellID->585340433]
}, Open  ]],
Cell[CellGroupData[{
Cell[53322, 1735, 134, 4, 70, "Input",
 CellID->201019853],
Cell[53459, 1741, 1112, 27, 54, "Output",
 CellID->83752]
}, Open  ]],
Cell[CellGroupData[{
Cell[54608, 1773, 229, 8, 70, "Input",
 CellID->5240558],
Cell[54840, 1783, 1072, 26, 54, "Output",
 CellID->363823630]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55961, 1815, 115, 3, 70, "Subsubsection",
 CellID->292614508],
Cell[56079, 1820, 554, 13, 70, "Text",
 CellID->104611666],
Cell[56636, 1835, 234, 10, 70, "Text",
 CellID->794714778],
Cell[56873, 1847, 1013, 35, 70, "Text",
 CellID->177985028],
Cell[57889, 1884, 442, 10, 70, "Text",
 CellID->317018286],
Cell[58334, 1896, 358, 15, 70, "Text",
 CellID->452776010],
Cell[58695, 1913, 246, 5, 70, "Text",
 CellID->128200992],
Cell[CellGroupData[{
Cell[58966, 1922, 425, 13, 70, "Input",
 CellID->9956353],
Cell[59394, 1937, 203, 7, 36, "Output",
 CellID->34436041]
}, Open  ]],
Cell[59612, 1947, 85, 1, 70, "Text",
 CellID->790473042],
Cell[CellGroupData[{
Cell[59722, 1952, 366, 12, 70, "Input",
 CellID->167614302],
Cell[60091, 1966, 310, 10, 36, "Output",
 CellID->12200932]
}, Open  ]],
Cell[60416, 1979, 170, 4, 70, "Text",
 CellID->54865923],
Cell[CellGroupData[{
Cell[60611, 1987, 224, 8, 70, "Input",
 CellID->87445909],
Cell[60838, 1997, 2008, 43, 137, "Output",
 CellID->166239599]
}, Open  ]],
Cell[62861, 2043, 162, 4, 70, "Text",
 CellID->134373867],
Cell[CellGroupData[{
Cell[63048, 2051, 261, 9, 70, "Input",
 CellID->134984038],
Cell[63312, 2062, 481, 13, 36, "Output",
 CellID->93986948]
}, Open  ]],
Cell[63808, 2078, 64, 1, 70, "Text",
 CellID->6313767],
Cell[CellGroupData[{
Cell[63897, 2083, 160, 5, 70, "Input",
 CellID->173842100],
Cell[64060, 2090, 499, 13, 36, "Output",
 CellID->154187580]
}, Open  ]],
Cell[64574, 2106, 154, 4, 70, "Text",
 CellID->201664465],
Cell[CellGroupData[{
Cell[64753, 2114, 259, 9, 70, "Input",
 CellID->51826491],
Cell[65015, 2125, 548, 15, 36, "Output",
 CellID->253364607]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65624, 2147, 111, 3, 70, "Subsection",
 CellID->37612957],
Cell[65738, 2152, 424, 13, 70, "Text",
 CellID->756079987],
Cell[66165, 2167, 282, 8, 70, "Input",
 CellID->178842356],
Cell[66450, 2177, 169, 4, 70, "Text",
 CellID->289996779],
Cell[CellGroupData[{
Cell[66644, 2185, 174, 6, 70, "Input",
 CellID->229212092],
Cell[66821, 2193, 209, 7, 36, "Output",
 CellID->15448748]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67091, 2207, 165, 4, 70, "Section",
 CellID->106827055],
Cell[67259, 2213, 389, 9, 70, "Text",
 CellID->784000936],
Cell[67651, 2224, 924, 37, 70, "Text",
 CellID->20572744],
Cell[68578, 2263, 628, 23, 70, "Text",
 CellID->321938409],
Cell[69209, 2288, 1497, 59, 70, "Text",
 CellID->206580932],
Cell[70709, 2349, 614, 22, 70, "Text",
 CellID->63853891],
Cell[71326, 2373, 1125, 32, 70, "Text",
 CellID->24556244],
Cell[CellGroupData[{
Cell[72476, 2409, 68, 1, 70, "Subsection",
 CellID->97066759],
Cell[CellGroupData[{
Cell[72569, 2414, 61, 1, 70, "Subsubsection",
 CellID->135427747],
Cell[72633, 2417, 144, 4, 70, "Text",
 CellID->181155074],
Cell[CellGroupData[{
Cell[72802, 2425, 140, 4, 70, "Input",
 CellID->536239764],
Cell[72945, 2431, 367, 10, 36, "Output",
 CellID->182606370]
}, Open  ]],
Cell[CellGroupData[{
Cell[73349, 2446, 134, 4, 70, "Input",
 CellID->677970246],
Cell[73486, 2452, 158, 5, 36, "Output",
 CellID->45611920]
}, Open  ]],
Cell[CellGroupData[{
Cell[73681, 2462, 134, 4, 70, "Input",
 CellID->191192788],
Cell[73818, 2468, 1115, 27, 54, "Output",
 CellID->53980787]
}, Open  ]],
Cell[CellGroupData[{
Cell[74970, 2500, 231, 8, 70, "Input",
 CellID->308931740],
Cell[75204, 2510, 1072, 26, 54, "Output",
 CellID->399907175]
}, Open  ]],
Cell[76291, 2539, 233, 5, 70, "Text",
 CellID->412865955],
Cell[CellGroupData[{
Cell[76549, 2548, 508, 17, 70, "Input",
 CellID->164764330],
Cell[77060, 2567, 1185, 28, 54, "Output",
 CellID->152351051]
}, Open  ]],
Cell[78260, 2598, 249, 5, 70, "Text",
 CellID->708988792],
Cell[CellGroupData[{
Cell[78534, 2607, 259, 8, 70, "Input",
 CellID->707799138],
Cell[78796, 2617, 445, 13, 36, "Output",
 CellID->786176867]
}, Open  ]],
Cell[79256, 2633, 94, 1, 70, "Text",
 CellID->829104254],
Cell[CellGroupData[{
Cell[79375, 2638, 323, 11, 70, "Input",
 CellID->240976878],
Cell[79701, 2651, 518, 15, 40, "Output",
 CellID->315967782]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80268, 2672, 95, 4, 70, "Subsubsection",
 CellID->306855904],
Cell[80366, 2678, 526, 13, 70, "Text",
 CellID->1539757],
Cell[80895, 2693, 667, 26, 70, "Text",
 CellID->202532084],
Cell[81565, 2721, 1154, 45, 70, "Text",
 CellID->207590312],
Cell[82722, 2768, 128, 4, 70, "Text",
 CellID->48064062],
Cell[CellGroupData[{
Cell[82875, 2776, 473, 15, 70, "Input",
 CellID->388039116],
Cell[83351, 2793, 362, 13, 36, "Output",
 CellID->434498979]
}, Open  ]],
Cell[83728, 2809, 141, 4, 70, "Text",
 CellID->65240430],
Cell[CellGroupData[{
Cell[83894, 2817, 606, 18, 70, "Input",
 CellID->24538656],
Cell[84503, 2837, 204, 7, 36, "Output",
 CellID->267931135]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84756, 2850, 60, 1, 70, "Subsubsection",
 CellID->94585002],
Cell[84819, 2853, 346, 8, 70, "Text",
 CellID->349121839],
Cell[85168, 2863, 940, 37, 70, "Text",
 CellID->55333495],
Cell[86111, 2902, 220, 5, 70, "Text",
 CellID->291362026],
Cell[86334, 2909, 469, 19, 70, "Text",
 CellID->404054939],
Cell[86806, 2930, 194, 4, 70, "Text",
 CellID->226623022],
Cell[87003, 2936, 751, 30, 70, "Text",
 CellID->335859064],
Cell[87757, 2968, 267, 5, 70, "Text",
 CellID->880967397]
}, Open  ]],
Cell[CellGroupData[{
Cell[88061, 2978, 129, 3, 70, "Subsubsection",
 CellID->102303559],
Cell[88193, 2983, 207, 5, 70, "Text",
 CellID->54578817],
Cell[88403, 2990, 964, 39, 70, "Text",
 CellID->329538159],
Cell[89370, 3031, 750, 30, 70, "Text",
 CellID->39977282],
Cell[90123, 3063, 82, 1, 70, "Text",
 CellID->397767550],
Cell[90208, 3066, 690, 28, 70, "Text",
 CellID->643737613],
Cell[90901, 3096, 794, 34, 70, "Text",
 CellID->856713082],
Cell[91698, 3132, 257, 5, 70, "Text",
 CellID->756125371],
Cell[CellGroupData[{
Cell[91980, 3141, 347, 11, 70, "Input",
 CellID->615129277],
Cell[92330, 3154, 1049, 32, 122, "Output",
 CellID->200252758]
}, Open  ]],
Cell[CellGroupData[{
Cell[93416, 3191, 215, 7, 70, "Input",
 CellID->16413054],
Cell[93634, 3200, 1088, 26, 122, "Output",
 CellID->506272189]
}, Open  ]],
Cell[CellGroupData[{
Cell[94759, 3231, 242, 8, 70, "Input",
 CellID->741221869],
Cell[95004, 3241, 1089, 26, 122, "Output",
 CellID->85676179]
}, Open  ]],
Cell[96108, 3270, 208, 5, 70, "Text",
 CellID->92270313],
Cell[CellGroupData[{
Cell[96341, 3279, 989, 30, 70, "Input",
 CellID->599743264],
Cell[97333, 3311, 1101, 33, 122, "Output",
 CellID->147518915]
}, Open  ]],
Cell[98449, 3347, 390, 15, 70, "Text",
 CellID->526156131],
Cell[CellGroupData[{
Cell[98864, 3366, 229, 7, 70, "Input",
 CellID->92044694],
Cell[99096, 3375, 362, 13, 36, "Output",
 CellID->327786406]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99507, 3394, 139, 4, 70, "Subsubsection",
 CellID->89512504],
Cell[99649, 3400, 285, 6, 70, "Text",
 CellID->126141448],
Cell[99937, 3408, 197, 4, 70, "Text",
 CellID->61776658],
Cell[100137, 3414, 846, 34, 70, "Text",
 CellID->72666099],
Cell[100986, 3450, 129, 4, 70, "Text",
 CellID->26705995],
Cell[101118, 3456, 468, 19, 70, "Text",
 CellID->44996651],
Cell[101589, 3477, 82, 1, 70, "Text",
 CellID->112301587],
Cell[101674, 3480, 335, 14, 70, "Text",
 CellID->47088591],
Cell[102012, 3496, 428, 19, 70, "Text",
 CellID->454274171],
Cell[102443, 3517, 286, 7, 70, "Text",
 CellID->31540012],
Cell[CellGroupData[{
Cell[102754, 3528, 350, 12, 70, "Input",
 CellID->262110288],
Cell[103107, 3542, 1027, 31, 122, "Output",
 CellID->496316663]
}, Open  ]],
Cell[104149, 3576, 274, 12, 70, "Text",
 CellID->278147230],
Cell[CellGroupData[{
Cell[104448, 3592, 184, 6, 70, "Input",
 CellID->97230909],
Cell[104635, 3600, 1084, 26, 122, "Output",
 CellID->52717624]
}, Open  ]],
Cell[105734, 3629, 295, 13, 70, "Text",
 CellID->727079737],
Cell[CellGroupData[{
Cell[106054, 3646, 153, 5, 70, "Input",
 CellID->19263021],
Cell[106210, 3653, 303, 11, 36, "Output",
 CellID->168315440]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[106562, 3670, 63, 1, 70, "Subsubsection",
 CellID->165742176],
Cell[106628, 3673, 298, 10, 70, "Text",
 CellID->12866520],
Cell[106929, 3685, 531, 22, 70, "Text",
 CellID->446515824],
Cell[107463, 3709, 153, 6, 70, "Text",
 CellID->111227654],
Cell[107619, 3717, 787, 30, 70, "Text",
 CellID->430827873],
Cell[108409, 3749, 752, 29, 70, "Text",
 CellID->19233526],
Cell[109164, 3780, 236, 8, 70, "Text",
 CellID->358389442],
Cell[109403, 3790, 763, 28, 70, "Text",
 CellID->268860931],
Cell[110169, 3820, 162, 6, 70, "Text",
 CellID->187237148],
Cell[110334, 3828, 885, 32, 70, "Text",
 CellID->710384853],
Cell[111222, 3862, 381, 13, 70, "Text",
 CellID->621887025],
Cell[111606, 3877, 280, 11, 70, "Text",
 CellID->947573354],
Cell[111889, 3890, 194, 6, 70, "Text",
 CellID->242166576],
Cell[112086, 3898, 166, 8, 70, "Text",
 CellID->159109476],
Cell[CellGroupData[{
Cell[112277, 3910, 243, 9, 70, "Input",
 CellID->588459847],
Cell[112523, 3921, 1356, 36, 122, "Output",
 CellID->631633575]
}, Open  ]],
Cell[113894, 3960, 216, 10, 70, "Text",
 CellID->167905182],
Cell[CellGroupData[{
Cell[114135, 3974, 388, 12, 70, "Input",
 CellID->119869274],
Cell[114526, 3988, 2161, 50, 122, "Output",
 CellID->55077927]
}, Open  ]],
Cell[116702, 4041, 122, 6, 70, "Text",
 CellID->597170703],
Cell[CellGroupData[{
Cell[116849, 4051, 382, 11, 70, "Input",
 CellID->284020968],
Cell[117234, 4064, 2209, 46, 137, "Output",
 CellID->234747518]
}, Open  ]],
Cell[119458, 4113, 118, 3, 70, "Text",
 CellID->328797457],
Cell[CellGroupData[{
Cell[119601, 4120, 188, 5, 70, "Input",
 CellID->244118140],
Cell[119792, 4127, 399, 11, 36, "Output",
 CellID->493201908]
}, Open  ]],
Cell[120206, 4141, 176, 5, 70, "Text",
 CellID->190811117],
Cell[CellGroupData[{
Cell[120407, 4150, 206, 6, 70, "Input",
 CellID->446810411],
Cell[120616, 4158, 501, 13, 36, "Output",
 CellID->36496744]
}, Open  ]],
Cell[121132, 4174, 154, 6, 70, "Text",
 CellID->253484638],
Cell[CellGroupData[{
Cell[121311, 4184, 155, 4, 70, "Input",
 CellID->215094552],
Cell[121469, 4190, 415, 12, 36, "Output",
 CellID->47862118]
}, Open  ]],
Cell[121899, 4205, 154, 6, 70, "Text",
 CellID->203098661],
Cell[CellGroupData[{
Cell[122078, 4215, 118, 4, 70, "Input",
 CellID->156425214],
Cell[122199, 4221, 415, 11, 36, "Output",
 CellID->407262288]
}, Open  ]],
Cell[122629, 4235, 136, 4, 70, "Text",
 CellID->64776907],
Cell[CellGroupData[{
Cell[122790, 4243, 283, 9, 70, "Input",
 CellID->57059381],
Cell[123076, 4254, 557, 16, 36, "Output",
 CellID->747573472]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[123694, 4277, 92, 1, 70, "Subsection",
 CellID->913638886],
Cell[123789, 4280, 393, 13, 70, "Text",
 CellID->213089269],
Cell[124185, 4295, 241, 5, 70, "Text",
 CellID->525928298],
Cell[124429, 4302, 316, 10, 70, "Input",
 CellID->239185265],
Cell[124748, 4314, 170, 4, 70, "Text",
 CellID->476901211],
Cell[CellGroupData[{
Cell[124943, 4322, 248, 8, 70, "Input",
 CellID->1385341],
Cell[125194, 4332, 235, 7, 36, "Output",
 CellID->6699110]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125490, 4346, 53, 1, 70, "Section",
 CellID->273428036],
Cell[125546, 4349, 418, 7, 70, "Text",
 CellID->107864109],
Cell[CellGroupData[{
Cell[125989, 4360, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[126057, 4363, 200, 6, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[126294, 4374, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[126369, 4377, 176, 4, 70, "RelatedTutorials",
 CellID->17795993],
Cell[126548, 4383, 176, 4, 70, "RelatedTutorials",
 CellID->14999323],
Cell[126727, 4389, 170, 4, 70, "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[126936, 4398, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

