(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     41609,       1107]
NotebookOptionsPosition[     36004,        931]
NotebookOutlinePosition[     38079,        978]
CellTagsIndexPosition[     38036,        975]
WindowTitle->3.1  Introduction to Panel Methods - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"2.3 Isolated Panel\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IsolatedPanel"], "\<\"3.2 Validation \
Example\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/ValidationExample"], "\<\"Table Of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Functions \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PMDoubletConstantDirichlet\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"], \
"\<\"PMDoubletQuadraticDirichlet\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"], \
"\<\"PMVortexLinearNeumann\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PMVortexLinearNeumann"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/IntroductionToPanelMethods\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/IntroductionToPanelMethods"]}, 
            Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/IntroductionToPanelMethods.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/IntroductionToPanelMethods", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["3.1  Introduction to Panel Methods", "Title",
 CellID->509267359],

Cell[TextData[{
 "Panel methods are numerical models for solving potential flow over an \
object, usually with relatively complex geometry such as an aircraft or its \
components.  These methods are based on a boundary-integral solution to \
Laplace's equation.  Source, vortex or doublet singularities are placed on \
the boundary of the object and suitable boundary conditions are applied.  \
Refer to ",
 ButtonBox["Low-Speed Aerodynamics by Katz and Plotkin (2001)",
  BaseStyle->"Hyperlink",
  ButtonData->{"References.nb", "katz2001"}],
 " for details."
}], "Text",
 CellID->1534169418],

Cell[TextData[{
 "Currently, the panel methods in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " are restricted to steady two-dimensional flow over a discretized airfoil \
specified by straight-line panels.  Three panel methods are implemented by \
defined functions in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellID->775308575],

Cell[BoxData[GridBox[{
   {
    ButtonBox["PMVortexLinearNeumann",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PMVortexLinearNeumann"], Cell["\<\
panel method using vortex panels of linearly varying strength and external \
Neumann boundary conditions \
\>", "TableText"]},
   {
    ButtonBox["PMDoubletConstantDirichlet",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PMDoubletConstantDirichlet"], 
    Cell["\<\
panel method using doublet panels of constant strength and internal Dirichlet \
boundary conditions\
\>", "TableText"]},
   {
    ButtonBox["PMDoubletQuadraticDirichlet",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PMDoubletQuadraticDirichlet"], 
    Cell["\<\
panel method using doublet panels of quadratically varying strength and \
internal Dirichlet boundary conditions\
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->2096742444],

Cell["Functions implementing two-dimensional panel methods.", "Caption",
 CellID->1891092685],

Cell[CellGroupData[{

Cell["3.1.1  Steps in implementation", "Section",
 CellID->432056375],

Cell["\<\
Although steps described below are common to the construction of any panel \
method, many choices remain.  These choices of details may have significant \
effects on model results. \
\>", "Text",
 CellID->250015064],

Cell[CellGroupData[{

Cell["Airfoil discretization", "Subsection",
 CellID->220682699],

Cell[TextData[{
 "Use points on the surface of an airfoil as endpoints for straight-line \
panels approximating the shape of the airfoil.  The resulting shape is \
referred to as the discretized airfoil.   In a commonly used airfoil-fixed \
coordinate system, the leading edge of the airfoil is located at the origin \
with the chord line coinciding with the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis.  This coordinate system is normalized such that the chord of the \
airfoil is one.  For airfoils specified by data files, there may be \
deviations from this convention in terms of the locations of leading and \
trailing edges.  Support functions constructing the discretized airfoil for \
use in panel methods are contained in the package ",
 Cell[BoxData[
  ButtonBox["AirfoilGeometry",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/guide/AirfoilGeometry"]], "InlineFormula"],
 "."
}], "Text",
 CellID->612564464]
}, Open  ]],

Cell[CellGroupData[{

Cell["Singularity distribution", "Subsection",
 CellID->64226099],

Cell[TextData[{
 "Singularities can be source, vortex or doublet, sometimes in combination.  \
Geometrically, they can be point, line or surface singularities.  For \
example, the two-dimensional panel methods in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " use two-dimensional line singularities; PMVortexLinearNeumann uses vortex \
panels of linearly varying strength, PMDoubletConstantDirichlet uses \
constant-strength doublet panels and PMDoubletQuadraticDirichlet uses doublet \
panels of quadratically varying strength.  Velocity, velocity potential and \
stream function induced at a point by a panel can be written as the product \
of geometric influence coefficients for the singularity and strength \
parameters.  Influence coefficients for commonly used singularities are \
contained in the package ",
 Cell[BoxData[
  ButtonBox["InfluenceCoefficients",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/guide/InfluenceCoefficients"]], 
  "InlineFormula"],
 "."
}], "Text",
 CellID->368099075]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions", "Subsection",
 CellID->178726099],

Cell[TextData[{
 "Boundary conditions are applied at a finite number of points referred to as \
collocation points.  For the models implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ", collocation points are associated with the middle of each panel.  For \
example, PMVortexLinearNeumann locates collocation points just outside the \
airfoil and requires that the component of velocity normal to the panel be \
zero at these points (tangent-flow boundary condition), \
PMDoubletConstantDirichlet and PMDoubletQuadraticDirichlet locate collocation \
points just inside the airfoil and require that the velocity potential be \
zero at collocation points.  "
}], "Text",
 CellID->55517967]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kutta condition", "Subsection",
 CellID->446287461],

Cell[TextData[{
 "The requirement that the flow leave the trailing edge smoothly is known as \
the Kutta condition, and it summarizes the gross effect of viscosity for \
these potential-flow models.  The Kutta condition implemented for \
PMVortexLinearNeumann requires that the circulation density be zero at the \
trailing edge.  Both doublet models implement a Kutta condition by adding a \
constant-strength doublet panel extending from the trailing edge of the \
airfoil to a point on the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis far downstream.  For PMDoubletConstantDirichlet, the circulation at \
the trailing edge is set to zero.  For PMDoubletQuadraticDirichlet, the \
circulation and circulation density at the trailing edge are set to zero."
}], "Text",
 CellID->107744017]
}, Open  ]],

Cell[CellGroupData[{

Cell["Smoothness conditions", "Subsection",
 CellID->252269107],

Cell["\<\
Models with singularities of linearly varying strength, such as \
PMVortexLinearNeumann, have additional equations requiring continuity of \
singularity strength from one panel to the next.  Models with singularities \
of quadratically varying strength, such as PMDoubletQuadraticDirichlet, \
require additional smoothness conditions on the slope of the singularity \
function from panel to panel.  These smoothness conditions are replaced by a \
Kutta condition at the trailing edge of the airfoil.\
\>", "Text",
 CellID->190335304]
}, Open  ]],

Cell[CellGroupData[{

Cell["System of equations", "Subsection",
 CellID->95542403],

Cell[TextData[{
 "All panel methods lead to a system of linear algebraic equations to be \
solved for unknown strength parameters.  Once the system of equations has \
been solved for the strength parameters, the flow field and aerodynamic \
properties can be computed.  Three fully implemented models are contained in \
the package ",
 Cell[BoxData[
  ButtonBox["PanelMethods",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "InlineFormula"],
 "."
}], "Text",
 CellID->340388638]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.1.2  Example", "Section",
 CellID->275406678],

Cell[TextData[{
 "The following example illustrates the application of each of the three \
panel methods implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " to a NACA-4412 airfoil at an angle of attack of 5 degrees.  Results are \
computed for lift coefficient, pitching-moment coefficient about the leading \
edge, and surface pressure coefficient."
}], "Text",
 CellID->137812698],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->836781195],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->2058623809],

Cell["\<\
Specify the airfoil identification number, discretization parameters and \
angle of attack.\
\>", "Text",
 CellID->48545141],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "=", "4412"}], ";", 
  RowBox[{"n", "=", "75"}], ";", 
  RowBox[{"layout", "=", "HalfCosineSpacing"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"5.", " ", "Degree"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->43842758],

Cell[TextData[{
 "Compute the collection of vectors locating panel endpoints for the \
discretized airfoil.  The ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 Cell[BoxData[
  ButtonBox["NACA4DigitAirfoil",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/NACA4DigitAirfoil"]], "InlineFormula"],
 " computes thickness and camber properties at a list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values generated by ",
 Cell[BoxData[
  ButtonBox["NDiscretizeUnitSegment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/NDiscretizeUnitSegment"]], 
  "InlineFormula"],
 ", and ",
 Cell[BoxData[
  ButtonBox["AirfoilSurfacePoints",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"]], 
  "InlineFormula"],
 " computes a collection of vectors on the surface of the airfoil specifying \
panel endpoints."
}], "Text",
 CellID->114570266],

Cell[BoxData[
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"NACA4DigitAirfoil", "[", 
     RowBox[{"id", ",", 
      RowBox[{"NDiscretizeUnitSegment", "[", 
       RowBox[{"n", ",", 
        RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellID->112440851],

Cell[TextData[{
 "Note that the trailing edge of the airfoil is not closed, but that the mean \
of the two trailing-edge points is very close to the expected value of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", ",", "z"}], ")"}], "=", 
   RowBox[{"(", 
    RowBox[{"1", ",", "0"}], ")"}]}]], "InlineFormula"],
 "."
}], "Text",
 CellID->253458896],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ptTEL", ",", "ptTEU", ",", "ptTEM"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"First", "[", "rP", "]"}], ",", 
    RowBox[{"Last", "[", "rP", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"First", "[", "rP", "]"}], ",", 
       RowBox[{"Last", "[", "rP", "]"}]}], "}"}], "]"}]}], "}"}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->59487574],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9998334737126852`", ",", 
     RowBox[{"-", "0.0012489471548601018`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0001665262873145`", ",", "0.0012489471548601265`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999998`", ",", "1.235990476633475`*^-17"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{472, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->197238257]
}, Open  ]],

Cell["\<\
For doublet models with Dirichlet boundary conditions, the trailing edge \
needs to be closed to obtain plausible results.\
\>", "Text",
 CellID->486625314],

Cell[BoxData[
 RowBox[{
  RowBox[{"rPClosed", "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "ptTEM"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "\[Rule]", "ptTEM"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->225120950],

Cell["\<\
Run each model for the specified airfoil and angle of attack.  In addition to \
the appropriate strength parameters for each model, locations of collocation \
points and surface speeds just outside the airfoil associated with each \
collocation point are computed. \
\>", "Text",
 CellID->59805657],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aV2", ",", "bV2", ",", "rCV2", ",", "vCV2"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aD1", ",", "aWD1", ",", "rCD1", ",", "vCD1"}], "}"}], "=", 
   RowBox[{"PMDoubletConstantDirichlet", "[", 
    RowBox[{"rPClosed", ",", "\[Alpha]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "aD3", ",", "bD3", ",", "cD3", ",", "aWD3", ",", "rCD3", ",", "vCD3"}], 
    "}"}], "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rPClosed", ",", "\[Alpha]"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->117496578],

Cell[TextData[{
 "Compute lift coefficient and pitching-moment coefficient about the leading \
edge, using the Aerodynamics function ",
 Cell[BoxData[
  ButtonBox["ForceAndMoment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/ForceAndMoment"]], "InlineFormula"],
 ".  Display lists of lift coefficient and pitching-moment coefficient to \
provide a comparison of results among the models."
}], "Text",
 CellID->474191],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "clV2", ",", "cmV2", ",", "\[CapitalDelta]clV2", ",", 
     "\[CapitalDelta]cmV2"}], "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Vortex\>\"", ",", "aV2", ",", "bV2", ",", "rP", ",", "\[Alpha]", ",",
      "rCV2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "clD1", ",", "cmD1", ",", "\[CapitalDelta]clD1", ",", 
     "\[CapitalDelta]cmD1"}], "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "aD1", ",", "rP", ",", "\[Alpha]", ",", "rCD1"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "clD3", ",", "cmD3", ",", "\[CapitalDelta]clD3", ",", 
     "\[CapitalDelta]cmD3"}], "}"}], "=", 
   RowBox[{"ForceAndMoment", "[", 
    RowBox[{
    "\"\<Doublet\>\"", ",", "aD3", ",", "bD3", ",", "cD3", ",", "rP", ",", 
     "\[Alpha]", ",", "rCD3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clV2", ",", "clD1", ",", "clD3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cmV2", ",", "cmD1", ",", "cmD3"}], "}"}]}], "}"}]}], "Input",
 CellLabel->"In[9]:=",
 CellID->499718542],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1.1159651419350756`", ",", "1.105004157997314`", ",", 
     "1.1208520355624525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.39615108610865046`"}], ",", 
     RowBox[{"-", "0.39082253368436926`"}], ",", 
     RowBox[{"-", "0.4029408100713303`"}]}], "}"}]}], "}"}]], "Output",
 ImageSize->{426, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->720036085]
}, Open  ]],

Cell["\<\
Use Bernouilli's equation to compute surface pressure coefficients at \
collocation points.\
\>", "Text",
 CellID->21296710],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cpV2", ",", "cpD1", ",", "cpD3"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"vCV2", "^", "2"}]}], ",", 
      RowBox[{"1", "-", 
       RowBox[{"vCD1", "^", "2"}]}], ",", 
      RowBox[{"1", "-", 
       RowBox[{"vCD3", "^", "2"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->36210806],

Cell["\<\
Plot the results of PMVortexLinearNeumann as a line, the results of \
PMDoubletConstantDirichlet as large filled circles colored red, and the \
results for PMDoubletQuadraticDirichlet as medium-sized filled circles \
colored blue.  The superposition of surface pressure coefficient associated \
with collocation points for the three models provide a visual indication of \
agreement among them for this example.\
\>", "Text",
 CellID->281832136],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xCV2", ",", "xCD1", ",", "xCD3"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Components", "[", "rCV2", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Components", "[", "rCD1", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Components", "[", "rCD3", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpV2", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xCV2", ",", "cpV2", ",", "rP", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpD1", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xCD1", ",", "cpD1", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "Large", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpD3", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xCD3", ",", "cpD3", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpV2", ",", "gCpD1", ",", "gCpD3"}], "]"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[14]:=",
 CellID->80931720],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3Q2UVOV9x/EbhWV9CYJE3KRpkprUKFbFSI9xE+OeUE5EGgkqspZSA9iN
thVsAo2vBYzZbRtotpgXaT2sCQIHwRQO7UztWQvHPVU5tWxK3RRZmu3Sg2N7
WDeyh+ha8Pa5++zevXPf5s7MnZn7PPf7OZPI3tmdubM785v//J/nPvfXlq28
ddnZhmHc/AHDeFf8z/q3CQAAAAAAgFTItBiWxvbeWu8JACB+ve3tGeu/Iu1J
egDQWaaFnAcAjWVaWjLOrw0AQI2UGed5tzVWwo91b/Jyvqw7AgCUpBLx29ve
OJL3mXZH44acB4CaiD1+nQW+s3NDzgNATVQtfsl5AKgJch4A9EbOA4DeyHkA
0Bs5DwB6I+cBQG/kPADojZwHAL2R8wCgN3IeAPRGzgOA3sh5ANAbOQ8AeiPn
AUBvKuZ8NmuuWWNu3x7X7QGAzpTL+W99c0jckrzcNqVze+NG8+WXY7llANCS
Wjmf/avX7ZAfT3tj1/ZHe8q/cQDQkko539fXfNYOb87Ly/bHjsSxmwCgG5Vy
vrn5u8b9QTl/tfFTc9++GHYUAPSiUs43NOwxbpltdM4welYZ31ljrP2U0ZtX
0jfcH8eeAoBWFMr57Iyvj0e60Sz+845RL8p4e+NNRpaSHgBclMn5vr7mCTvz
In3kX85OzlJj85q6VmbgAICTMjmf35xvMx4wL7xQlvTi303GvjuMHXnVPoU9
AIxQJucbGuxIf8BoGzSmWIF+2WV2d77Z2G7n/KeM3u0f/2ZMOw4AalMm55ua
3DNsGhqsI2PHvvROxWGmJQCYCuW8I9LHejdt1vaODnPKFLuBM934H4ZlAcBJ
mZw3rUg//cHJVoLX14+GvC3rMyw72+jcft5yxmQBpJxKOW+ae3b3bFjf5X+d
KOzPOktW9VcZ/8aYLABICuW8qNnnzv3v+1ceC/yOsR6+c0x2lvEvTLYEkGaq
5Hx221uFB1j9ujcU9gBSTo2c7+trrnsu0gBrR4c5YYI9A/Ny42cU9gBSTo2c
9x4kNXNm4DeHTraksAeQNmrkvO9BUiHyJ1tS2ANIMzVy3vcgqYIo7AFAlZwP
OkiqIAp7AKmnRs6bVmKfmXyB/0FSBRUq7B8w2tbc1ceJxQFoSZmcN83ug8dX
rthb4g+HFvYsiQNAY2nJealQYX+Tkc3OemTNJ56mmQNAGwrlfDZzuK11f7n7
4SnsZxudds4vNTYzSgtAM6nL+dHbGi/snTM2bzXyjsbKfnAhtT0A1SmU81uf
6d705IFYdsYyVtg7L66zEDpre/o5ABSlUM53bH5VXGLZmXH5MzaDavtZxr+Q
+QAUpVDOb1jftWd3Tyw7k8cu7Ovqgmr7q42fBmU+PXwACadKzou6e/bs/3rg
m8fj2h9/duaPLWUva/tW40HfzKeHDyD5lMj5SIsSxyu4n+PMfPf8nOeey87Z
QOwDSBQFcj76osTxCujnhM3POevmvNi/6SZrZZ7mZjIfQA0pkPNFLUpcIRF6
+GLHnOexsmLfuGmNsdYKfPE1bXwANaJAzhe7KHGlBfTwxY6FTMs0r7iClg6A
mlAg50tblLgKPKtohrV0jJvo5AOoCQVyvuRFiavAru3r682lS4to6bg6+fv2
mbmc+dWv0s8HEDsFct4cj9P3JxW/KHE1Odr4IS0db+ybM2aIH6SfD6AS1Mj5
EYsWbsvlTsayM9XgLPUvuSQ89sV/3I0d+vkAYkLOV0NoJ1/E/vtnneWdq+Pq
59PVAVAacr5Kgjv54jJ44UcKNHbOPpuuDoDSKJTzc2Y/NTx8OpadqT1n7Le1
iYI/vLHjLu9nzjRzORo7AKJQKOdvvGFTLHuSUKH9fHd5bxjZ825zz9gBAD/k
fBJ5+vnucdv6enfyU+EDCEDOJ1R+P99V3v/y7HqfGTveCp85+QDUyfmhoeF5
czti2hcF5ffzz3zhRlfyn5k0iTn5AHypkvO53MlFC7fFtTPK8zR23q07p/Cc
fHo7QCqR86pyzdhpanLPyf+Ae04+o7dAOpHzmvBU+EPTP8roLQCTnNdJoTn5
/r0dKnxAd6rkfPfB4ytX7I1rZ9IiP/nf/sz17pX8fSt806TIB3RCzqeId5md
CT7zM82+Pop8QCfkfLrkV/jDjTe4R28vbjCbm33b+EzFBxRFzqeap8J/+tO3
D5031afIZyo+oCxVcv773ztx3XWvb98e1+5gjKvCHz79i2s+623j+0zFN02K
fEAJSuR8dttb4yHz2JEY9wo+/A7C8k7FN/v6KPIBJSiQ8319zXV559QmTyou
v8gXFb67k9NgtfH9i3wACaNAzjc3u0OGPKkyz1T8fV9qGb7wIp8i32ROJpA4
CuR8Q4O7XVytfcY4R4U/vO7xbObwzz9+lU+Rz5xMIHkUyPmmJle72MoT1Jyn
yB/85hr/OZkmI7ZALSmQ855hQeugfiTBWJH//qT67kUrlize8Ytz3Gc8ZMQW
qDkFct608uT/zp88vnILkuqX133O3WRjxBaoNTVyXhT1mcNtrfvj2hlUiufD
14Gv/MHpi6YHjdjSzAGqgJxHzBwjtqcefWzrM90/u3iG74gtzRygOsh5VJxn
xNZqvtHMAaqFnEc1jBX5Z+om7Zh558oVe0Om39PMAeJFzqP6ug8e7/vE1TRz
gOog51EbNHOAaiHnUTOOZs6uWYtXrtj73rSAZg6AMpDzSIjug8eP/qrfWgom
a+YAZalAzve2N4pbbcnEekfkfCr4NnNYMwcoT2XqeRH15DxKMtbMOT2xbsfM
O8XfPXDNHADRqJLze3b3bFjfVc4tQDm53Enx5j5Y77dmDoDIVMn5js2viks5
twBFeU9WPr5gKX17IIJycz7TYjg1tvdaW/1z3qnY+yHn0ytowVL69kA01PNQ
gGMG5t7Gu1au2Nt98Dh9eyCiSuT8aI0/WtvHc0fkPGwi5EXUv33uVP++PSsn
APlUmT9PzsNlaNb1Pn17Vk4APMh5qMq3b8/KCYAHOQ+FjZ+4cFLnb929YP6W
dy6YxsoJgAs5D20MDJw6fuln/FdOMJmEifQi56EVz8oJpx//trWdSZhIMXIe
unE0c/Z9qWXB/C0b1neduuVW/0mYTM5BCpDz0NvQ0PCe3T2/OMdv8QQm5yAd
yHmkQlOTzyRMJucgHch5pIJnEua2K5vDJufQz4FGyHmkxVjf3qyvN9vacrmT
gZNz6OdAL0rkvKjF5s9/456v/TzG/QG8k3PeuO9Bazv9HOgl+Tmf3fbW+Cvu
sSPx7hXSzlHkv/7Vr69csXfRwm2nJtPPgVaSnvN9fc11z+W94vgEjUrK5U6+
efks+jnQSdJzvrnZ/YrjEzQqzdPPEaX+0NAw/RwoKuk539Dgng7HciWoAkc/
5437Hmxr3T9vbsfQ+ReG9HNYVAGJlfScb2pyr0loL1cCVNdbV18X1M9hUQUk
WdJzPuiccUD1efo5XTd/rcCZrRi3RQIkPefNvHPGEfKoMUc/Z3jd43t296xc
sXdw0gX+Z7Zi3BbJoEDOj2hr3Z/NHI5rZ4AYvfe5G3wWVTCZh4+kIOeBcvkt
qvDExpdOXzSdefhIAnIeiIFnUYWdzx46/OErmIePJCDngUrxjNue+Maj1nb6
Oaguch6ooPGTntT/+++sXL5sV8F1FZiHj9iR80A15XIn//eK32QePqqJnAeq
jXn4qC5yHqgBx7jtqUcfYx4+KoqcBxKCefioEHIeSArPPPynP327eOYPX3gR
8/BRDnIeSJD8efhDQ8Piad/3iauZh49ykPNA0rEePspDzgMKcNT5fV/7E7ke
/tvnTg3s55hMxcc4ch5Q1NCs6/37OSZT8ZGHnAdU5enn7Jh5Z8fmV3uPnGAq
PpzIeUBh+eO2/f2DIueXL9s1WD+FqfiwkfOAfoYbmYqPceQ8oCHPVPwtM+7Y
sL7rvWnBS+KbtHS0Rc4Despv6QwMnNqzu6f3o1eGDN3S0tGVKjm/elXmwCvH
4toZIKU8Q7dH7141PHzauoqWjr5UyfmVK/ZaC/oBKJOjzhchv25t57y5HQ8/
9Py7Uz/E6gq6IueBlBP1fNeLff2XzGR1BV2R8wAsnpbOz5b88cDAKfo5GiDn
AYxytHTeuO/BDeu7FszfwuoKGiDnAYRgdQUNkPMAwnj6ObtmLd757KFc7mTY
6gpIEnIeQAH5U/F7j5x4YuNLixZu+8U5AasrmPRzksURv5kWY0Rje2+mvb23
cndUCnK+JkTNJn7t9mXP7p6Oza86L22t+8WfJuRy7z27b7xhk/cS/lPy4rov
edn6TLdzl8TFGitELfzyus/5r65APydhRuO3t73Ryndz7N8tmQrdUanI+bgM
D5+2E9I3rufMfspOY1GzOYN3w/ouV+pmM4ddqeu69Lz2pu9uhP+Ua/ecl01P
HnC9HSyYv8X5DrJ82S7ntaLytH/2hc6j9o2PHhyEcnhWV5AtnXe+cjv9nEQZ
iV+R7I2OAr63vSX2cp6crx47yUXp68xwGYMixr0FszOuVQ/A3iMnnG8WInbs
h7lubaf37Uy8TXh/IV0v9vFhIRK/lk7gapkSLZ2qs+LXFfOVu6MykPNeQ0PD
4ncialSRS6LSFr8iUco6k1yUvs4Mr/X+JpRIcu8niIcfet71YcH+aGN/qLHf
C2r9CJKnqcnVzzkz/eLRq2jp1IIVv5mWCvRp/O6oDCnPeZlFsj2+elVG5vm8
uR3i1yJqVLFRXCW+wTrBBCrDHqqwByns9wL5RrBk8Q7xb/HXcb4LpPQv4rda
pvjliF/d/91+By2d6huJXxH04wW9o2tjjcy2tLc3Gkb59X7pOT/yKe++yT94
6qr1KfmUJyPFbrmI+lz2FmQleeCVYylNj2Tr7x8UfzXx13G+C8h3ZHvUQGyU
1+rRIguT388xR0ZkxBP4rUkX0NKpPsc4rGFPt7GvtYLe+jrTUnbBX2LOp+BT
nmyn73z2kOy92C0Cu+Wicxqkhhw1EEW+zHnnGIF8C5Bv4vp/LvO0dDjqqgpC
4zfTIkN/7L8Vu6NgOh6IMTBwSr7exWd8Eemynf7Expfka7zWe4dqk28Bsh3k
HGexZ5/KcRZNxgI8LZ2nP327eNTWQ9PxxZ4QYfE7WsXH074vMecbGsI+5SlC
Vuxbn+kWH9sXzN8iLvLzu/iMbx1UCARwzpuyxwJkYSAHAsTHQPEN/f2Dtd7T
YuS3dIaGhsV7nHhEYbN06OeUJyR+HcdNVfaOwoR8yks28dLLZg6LQkXUZvKF
KaoyUcYzTw9lkmWDHAgQHwPFU2vJ4h32QLA8XkBcG3TkQmIFntOWfk7ZguM3
hp58tDsK5fmUJ8d0kklku6hM1q3tFBW7eNG1te63ztSmca8VSSIHguXxAqLa
l0ciu0bwEx3+nhd75oavimLpzB2L6OeUKSB+ZS0f56z60ufbjH3KO1M3KYEh
78p28YJ6ofMoRTsSwjUjV4a/HOgXlb9cRCJBbZ/8lo54YxLFElN0ysc6ZiUY
GhoWYS4iXbxeyHYoR07cFZW/XERCtn2WL9sle/5Jm+V15gs3MkWnTOR8dKLs
ES8NURHNm9shCnhRIzGKCm30Hjkhe/72URvyQDxR9svRXlHe1GbP/FbREa8+
a3+YohMNOV+QXLJD1DziIv6R6A4nEB+5sIYIeTnaK2JfdvvFpwA5B7h6Nb9n
FR3xIVrsz9D5F4a3dDh9uUTOB5GH74kntvg8K57qCephAjUiu/1bn+mW8/zt
I7VrkPwj3rr6upCWDqcvt5HzLna8y+U46LoDIYKSX64CXfHJZp6WztG7V41e
xenLHch5KZc7KWoSOQ+BeAdKJpNfrgItD+y9957dba375dye+Jv8jpbOsT94
QM58E6/lM9MvDjt9ecqkPOfFx8xs5rB4HoqEF89DxlWB2PW89qZ4lcm5PfPm
dojXmpzY0/ViXyVeceKNRryWey6aEXj6cjN1szFTm/P9/YOyPyMqDYZWgaoR
2S4n9jz80PPO9Z3Ee0GcfR7P6cvHj75J32zMFOb8C51H5Zzh0alZAGrHXq9V
VFyyzyMP4BUvz3ILsLGWzumJdduubF63tlO8v1jb0zcbMz05LyJdPJdE/SD+
3DWfig8giDyAV0S9PHpX/H8ssS8KvNWrMqLAe3fqhzRYHbEoacj5gYFT4lOh
SHjx/3TgAbWIeI8x9vv7B4998prA2Zia9u31znk74UUlT4sG0IAr9u3efhFH
uAStjqhv317XnHcmfHJW6gAQL7u3v2TxjiIWAHesjri38S7xlvFC51GN+/b6
5bxI9a3PdIs/OgkPpIrrhD5yME7kQMEOj/gG8Z1hJzpRnGY5f+CVYyLhxRs6
XRog5XK5k6JKF5/r7Q6PSAaxJWiQLvBEJ2M3p27rXpucFx/TVq/KiAsjrQC8
ZKkv6nZR58tzd8pDdMe/w9O3P/XoY6NXKd661yPn9+zuEWX86ORYAAglysKu
F/vkIbpyDo8o+62zSPxgs72Kwr//zko5Sc9q9Sveulc952UZv2F9F40aAKXp
ee3Nnc8ekmvjiGyXZ/zs7x8cHj4tD7o5NXma0q17pXNe/HWWL9tFGQ8gLrnc
yWzmsCgdlyzeMW9ux8MPPf/jH/3rP199c3jrPuEL3aub8+JvITaysCSAChka
GpbtnXubn7ZGcq/6RsfHv3xg6hXDZ010rpaT/IXuVcl58UlKBLv9pTy7GdMm
AVRJR0f3r3xG5PyqK+//4ud/eOuCLd/5ixetlv4dv5f8he5VzHkR8uISx04B
QNFEnf9nrftvmff0PV/72wXXb5h97d/8+qe6pl90tK7uVDIXulcu5+XZKmPa
KQAo0cDAKZFLhz98xbfO/ZOPfLjn8ss6r79uy83Xfm/DVb9v1flJaimrlfMH
Xjm2elUmrl0CgDIdf2qHc4j2tXN/fc+9fymn7ixZvGPD+q6uF/tqPhtQoZzf
tfPQ8mW7EvUuCQBmR8fpD06WC92ffvzb9ub+/sE9P3757qbvz/7cpltv+OET
Dz5Xq8xXKOe/8fW/3/nsobj2BwDitfWZ7kULt43P9HYcRXv+eSce+pVVD7ds
nTe34957dm968kA1T2OnSs6vXdN5y2//iAk2AJJMHrm5bm1nyFG0IuHFO4JI
+zmzn3r4oedF+VrEosolqUTOZ1rErRqN7b0x3tEf/eEecSlvvwCgGl7oPBrl
xFWicO16se+JjS+Jb5bnqq7QAG78OS9SviUz8t+8pC/zjn538Y7Wb/9TmbsG
ANUxNDTcf8nMsKNo84l4z2YOywHc5ct2bXryQIxH+see873tjS1yRkx+0Jd5
Rwu+smXTD18pb9cAoIqCTlxlFlgqoffIia3PdK9elbnxhk3i/8sfl4w958fK
eZ+cL8fll909/aLfLPNGACCxplxwqffya59YcO1nHin/xuPN+QrV8/e0/O03
vv735e0aAIX19w92HzwefhFlsDxePvpFrk5c7EWeuyTeS8jdlfmriz3nK9Sf
Z74NkCg9r73pm7QvdB4NCdXw8Jwz+6mQGFyyeEfB+BWhXWzOy7ONFHspYVak
eJ8aPRFtQ4N7Hk6F5z3Gn/OVmW/T1rr/L/5sv/j/8nYNSJHeIye8AeWbdatX
ZXxjc9HCbUGpKyLL90fWre0MCdXw8NS+kBMPUPx+jn3yGvc8nODx2VhUIudj
vqOR0zLeP/XJH17+5x2P7WZxG2jMWyT7lsfeWBa1rjeKly/b5c1h3/g98Mox
3+DlLJyV8PKfbnLPw7HHZ82KrGaf9Jz3nJZxZ+tPxJOc1Q+QEENDw1FqZlHF
ufJWhHCUItm3PPbGcqUPtEG8jj/+V6fqzpMnKMwL+ZHV7POm6MSxmn3Sc97v
gDLxJBfVi3i213x1IKjLO6i3Z3ePK07bWvcXLJvnze2IUjOLstx1d71HTtT6
d4BaEvElnirO02pYmpvdUzHjWM0+6Tnf0OB7QJn4FYnXzqKF2zas76KSSQ/f
4tk7xUI8Kwr2mb2DeuKnXLcjXoOUzago1xmUrEa9YeSdnSqOiE56zjc1hRxQ
Jl71ogYTL1jxEbgKa0SgHAMDp5yBKT6UldDZ8C2evVMsxLOCPjNUkRf1TU3u
s1PFMUSb9JwPOaDMQXwElmtEyHO1i18ar+vYhae0K3sXzN/iimixxfkNq1dl
6GwA0njUZ7PuTrVf4hUr6TlvWms7y4GJ0xPrCj5kea528UuTn9Plh3E5P5bk
Nz0T7cTvypm0Dz/0vDOKQw7i8Ka0K6IZKAeKYkf9d+88MF7VfmlfLDeuQM6P
6CjpnLBycE0e7yaTX3ZlZSfWeXxEOftWNd6hQ++kO9fQ4by5HSET7cQ3O3+2
68U+543X+uEC6SKj/p13rHq2qcl84AFzMKZWtN457yWjUs6scB7vHDQ8F37Q
R/kXb1M6pPXhHTr07p5r6JApSYBC3MOyMUlbzhfkqpnDD+Iu/+JtStP6ANKs
ElFPzgNAosQe9eQ8AFRbyOIGI1cd++Q1w7cuTMu6B2PIeQCaCFncIJ3rHowh
5wHkKVQSJ/eqkMUN0rnuwRhyHrUX9LL13V7UN5ewvbY3Fe+PlHBrpZXECblq
ZHED96XgVWUg56Gw6AFbfkQHvWx9txf1zSVsL/QjeQukhG+v+Y+UdmsjdW/e
VfklcaKvEk8t11X24gYhV5WBnEeylBm8vslQVIwEfXPQy9Z3e1HfXML20B9x
L5ASvr3mP1LarTU0uK9ylMRJvyqbdV9lH+kfclUZyHlNuJLQG4wFt0QM2NK2
RNwYPbrNwID1SYaiYiTom4Netn7b35s23bux++DxuLYHXSVeI7+8YJr3nHQh
22P8kZUr9r597lTf7SVctWjhtoG6yd7t8pjB7gsudV0lvrn6V/3s4hmuq8Rj
kQuD5C671nWV+JPZh5k3X/fz8asu/U/H6/jkLb9x2PeqcpDzNRMes0V96Y3H
88/P+3L7dvc3eLe4fsS3+TDyU3nRGmVL9DL7i1+MGt1mYMB6k6GoUArKlqAX
u3e7uNnej17p+/KPa7vvVeJhiteIiBfXUt7h2+P6ERliQ7Ou991ewlXWglRN
TYHn18tm3Vc5SuKqXfU/P9rluuqN+x6UC/394x9vdF21t/Eu+9D7T17ykn3V
VVf+1D7mXby7feELr43/VAy1vIWcryxnIP/d343/+yc/8cZsXr4V9aU3Hl1f
Tp1aeEuU5sPUqe5ojbIlepk9caI3ut+d+iFv8C5ZvCMoYL3RVFQoBWZL0Ivd
d3tR31zC9tAf8T8nXdD2mv9Iabdmmu/89Y/b6tdaV034zuCa7zpfdgpc9Y65
4r63Z816d+nSoddfH3Jdxfo2SRQ5zENy1ZVvRX3pjUdvWhbcErH54I3cKFt8
K2rfctob3f2XzPSmsXWugYCA9UmGomIkOFuCXra+24v65hK2h101tsSr+5x0
Qdtr/iOl3RoiI+dLZGf7l7/s6ngEhXl4rrryragvvfHo+vL02RMKbonSfBA/
5YrWMxMmFtwSVFF7y2nxWSBqdI/wDzrfZCgqRsgW6IWcL0KEbA8J80bjn0Ny
1ZVvRX3pjUf3NyxdWnBLpObD0qXuyI2ypZgyu4joBhCNKjm/89lDT2x8Ka6d
KUKR2R4S5pcZ/xGSq67EK+pLbzx607LglqjNB2/kRtlS1EYAsVIl5+VZouLa
mag8E04KZntImH/LeCQvqxfcmRehrsQr6ksACEbO+7Br+I99rNhsDwvz+XcR
zgCqj5wfJ+P9s5816+qKzvYJjxDmAJKJnB/laNEUne35s90AIFHSnvN+LRqy
HYBOUp3z+cfdO8v4vGz/wINkOwB1pTTnZRk/fXpQi+ZS43XfQ60BQDlpzHlH
GR8yJZKxVAB6SFfO+5XxtGgA6E2VnD/wyrHVqzJl7YFjRo3zMFVaNAD0pkrO
dx88vnLF3rL2wLHK7u8ZP6JFAyAlFMj5XC47Z8ODH3mq9cPr3OcOjnwLVrtm
5OgnO95FSU8ZDyANkp7zfX3Z826zw9la7Nc+EXDkW/Bt18jlfCnjAWgv6Tnf
7F6YffxEwJFvIbBdQ8IDSIGk53xDg3sJ9KJuJ5czzznHp13DjBoAqZH0nG9q
cq+1bp8IuKCxjo3rE8H7F19cyp4AgJqSnvPZrHuae/Rmy1jH5kvGP9CuAZBa
Sc95c/yUQ++dXVdcRDc0ODs2M4we6xMB7RoAKaNAzo8obv68nEg5ZYp7DDd6
zwcAdKFKzvf3Dy5ZvCPStzqWr2GCDQCokvO53MlFC7dF+tbmZibYAIBNw5xv
aPA5HgoA0kq3nM/lfKbc05YHkGJa5fxYZ/5h43GWrwEASaucz+/MW4vhfOAs
Qh5AymmV83TmAcBDq5xvaqIzDwAu+uR8LmfOmeNeDIemDYDU0yTnHcdGWW15
cV91RS6SAACaUiXnh4dPz5n9VODV3hHYYpepBwBNqZLzwo03bAq8jhFYAAig
Sc4zAgsAAXTIeUZgASCYQjm/YP6WgYFT7q2MwAJAKIVyftHCbbncSfdWRmAB
IJTyOc8ILACEUj7nGYEFgFBq5Hwul52z4Y/O/37HNRvMl1/OuyqbZQQWAEIo
kPN9fdnzbsvrwO/bN3qVPA/sZZe9P3GidV19PSEPAC4K5Hxzs7sDL0davTNt
7PwHAIxRIOe954eSN8VMGwCIQIGcb2pyd+DlSCszbQAgAgVyPps17TQfrelH
mvDMtAGACBTIeaGjw5wyRdzEmbpJ4yOtzLQBgAjUyPkRba37s5nDo1+MzbSx
Vjlgpg0ABFMo55/Y+NLOZw9Z/2KmDQBEplDOd2x+VVysfzHTBgAiUzLnmWkD
AJEpmfPMtAGAyBTK+Z3PHnpi40vWv5hpAwCRKZTz2czhttb91r9yOfPznzcn
TLBmWk6cSMgDQAiFcv7AK8dWr8ow2QYAiqJQzncfPL5yxV4m2wBAUdTI+ZH1
5x/51c3rpj1qTpvGZBsAiE6BnPesP89kGwCIToGc96w/z2QbAIhOgZz3XX9e
XurqCHkACKdAzuevP7/LuG18pg0jsABQiAI571h/3j3ThhFYACikAjnf294o
brUlE+MddXSYkyeLm3DPtGEEFgAKqUw9L6I+1pzv6xM5L4r5a41X8xr1NOcB
oBA1cj7/2ChxmW/sHrz40+XtJACkgho5n78QMYdHAUB01cx5p+JuL38hYg6P
AoDo1KjnRxYi/pbxyCXGf37M6L/f+C6HRwFARJXI+UzLSMne2N4b4x11dJjn
njtazU+YQMgDQEQKzJ8HAJSBnAcAvZHzAKA3ch4A9EbOA4DeyHkA0Bs5DwB6
I+cBQG/kPADojZwHAL2R8wCgN1VynreJlP8GePi13oVaSvnDN9XJT1X2kx1I
Jh5+rXehlmr+8FXfgfTkfG13gP1Xev9T/vBrvgPsf813oDp3pPoviv1Xev9T
/vBrvgPsf813IPodAQBqojo5DwAAAAAAAAAAEk6eSTz/ROJh2/UT8Eh9T7Gu
obA/dG97Y0um6ntUVSEPXzx67Z8AAQ9fPnTdH7xFPlKfZ7lWASgezMhDzLTk
P6Cg7foJeKS97e2Z0au1/g2E/aFHnul653zwwxevf63/8COCHv7Y+/vY9Xrz
q2b0CsDxR5j/eIK266fgI9X7FxDy8DMtLRnd6/nAhz9Wz+r9Phf81x+NOes5
UJtdqyafZ7lmATj+fp3/cIK266fQI9X8mR748OXj1j3ngx6+Xczr/XEu7Mmf
gg9zY3ye5ZoFIPV8+CMd695oK+Dhj5ez+rQo/aT8+R9Wz8tyXuc/vk3/ep7+
fIQObaZd419B+B9a93o+7Pk/skHzX0Chl38qBilS0J833cPKzs8rmtdyNt/f
wOhsG+1btMFPAIvmMWcJf/5r/rcPfPj2BzrdH797Xl0aAxAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAgKQaXSCxpd36r/6LJAJAGllRL3Je8zO7AECq
peQERgCQTvIUD/knOgEAaKJ3tC8v+/QU9QAAAAAAAAAAACjG/wOhva0H
    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->125360763]
}, Open  ]],

Cell["", "Text",
 CellID->152202905],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["2.3 Isolated Panel",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IsolatedPanel"]], "RelatedTutorials",
 CellID->59868671],

Cell[TextData[ButtonBox["3.2 Validation Example",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/ValidationExample"]], "RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"3.1  Introduction to Panel Methods - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 11, 0, 19.9626000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "Panel methods are numerical models for solving potential flow over an \
object, usually with relatively complex geometry such as an aircraft or its \
components. These methods are based on a boundary-integral solution to \
Laplace's equation. Source, vortex or doublet singularities are placed on the \
boundary of the object and suitable boundary conditions are applied. Refer to \
Low-Speed Aerodynamics by Katz and Plotkin (2001) for details. Currently, the \
panel methods in Aerodynamics are restricted to steady two-dimensional flow \
over a discretized airfoil specified by straight-line panels. Three panel \
methods are implemented by defined functions in Aerodynamics. Functions \
implementing two-dimensional panel methods.", "synonyms" -> {}, "title" -> 
    "3.1  Introduction to Panel Methods", "type" -> "Tutorial", "uri" -> 
    "Aerodynamics/tutorial/IntroductionToPanelMethods"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[615, 21, 78, 1, 70, "TutorialColorBar"],
Cell[696, 24, 191, 5, 70, "LinkTrail"],
Cell[890, 31, 3641, 82, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4556, 117, 71, 1, 70, "Title",
 CellID->509267359],
Cell[4630, 120, 592, 12, 70, "Text",
 CellID->1534169418],
Cell[5225, 134, 368, 11, 70, "Text",
 CellID->775308575],
Cell[5596, 147, 915, 25, 70, "DefinitionBox",
 CellID->2096742444],
Cell[6514, 174, 93, 1, 70, "Caption",
 CellID->1891092685],
Cell[CellGroupData[{
Cell[6632, 179, 69, 1, 70, "Section",
 CellID->432056375],
Cell[6704, 182, 225, 5, 70, "Text",
 CellID->250015064],
Cell[CellGroupData[{
Cell[6954, 191, 64, 1, 70, "Subsection",
 CellID->220682699],
Cell[7021, 194, 955, 19, 70, "Text",
 CellID->612564464]
}, Open  ]],
Cell[CellGroupData[{
Cell[8013, 218, 65, 1, 70, "Subsection",
 CellID->64226099],
Cell[8081, 221, 1024, 21, 70, "Text",
 CellID->368099075]
}, Open  ]],
Cell[CellGroupData[{
Cell[9142, 247, 61, 1, 70, "Subsection",
 CellID->178726099],
Cell[9206, 250, 705, 13, 70, "Text",
 CellID->55517967]
}, Open  ]],
Cell[CellGroupData[{
Cell[9948, 268, 57, 1, 70, "Subsection",
 CellID->446287461],
Cell[10008, 271, 811, 14, 70, "Text",
 CellID->107744017]
}, Open  ]],
Cell[CellGroupData[{
Cell[10856, 290, 63, 1, 70, "Subsection",
 CellID->252269107],
Cell[10922, 293, 543, 9, 70, "Text",
 CellID->190335304]
}, Open  ]],
Cell[CellGroupData[{
Cell[11502, 307, 60, 1, 70, "Subsection",
 CellID->95542403],
Cell[11565, 310, 513, 12, 70, "Text",
 CellID->340388638]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12127, 328, 53, 1, 70, "Section",
 CellID->275406678],
Cell[12183, 331, 401, 9, 70, "Text",
 CellID->137812698],
Cell[12587, 342, 125, 6, 70, "Text",
 CellID->836781195],
Cell[12715, 350, 101, 3, 70, "Input",
 CellID->2058623809],
Cell[12819, 355, 134, 4, 70, "Text",
 CellID->48545141],
Cell[12956, 361, 308, 9, 70, "Input",
 CellID->43842758],
Cell[13267, 372, 935, 28, 70, "Text",
 CellID->114570266],
Cell[14205, 402, 338, 10, 70, "Input",
 CellID->112440851],
Cell[14546, 414, 365, 11, 70, "Text",
 CellID->253458896],
Cell[CellGroupData[{
Cell[14936, 429, 447, 14, 70, "Input",
 CellID->59487574],
Cell[15386, 445, 507, 16, 39, "Output",
 CellID->197238257]
}, Open  ]],
Cell[15908, 464, 166, 4, 70, "Text",
 CellID->486625314],
Cell[16077, 470, 338, 12, 70, "Input",
 CellID->225120950],
Cell[16418, 484, 308, 6, 70, "Text",
 CellID->59805657],
Cell[16729, 492, 793, 23, 70, "Input",
 CellID->117496578],
Cell[17525, 517, 435, 10, 70, "Text",
 CellID->474191],
Cell[CellGroupData[{
Cell[17985, 531, 1262, 38, 70, "Input",
 CellID->499718542],
Cell[19250, 571, 506, 16, 36, "Output",
 CellID->720036085]
}, Open  ]],
Cell[19771, 590, 134, 4, 70, "Text",
 CellID->21296710],
Cell[19908, 596, 455, 16, 70, "Input",
 CellID->36210806],
Cell[20366, 614, 455, 8, 70, "Text",
 CellID->281832136],
Cell[CellGroupData[{
Cell[20846, 626, 1527, 44, 19, "Input",
 CellOpen->False,
 CellID->80931720],
Cell[22376, 672, 12627, 214, 351, "Output",
 CellID->125360763]
}, Open  ]],
Cell[35018, 889, 36, 1, 70, "Text",
 CellID->152202905],
Cell[CellGroupData[{
Cell[35079, 894, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[35147, 897, 158, 3, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[35342, 905, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[35417, 908, 168, 4, 70, "RelatedTutorials",
 CellID->59868671],
Cell[35588, 914, 177, 4, 70, "RelatedTutorials",
 CellID->806871991],
Cell[35768, 920, 170, 4, 70, "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[35977, 929, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

