(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     36210,        988]
NotebookOptionsPosition[     31108,        832]
NotebookOutlinePosition[     33249,        880]
CellTagsIndexPosition[     33206,        877]
WindowTitle->1.5 Panel Geometry - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"1.4 Airfoils From Conformal Mapping\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"], "\<\"2.1 \
Introduction To Influence Coefficients\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"], "\
\<\"Table Of Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Airfoil Geometry\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/guide/AirfoilGeometry"], "\<\"Aerodynamics\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/Aerodynamics"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Functions \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelAngles\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PanelAngles"], "\<\"PanelLengths\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PanelLengths"], "\<\"PanelNormals\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PanelNormals"], "\<\"PanelPoints\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/PanelPoints"], "\<\"ThickAirfoilQ\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/ref/ThickAirfoilQ"], "\<\"TrailingEdgeAngle\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/ref/TrailingEdgeAngle"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Aerodynamics/tutorial/PanelGeometry\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/PanelGeometry"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/PanelGeometry.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/PanelGeometry", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["1.5 Panel Geometry", "Title",
 CellID->509267359],

Cell["\<\
Different sources of information about airfoil geometry require different \
procedures for determining a collection of vectors locating points on the \
surface of the airfoil that serve as panel endpoints.  Once the panel \
endpoints are established, however, computing geometric properties of the \
discretized airfoil is based on this collection of vectors.   The purpose of \
most of these functions should be clear from the short descriptions given \
below.  The function PanelPoints is used to locate collocation points on the \
panels where boundary conditions are applied for numerical models.\
\>", "Text",
 CellID->1534169418],

Cell[BoxData[GridBox[{
   {
    ButtonBox["PanelAngles",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PanelAngles"], Cell[
    "angles that panels make with x axis", "TableText"]},
   {
    ButtonBox["PanelLengths",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PanelLengths"], Cell[
    "list of panel lengths", "TableText"]},
   {
    ButtonBox["PanelNormals",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PanelNormals"], Cell[
    "outward unit normals to panels", "TableText"]},
   {
    ButtonBox["PanelPoints",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/PanelPoints"], Cell[
    "points on panels", "TableText"]},
   {
    ButtonBox["TrailingEdgeAngle",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/TrailingEdgeAngle"], Cell[
    "included angle between trailing edge panels", "TableText"]},
   {
    ButtonBox["ThickAirfoilQ",
     BaseStyle->"Link",
     ButtonData->"paclet:Aerodynamics/ref/ThickAirfoilQ"], Cell[
    "does the airfoil have thickness", "TableText"]}
  }]], "DefinitionBox",
 CellID->306953523],

Cell["Functions to compute panel geometry from panel endpoints.", "Caption",
 CellID->711473682],

Cell["\<\
The family of NACA four-digit airfoils is chosen as the example for this \
section because airfoils with and without thickness can be generated simply \
by changing the identification number.\
\>", "Text",
 CellID->157402686],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->38213042],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->318373978],

Cell[CellGroupData[{

Cell["1.5.1 Airfoil With Thickness", "Section",
 CellID->282162397],

Cell[TextData[{
 "Once panel endpoints specifying a discretized airfoil have been \
established, additional geometric quantities for the discretized airfoil can \
be computed.  Unit normal vectors to panels are displayed graphically and \
numbered to illustrate the clockwise numbering convention used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  Additionally, panel angles, panel lengths and trailing-edge angle are \
computed."
}], "Text",
 CellID->311381061],

Cell["\<\
Specify the identification number for an airfoil and discretization \
parameters.  Compute the collection of vectors locating panel endpoints, and \
prepare a graphic showing the discretized airfoil.\
\>", "Text",
 CellID->160892231],

Cell[BoxData[{
 RowBox[{
  RowBox[{"id", "=", "4415"}], ";", 
  RowBox[{"n", "=", "5"}], ";", 
  RowBox[{"layout", "=", "HalfCosineSpacing"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"NACA4DigitAirfoil", "[", 
     RowBox[{"id", ",", 
      RowBox[{"NDiscretizeUnitSegment", "[", 
       RowBox[{"n", ",", 
        RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gPanels", "=", 
   RowBox[{"PlotAirfoil", "[", "rP", "]"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->32270844],

Cell[TextData[{
 "Compute outward unit normals to panels and show them on a plot of the \
discretized airfoil with tails at midpanel, which is the default value for \
the option PanelOffset in the function PanelPoints.  Label the normal vectors \
with panel number",
 StyleBox[".",
  FontSlant->"Italic"]
}], "Text",
 CellID->769934012],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uN", "=", 
   RowBox[{"PanelNormals", "[", "rP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rC", "=", 
   RowBox[{"PanelPoints", "[", "rP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gNormals", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Arrow", "[", 
     RowBox[{"rC", ",", 
      RowBox[{"rC", "+", 
       RowBox[{"0.15", "uN"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gPanels", ",", "gNormals", ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"rC", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", 
          RowBox[{"0.17", " ", 
           RowBox[{"uN", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"NumberOfVectors", "[", "rC", "]"}]}], "}"}]}], "]"}], 
     "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.25"}], ",", "1.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.25"}], ",", "0.3"}], "}"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->66680097],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    LineBox[{{0.9997918421408566, -0.0015611839435751304`}, {
     0.6879573940418148, -0.016198441614263596`}, {
     0.41201947304449976`, -0.03195715360845929}, {
     0.19836607364310915`, -0.04156765018480128}, {
     0.05655570289022391, -0.03417765488167223}, {0., 0.}, {
     0.04133126451946903, 0.052557316065027525`}, {0.18359993760699594`, 
     0.09972359821603287}, {0.4124100223705542, 0.11192399803922404`}, {
     0.6940086172082903, 0.07738263948924372}, {1.0002081578591433`, 
     0.0015611839435751551`}}]}, {
    ArrowBox[{{0.8438746180913357, -0.008879812778919364}, {
     0.850907753450712, -0.1587148387475382}}], 
    ArrowBox[{{0.5499884335431573, -0.024077797611361446`}, {
     0.558540942038854, -0.17383378112598113`}}], 
    ArrowBox[{{0.30519277334380446`, -0.036762401896630284`}, {
     0.31193321506669125`, -0.1866108801851346}}], 
    ArrowBox[{{0.12746088826666652`, -0.03787265253323675}, {
     0.11965470875219478`, -0.18766939335688698`}}], 
    ArrowBox[{{
     0.028277851445111954`, -0.017088827440836115`}, {-0.04930376944253391, \
-0.14546753323134326`}}], 
    ArrowBox[{{0.020665632259734515`, 
     0.026278658032513762`}, {-0.09724262155768046, 0.11900213770043848`}}], 
    ArrowBox[{{0.11246560106323249`, 0.0761404571405302}, {
     0.06526262638099037, 0.21851980670059667`}}], 
    ArrowBox[{{0.29800497998877507`, 0.10582379812762846`}, {
     0.2900181643989505, 0.25561101646328666`}}], 
    ArrowBox[{{0.5532093197894222, 0.09465331876423388}, {0.5714716988182416, 
     0.24353745328570578`}}], 
    ArrowBox[{{0.8471083875337169, 0.03947191171640944}, {0.8831626359547899, 
     0.18507442258346674`}}]}},
  Epilog->{{
     InsetBox[
      FormBox["1", TraditionalForm], {
      0.8518455048319622, -0.1786928422100207}], 
     InsetBox[
      FormBox["2", TraditionalForm], {
      0.5596812765049468, -0.1938012455945971}], 
     InsetBox[
      FormBox["3", TraditionalForm], {
      0.31283194062974284`, -0.2065906772902686}], 
     InsetBox[
      FormBox["4", TraditionalForm], {
      0.11861388481693187`, -0.2076422921333737}], 
     InsetBox[
      FormBox[
      "5", TraditionalForm], {-0.0596479855608867, -0.16258469400341088`}], 
     InsetBox[
      FormBox["6", TraditionalForm], {-0.11296372206666914`, 
      0.13136526832282844`}], 
     InsetBox[
      FormBox["7", TraditionalForm], {0.05896889642335807, 
      0.23750371997527223`}], 
     InsetBox[
      FormBox["8", TraditionalForm], {0.2889532556536406, 
      0.27558264557470774`}], 
     InsetBox[
      FormBox["9", TraditionalForm], {0.5739066826887508, 0.263388671221902}], 
     InsetBox[
      FormBox["10", TraditionalForm], {0.8879698690775997, 
      0.20448809069907442`}]}},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->{{{-1.2, 
      FormBox[
       RowBox[{"-", "1.2`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.7999999999999999, 
      FormBox[
       RowBox[{"-", "0.7999999999999999`"}], 
       TraditionalForm]}, {-0.5999999999999999, 
      FormBox[
       RowBox[{"-", "0.5999999999999999`"}], 
       TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {1.0000000000000002`, 
      FormBox["1.0000000000000002`", TraditionalForm]}, {1.2000000000000004`, 
      FormBox["1.2000000000000004`", TraditionalForm]}, {1.4000000000000001`, 
      FormBox["1.4000000000000001`", TraditionalForm]}, {1.6, 
      FormBox["1.6`", TraditionalForm]}}, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}, None, {{-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.9, 
      FormBox[
       RowBox[{"-", "0.9`"}], TraditionalForm]}, {-0.8, 
      FormBox[
       RowBox[{"-", "0.8`"}], TraditionalForm]}, {-0.7, 
      FormBox[
       RowBox[{"-", "0.7`"}], TraditionalForm]}, {-0.6, 
      FormBox[
       RowBox[{"-", "0.6`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {-0.3999999999999999, 
      FormBox[
       RowBox[{"-", "0.3999999999999999`"}], 
       TraditionalForm]}, {-0.29999999999999993`, 
      FormBox[
       RowBox[{"-", "0.29999999999999993`"}], 
       TraditionalForm]}, {-0.19999999999999996`, 
      FormBox[
       RowBox[{"-", "0.19999999999999996`"}], 
       TraditionalForm]}, {-0.09999999999999998, 
      FormBox[
       RowBox[{"-", "0.09999999999999998`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.10000000000000009`, 
      FormBox["0.10000000000000009`", TraditionalForm]}, {
     0.20000000000000018`, 
      FormBox["0.20000000000000018`", TraditionalForm]}, {
     0.30000000000000004`, 
      FormBox["0.30000000000000004`", TraditionalForm]}, {
     0.40000000000000013`, 
      FormBox["0.40000000000000013`", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {0.6000000000000001, 
      FormBox["0.6000000000000001`", TraditionalForm]}, {0.7000000000000002, 
      FormBox["0.7000000000000002`", TraditionalForm]}, {0.8, 
      FormBox["0.8`", TraditionalForm]}, {0.9000000000000001, 
      FormBox["0.9000000000000001`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}}},
  ImageSize->{504., 180.},
  PlotRange->{{-0.25, 1.2}, {-0.25, 0.3}},
  PlotRangeClipping->True,
  RotateLabel->False]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->620993]
}, Open  ]],

Cell[TextData[{
 "Compute the list of angles that the panels make with the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis."
}], "Text",
 CellID->182365288],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PanelAngles", "[", "rP", "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->594385488],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.0946878875587047`"}], ",", 
   RowBox[{"-", "3.084544992329381`"}], ",", 
   RowBox[{"-", "3.096641238605829`"}], ",", "3.089527937743146`", ",", 
   "2.598003868947146`", ",", "0.9044010084478203`", ",", 
   "0.3201263540894222`", ",", "0.05327062856620143`", ",", 
   RowBox[{"-", "0.12205199635460329`"}], ",", 
   RowBox[{"-", "0.24273841274686234`"}]}], "}"}]], "Output",
 ImageSize->{366, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->435067307]
}, Open  ]],

Cell["Compute the list of panel lengths.", "Text",
 CellID->61777939],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PanelLengths", "[", "rP", "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->497996672],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.31217778962211923`", ",", "0.2763875417742928`", ",", 
   "0.21386943849043513`", ",", "0.1420027932248202`", ",", 
   "0.06608070537318722`", ",", "0.06686213351918648`", ",", 
   "0.14988339972803474`", ",", "0.22913512311593007`", ",", 
   "0.2837091363792604`", ",", "0.31544738359329777`"}], "}"}]], "Output",
 ImageSize->{424, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->200030463]
}, Open  ]],

Cell["Compute the trailing-edge angle in degrees.", "Text",
 CellID->368516261],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TrailingEdgeAngle", "[", "rP", "]"}], "/", "Degree"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->14075685],

Cell[BoxData["16.595331708729734`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->612027810]
}, Open  ]],

Cell["\<\
It can be useful to have a test for whether an airfoil has thickness.\
\>", "Text",
 CellID->814060285],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThickAirfoilQ", "[", "rP", "]"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->257551952],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[20]=",
 CellID->143998578]
}, Open  ]],

Cell["\<\
Note that the number of panels for an airfoil with thickness is twice the \
discretization number used as input.\
\>", "Text",
 CellID->212162634]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5.2 Airfoil Without Thickness (Camber Line)", "Section",
 CellID->848281288],

Cell[TextData[{
 "Sometimes, it is useful to work with the camber line, which can be \
considered a reference airfoil without thickness.  Such an airfoil can be \
constructed by setting the last two digits of the identification number for a \
NACA four-digit airfoil to zero.  The fore-to-aft numbering convention is \
used in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " for the special case of reference airfoils without thickness.  The graphic \
below shows unit normals to panels and labels the vectors with panel numbers \
to illustrate this.  Note that for airfoils without thickness, the number of \
panels is equal to the discretization number."
}], "Text",
 CellID->148980166],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rPCamberLine", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"NACA4DigitAirfoil", "[", 
     RowBox[{"4400", ",", 
      RowBox[{"NDiscretizeUnitSegment", "[", 
       RowBox[{"n", ",", 
        RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gPanelsCamberLine", "=", 
   RowBox[{"PlotAirfoil", "[", "rPCamberLine", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uNCamberLine", "=", 
   RowBox[{"PanelNormals", "[", "rPCamberLine", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rCCamberLine", "=", 
   RowBox[{"PanelPoints", "[", "rPCamberLine", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gUNCamberLine", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Arrow", "[", 
     RowBox[{"rCCamberLine", ",", 
      RowBox[{"rCCamberLine", "+", 
       RowBox[{"0.15", "uNCamberLine"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gPanelsCamberLine", ",", "gUNCamberLine", ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"rCCamberLine", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", 
          RowBox[{"0.17", " ", 
           RowBox[{"uNCamberLine", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"NumberOfVectors", "[", "rCCamberLine", "]"}]}], "}"}]}], 
      "]"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.25"}], ",", "1.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.25"}], ",", "0.3"}], "}"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellLabel->"In[12]:=",
 CellID->10976936],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U+IpEcZx/ERLwMhMqewpzDe5rinJayIAyI7wUPWSMioyA4RJiOKWcTo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    "], {{0, 180}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 180},
  PlotRange->{{0, 504}, {0, 180}}]], "Output",
 ImageSize->{508, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->161139875]
}, Open  ]],

Cell["Test the airfoil for thickness.", "Text",
 CellID->112816300],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThickAirfoilQ", "[", "rPCamberLine", "]"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->61466950],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->51801432]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["Airfoil Geometry",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/guide/AirfoilGeometry"]], "TutorialMoreAbout",
 CellID->8867598],

Cell[TextData[ButtonBox["Aerodynamics",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["1.4 Airfoils From Conformal Mapping",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/AirfoilsFromConformalMapping"]], \
"RelatedTutorials",
 CellID->58607457],

Cell[TextData[ButtonBox["2.1 Introduction To Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"]], \
"RelatedTutorials",
 CellID->76715951],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->172539578]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"1.5 Panel Geometry - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 11, 0, 33.3942000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "Different sources of information about airfoil geometry require \
different procedures for determining a collection of vectors locating points \
on the surface of the airfoil that serve as panel endpoints. Once the panel \
endpoints are established, however, computing geometric properties of the \
discretized airfoil is based on this collection of vectors. The purpose of \
most of these functions should be clear from the short descriptions given \
below. The function PanelPoints is used to locate collocation points on the \
panels where boundary conditions are applied for numerical models. Functions \
to compute panel geometry from panel endpoints. The family of NACA four-digit \
airfoils is chosen as the example for this section because airfoils with and \
without thickness can be generated simply by changing the identification \
number.", "synonyms" -> {}, "title" -> "1.5 Panel Geometry", "type" -> 
    "Tutorial", "uri" -> "Aerodynamics/tutorial/PanelGeometry"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[599, 21, 78, 1, 70, "TutorialColorBar"],
Cell[680, 24, 191, 5, 70, "LinkTrail"],
Cell[874, 31, 3993, 86, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4892, 121, 55, 1, 70, "Title",
 CellID->509267359],
Cell[4950, 124, 645, 10, 70, "Text",
 CellID->1534169418],
Cell[5598, 136, 1125, 32, 70, "DefinitionBox",
 CellID->306953523],
Cell[6726, 170, 96, 1, 70, "Caption",
 CellID->711473682],
Cell[6825, 173, 235, 5, 70, "Text",
 CellID->157402686],
Cell[7063, 180, 124, 6, 70, "Text",
 CellID->38213042],
Cell[7190, 188, 100, 3, 70, "Input",
 CellID->318373978],
Cell[CellGroupData[{
Cell[7315, 195, 67, 1, 70, "Section",
 CellID->282162397],
Cell[7385, 198, 477, 10, 70, "Text",
 CellID->311381061],
Cell[7865, 210, 243, 5, 70, "Text",
 CellID->160892231],
Cell[8111, 217, 635, 18, 70, "Input",
 CellID->32270844],
Cell[8749, 237, 336, 8, 70, "Text",
 CellID->769934012],
Cell[CellGroupData[{
Cell[9110, 249, 1370, 44, 70, "Input",
 CellID->66680097],
Cell[10483, 295, 7645, 175, 201, "Output",
 CellID->620993]
}, Open  ]],
Cell[18143, 473, 176, 6, 70, "Text",
 CellID->182365288],
Cell[CellGroupData[{
Cell[18344, 483, 108, 3, 70, "Input",
 CellID->594385488],
Cell[18455, 488, 566, 14, 54, "Output",
 CellID->435067307]
}, Open  ]],
Cell[19036, 505, 69, 1, 70, "Text",
 CellID->61777939],
Cell[CellGroupData[{
Cell[19130, 510, 109, 3, 70, "Input",
 CellID->497996672],
Cell[19242, 515, 490, 12, 54, "Output",
 CellID->200030463]
}, Open  ]],
Cell[19747, 530, 79, 1, 70, "Text",
 CellID->368516261],
Cell[CellGroupData[{
Cell[19851, 535, 142, 4, 70, "Input",
 CellID->14075685],
Cell[19996, 541, 177, 5, 36, "Output",
 CellID->612027810]
}, Open  ]],
Cell[20188, 549, 113, 3, 70, "Text",
 CellID->814060285],
Cell[CellGroupData[{
Cell[20326, 556, 111, 3, 70, "Input",
 CellID->257551952],
Cell[20440, 561, 162, 5, 36, "Output",
 CellID->143998578]
}, Open  ]],
Cell[20617, 569, 156, 4, 70, "Text",
 CellID->212162634]
}, Open  ]],
Cell[CellGroupData[{
Cell[20810, 578, 84, 1, 70, "Section",
 CellID->848281288],
Cell[20897, 581, 696, 13, 70, "Text",
 CellID->148980166],
Cell[CellGroupData[{
Cell[21618, 598, 1966, 59, 173, "Input",
 CellID->10976936],
Cell[23587, 659, 5926, 105, 201, "Output",
 CellID->161139875]
}, Open  ]],
Cell[29528, 767, 67, 1, 70, "Text",
 CellID->112816300],
Cell[CellGroupData[{
Cell[29620, 772, 120, 3, 70, "Input",
 CellID->61466950],
Cell[29743, 777, 162, 5, 36, "Output",
 CellID->51801432]
}, Open  ]],
Cell[CellGroupData[{
Cell[29942, 787, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[30010, 790, 165, 4, 70, "TutorialMoreAbout",
 CellID->8867598],
Cell[30178, 796, 158, 3, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[30373, 804, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[30448, 807, 202, 5, 70, "RelatedTutorials",
 CellID->58607457],
Cell[30653, 814, 216, 5, 70, "RelatedTutorials",
 CellID->76715951],
Cell[30872, 821, 170, 4, 70, "RelatedTutorials",
 CellID->172539578]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[31081, 830, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

