(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    295862,       6341]
NotebookOptionsPosition[    284675,       5961]
NotebookOutlinePosition[    287105,       6013]
CellTagsIndexPosition[    287062,       6010]
WindowTitle->2.2 Point Singularities - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"2.1 Introduction to Influence Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"], "\
\<\"2.3 Isolated Panel\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IsolatedPanel"], "\<\"Table of \
Contents\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Influence Coefficients\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/guide/InfluenceCoefficients"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/PointSingularities\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/PointSingularities"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/PointSingularities.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/PointSingularities", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["2.2 Point Singularities", "Title",
 CellID->509267359],

Cell[TextData[{
 "Although the primary purpose of ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " is to support the development of two-dimensional panels methods for \
uniform flow over airfoils, the package includes influence coefficients for \
point singularities as well.  Two simple flows that are treated in most \
undergraduate textbooks on aerodynamics are discussed in this section: \
uniform flow over a circular cylinder, and a flat plate at an angle of attack."
}], "Text",
 CellID->739302563],

Cell[TextData[{
 "The capability of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to handle algebraic and numerical computation in a seamless manner is \
utilized in these examples.  ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " is designed to handle large collections of vectors used in computing the \
flow over airfoils, so using these tools for simple problems actually causes \
some minor inconveniences.  A data type, CartesianVectors is defined to \
facilitate the manipulation of collections of vectors.  The constructor and \
selector for this data type are ",
 ButtonBox["MakeCartesianVectors",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/MakeCartesianVectors"],
 " and ",
 ButtonBox["Components",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/Components"],
 ".  Although explicit use of the data type is hidden in normal use, it is \
currently necessary to use the constructor and selector for simple problems."
}], "Text",
 CellID->370043398],

Cell[TextData[{
 "Load the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " packages."
}], "Text",
 CellID->819798417],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->5378332],

Cell[CellGroupData[{

Cell["\<\
2.2.1  Uniform Flow Over a Circular Cylinder Without Circulation\
\>", "Section",
 CellID->100587181],

Cell[TextData[{
 "Two-dimensional potential flow over a circular cylinder can be described \
using the superposition of uniform flow and a two-dimensional point doublet.  \
The characteristic length is chosen as the radius of the circle and the \
characteristic speed is that of the uniform flow, which is chosen to be in \
the positive ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-direction.  The following discussion applies to the dimensionless problem."
}], "Text",
 CellID->1534169418],

Cell[CellGroupData[{

Cell["Point doublet", "Subsection",
 CellID->215672006],

Cell[TextData[{
 "Compute the velocity at an arbitrary field point, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 " due to a point doublet at the origin with the doublet oriented along the \
negative ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-direction.  The velocity at ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 " can be written as the product of a geometric influence coefficient and the \
strength of the doublet, ",
 Cell[BoxData[
  StyleBox["\[Mu]", "TR"]], "InlineFormula"],
 ".  Note in the following results that an infix arrow is used to denote the \
data type CartesianVectors."
}], "Text",
 CellID->629377630],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rOrigin", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "0", "}"}], ",", 
     RowBox[{"{", "0", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->490239154],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "0", "}"}], "\[UpArrow]", 
   RowBox[{"{", "0", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0}, {0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->5880638]
}, Open  ]],

Cell[TextData[{
 "Orient of the doublet along the negative ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " axis."
}], "Text",
 CellID->141085961],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uv", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}], ",", 
     RowBox[{"{", "0", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->320702810],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"-", "1"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", "0", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{-1}, {0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{63, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->461790718]
}, Open  ]],

Cell[TextData[{
 "Specify an arbitrary field point ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 " as a collection of one vector of the data type CartesianVectors."
}], "Text",
 CellID->516541598],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rField", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "x", "}"}], ",", 
     RowBox[{"{", "z", "}"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->96784033],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "x", "}"}], "\[UpArrow]", 
   RowBox[{"{", "z", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{$CellContext`x}, \
{$CellContext`z}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->9322882]
}, Open  ]],

Cell[TextData[{
 "Compute the geometric velocity influence coefficient using the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 ButtonBox["ICDoubletPoint",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/ICDoubletPoint"],
 ", and multiply it by the strength of the doublet ",
 Cell[BoxData[
  StyleBox["\[Mu]", "TR"]], "InlineFormula"],
 " to obtain the velocity, ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["d", "TI"]]], "InlineFormula"],
 ", induced by the doublet at the field point."
}], "Text",
 CellID->836781195],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vD", "=", 
  RowBox[{"\[Mu]", " ", 
   RowBox[{"ICDoubletPoint", "[", 
    RowBox[{"rField", ",", "rOrigin", ",", "uv"}], "]"}]}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->497839038],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["x", "2"]}], "+", 
          SuperscriptBox["z", "2"]}], ")"}], " ", "\[Mu]"}], 
       RowBox[{"2", " ", "\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], "2"]}]]}], "}"}], "}"}], 
   "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"{", 
     FractionBox[
      RowBox[{"x", " ", "z", " ", "\[Mu]"}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], "2"]}]], "}"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{{
     Rational[-1, 2] 
      Pi^(-1) (-$CellContext`x^2 + $CellContext`z^2) ($CellContext`x^2 + \
$CellContext`z^2)^(-2) $CellContext`\[Mu]}}, {{
     Pi^(-1) $CellContext`x $CellContext`z ($CellContext`x^2 + \
$CellContext`z^2)^(-2) $CellContext`\[Mu]}}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{234, 42},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->249638242]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["d", "TI"]]], "InlineFormula"],
 " is a collection of one vector of the data type CartesianVectors."
}], "Text",
 CellID->126311503],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"NumberOfVectors", "[", "vD", "]"}], ",", 
   RowBox[{"Head", "[", "vD", "]"}]}], "}"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->222401865],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "CartesianVectors"}], "}"}]], "Output",
 ImageSize->{148, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->101916841]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Superposition with uniform flow", "Subsection",
 CellID->89762736],

Cell[TextData[{
 "Use the ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " function ",
 ButtonBox["UniformFlow",
  BaseStyle->"Link",
  ButtonData->"paclet:Aerodynamics/ref/UniformFlow"],
 " to write the uniform velocity in the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-direction at ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["r", "TI"], 
   StyleBox["f", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->438888709],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v\[Infinity]", "=", 
  RowBox[{"UniformFlow", "[", 
   RowBox[{"1", ",", "0"}], "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->264747966],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "1", "}"}], "\[UpArrow]", 
   RowBox[{"{", "0", "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{1}, {0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{55, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->522069498]
}, Open  ]],

Cell["Superimpose uniform flow and doublet flow.", "Text",
 CellID->636578530],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v", "=", 
  RowBox[{"v\[Infinity]", "+", "vD"}]}]], "Input",
 CellLabel->"In[7]:=",
 CellID->748303819],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["x", "2"]}], "+", 
          SuperscriptBox["z", "2"]}], ")"}], " ", "\[Mu]"}], 
       RowBox[{"2", " ", "\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], "2"]}]]}], "}"}], "}"}], 
   "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"{", 
     FractionBox[
      RowBox[{"x", " ", "z", " ", "\[Mu]"}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], "2"]}]], "}"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{{
     1 + Rational[-1, 2] 
       Pi^(-1) (-$CellContext`x^2 + $CellContext`z^2) ($CellContext`x^2 + \
$CellContext`z^2)^(-2) $CellContext`\[Mu]}}, {{
     Pi^(-1) $CellContext`x $CellContext`z ($CellContext`x^2 + \
$CellContext`z^2)^(-2) $CellContext`\[Mu]}}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{246, 42},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->18798916]
}, Open  ]],

Cell["\<\
Take the components of the vector and flatten the result to suppress the \
extra brackets.\
\>", "Text",
 CellID->373058785],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"u", ",", "w"}], "}"}], "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Components", "[", "v", "]"}], "]"}]}]], "Input",
 CellLabel->"In[8]:=",
 CellID->400889610],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "+", 
        SuperscriptBox["z", "2"]}], ")"}], " ", "\[Mu]"}], 
     RowBox[{"2", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}], "2"]}]]}], ",", 
   FractionBox[
    RowBox[{"x", " ", "z", " ", "\[Mu]"}], 
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], "2"]}]]}], "}"}]], "Output",
 ImageSize->{206, 42},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->169256835]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary condition", "Subsection",
 CellID->440858664],

Cell[TextData[{
 "Determine the value of the doublet strength by applying the tangent-flow \
boundary condition at some point on the cylinder.  Choose the point ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     StyleBox["x", "TI"], ",", " ", 
     StyleBox["z", "TI"]}], ")"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", " ", "0"}], ")"}]}]], "InlineFormula"],
 "."
}], "Text",
 CellID->280989992],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"{", "soln", "}"}], "}"}], "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"u", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z", "\[Rule]", "0"}], ",", 
         RowBox[{"x", "->", "1"}]}], "}"}]}], ")"}], "\[Equal]", "0"}], ",", 
    "\[Mu]"}], "]"}]}]], "Input",
 CellLabel->"In[9]:=",
 CellID->23226259],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Mu]", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "\[Pi]"}]}], "}"}], "}"}]], "Output",
 ImageSize->{81, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->72728038]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  StyleBox["w", "TI"]], "InlineFormula"],
 " is zero everywhere on the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis, so the point ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     StyleBox["x", "TI"], ",", " ", 
     StyleBox["z", "TI"]}], ")"}], " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", " ", "0"}], ")"}]}]], "InlineFormula"],
 " is a stagnation point of the flow."
}], "Text",
 CellID->61000964],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", "/.", 
  RowBox[{"z", "\[Rule]", "0"}]}]], "Input",
 CellLabel->"In[10]:=",
 CellID->559540791],

Cell[BoxData["0"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->499496773]
}, Open  ]],

Cell["\<\
Write the resulting velocity field for steady two-dimensional potential flow \
around a circular cylinder.\
\>", "Text",
 CellID->14002195],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"uC", ",", "wC"}], "}"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "w"}], "}"}], "/.", "soln"}]}]], "Input",
 CellLabel->"In[11]:=",
 CellID->51306124],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["x", "2"]}], "+", 
      SuperscriptBox["z", "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], "2"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "x", " ", "z"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], "2"]]}]}], "}"}]], "Output",
 ImageSize->{184, 41},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->838689689]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for velocity potential and stream function", "Subsection",
 CellID->344238109],

Cell["\<\
In addition to velocity influence coefficients, the package \
InfluenceCoefficients contains functions for velocity-potential and \
stream-function influence coefficients.  Compute velocity potential and \
stream function.\
\>", "Text",
 CellID->125144588],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Phi]C", ",", "\[Psi]C"}], "}"}], "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"UniformFlow\[Phi]", "[", 
        RowBox[{"rField", ",", "0"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"IC\[Phi]DoubletPoint", "[", 
         RowBox[{"rField", ",", "rOrigin", ",", "uv"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"UniformFlow\[Psi]", "[", 
        RowBox[{"rField", ",", "0"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"IC\[Psi]DoubletPoint", "[", 
         RowBox[{"rField", ",", "rOrigin", ",", "uv"}], "]"}]}]}]}], "}"}], 
    "]"}], "/.", "soln"}]}]], "Input",
 CellLabel->"In[12]:=",
 CellID->31426684],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "+", 
    FractionBox["x", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["z", "2"]}]]}], ",", 
   RowBox[{"z", "-", 
    FractionBox["z", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["z", "2"]}]]}]}], "}"}]], "Output",
 ImageSize->{156, 30},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->770633589]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure coefficient", "Subsection",
 CellID->668703906],

Cell["\<\
The pressure coefficient is computed using Bernouilli's equation.\
\>", "Text",
 CellID->335981067],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cp", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"1", "-", 
    RowBox[{"uC", "^", "2"}], "-", 
    RowBox[{"wC", "^", "2"}]}], "]"}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->87854713],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["z", "2"]}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["z", "2"]}], ")"}], "2"]]], "Output",
 ImageSize->{96, 41},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->83259421]
}, Open  ]],

Cell[TextData[{
 "Compute the surface pressure coefficient as a function of angular \
displacement from the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis."
}], "Text",
 CellID->694048433],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cpSurface", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"cp", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"z", "^", "2"}]}], ")"}], "\[Rule]", "1"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[14]:=",
 CellID->23700232],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}]], "Output",
 ImageSize->{94, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->176594109]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flow visualization", "Subsection",
 CellID->22002075],

Cell["\<\
The flow field is visualized below with multiple plots on the same graph.  \
The velocity field is presented as arrows on a grid.  Streamlines and \
equipotential lines are plotted.  Superimposed on this is a color density \
plot of pressure coefficient.  Positive values of pressure coefficient are \
shown in orange and negative values, in blue.  Below the graphic for the flow \
field is a plot of surface pressure coefficient with a thickened line using \
the same color scheme.\
\>", "Text",
 CellID->477749764],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xMin", ",", "xMax", ",", "zMin", ",", "zMax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"colorFunction", "[", "c_", "]"}], ":=", 
   RowBox[{"Hue", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", ".0483667", ",", 
       "0.633338"}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", "c", ",", 
       RowBox[{
        RowBox[{"-", "c"}], "/", "3"}]}], "]"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[GreaterEqual]", "0"}], ",", "1", ",", 
       RowBox[{"1", "+", 
        RowBox[{".1176", "c"}]}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCp", "=", 
   RowBox[{"DensityPlot", "[", 
    RowBox[{"cp", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"colorFunction", "[", "#", "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "z"}], "}"}], ",", 
        RowBox[{"1", "\[LessEqual]", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"z", "^", "2"}]}]}]}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Full", ",", "Full", ",", "Full"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gV", "=", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"uC", ",", "wC"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "z"}], "}"}], ",", 
        RowBox[{"1", "\[LessEqual]", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"z", "^", "2"}]}]}]}], "]"}]}], ",", 
     RowBox[{"VectorStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"VectorPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"20", ",", "20"}], "}"}]}], ",", 
     RowBox[{"VectorScale", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{".5", ",", ".09", ",", "Automatic"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g\[Phi]", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Phi]C", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "20"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"1", "\[LessEqual]", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}]}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g\[Psi]", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{"\[Psi]C", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xMin", ",", "xMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "zMin", ",", "zMax"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "20"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "z"}], "}"}], ",", 
        RowBox[{"1", "\[LessEqual]", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"z", "^", "2"}]}]}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gDisk", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "LightGray", ",", 
      RowBox[{"Disk", "[", "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
  "gCp", ",", " ", "gV", ",", " ", "g\[Phi]", ",", " ", "g\[Psi]", ",", " ", 
   "gDisk", ",", " ", 
   RowBox[{"Frame", " ", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", " ", "\"\<z\>\""}], "}"}]}], ",", " ", 
   RowBox[{"FrameTicks", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "3"}], ",", " ", "3", ",", " ", "0.5"}], "]"}], "]"}], 
      ",", " ", 
      RowBox[{"Chop", "[", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "3"}], ",", " ", "3", ",", " ", "0.5"}], "]"}], "]"}], 
      ",", " ", "None", ",", " ", "None"}], "}"}]}], ",", " ", 
   RowBox[{"ImageSize", " ", "\[Rule]", " ", 
    RowBox[{"7", " ", "72"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Potential Flow Over a Circular Cylinder\>\""}], ",", 
   RowBox[{"RotateLabel", " ", "\[Rule]", " ", "False"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"gCpSurface", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"cpSurface", ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], ",", 
       RowBox[{"colorFunction", "[", "y", "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\[Theta]\>\"", ",", "\"\<\!\(\*SubscriptBox[\(c\), \(p\)]\)\>\""}],
       "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"7", " ", "72"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Surface Pressure Coefficient\>\""}], 
    ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"AbsoluteThickness", "[", "5", "]"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}]}], "Input",
 CellOpen->False,
 CellLabel->"In[15]:=",
 CellID->121377790],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyF3F2spdVZB/AZPMWaIhdcNWKagIiGpBYT76p5j6jA4Fdi7BUhUYJNO5SC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    "], {
     {GrayLevel[0.8], EdgeForm[None], 
      GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxN3XX4bUXVB/Bzzj6HLpFukC7p7haQuHSHhHSIIKWIoISA6FURwUAFBQEJ
RUrpEClRCekSBJQXRBCJd33ufH/P5Y95Zp3Za2ZPrp595t3zkHEHD3q93kmT
93pd5Sv2ez2/P1ZplkqTVapHvZkrTZrf0/caDvyPJx9WmiH5qNKsqTdFpdmS
T1lp3rStjXkqTZffP6z3nl/pTwXPWWnqStNUmjHtTVJp9rQxVSWdXqXwV670
ifTD++fIc/Wnr2cLG1OlmdKGMcwfXG0vnjreuVje4ffq/TbmBSstlPGbj4WT
G98SqTdXpU9WmjtjeqnqrtFvdT9W+QKVL1dpvYLX6bf21qp8zfR9vsyHMSyV
NszTdP3W12UrrdpvY9DW0nmu3iLpizleOb8XrXRH4X+z0tMFb1j5BpWW8d68
QxurBNe4V01uPlZLbnyr1+JuVHVnqLRFzfk6lWYs+FN5nzYOHzR4o0qXVfqB
9ay0RtX9Sj2bxXzU7yUzT4dW2cbGU2nWSivpY6VN0g/v36pwNrUGlX5U8NaV
P1vla6YNY/i0/vVa28sUzrmFc2qlqyt9t9JzVb556hj3EYWzRZVvXmmbgsdV
PlulIwv+R+WzV3ql0rb9NpY5+q3+TpV2zPs2s079Ns/6vV2ljdP3jTMfxrB9
5mibSjtU2vQj9ddIn7btNRz1flXpR5V+nDWZLXtx+jpQN9U83lhpt2pz137r
z15pV7+2rf7vVOVzVZq73965W6Xd837vublwbqq0Rz1fuvKfVv6TSgfXs8+k
vYMq7Znf29X7jim8HQtn/4+0t0faM+5f1vNLKs1bOAd85PmzVXZ8pZ9V+S79
Vne/SocVfGilY/KO7TOGQ+pdu1T6Vz3bvurt78xU2s/+r3SI/vVbG5+zjmlP
vz6f3Pv3q7m6ufDe0X6194uCD6x0Uv0+qtIXKn2l0pH5/W9tVzq64BM+0val
1Yfdq3zvghes/PDKv1jpy3nunV8snM86v85zv9X9kndU+Q71e85Kf6v+TF6/
/5d1PbvSNyudFVzvPDNt+/2L6vOplb5ddX5Sdf9WbVxR6Vv1+7LKP1/pG6n3
5bR1Ysb0UOEcU88Xtz8KPrryxSpdWs/O77Uz+aUq/2rl3670QMFH2cfaTxvm
6Yoq/1WlRa1b5cdVvmSl8Xl+cqUL8m71Du63/p9h7Qv/P/X7k5V+2mt1vOsn
wR2fvpyRcf8gufn4YXLjW6rqf6fyn1V62351nu23Suelja/0G3xJpXvsQ7Qe
jat0rrmstEuVb1RpiSo7odKXKp1T5e9Wvmyl75v7fuuPto4t+HuV/zz748Cc
iSuyfsY9Z84funBiv73nt9aj3+pdU+nK4Br3VcnNx9XJjeva9PHiStclN5ab
8z5t3NRrdMHvMT6K1t/Ya+uK1v467V1Y6fq0YZ5O6re6v690a/rh/Tfkufp4
6exp9zdp46JKtwVX2+9VO1/tt3fek3do447UMd47k5uHu5Ib30r9Jk/g8eQF
PA6vJ0PgoWMyhRxvmzzj8wzPx5/x6VsyH8YwJnNoa5LUg3d7+qtPY7IIvLvT
F3NMLpgjY34pvHj5XuvfPL3Gv8kNcwaPbAGeJv2eN3jaxpfx7hmrQ4eFn60a
fj1jxoTPL5j28NLFM9fo+yK9ifLEQhnPfHnHrHnu2eqRH2ZKn7QxJqcslrbI
FWSdFTLmMZlCX/HJT6Y9PBrPwr9WTPvkkOkiG5BVls3YyC9klgXyjlVSf0xW
8HuzQZMtZoh8sVZvomyy9Efejdetkfn1e8neRDlj1eCtFTwy0dLp/5Kph8dv
XfP8g36jrX/IetqL4yKTzBQZA38dkwvk+O4vBk0OIWuQVTbMPBgP/rtR3r15
6m8evq9Pq5Bt0JBKf6mN9f169pb+RD4h23ynyv9a+ZX9Ni8bp93rI2+QMX5e
/f9apdMGTcYgH2xdOKfU72/1myyCl+KXn828bPKRtvBcvHy78GS8/jP13t9U
/nbGiZdun3HvmN9kmB0zrp0iH+yatnbvNd68Y/Xr69Xub+vZLYMmZ8xjPxW8
fKUFB60tMgK+TVYiI22Vfu2Rtsgme+Xd+r1dnm+femSLLQdNniRDqoNv49+H
hE/j0fjqXuG7dxT+7ZX27bf66PGBae/g/MarD07/yAV49Od6E+UDv/+Er1aa
HW+v/K7IGdfm7M4cWeMLafeyQZMD5uu39+EH5IYdBk0uIZ/cO2jyBRnhoPR9
TK4g5+CVZxXOhf0mCy0UXmlck1X5L/uNbz04aLIR/qWvePsJeR++fGLaPSm/
b0XbK/2r4CdrD3zXHPVbHfxzTL6Qn5k13j9z83D4Pr59aaWLySlVPk2VX17w
U73WR/XOyDyekPZ2HDQZZJHM00GZK/0jD5yd/n0rv9fqmvxAHiBPkAXIH2t2
TcYgn+wcWYXc8mhkGPyaHPHF8Gj9wPPP602UG/xeKnLGt/M+PPfHvYnyBLzd
IwOQYc7O8x/1mlxBHsDzyCXaGZNTfpK2Xqh6v3d2+00GwWfJJWM8+9q0hc9e
3msyBZ5O/iBjkFEuTr/x3EvS70vzW1+uSH3vuzK/x+QGv3+R9+Cp+oq//bo3
UZ6AR7Yhu+DdP8tzz5aJTEKmIavg0X6TVbRzUebosvRJ/67P2C6tfbVrpeX6
rS0yATniyzUnJ/cnyhc39ZqMod8357d+35Lf+nJ76nvnHfk9Jjf4/bdq8+xq
71P99m70/e7eRHnizozz1rR7bZ57tmfVHV/1Nuk3OYWMckPGcU/aMrYbU/7v
2nt3Ft7/ZQ3GcF+s8hcq/bvgJ6rNxyt9Dy2u/LzKT6t0g71aaauCz6n815W/
YR9WvR8X/CPnp+D/1bMf2DuVLqiy7So9VuUHVpqk0s6V/q+e3VjlmxV8TeWn
V/puwd+pdE/B59Xcz104/UqfqbRNlX260req/C+V/7nSToV7bj27vt9ke/sY
zTmv4Iuq7Ov4UwlSP646d6F5ld9e6aBK9xXOHysdVDhTVD5ppVsKHhXesNIH
Bf+k8m9UmrWevVr51JW/V+2/VPk36vmRlfYu+LbKP1dpv4Kv6jd+9mi945FK
Dxa8T5WfhbZVurvSXZXe7LUy9Oa0SssX7uPe32/r+XSVrVvp9Sr/V6Wuyp6r
dFOl/1b5y/02J2wCB1b7f+g3HWmZ6udj0W/vQ6PRksJ5qsqeHDQZ4qeVP1z5
VJX+V23Pn3X6XuXThQ/uWu3MUPA/C16p4OdDx48r/CkLfr7gF+lTg6ZnrlY4
3y946n7bN2wP61eat8qeqd+TV3rPulf6Y8FLVfmMlR4o+P5KZ1R61b4eNPiA
flsDNP4U573qLVlrOWc9f6PfxmsOZxk0W4/9/Jl6/uXq3/v1++VBs6nZn1+p
sp8YY6WPFc50o7ZO36vyl+y5gh8mw1SazXpWfmulC42t8jMK58uVPuy3s0D+
OaTKN6w0vsoXGLQ5NM+frrL5Cn628P4xaHubfHJJlV9c6an6/U7lM2ffvBUa
S2dfpMofs3cqXVntXlHpZ/X8CXuj0qcLnip7lU69bpWtU2mO+j3toPEw+3Ph
KhvaM5X+UW2sWeO9ufK56vffu3bWJ6myUaUfVtkP6/cnCx5U/U5e6dwq/8+g
8Uj77c/OWqV5rGc9W2zQ1u2qgq/URv0+oJ7vX+ljBV9svbrGm1+pfL1q8w+V
71H5boV/SsGTFTzpqMmVe1ZaodLX7ZHKtxq1dSRXdjkPv0JnBs0edg7bWtf2
+F7DJguuMWpnxF57pfB3rN/nFc5ZXePp5A98HF2ZrOC/F7xi4dwQ2fQP1cbv
Kj+z0r0F/7HSNWwzle9c6eSCN618E7+r3tqDJvuvgzdV2S1ds72hjc7WC1W+
WOF9K3aNOwrnhK7tjRkLftRZMKeFM/eo0bUtq3yLSl/qmh5CN6HPXDRoMP1k
/X7TYcjw9BrwwsHRH7qM33QiutVrXaNfUzin/abnaPvng4ZDF7ql3rlspYsK
b+3g0H/2Hza70jT406DxKLLr56xzpeUGrT+zpp2TrE2/6QXr9pteop1rqvw3
g8an6ItrDprMuVnq0kk+P2hzSl/Yst9sDfQQ8jQ5nt2BDIjOk1N+h4cMGn9Z
u/ry20HjEesUfF341OapS/4/tsrWHTTdYaVBezeb55yF/5l+s+OZE32nS+7c
b7j0hY2rfJ9+k4dvLXjPwK/2m05BxryYbDBousNxwQHfNmjts5UtYK8NGvxm
v8nO9ublg1bu9+aDtgbm2TvJ2myA83WtffOyd7/J6+TPO6tsvUHDo9foD92K
jAqHfW/P2l8H1zp+s2syrbNADt/Avh80entVZFK2po2q/P7wx79a40GTew/v
N1mWHPuFwGTCTQr/T4PGBx+pfMNBk2n/UvmfB433wSezklc3rbLj+00ufavf
ZF5y2pVVfma/9WPXQeOxS6ZvS+ddVw+aTE02Xj/w6fowaP2jR5APvYs8OHeN
+59dOwf3VLq+a3z4v/0mI/4ibZJfx2xnYLLrZVV38VHjHacVvFfBv6/6n6r8
4dCjj+MXXTv/Uxf8ZGjflIWzdKUz8N36/XblDEH6ZCzk2WXq+ZlVNsx8LJN5
mKHaubtrcsuPK32znk9iPSq90G92pV/n90qhB+vnDH4s55ztYtXAzvuL/WbT
Yc9hkwHPlXyVwOw2bC7sLX/vN3jB0KG1QovWDIzOrIwXVNplNPHZfL1W37tn
TDtr9Cf6btZM3S2yz9GHdYPDHqW/qwbfWOCge2jZOumP+mwu2ps1Y0cP1xq0
8rV7rb1107566+VcTx9Ye3wx6+a940Kf1k3bG6adzWv+Dxk0fxJbmblnD3NO
N0rf0DZ69Hq9RoM3zBi3DM3EI9C8ddIHOBulfC6yWb/xJH6eTdIOPjNXeJVx
scus1Wv0adO0c21oHnw+HzC56xehbxv0Gi1Vd4te8sAzdY3m+s33iF5u2Wu0
c1xg+BPq95qfSJtoNTv/lmmHwZEeou/Xh+4qp9OMyxg3dma6pue/nHHq8//1
m82Hbo5msQuhYUehJYNmZ1k3ued7DZotCs0/JvlWoY1sYzubn67pKX7TK9iL
duk1Wu1du4ZG7pQ2Z+0ab9gx87dN+jZXcOCzWym/v9f8PjunfPqu2aT8/lT6
z56GV7EH4V13hb7y+6zbNRsT3oBfsDXBfa3f7DhsOHsHRvNfGTRewm81W9f8
Suqu1zW7FL4yV9f8MeDtw6cO7cWH0288wjyzKbGtPT1oupo28QDleMKbg8ar
2JouSzuHhIfsHdiY9Jlv6Oh67ye6pmfp/64pX7BrPgljVpe9CA8a82lpZ/2u
8S02KPaF/dPnDbuml7ErXZ78MDRk0Gw1+BFed2ja3GDQbDlsJA+EXx3fa3z2
sxkfPntwyifMQeaBLMHuRmc8OjCeycZJh3mg1/bs3F173/6DVu580f/YgvCd
K8J3vtZrdik8kM7yUPjhqb1mnzoiML6q7nEFb1Vt7ztotqfdwu+0iZcenXbw
WLxzAt/sGj9mw9olfJX+aHxHZYz47TF5Fz6qHTx9qbSDhz6YPuPjn+4az1YH
z2O3YQsZ8w+x3+DXbFn4I357XPq5e/gWnoV3HR8c/P9LeS8+B74o+QmBz8u7
vIdthF2GXeTY4PBVkQ2ODfxOv+FcFFj5mM+JfYe9BE8/MeXkmsNy7thq2GzY
qf4WWn4vHlHw6oMmD7KRsKGwiZxIHuu33xKYPeWtrtlQTuk3n/tp2SefHDRd
2+/tu+Y/RnvYOM/M3pi/a/qy80JH9xxdWrHgJdPWsYVzTKWDu+b7ZCN4snAW
6tq5ohvz8cofyZhOzrhOGDTfp/f9r9+esU2hwWwS6Ln99Y2sHb6ERqPP7PBn
Z06e7rX5wQdPHTR7kfr40viUXxn4vl6LOyDz4zXPhQ85I9sXX9iu0old26dn
Za9uzKYRWw/frv483mvni19BW2w+2rk/Z9w+/HqvrdW5eddnM+fP95ptCg97
sNf09O9nXb4XWL/M73kpZ4c4L3XxCXYRvGObrtm1/NbeD9PmAYPGe9hJFu6a
vwANZSOEI26H/ez8zPMWXbO3wFm28oUq3VDw0l2zvbCX9UetLTCbk73yWK/5
NLznz71mH/9l9s9w1PYF2xa7GBvPX8z5oOknbOyvVf5qpWv1o2vP2G3OHzQ7
jLpsOWguertH1/wBfrN/ed+x9kzX7FRoLhrMxoMOr1Z1Vx00vW+vrtmjPHsm
5fpEDr8kfb4vdPtRNHPQ7HYXpt1LU355zeE79exP/UYX2bHQxvGDZnPz+6XQ
SPvkDzkbzsW/QnPRSba0y7PHyK3kTjKkfQffc3vW3rXH7emrsl73BH6m4JlG
za6nXTa5q7N/tu2aXcn++GTXbGpgtpUrcxbYFo2LT4H95zdZxx26RhfYg/47
aLa26wqetGs8ns3tX5X/M+WTdc0WZx1fHzQ/Cnixrv1m83y/8vcqPVLwG4MW
12KP7dm1dWVXWr7yD6v8g0oLD5o9D857w2b7079FulafPZYcqo9sI9OidVW+
SKXZuyYf/K7fbMPn5hyt0jW7n3exB9oPbC9iONi3nuhNpFnsew9kn9ljfEC3
ZM/PPGrzzreDZ6qLf7GT3R54n8DW3f65K/M8S2jUvaFbdwRmS9OePcKGekfW
fXz0P/bDN9KO/bZf2rEH2OX0GY31/O68a5/ocfbqAqE/43qNxt2TutOPmp3R
74XqvbNW+rCez1v5plX+Rtfq3Rf6c0bsWP8Jnb8/8/NY4V/bNfveTINmpzZ/
fHj3Zz7ZptlC/9lrNrkHUteZ+UPGJY7mwez/C6q9k7pme927azY+a3ZFvetX
lVatst9UOtz+65odC71iy1q5a7ZgZxjMXvUPczhsdsq/5Gz9NfPMhqjuyjXm
e8ljld4tvDmr/Dl2sK7pjvo3qDT5qK2Z9Zpi1H7/LXZMbX5Afih4pUq/7ZrN
zfkc5nz/LWN8YNhs/tqaMzTnr71ma3w8Z3nfrp3Dh/rNXvhM9u01OQNstvcV
zuqjZrOlhz2V8qno9pU+Pmj2U3VXY7+rslVHzeb9uSrfrNL5XdMX6exVPME2
zEbJpsoX8WzgOwt+s2s2TevxXPozWfrjPM5WOBtU+38tnPnYZ7smjwgKEQ9K
v18jdI+OPH/hLjBqdgP6E787fYcO+lJw6GH0sWd7Tb8B033Y1fi56Vbbpy69
ht5Ej6L77BKY7ev46sNxXdMJ+l3z76A1dAK6Ab1m5q7pddrdPeX0hSm65mt4
vX4fRtbuGs2Zo2t0Rzts22zc6P81NfazCx4NmqxH5mOzIaPzPR+dM/tGzvgf
AjsLfNb0AXIymRnM/sb3StYkZ5IrwWRasi5fLBl1mbyLbEmO5UMl334xOF/P
nNC16BdLB4f8u1fK6blk2HfSzrGBybSHpP/0EfYnPlTyOD+IODrngsxCvkF7
u67JqWKUXo/fgx8Erjro6gmB8cf7Cuf7lZZgq6k036jJIOz+5AmyxLXOlr0b
u9Ug5ct2zbcE7/vpAz/I+cPmq4N3f+U/qrRU1V28a7yKXWvRrvGYTntd86GS
T5foml3LOn4l4zXPi4bWvRaYv4nPgxyEZxjXLYHJGXwik6cc/ZsifMU5mTLt
TJp2+E345ewntGLayBiPZ96mCo5z4/yQuSZN+dh7Jw18efaluu93zQ+nLXoB
mZ68OXX2Lb/MkikXo4uez5i+zVDv+Pio8enPVztTd+1MHIR25Pc0OVfOyeKp
+26v5TMNJo57prRpz+MN9j++h0fiifgqnoqf7hb+rs1ZRy2WwjN+On4w68vn
oR385c60Y48t1zXfKxll0VHz26hDTuYLG5c9w9eCdj0aP5V5YO9El9Hk8cPm
0/X7ydBZNJafSd1ela0yar/BysDo4uyjFhfsfego2oqWosdo8Gqx1eKXeCVf
kHL0/tlh82N5tlPlb4cvPpd24OzXNflsuoxpgbFxDZqsJX74kNAqchH7C5sM
PwJZi8y/b6/FES0UfLlnZDA0TN2He23tFh1M3KeLZh3tmSXy3qX5JLsWx4P/
4/d4PTq5cN41zaj5Vj2jky6ZupuMGu+3dy5Mbv/oz4Kp+7u8i0+EfGK8ZBKy
nj2N5ij/ZNq095ZKO4sFtg/pAEuHbqyY83Bqxr5s5mHpwDekfIX0Q1o+c8i2
Rs+gI6+SsWjH8+WCs2TGeVrKV0j7q6UdMJsl/Z7OKJZtpYxxr+xXY6G7rBZ8
ba+a95qPlYO/RmB9kK/ykf6slj6Zq9VTPiEmcNBstuL52X/ZbNnV6GuHpj9r
pE9Lps0l8nv19Bm/VpeNWswhH9navfZ8jbwLHaR3LZz5XzVj2Sb46/RafDJ/
CT61Y2B2AD46MYTs5GP21gmxbYMGkxnETW2QuvgdmM2NXZxfkE1gncD8VmLg
jZGPjG9HDBJ+6g7CWum/2Cd2IjyUrwcO3U0b66RNfBYOviz2jO0Pfz8846Vj
sr2ywbLXrjBqsiFfORsVuxX/0fGB2aZernP00rDFMvAtsOOz4ZOdyEXmeaOU
GwucLQJbB2s5c+ZsXPoJf8vMM9v/Zhnjp1I+Y/C3yDyz32+V/XBN2rEO7KDb
Z29YN+3wFbCJsI2w/bOh7pB52Cf4bKts1dtmvSbYzDMnO2Z+7Gfzt0Pw6do7
Zg+Y+10y/+bb2vDfjcseMi52JfYlNsVN0x92HvtIO/yDbI07Z031X93ZUq7u
KZHT9INd7i95rz3CDrpr+kBP51OgU7NZ7ZZ11M/ds5es6e4pJ3/tkf25deqy
V5Fp2ZLYkb4bmI2fHkmfZJfCE+n7T+S8owvjMi5tkgEvCL3gb9BHfdWvs9IO
nfRXaYf+elz6fHrkhH0zLr6mQ7PWeAr6o222B/rnM+Gz4G9ljvfPPD8R2F7A
38kb+DIZA0zn+3jXfIL9XovNPjR0g25AR+Dr4y+EQy8hT7Kj0UNniB4xbei8
cnSVTn1I9rmzOeHM5ywclvbFEost5oN7hJ44anFGfEufzx6wHz6fc8G3A3+j
1PN7w9Cfz6WcvnBkytFwMDosFpp/h12Orwm8RfbwrtkPfEBfGEz0cx3xkfce
lTb5r+Dwp4tV409iq6GfwNk29FtdfjB+Ijhb5XwdGxjf53/h0/9sYPI/v4G4
NPK8+0f8OOIB2Of4cfbpNV8OGJ3k3zku5WIZnDHrLt5BO+z/ZH0yP5s0f6P5
R4vmiVz9u8KZN3rBH3stno0OMGYThnNSaMKxoQ/O5Qk5m+I3xIrjO/yqYD5l
+UmhP2IUxCrwrZg7MQl8WO5XgdlRxeCxddNh2QfB7IfsyWzNZFH2ZvC45Kdm
z7OBsa8+1Gvnl+/t2ZyLU1NXTPTX0ubpg4bjjNM16C1kDz7501M++bDFoJ+e
Pl6cPrPPehdf2BTDdgfpO4Omm5DPyGa3dy3+jNzKhskWR3Z9LTC761l5xrY5
berSZ+kQ30w7d1b5j6Lz/HfY4sDYydjAx+f8js9vOsUdXYvNMh42cuVo9uLp
iz7oqzaeCB0Yn7psHt8Izt0ZExz2GOeSTYZcS4ZnV2TPFLfEziNWDix2jpzP
VvlSr9knwWyV4pXY/dh/2P7AYtjYmc/LurNPigtjqySTn5/yrwaHH+S99OGl
7Bk4bNSndy3Oy7pfXfO0YL1vo0pvFfzvYbMZP1XptK7FmPUL5odWB21XhiaL
ZzJediwxvRdkXCcXfFKl67pW9pOUnxMY/of1/INKy7PpjFqcFjvXVVVnoVGL
D3QufpHz4q6oGCyyhHjICzMng2Hrn1gRcRRwxAZczXbaNXuSu6I/z1kTnwAm
G4jD4dfEW9FA73Iu+fqUs2OI0+ev5Vdlf3CPgn1G/svAYrXAZGa2l0uDT364
LPTHebo8Z2rM/+qsi1UXl7NYYP5Octei+c2fKCZKm+w5cH8VHDYQsTvfjfxw
ZcrJb9rRhvgrfUUzxcZflTbRYXYoNB8tRBNnDu8S+4LHoYFiL/DTTQKzX8mv
SfmnU3f94F8bHDFj16ZNfhs+pAmxC/3cXek12iQeAv8Szy9O6NzwHeV8B2w1
ytku8CLt4E3i0K5PXT5zNAf93y7jwjv4J/kpye1o/82hRReEJ+FHeA5YPb57
dBaNPTnwPGn/lsz/noGVize4NeVopvsk+JT8tsDW7dbsgZvSB3XFGEyIB+g1
uZS/foHsk9tTl///9uwZstPv0s/b8q59M9bfZR3pKWID6K1HdS3eV3wEHwF4
gr190GDxAwdkfsiKYtXuyVy53ypOgP+Iz/+POQvo4/05L8ruC464gnuDQ/a8
M22y/92bfS4m4a6UizfQDpshX4N2vGdc9pW9JqaFH50PHf/Ea9na+NH54Mm0
ZEG+fLz16MCLB0d8ADuM2LmHUq7eX1J3l8BH5Lz/NePir2evpBPRw+hmbJnk
VThk4CPSlvbFDDyccvH2fM9sMuT8R9KO/jySPuBh/Ib4Gjvoo+kPfU453YR/
9MnsQ/FRfOpkQv5W/iG2gnMDn5P8icDuC6iL18ifCsyXBv5B3vVs+kCX5V/c
JTLG0zkjyh5LOX/r0+kPuUJ/yAnHpx17+7G0Qz/eP/3RX37S5zMufjK265d7
zbflDgwe5zmYn5R9nq+LXIMv803iuXymf8+ewePg4HfiBPkI6TLiPeDTHYyX
PxHf4YfjL2T74iv8R86+Pfj37D331F7J2I3r1cwPXyGY3PjDtIn+6O/z6b/n
rwWfvEPGwsfZ1o2XHUbZv1L+vcB8ke5Z8DmSE8g5YHIFGw6/IVnLnY430o67
7G/m7JsrPiZ2OXZG9sbXQx8m4PRam6+l/UWCw572TvpJDuTTfCv0gV8O/E74
yIOhCZfmXc77beSWrvnq+HncSXkoY3wn4/pfnl2X8YLJIXxD7wYmm5BRyDD8
V++lfKbi5693za81l3sJlZ4ftrm0h/hS4b6fumSW/+Vd/F7KH8ncs+u+nL33
YeryL32Qfcjn+E7mYcLHSrqmo7ENT5m6vx62WHwyEtmfb4D8jx6JLWCv/mXg
M5OPAr/NlzRsfpXryUTkq+w19k/7iv15irzLXrLnrNd0wbFnZshY7Cm208lS
l87B7k83OTDt2ANn1XvGDdu9Ab6ItzPGI7rmt54yeh5dDi+2L6ZNXW1Mnf4c
WfkK+e3906R8isD6dXbq2l8v1jtf4LOs3zOOmv19uujN9Ge+OrISmYltact6
/kDXfKKz81d27T7TcsEhU9Gz6dvkC7Hx03cT7VJgNGq5UZP1+A2tI31b3O0R
kQGf7jdeT8+kn9GV6a5r95ruSx8e003BY3GY5kcMy7GpS64gS9Anx/TL2bIW
YgXJW2QtNuM5sl7OIl+b83hYxkKvdw9IufN4RPpDPiKvzZmxez5H6irzjjGd
eK68i82HPnxy9gN9VdySvUpfFV9lDOI4x3RKMHouboqccVhkGPC+kT08o0eg
t/MHhw4u/u8TkVXAdFUyhhiqA0IDxd7Yb2zp/O5jz8HkE3E5cOiIaBsfFlpH
BlkwOO67KL8x/HCp4CtbNPjoJV8YmumuDBhNoMPR5YZ5vnhw7FX6J7/YNwPT
H+k04sqfjJ5CZxvjmWA8VHzRUoH56vjsfhqe65kx0QGXDs5jwSEPiFfXZ346
chB5iNxH/iJ7LRw6SScc0x3B6CHat3z28JQ5v+jXsqN2NqdH04fNp7VCzvaK
OQtTB345fFaMAZ5FhwWTR8QWiDkYK1s5OPROutY7gVdJ+Y31rhsqXWJvVv50
1+4mulsD3z01viQ+KvPEfkt/Wza6zLo5O/Q7uhm97OeB2UDoN3QVespVgelH
7H70BDoCnQDMfkj/oG/QNa4NTC+hQ9AT6AjXB6Zb3JI+kNutz7JZI/6R9XLW
bgvsrN2Z9SK70i+Nhd34hcwJHf2erKP9/4Wuyd9iv8i/5GM6H3mDzknOfCAw
2YOeIhZ27ByDyb3yjQPjw2C45FxyLXnyocBkYfIpeZQs+nBgsi2bIjmSDEne
JOOSScVjbJax26vg0yPfwWebfCT450Se3KKbGMu3bc4IuZWcd2j22JbZV+IE
yG3HReYHk/fZa8lqR0a+A7PjapP98cHoemB0S+4Z2XXbwHDIYtsGNpbt0/8J
setdk/H8Bu+YfPuUP52xoCf3d41Pulv3x6wXXQYdIxeSCV8JjBc7m+S2sfix
nUJzyBtktRtC03YO7RK7QW7bN7wAjObzEe8aePbAE+I6uvZsTKbbLTjizshq
5DSy8u6hIb/Ps59n7+0RHHLcntmfxr1Dxi62kI5HliNH7Beao8wzsvfegeGQ
+/YOrAxM9iRTkJ/Q+XcCi90i65Hz0C538MDkQ3LfZ1P+XmBy2qTpAx5KNtdP
68lvv3/mEM0Ho5/7Z726rNdncr7YcefOeSFzkYfIM78fNvq4xajFwPAr+x4U
uohmopMrBEYvxciIBcUX2MvA+CD55tCUHxs87cgPC4w2kznQavILeYWsckhw
Fsn6H5I1JSMdnr2nv2IUyFZTpR20fPq0Qyb61LDd5f52v8lm8NH/bap862G7
1yrG+ej02R5Bi8b0/qOyN+RfCLxH4N0z7mNS9/jAxiU/NvDd9Z6bh+3ur/cc
l719aHAOTr+OzHzuEhx1V0i5Pmvz+G5iG8cH5xMp06b7wuyB7kj+ueCHhu0e
MP+4mAJ+/MMzJ+IE/5P8GbLKqMV8TdJvMYBgvpgjh+3+ufiLf47l8Kt8NGz3
0hcdtnu2bKA7jdr94UVGzRbuPuuzhb9jle0wbP3Yfdju/7p7687r6cF5etju
qGrn3WGzTbuvOs2wfXvN3Wf3id3JdRd3+1G7r77wqMWG6Is4E/hiGcUMuJ97
Rsa197Dd0XWv1h1id2fFb2xQZetnLAcM213Tsws+tfJThu2e3g+GLcbI/eSN
hu3+3vj0U59fr3etPWx3g43H3IxPf9zpFpfiTv23hy3WxB3y54Yt/kMchVhN
cei+e2BNrJG4zX8M2/44MOMwnvtCT+iVaIg4FOMxljXM86j9di6+n/NlL4g7
EU+y5rDFCPrtHrDYQHEra4+avuqOoBgtuWBBdn/2/7HYKvcAxfJd1rV7g8PI
h3wKZMV1Rs3HAO+Jrsle9vBUlV/atbuInx+2PSEW5OjKdx01n8cG2W9T9tte
A1tbMirfh/icX3dNZzKuv1uTYYsVfS5xKeJAlrF/uvbb+WN/Z0tfbtj8gn5/
oeC1PuKPkZ+Web0kc8tfoV98G6sW7lQf2etysrAYFuNwzr6SNbLfxLL+smvf
oKAXmy9zxYaP9pD9xJ/yKfww83d55vCYwn+5m7if5HwKq1X5dqnPL+B+Pl+A
+9r8ARdG1nVffIWs/68zV2Lqdh+1b1882DU9ED2XX5394h6lWF9xui9mXumk
S/ETde237wCIbfB9AHdSx3wXU4+aHm2NnTV32F/stZhlZ0jc8hnD9g0g8VBf
y/l39vmgb8yZnT51J+23/Ma0Q5ckW+B9zqk2xFN9d9i+/XRzcG9KO2KsxMGu
Fh8wXzB/k28giKd1T/9rBX81Z/z0ytcbtu8Z/DI0Rx/YCvkc+VbOGbb3+ZbB
RfbPqN23tdfteefAbz4//r7FC+fd/HaenC9n17nhz7Ov/+QceO+oxZ+7a8tH
Jr87MFqC5phL93rdPaB/LVH1phw2POeKr855/emwfbsQHpmCbEGm+PqwjVlb
Pxs2PN9E8G0B9H2fgtcfNXxyyBeHLZZFHAvey/6A/26YWGpt+haBGGVxyZ7f
H5y9R8224je5wp6z31bPHtgvcXFg8W/iJMUV+6YH2oRGWUP78aGuxe1NN2z9
0zfxeL4HMU/kI/0hI02ZtrQjng6M981SdWcetj7yhbGHsoX6DgV+5O6M8/F4
186IOXg0Y5x22MYMfmXY6DLbC9zHgr/1qNlllL06bLQP3ZugK2e9Nh81u5t+
PtM1XRB9WHLYvk/xZOp6B/sOW91TWQv10Au0Al15JnU9fzo46Br6Zr+z7T0b
/EmH7RscxuzOk++N4DW+QeK+EP+R/MXMw0uB4dwTfv1hr32746XAaBIaxZ/4
v67dRQd/0LU77uQEsJjUV/NufXBO8fDnuxYrbMyvZE/zf72QPmw8au34XoTv
i2jjvcyh2P1nx96Td5kPOrb5cK/K/QbfeHkpY/Z9lXmGLQYRzbZfXs9avJE6
ZJ43UxeMnr8Z2L0J8BP9Fu9OfiI7+daLu3jiUdVzt8J7xbRoU/yqmIF/B1/M
/KcLZ99Ry7V1Sp6/FZzvpM/m3/0174KPB/Aviy362LDNhf6LybfXPzFoNBqt
dl7xP3zQeNEgtAiv+8Sw2RMPz7jfSz8/DKz/cr/F01rDDzLPr2ZN+fndKRF3
C+fA4MEh572dczfZsLWjzdfSjjZ8D8Eaozl7ZlzOI5rqWwbo6IqVjxs1uY/v
ehCch3OG7bdJhu1uhnsZE77TMmzy4TB17TXfySGTfbVrch6YbLbgsH0rwRld
YNhiL/B8e3nS0AjtDdPm/MMWw2EOyWNkTXIpWWCqtIMWT5l29E+/rdtNwceb
ehnPfaHhvrOwQr/tR+tqTeHjhWN8EIy/4SnmZ/l+4x3q4hXoou+5oFtoFd/A
vaFRs4deWQdrZr3QwZlDn9E5NA59sy9mCZ1EV9Dch0JL7bMxOg2239AGdOHD
0A0w2uE7Or6ns3D2uX0/dm7A9vM/sw/sAXsB/Fr2rLNq39rL9uvh2b/zZ/7d
v6FrkEMeHLb7Nn6TTVZKub23UPafc+kMO7/WZ4Gskf2zcPaQuzvuApF/rOeC
WVPtTnjfqNEA7TjrcLcZte9OHDpssdHkeTIpmclZtFbWzPmzVtZ7bI8skXVX
j8zqvPr+DTkVLaffrJA5/HrmlB6hvytmXypbPuX6ok/uMW07bLrudtGT6Evu
KNFXth01GdY9JM+UTzgHw0aPtbFy5kEsvG9APJV5puP1Cz4hOLtE36B30Kno
g2RlZwJ/ppN47v6iM00u8k0kegg+T74m/9P16JXr55yi+WQx9B/v9xv9J/OS
g68IHVknOOR38jy5Ur31Ur552pkj49g0YyF3rJ718k66B71D3D29ma60b/CN
Cz12ZxgfOWwYuGvPtEv/ctdKXfoUvWqzwMcOm4zue0pbBCar+3YXfZJ8xybh
Gb2A3qM/aBVdXju+H7Va6qtLR/xU+kA+2jxjXGXY9h8d6bXKdxtN9G/J2YLY
AdyJZhu5Iu/2Xm1vnX5unf0Dtoe2yZyrt33Or7MMprO6v0DHRxOcazIlHU6Z
Z3gCPWnHwNrbNu2/nfrq8h27z8wf7XtX2kEf2CJ2zhqhZ1sNm4zkO17wyQx8
sr4TRS94f9jul/omFxq1e3Dgg09JXd8C831Fusgew6ZvXZx6/OD7DJvdgL7w
fmD6iD3z2ayRMnhnBt47OPrlHcuFhu8dnN1Trj+jtGPP22v2HHnat9+MhU/h
wGGzS7Dt2Dv2E33PtwR9T2nafrNVgOlZcA/IPJwWmE1D+YGB4foek7r24SHp
g732uew3a3141ndc9tKl2XeHZe9p56C8d5R27Gf78/DssU2i81+QM3dozh1f
ubr88nSXI4bN1mD/H5m1Pn7YYuSfj2wPdjdK/LxndBO61FHDZiPAw9kU0BU2
Gbo0WRXfpvOjE+RWMiv+rI0vph2ynO/3nZJ9tP/YXuq3Z2S8E4OjDE9wFxRf
IL/BUdc+PTL7H41EK+kxYr/RQTSQ/Kst7YgBZCOkR7MZ+v3FruUnB2aPoqv6
dhb9jR5Hb5VOyfxbi1OCIz818FcDw6WD+34U/Ut+WvaDPQKmkzlbZ+Z8oU/0
Ru/8U+qP1T0j+P8cNlpD30OH6NJoLtlCGdpDR6c7k9Pg0w8n75oM8o3gkrnO
HjY9AS/65rDpBm8O2/3esTtacj44drTxKYMDfr/X8m8HJhN+J++9Of1wP9gd
RHeD2QTo8/rmufyc4JNnfJ+RbPON9Fk/3VEW+8lGxL/3q8C+W6hddjN+PXcS
BQgOAveTn59y9kSw5/IfpNz9RXd62S7ErILZ191p/FHKJwnMFsd+4K4xvuy+
MdidczYAOv4gZfDIin/LM+X0LrC7y2wB8JXxz5ofvlplPwu+b5GJYUXTyA/u
P1+dnE0Ej/95YHKF3G9yPZnZtyzZx/BgdBaNRWvBaKz8ksCrx17zVORhdhny
9q7pAx6xRObcOrJHXZa+eX5ZzhSfi/W6Lv25MH1jc7kg8/ZW1pFOzQfiu4v8
IHRttjx30unSfOd8WHzl4GHKrgp8dWC4bHtXB1YGFhvzm2GzCYKvCjyMndAz
tkL+d7Ew/DLsEux37sOKi3E3lp3w7cDsD/JrPwJfF3zwNcFnX7wuMLuo7y2S
M9k7b8geNgc3ZLzyGwObD/My5v8Bfzxz9fvANwU2b3K/2X3QNu9jg70lMJq2
bPoA5rvgwyDbSPgf3ocOg/E++W2BjeP6jNH9V/dpyYf6f0XWkX3b9y7xOPfc
weQx99z5POgC5Hm/wcrA9H74d6XuwYEPSt/vHk6kz2Djw999u5O+Rt5gNyFj
XJO5M2/O6/05s8ruzVzZv2zu6MaY/d2+ZleE79x7tz7hlfQR+o6z7vulvhlL
/lf2YPYzOR0M1x6nKzr7MwS298nffAN4PbkVTO6V/znlmwX23J1r30l9rtfe
CWY3oE/+NfAd6ad5U/Zw+kZ/AcOlV1gvd59/nLHo83WZ0wuyno9mTfFO36FQ
zzdo2aDpd54rJ/e6N+07De6nwwGTE9yxezww3VBdvF7cvrvGfDfuG4PF7LNF
upN7f3Slp4PjuTps/r4L8Xj68HTK4Uw7aj6ddwO7B/tMnsOjc4nlZ7tntycD
wfdOvJbdj57Or8H+TobnJxXXIiZPvBiYPd+zFwKL/QOz1ZP9/566Lwamh+rv
Sxk7+6V3TR/5hyx1XNJLmSv9ei5jeSk46tJRles739Q/0s5jgQ9Mv15Mf7zn
1eDQ8fj1+FN8C8X3AshUZATyw7jk5AOyAX4L9pz9RZ2ne+3bvK+njH3n/wJP
aG/YZCr0Xrwjmk92IB+QB8gOfovluSNt6sMHKX8/NAQ/0AYbrHbQk/FpRxtk
4dfSz38HHw67r/Faz9lGbbyvx8+OXo/RZzC6DMe997F7OHJ3AdV7N3XtQ7D5
m2PU7pz7bo47IR+kz8rpO/QOcbyei9+3Hv/Je/FZOJ57t3L8hc5Ctxl7/n7a
MR8fZK/6M5gP887HcjadR7Fpvt8gtsE3m8E/juwwCOw7D2D0Td4FRvfAcPnC
fedAzIBvQoMviuwzCux7CGD0cxQZaJLQHnQQPSKT+MbKKLQKjF7JJ0v5hP+E
GjVaMUGGGrX3oKfKnWt3IdnHtww9cebV48cUo0aPFqcG5nORe8YPM3VgOPb0
1IGnyjM6FLqAPozdWQc7a/JpAzuD04aG0LX4ifmF2cj1bcyG/7HAnoGvyjim
yFism/VjO/F8+uCjKWJHxI24M+rbR/xNysSj8uPMGfjD+IDEYTjXymYMjnoz
p+4sgW+NzDlLYLZL+/bF0FJ7fgLtHTUcvAmettxhfSc4aLN6c6Tuf3Nmxp7P
lnbsd3h8ifbwHDkjYmA+nn66L+b+FFuH/s+ZsdjfytEEZXOl3G91xmL85k5d
9A0OWuyeFv4/VWwp/Lvas3/nz34WV/yJ7Hn+v/kCe+e8adO5mS/nSLtzZs75
FOfPPh+knX7OwQI5J/8P/aw9Ww==
        "]]]}, {}, {}, {}, {}},
    VertexColors->{
      Hue[0.633338, 0.0010288065843621398`, 0.999637037037037], 
      Hue[0.633338, 0.007898386660401265, 0.9972134491862105], 
      Hue[0.633338, 0.017712156601045484`, 0.9937511511511512], 
      Hue[0.633338, 0.03068838726958384, 0.9891731369712908], 
      Hue[0.633338, 0.04609567289577858, 0.9837374466023693], 
      Hue[0.633338, 0.06166393441422119, 0.9782449639386628], 
      Hue[0.633338, 0.07364115226337446, 0.9740194014814815], 
      Hue[0.633338, 0.07818930041152262, 0.9724148148148148], 
      Hue[0.633338, 0.0736411522633745, 0.9740194014814815], 
      Hue[0.633338, 0.06166393441422119, 0.9782449639386628], 
      Hue[0.633338, 0.0460956728957786, 0.9837374466023693], 
      Hue[0.633338, 0.030688387269583856`, 0.9891731369712908], 
      Hue[0.633338, 0.017712156601045505`, 0.9937511511511511], 
      Hue[0.633338, 0.007898386660401283, 0.9972134491862105], 
      Hue[0.633338, 0.0010288065843621398`, 0.999637037037037], 
      Hue[0.0483667, 0.015489768892306369`, 1], 
      Hue[0.633338, 0.001905991210689427, 0.9993275663008687], 
      Hue[0.633338, 0.01338526857353934, 0.9952776772472554], 
      Hue[0.633338, 0.030500462658582295`, 0.9892394367740521], 
      Hue[0.633338, 0.05327439922775998, 0.9812047919524463], 
      Hue[0.633338, 0.0787680041152263, 0.9722106481481482], 
      Hue[0.633338, 0.10001292583875165`, 0.9647154397640885], 
      Hue[0.633338, 0.1084470101102474, 0.9617398948331047], 
      Hue[0.633338, 0.10001292583875165`, 0.9647154397640885], 
      Hue[0.633338, 0.07876800411522634, 0.9722106481481482], 
      Hue[0.633338, 0.05327439922776002, 0.9812047919524463], 
      Hue[0.633338, 0.03050046265858234, 0.9892394367740521], 
      Hue[0.633338, 0.013385268573539368`, 0.9952776772472554], 
      Hue[0.633338, 0.0019059912106894447`, 0.9993275663008687], 
      Hue[0.0483667, 0.015489768892306369`, 1], 
      Hue[0.0483667, 0.04231032834636436, 1], 
      Hue[0.0483667, 0.02422354272215419, 1], 
      Hue[0.633338, 0.003952263374485594, 0.9986056414814815], 
      Hue[0.633338, 0.025310722845259155`, 0.9910703769801925], 
      Hue[0.633338, 0.058784370683640175`, 0.9792608740228117], 
      Hue[0.633338, 0.10238154656175524`, 0.9638797903730127], 
      Hue[0.633338, 0.14347894903450453`, 0.9493806267806268], 
      Hue[0.633338, 0.1609942386831275, 0.9432012325925926], 
      Hue[0.633338, 0.14347894903450453`, 0.9493806267806268], 
      Hue[0.633338, 0.10238154656175535`, 0.9638797903730127], 
      Hue[0.633338, 0.05878437068364023, 0.9792608740228117], 
      Hue[0.633338, 0.02531072284525919, 0.9910703769801925], 
      Hue[0.633338, 0.003952263374485626, 0.9986056414814815], 
      Hue[0.0483667, 0.02422354272215414, 1], 
      Hue[0.0483667, 0.04231032834636436, 1], 
      Hue[0.0483667, 0.07803345752063696, 1], 
      Hue[0.0483667, 0.06957685002556793, 1], 
      Hue[0.0483667, 0.04066509499783343, 1], 
      Hue[0.633338, 0.00964908050411522, 0.9965958043981481], 
      Hue[0.633338, 0.056460905349794185`, 0.9800805925925926], 
      Hue[0.633338, 0.1335905349794238, 0.9528692592592592], 
      Hue[0.633338, 0.2225782106597176, 0.9214744072792517], 
      Hue[0.633338, 0.26544817386831265`, 0.9063498842592593], 
      Hue[0.633338, 0.22257821065971778`, 0.9214744072792516], 
      Hue[0.633338, 0.13359053497942389`, 0.9528692592592592], 
      Hue[0.633338, 0.05646090534979429, 0.9800805925925926], 
      Hue[0.633338, 0.009649080504115271, 0.9965958043981481], 
      Hue[0.0483667, 0.04066509499783335, 1], 
      Hue[0.0483667, 0.06957685002556792, 1], 
      Hue[0.0483667, 0.07803345752063696, 1], 
      Hue[0.0483667, 0.12066396559064017`, 1], 
      Hue[0.0483667, 0.13054717268709035`, 1], 
      Hue[0.0483667, 0.12506941774531158`, 1], 
      Hue[0.0483667, 0.07452839506172836, 1], 
      Hue[0.633338, 0.03049585937103081, 0.9892410608139003], 
      Hue[0.633338, 0.1658509265346871, 0.9414877931185623], 
      Hue[0.633338, 0.38917695473251, 0.8626983703703704], 
      Hue[0.633338, 0.5252756185540819, 0.8146827617741199], 
      Hue[0.633338, 0.38917695473251024`, 0.8626983703703703], 
      Hue[0.633338, 0.16585092653468736`, 0.9414877931185623], 
      Hue[0.633338, 0.030495859371030935`, 0.9892410608139003], 
      Hue[0.0483667, 0.07452839506172823, 1], 
      Hue[0.0483667, 0.12506941774531155`, 1], 
      Hue[0.0483667, 0.13054717268709037`, 1], 
      Hue[0.0483667, 0.12066396559064017`, 1], 
      Hue[0.0483667, 0.16388680124291846`, 1], 
      Hue[0.0483667, 0.19925154320987645`, 1], 
      Hue[0.0483667, 0.23665242729848346`, 1], 
      Hue[0.0483667, 0.25256172839506164`, 1], 
      Hue[0.0483667, 0.146760172401198, 1], 
      Hue[0.633338, 0.15438528806584342`, 0.9455328703703705], 
      Hue[0.633338, 0.154385288065844, 0.9455328703703703], 
      Hue[0.0483667, 0.14676017240119762`, 1], 
      Hue[0.0483667, 0.2525617283950616, 1], 
      Hue[0.0483667, 0.23665242729848354`, 1], 
      Hue[0.0483667, 0.19925154320987654`, 1], 
      Hue[0.0483667, 0.16388680124291846`, 1], 
      Hue[0.0483667, 0.19720987654320984`, 1], 
      Hue[0.0483667, 0.2567342116891666, 1], 
      Hue[0.0483667, 0.34273869530279777`, 1], 
      Hue[0.0483667, 0.46259985475671717`, 1], 
      Hue[0.0483667, 0.5746913580246912, 1], 
      Hue[0.0483667, 0.5746913580246912, 1], 
      Hue[0.0483667, 0.4625998547567174, 1], 
      Hue[0.0483667, 0.342738695302798, 1], 
      Hue[0.0483667, 0.25673421168916677`, 1], 
      Hue[0.0483667, 0.19720987654320984`, 1], 
      Hue[0.0483667, 0.20987654320987653`, 1], 
      Hue[0.0483667, 0.279597241274196, 1], 
      Hue[0.0483667, 0.38812839506172825`, 1], 
      Hue[0.0483667, 0.5647665895061728, 1], 
      Hue[0.0483667, 0.8439262307575063, 1], 
      Hue[0.0483667, 0.8439262307575067, 1], 
      Hue[0.0483667, 0.564766589506173, 1], 
      Hue[0.0483667, 0.3881283950617286, 1], 
      Hue[0.0483667, 0.2795972412741961, 1], 
      Hue[0.0483667, 0.20987654320987653`, 1], 
      Hue[0.0483667, 0.19720987654320993`, 1], 
      Hue[0.0483667, 0.2567342116891666, 1], 
      Hue[0.0483667, 0.3427386953027978, 1], 
      Hue[0.0483667, 0.4625998547567176, 1], 
      Hue[0.0483667, 0.5746913580246916, 1], 
      Hue[0.0483667, 0.5746913580246917, 1], 
      Hue[0.0483667, 0.46259985475671783`, 1], 
      Hue[0.0483667, 0.34273869530279805`, 1], 
      Hue[0.0483667, 0.25673421168916677`, 1], 
      Hue[0.0483667, 0.19720987654320993`, 1], 
      Hue[0.0483667, 0.1638868012429185, 1], 
      Hue[0.0483667, 0.1992515432098766, 1], 
      Hue[0.0483667, 0.2366524272984837, 1], 
      Hue[0.0483667, 0.25256172839506186`, 1], 
      Hue[0.0483667, 0.1467601724011985, 1], 
      Hue[0.633338, 0.15438528806584328`, 0.9455328703703705], 
      Hue[0.633338, 0.15438528806584387`, 0.9455328703703703], 
      Hue[0.0483667, 0.14676017240119818`, 1], 
      Hue[0.0483667, 0.25256172839506186`, 1], 
      Hue[0.0483667, 0.2366524272984838, 1], 
      Hue[0.0483667, 0.1992515432098767, 1], 
      Hue[0.0483667, 0.1638868012429185, 1], 
      Hue[0.0483667, 0.12066396559064023`, 1], 
      Hue[0.0483667, 0.13054717268709046`, 1], 
      Hue[0.0483667, 0.12506941774531175`, 1], 
      Hue[0.0483667, 0.07452839506172856, 1], 
      Hue[0.633338, 0.03049585937103075, 0.9892410608139004], 
      Hue[0.633338, 0.16585092653468708`, 0.9414877931185623], 
      Hue[0.633338, 0.3891769547325104, 0.8626983703703703], 
      Hue[0.633338, 0.5252756185540824, 0.8146827617741197], 
      Hue[0.633338, 0.3891769547325106, 0.8626983703703702], 
      Hue[0.633338, 0.16585092653468742`, 0.9414877931185622], 
      Hue[0.633338, 0.030495859371030866`, 0.9892410608139003], 
      Hue[0.0483667, 0.07452839506172844, 1], 
      Hue[0.0483667, 0.12506941774531172`, 1], 
      Hue[0.0483667, 0.13054717268709043`, 1], 
      Hue[0.0483667, 0.12066396559064023`, 1], 
      Hue[0.0483667, 0.07803345752063703, 1], 
      Hue[0.0483667, 0.06957685002556804, 1], 
      Hue[0.0483667, 0.04066509499783353, 1], 
      Hue[0.633338, 0.009649080504115184, 0.9965958043981482], 
      Hue[0.633338, 0.056460905349794185`, 0.9800805925925926], 
      Hue[0.633338, 0.13359053497942383`, 0.9528692592592592], 
      Hue[0.633338, 0.22257821065971775`, 0.9214744072792516], 
      Hue[0.633338, 0.2654481738683129, 0.9063498842592592], 
      Hue[0.633338, 0.22257821065971795`, 0.9214744072792516], 
      Hue[0.633338, 0.13359053497942394`, 0.9528692592592592], 
      Hue[0.633338, 0.05646090534979429, 0.9800805925925926], 
      Hue[0.633338, 0.009649080504115233, 0.9965958043981481], 
      Hue[0.0483667, 0.04066509499783345, 1], 
      Hue[0.0483667, 0.069576850025568, 1], 
      Hue[0.0483667, 0.07803345752063703, 1], 
      Hue[0.0483667, 0.04231032834636443, 1], 
      Hue[0.0483667, 0.02422354272215426, 1], 
      Hue[0.633338, 0.0039522633744855686`, 0.9986056414814815], 
      Hue[0.633338, 0.025310722845259138`, 0.9910703769801926], 
      Hue[0.633338, 0.058784370683640175`, 0.9792608740228117], 
      Hue[0.633338, 0.1023815465617553, 0.9638797903730127], 
      Hue[0.633338, 0.14347894903450467`, 0.9493806267806267], 
      Hue[0.633338, 0.16099423868312768`, 0.9432012325925926], 
      Hue[0.633338, 0.14347894903450467`, 0.9493806267806267], 
      Hue[0.633338, 0.10238154656175541`, 0.9638797903730127], 
      Hue[0.633338, 0.05878437068364024, 0.9792608740228117], 
      Hue[0.633338, 0.025310722845259176`, 0.9910703769801925], 
      Hue[0.633338, 0.003952263374485601, 0.9986056414814815], 
      Hue[0.0483667, 0.024223542722154212`, 1], 
      Hue[0.0483667, 0.04231032834636443, 1], 
      Hue[0.0483667, 0.015489768892306414`, 1], 
      Hue[0.633338, 0.0019059912106894107`, 0.9993275663008688], 
      Hue[0.633338, 0.013385268573539328`, 0.9952776772472554], 
      Hue[0.633338, 0.030500462658582306`, 0.9892394367740521], 
      Hue[0.633338, 0.053274399227760005`, 0.9812047919524463], 
      Hue[0.633338, 0.07876800411522634, 0.9722106481481482], 
      Hue[0.633338, 0.10001292583875172`, 0.9647154397640884], 
      Hue[0.633338, 0.10844701011024746`, 0.9617398948331047], 
      Hue[0.633338, 0.10001292583875172`, 0.9647154397640884], 
      Hue[0.633338, 0.0787680041152264, 0.9722106481481482], 
      Hue[0.633338, 0.05327439922776002, 0.9812047919524463], 
      Hue[0.633338, 0.030500462658582334`, 0.9892394367740521], 
      Hue[0.633338, 0.013385268573539355`, 0.9952776772472554], 
      Hue[0.633338, 0.0019059912106894291`, 0.9993275663008687], 
      Hue[0.0483667, 0.015489768892306414`, 1], 
      Hue[0.633338, 0.0010288065843621398`, 0.999637037037037], 
      Hue[0.633338, 0.007898386660401265, 0.9972134491862105], 
      Hue[0.633338, 0.017712156601045484`, 0.9937511511511512], 
      Hue[0.633338, 0.03068838726958384, 0.9891731369712908], 
      Hue[0.633338, 0.04609567289577858, 0.9837374466023693], 
      Hue[0.633338, 0.06166393441422119, 0.9782449639386628], 
      Hue[0.633338, 0.07364115226337446, 0.9740194014814815], 
      Hue[0.633338, 0.07818930041152262, 0.9724148148148148], 
      Hue[0.633338, 0.0736411522633745, 0.9740194014814815], 
      Hue[0.633338, 0.06166393441422119, 0.9782449639386628], 
      Hue[0.633338, 0.0460956728957786, 0.9837374466023693], 
      Hue[0.633338, 0.030688387269583856`, 0.9891731369712908], 
      Hue[0.633338, 0.017712156601045505`, 0.9937511511511511], 
      Hue[0.633338, 0.007898386660401283, 0.9972134491862105], 
      Hue[0.633338, 0.0010288065843621398`, 0.999637037037037], 
      Hue[0.633338, 0.3377048713457783, 0.8808577213892094], 
      Hue[0.633338, 0.7493120997394496, 0.7356426912119222], 
      Hue[0.633338, 0.7493120997394503, 0.7356426912119219], 
      Hue[0.633338, 0.3377048713457789, 0.8808577213892091], 
      Hue[0.0483667, 0.1925755051475926, 1], 
      Hue[0.633338, 0.09033744855967059, 0.9681289481481482], 
      Hue[0.0483667, 0.8447658704068957, 1], 
      Hue[0.0483667, 0.19257550514759209`, 1], 
      Hue[0.0483667, 0.8447658704068957, 1], 
      Hue[0.0483667, 0.8447658704068967, 1], 
      Hue[0.0483667, 0.8447658704068965, 1], 
      Hue[0.0483667, 0.1925755051475935, 1], 
      Hue[0.0483667, 0.19257550514759303`, 1], 
      Hue[0.633338, 0.3377048713457785, 0.8808577213892094], 
      Hue[0.633338, 0.09033744855967103, 0.9681289481481481], 
      Hue[0.633338, 0.33770487134577915`, 0.8808577213892091], 
      Hue[0.633338, 0.7493120997394503, 0.7356426912119219], 
      Hue[0.633338, 0.7493120997394509, 0.7356426912119217], 
      Hue[0.633338, 0.5505106110205865, 0.8057798564319371], 
      Hue[0.633338, 0.5505106110205855, 0.8057798564319374], 
      Hue[0.633338, 0.41555226337448514`, 0.8533931614814816], 
      Hue[0.633338, 0.8336855967078185, 0.7058757214814817], 
      Hue[0.633338, 0.5505106110205861, 0.8057798564319372], 
      Hue[0.633338, 0.41555226337448603`, 0.8533931614814814], 
      Hue[0.0483667, 0.5236564348732399, 1], 
      Hue[0.633338, 0.09033744855967131, 0.968128948148148], 
      Hue[0.0483667, 0.5236564348732397, 1], 
      Hue[0.0483667, 0.9833876543209875, 1], 
      Hue[0.0483667, 0.9833876543209878, 1], 
      Hue[0.0483667, 0.523656434873241, 1], 
      Hue[0.0483667, 0.5236564348732407, 1], 
      Hue[0.633338, 0.09033744855967027, 0.9681289481481483], 
      Hue[0.633338, 0.4155522633744853, 0.8533931614814816], 
      Hue[0.633338, 0.41555226337448636`, 0.8533931614814813], 
      Hue[0.633338, 0.550510611020586, 0.8057798564319373], 
      Hue[0.633338, 0.8336855967078196, 0.7058757214814813], 
      Hue[0.633338, 0.514560048755689, 0.818463214798993], 
      Hue[0.0483667, 0.19296001828338344`, 1], 
      Hue[0.633338, 0.2633744855967084, 0.9070814814814813], 
      Hue[0.633338, 0.2633744855967075, 0.9070814814814816], 
      Hue[0.633338, 0.5145600487556901, 0.8184632147989925], 
      Hue[0.633338, 0.2633744855967085, 0.9070814814814813], 
      Hue[0.0483667, 0.19296001828338244`, 1], 
      Hue[0.0483667, 0.1929600182833847, 1], 
      Hue[0.0483667, 0.19296001828338366`, 1], 
      Hue[0.633338, 0.26337448559670745`, 0.9070814814814816], 
      Hue[0.633338, 0.5145600487556894, 0.8184632147989928], 
      Hue[0.633338, 0.5145600487556904, 0.8184632147989924], 
      Hue[0.0483667, 0.6171415379132296, 1], 
      Hue[0.633338, 0.8780917782253801, 0.6902092206420859], 
      Hue[0.633338, 0.24879675908126475`, 0.9122245033961298], 
      Hue[0.0483667, 0.6171415379132273, 1], 
      Hue[0.633338, 0.8780917782253812, 0.6902092206420856], 
      Hue[0.633338, 0.8780917782253824, 0.6902092206420851], 
      Hue[0.633338, 0.6700248033250708, 0.763615249386915], 
      Hue[0.633338, 0.878091778225381, 0.6902092206420856], 
      Hue[0.633338, 0.6700248033250715, 0.7636152493869148], 
      Hue[0.633338, 0.42135122531220254`, 0.8513472877098549], 
      Hue[0.633338, 0.24879675908126586`, 0.9122245033961294], 
      Hue[0.0483667, 0.39707713523563476`, 1], 
      Hue[0.0483667, 0.39707713523563615`, 1], 
      Hue[0.633338, 0.6486539778965377, 0.7711548765981016], 
      Hue[0.633338, 0.4367442469546928, 0.8459166296743843], 
      Hue[0.0483667, 0.39707713523563576`, 1], 
      Hue[0.0483667, 0.397077135235637, 1], 
      Hue[0.633338, 0.05395924051993665, 0.9809631799445664], 
      Hue[0.633338, 0.0539592405199375, 0.980963179944566], 
      Hue[0.633338, 0.08643000818943221, 0.9695074931107683], 
      Hue[0.633338, 0.14857084793984648`, 0.9475842048468222], 
      Hue[0.633338, 0.14857084793984654`, 0.9475842048468222], 
      Hue[0.633338, 0.08643000818943226, 0.9695074931107683], 
      Hue[0.633338, 0.09250090931772609, 0.9673656791927062], 
      Hue[0.633338, 0.21962879777650537`, 0.9225149601444489], 
      Hue[0.633338, 0.3419917695473248, 0.8793453037037038], 
      Hue[0.633338, 0.34199176954732496`, 0.8793453037037038], 
      Hue[0.633338, 0.21962879777650549`, 0.9225149601444489], 
      Hue[0.633338, 0.0925009093177262, 0.9673656791927062], 
      Hue[0.633338, 0.0632362139917695, 0.9776902637037037], 
      Hue[0.633338, 0.06323621399176967, 0.9776902637037037], 
      Hue[0.0483667, 0.3286084438347811, 1], 
      Hue[0.0483667, 0.376917543782387, 1], 
      Hue[0.0483667, 0.37691754378238707`, 1], 
      Hue[0.0483667, 0.3286084438347812, 1], 
      Hue[0.0483667, 0.6465580246913576, 1], 
      Hue[0.0483667, 0.6465580246913581, 1], 
      Hue[0.0483667, 0.646558024691358, 1], 
      Hue[0.0483667, 0.6465580246913585, 1], 
      Hue[0.0483667, 0.3286084438347813, 1], 
      Hue[0.0483667, 0.3769175437823874, 1], 
      Hue[0.0483667, 0.3769175437823875, 1], 
      Hue[0.0483667, 0.32860844383478144`, 1], 
      Hue[0.633338, 0.06323621399176944, 0.9776902637037037], 
      Hue[0.633338, 0.06323621399176961, 0.9776902637037037], 
      Hue[0.633338, 0.09250090931772609, 0.9673656791927062], 
      Hue[0.633338, 0.2196287977765056, 0.9225149601444488], 
      Hue[0.633338, 0.34199176954732524`, 0.8793453037037037], 
      Hue[0.633338, 0.3419917695473254, 0.8793453037037036], 
      Hue[0.633338, 0.2196287977765057, 0.9225149601444488], 
      Hue[0.633338, 0.09250090931772617, 0.9673656791927062], 
      Hue[0.633338, 0.08643000818943222, 0.9695074931107683], 
      Hue[0.633338, 0.14857084793984657`, 0.9475842048468222], 
      Hue[0.633338, 0.14857084793984665`, 0.9475842048468222], 
      Hue[0.633338, 0.0864300081894323, 0.9695074931107683], 
      Hue[0.633338, 0.0192875903241785, 0.9931953381336298], 
      Hue[0.633338, 0.9347182247845733, 0.6702314102960025], 
      Hue[0.633338, 0.9347182247845739, 0.6702314102960023], 
      Hue[0.633338, 0.0013837972670724405`, 0.9995117963241769], 
      Hue[0.0483667, 0.005267242597573497, 1], 
      Hue[0.633338, 0.0013837972670724405`, 0.9995117963241769], 
      Hue[0.0483667, 0.005267242597573497, 1], 
      Hue[0.633338, 0.1055718703581951, 0.9627542441376288], 
      Hue[0.633338, 0.12450767781875334`, 0.9560736912655439], 
      Hue[0.633338, 0.12767486947068296`, 0.9549563060507431], 
      Hue[0.633338, 0.19624806907508996`, 0.9307636812303083], 
      Hue[0.633338, 0.036845155477634076`, 0.9870010291474907], 
      Hue[0.633338, 0.05927561314287068, 0.9790875636831953], 
      Hue[0.633338, 0.17951004944603902`, 0.9366688545554375], 
      Hue[0.633338, 0.19624806907509, 0.9307636812303083], 
      Hue[0.633338, 0.2539070299754059, 0.9104215998246769], 
      Hue[0.633338, 0.17661127486579237`, 0.9376915422273484], 
      Hue[0.633338, 0.09144208524197023, 0.967739232326633], 
      Hue[0.633338, 0.01646090534979422, 0.9941925925925926], 
      Hue[0.633338, 0.04800432881939992, 0.9830640727925157], 
      Hue[0.633338, 0.15081695765456438`, 0.9467917773394697], 
      Hue[0.633338, 0.271649646903419, 0.9041620045724738], 
      Hue[0.633338, 0.362139917695473, 0.8722370370370371], 
      Hue[0.633338, 0.48666083500918283`, 0.8283060574087603], 
      Hue[0.633338, 0.2888657416563749, 0.8980881663436309], 
      Hue[0.633338, 0.4866608350091833, 0.8283060574087602], 
      Hue[0.633338, 0.0854056002910852, 0.9698689042173051], 
      Hue[0.0483667, 0.10428446464482505`, 1], 
      Hue[0.0483667, 0.0013005928978338827`, 1], 
      Hue[0.0483667, 0.2279436043538607, 1], 
      Hue[0.633338, 0.17177703845692455`, 0.939397060832397], 
      Hue[0.633338, 0.016314020412110185`, 0.9942444135986075], 
      Hue[0.633338, 0.6381575818704425, 0.7748580051161079], 
      Hue[0.633338, 0.6381575818704427, 0.7748580051161078], 
      Hue[0.0483667, 0.10428446464482477`, 1], 
      Hue[0.633338, 0.016314020412110365`, 0.9942444135986075], 
      Hue[0.0483667, 0.17487001656931633`, 1], 
      Hue[0.0483667, 0.34653254077122375`, 1], 
      Hue[0.0483667, 0.3465325407712235, 1], 
      Hue[0.0483667, 0.360533674351151, 1], 
      Hue[0.0483667, 0.5289171929732033, 1], 
      Hue[0.0483667, 0.4476759130734939, 1], 
      Hue[0.0483667, 0.4476759130734937, 1], 
      Hue[0.0483667, 0.5372138213163852, 1], 
      Hue[0.0483667, 0.44767591307349386`, 1], 
      Hue[0.0483667, 0.7671094517941359, 1], 
      Hue[0.0483667, 0.6913580246913578, 1], 
      Hue[0.0483667, 0.6913580246913583, 1], 
      Hue[0.0483667, 0.4476759130734941, 1], 
      Hue[0.0483667, 0.39854756717501827`, 1], 
      Hue[0.0483667, 0.5289171929732036, 1], 
      Hue[0.0483667, 0.7671094517941371, 1], 
      Hue[0.0483667, 0.5372138213163857, 1], 
      Hue[0.0483667, 0.3605336743511511, 1], 
      Hue[0.0483667, 0.3465325407712245, 1], 
      Hue[0.633338, 0.016314020412109997`, 0.9942444135986076], 
      Hue[0.0483667, 0.3465325407712242, 1], 
      Hue[0.633338, 0.01631402041211018, 0.9942444135986075], 
      Hue[0.0483667, 0.10428446464482498`, 1], 
      Hue[0.0483667, 0.1748700165693165, 1], 
      Hue[0.0483667, 0.10428446464482527`, 1], 
      Hue[0.0483667, 0.00130059289783411, 1], 
      Hue[0.633338, 0.08540560029108499, 0.9698689042173052], 
      Hue[0.633338, 0.4866608350091835, 0.8283060574087601], 
      Hue[0.633338, 0.4866608350091838, 0.82830605740876], 
      Hue[0.633338, 0.171777038456925, 0.9393970608323968], 
      Hue[0.633338, 0.2716496469034195, 0.9041620045724736], 
      Hue[0.0483667, 0.0013005928978337149`, 1], 
      Hue[0.633338, 0.09144208524197023, 0.967739232326633], 
      Hue[0.633338, 0.28886574165637496`, 0.8980881663436309], 
      Hue[0.633338, 0.3621399176954735, 0.8722370370370369], 
      Hue[0.633338, 0.19624806907509013`, 0.9307636812303082], 
      Hue[0.633338, 0.1508169576545646, 0.9467917773394696], 
      Hue[0.633338, 0.17951004944603924`, 0.9366688545554374], 
      Hue[0.633338, 0.016460905349794257`, 0.9941925925925926], 
      Hue[0.633338, 0.1962480690750901, 0.9307636812303082], 
      Hue[0.633338, 0.20333646318845058`, 0.9282628957871146], 
      Hue[0.633338, 0.12767486947068307`, 0.954956306050743], 
      Hue[0.633338, 0.10557187035819522`, 0.9627542441376287], 
      Hue[0.633338, 0.036845155477634145`, 0.9870010291474907], 
      Hue[0.633338, 0.0013837972670724405`, 0.9995117963241769], 
      Hue[0.0483667, 0.005267242597573497, 1], 
      Hue[0.633338, 0.0013837972670724405`, 0.9995117963241769], 
      Hue[0.633338, 0.004129033852350716, 0.9985432768568907], 
      Hue[0.633338, 0.6184056255678612, 0.7818264952996585], 
      Hue[0.633338, 0.171777038456925, 0.9393970608323968], 
      Hue[0.633338, 0.2596342562154532, 0.9084010344071881], 
      Hue[0.0483667, 0.42864457000942835`, 1], 
      Hue[0.0483667, 0.7055942727737604, 1], 
      Hue[0.633338, 0.03970876859765718, 0.9859907464387465], 
      Hue[0.633338, 0.2716496469034191, 0.9041620045724738], 
      Hue[0.633338, 0.5345411157376974, 0.8114138943677404], 
      Hue[0.633338, 0.2322069859170977, 0.9180773753684479], 
      Hue[0.633338, 0.23220698591709732`, 0.918077375368448], 
      Hue[0.633338, 0.38021015531909763`, 0.8658618572034223], 
      Hue[0.633338, 0.2596342562154525, 0.9084010344071883], 
      Hue[0.633338, 0.5345411157376964, 0.8114138943677407], 
      Hue[0.633338, 0.4367442469546915, 0.8459166296743849], 
      Hue[0.633338, 0.33597008021096386`, 0.8814697557015719], 
      Hue[0.633338, 0.5345411157376968, 0.8114138943677406], 
      Hue[0.633338, 0.2716496469034194, 0.9041620045724736], 
      Hue[0.633338, 0.3802101553190981, 0.8658618572034222], 
      Hue[0.633338, 0.2322069859170976, 0.9180773753684479], 
      Hue[0.633338, 0.4406402633744858, 0.8445421150814814], 
      Hue[0.633338, 0.3756871862812565, 0.8674575606799727], 
      Hue[0.633338, 0.039708768597657415`, 0.9859907464387465], 
      Hue[0.0483667, 0.4286445700094287, 1], 
      Hue[0.0483667, 0.018383689165582216`, 1], 
      Hue[0.0483667, 0.7055942727737595, 1], 
      Hue[0.0483667, 0.6957222913231101, 1], 
      Hue[0.633338, 0.039708768597657776`, 0.9859907464387463], 
      Hue[0.0483667, 0.7671094517941363, 1], 
      Hue[0.0483667, 0.7055942727737596, 1], 
      Hue[0.0483667, 0.7671094517941367, 1], 
      Hue[0.0483667, 0.7055942727737602, 1], 
      Hue[0.0483667, 0.6957222913231108, 1], 
      Hue[0.0483667, 0.42864457000942957`, 1], 
      Hue[0.0483667, 0.4286445700094293, 1], 
      Hue[0.633338, 0.03970876859765753, 0.9859907464387464], 
      Hue[0.633338, 0.17177703845692455`, 0.939397060832397], 
      Hue[0.633338, 0.23220698591709724`, 0.9180773753684481], 
      Hue[0.0483667, 0.018383689165582084`, 1], 
      Hue[0.633338, 0.2596342562154533, 0.9084010344071881], 
      Hue[0.633338, 0.3802101553190983, 0.8658618572034221], 
      Hue[0.633338, 0.5345411157376969, 0.8114138943677405], 
      Hue[0.633338, 0.6577046797754001, 0.7679617889752388], 
      Hue[0.633338, 0.6577046797753989, 0.7679617889752393], 
      Hue[0.633338, 0.2663137027787524, 0.9060445256596561], 
      Hue[0.633338, 0.6577046797753996, 0.767961788975239], 
      Hue[0.0483667, 0.3506125432098763, 1], 
      Hue[0.0483667, 0.018383689165581137`, 1], 
      Hue[0.0483667, 0.35061254320987584`, 1], 
      Hue[0.0483667, 0.8948079137096425, 1], 
      Hue[0.0483667, 0.8948079137096427, 1], 
      Hue[0.0483667, 0.9469320969500689, 1], 
      Hue[0.0483667, 0.9469320969500693, 1], 
      Hue[0.0483667, 0.8948079137096427, 1], 
      Hue[0.0483667, 0.9469320969500689, 1], 
      Hue[0.0483667, 0.894807913709643, 1], 
      Hue[0.0483667, 0.3506125432098772, 1], 
      Hue[0.0483667, 0.35061254320987684`, 1], 
      Hue[0.0483667, 0.018383689165583163`, 1], 
      Hue[0.633338, 0.2596342562154526, 0.9084010344071883], 
      Hue[0.633338, 0.6577046797753995, 0.767961788975239], 
      Hue[0.633338, 0.638157581870443, 0.7748580051161077], 
      Hue[0.633338, 0.6381575818704432, 0.7748580051161076], 
      Hue[0.633338, 0.4406402633744853, 0.8445421150814816], 
      Hue[0.633338, 0.3756871862812557, 0.867457560679973], 
      Hue[0.633338, 0.1298721472754072, 0.9541811064412363], 
      Hue[0.633338, 0.17690860600724048`, 0.9375866438006456], 
      Hue[0.633338, 0.26631370277875327`, 0.9060445256596559], 
      Hue[0.633338, 0.3445062327509408, 0.8784582010854681], 
      Hue[0.633338, 0.648653977896537, 0.7711548765981018], 
      Hue[0.633338, 0.26631370277875316`, 0.9060445256596559], 
      Hue[0.633338, 0.3445062327509417, 0.8784582010854678], 
      Hue[0.633338, 0.12987214727540647`, 0.9541811064412365], 
      Hue[0.633338, 0.2663137027787524, 0.9060445256596561], 
      Hue[0.633338, 0.6700248033250724, 0.7636152493869145], 
      Hue[0.0483667, 0.9049770491211928, 1], 
      Hue[0.0483667, 0.9879618230197679, 1], 
      Hue[0.0483667, 0.695722291323111, 1], 
      Hue[0.0483667, 0.5711826440757638, 1], 
      Hue[0.633338, 0.6719073253966501, 0.7629510956000618], 
      Hue[0.0483667, 0.5711826440757629, 1], 
      Hue[0.0483667, 0.9879618230197679, 1], 
      Hue[0.633338, 0.6700248033250712, 0.7636152493869148], 
      Hue[0.633338, 0.6719073253966505, 0.7629510956000617], 
      Hue[0.633338, 0.6719073253966512, 0.7629510956000615], 
      Hue[0.633338, 0.6719073253966507, 0.7629510956000616], 
      Hue[0.633338, 0.5335483858643788, 0.8117641294670471], 
      Hue[0.0483667, 0.37732314052072635`, 1], 
      Hue[0.0483667, 0.17194563933302523`, 1], 
      Hue[0.0483667, 0.9879618230197679, 1], 
      Hue[0.0483667, 0.5711826440757635, 1], 
      Hue[0.0483667, 0.1719456393330266, 1], 
      Hue[0.0483667, 0.3773231405207276, 1], 
      Hue[0.633338, 0.6184056255678618, 0.7818264952996583], 
      Hue[0.633338, 0.004129033852350716, 0.9985432768568907], 
      Hue[0.633338, 0.004129033852350716, 0.9985432768568907], 
      Hue[0.633338, 0.15639877152365028`, 0.9448225134064562], 
      Hue[0.633338, 0.20333646318845047`, 0.9282628957871146], 
      Hue[0.633338, 0.6527157654964646, 0.7697218779328473], 
      Hue[0.0483667, 0.0013005928978334876`, 1], 
      Hue[0.0483667, 0.15457581892796293`, 1], 
      Hue[0.0483667, 0.39854756717501816`, 1], 
      Hue[0.0483667, 0.46543642662120527`, 1], 
      Hue[0.0483667, 0.92155885594403, 1], 
      Hue[0.0483667, 0.8189218765432102, 1], 
      Hue[0.0483667, 0.9469320969500695, 1], 
      Hue[0.0483667, 0.46543642662120555`, 1], 
      Hue[0.633338, 0.19985766397398813`, 0.929490216149977], 
      Hue[0.0483667, 0.22794360435386085`, 1], 
      Hue[0.0483667, 0.15457581892796315`, 1], 
      Hue[0.633338, 0.2539070299754062, 0.9104215998246767], 
      Hue[0.633338, 0.04800432881939996, 0.9830640727925157], 
      Hue[0.633338, 0.17661127486579237`, 0.9376915422273484], 
      Hue[0.633338, 0.1563987715236504, 0.9448225134064562], 
      Hue[0.633338, 0.12450767781875349`, 0.9560736912655438], 
      Hue[0.633338, 0.059275613142870734`, 0.9790875636831952], 
      Hue[0.633338, 0.004129033852350716, 0.9985432768568907], 
      Hue[0.0483667, 0.005267242597573497, 1], 
      Hue[0.633338, 0.6485668852035211, 0.7711856029001978], 
      Hue[0.633338, 0.3802101553190978, 0.8658618572034222], 
      Hue[0.633338, 0.41417282788624366`, 0.8538798263217332], 
      Hue[0.0483667, 0.7566722314858726, 1], 
      Hue[0.0483667, 0.6957222913231099, 1], 
      Hue[0.0483667, 0.7566722314858724, 1], 
      Hue[0.0483667, 0.9049770491211927, 1], 
      Hue[0.0483667, 0.9049770491211936, 1], 
      Hue[0.0483667, 0.9049770491211937, 1], 
      Hue[0.0483667, 0.7566722314858734, 1], 
      Hue[0.633338, 0.37568718628125597`, 0.8674575606799728], 
      Hue[0.633338, 0.24734139621857382`, 0.9127379554140872], 
      Hue[0.633338, 0.44064026337448553`, 0.8445421150814815], 
      Hue[0.633338, 0.32582679826036903`, 0.8850483055737418], 
      Hue[0.633338, 0.4729146622992875, 0.8331557071408113], 
      Hue[0.633338, 0.4141728278862431, 0.8538798263217334], 
      Hue[0.633338, 0.37568718628125675`, 0.8674575606799726], 
      Hue[0.633338, 0.4406402633744862, 0.8445421150814812], 
      Hue[0.633338, 0.4141728278862439, 0.8538798263217331], 
      Hue[0.0483667, 0.9215588559440298, 1], 
      Hue[0.0483667, 0.9560953459871327, 1], 
      Hue[0.0483667, 0.9879618230197679, 1], 
      Hue[0.0483667, 0.9987903563101217, 1], 
      Hue[0.0483667, 0.9480640253419953, 1], 
      Hue[0.633338, 0.34450623275094083`, 0.878458201085468], 
      Hue[0.633338, 0.3359499223945205, 0.8814768673792132], 
      Hue[0.633338, 0.6527157654964653, 0.7697218779328471], 
      Hue[0.633338, 0.4141728278862429, 0.8538798263217335], 
      Hue[0.633338, 0.3445062327509419, 0.8784582010854677], 
      Hue[0.633338, 0.6485668852035222, 0.7711856029001973], 
      Hue[0.633338, 0.17690860600723957`, 0.9375866438006459], 
      Hue[0.633338, 0.6485668852035229, 0.7711856029001971], 
      Hue[0.0483667, 0.7566722314858736, 1], 
      Hue[0.0483667, 0.292214413265065, 1], 
      Hue[0.0483667, 0.5711826440757624, 1], 
      Hue[0.0483667, 0.5047898970038364, 1], 
      Hue[0.0483667, 0.5047898970038377, 1], 
      Hue[0.0483667, 0.29221441326506625`, 1], 
      Hue[0.633338, 0.5335483858643779, 0.8117641294670475], 
      Hue[0.633338, 0.12987214727540733`, 0.9541811064412363], 
      Hue[0.633338, 0.19985766397398824`, 0.929490216149977], 
      Hue[0.0483667, 0.7502071852706227, 1], 
      Hue[0.0483667, 0.8240395766356925, 1], 
      Hue[0.0483667, 0.8776924260204196, 1], 
      Hue[0.0483667, 0.8871233043743336, 1], 
      Hue[0.633338, 0.3955119495954186, 0.8604633841827363], 
      Hue[0.633338, 0.19985766397398735`, 0.9294902161499773], 
      Hue[0.633338, 0.35085890001675707`, 0.8762169800740881], 
      Hue[0.633338, 0.09638197529609766, 0.9659964391155368], 
      Hue[0.633338, 0.16726315428918176`, 0.9409895591667766], 
      Hue[0.633338, 0.2094586591685551, 0.9261029850453337], 
      Hue[0.633338, 0.26634790791817375`, 0.9060324580864683], 
      Hue[0.0483667, 0.8189218765432097, 1], 
      Hue[0.633338, 0.24734139621857423`, 0.912737955414087], 
      Hue[0.0483667, 0.8325226688341258, 1], 
      Hue[0.0483667, 0.6402982538992303, 1], 
      Hue[0.0483667, 0.7069504823968166, 1], 
      Hue[0.0483667, 0.7659296656633016, 1], 
      Hue[0.633338, 0.2098553077235289, 0.925963047435139], 
      Hue[0.633338, 0.11891999614336221`, 0.9580450253606219], 
      Hue[0.633338, 0.1108896543780164, 0.9608781299354359], 
      Hue[0.633338, 0.13537635571139867`, 0.9522392217050185], 
      Hue[0.0483667, 0.6805781674137148, 1], 
      Hue[0.0483667, 0.7022953904594931, 1], 
      Hue[0.633338, 0.17062588113639188`, 0.939803189135081], 
      Hue[0.633338, 0.14220344153081188`, 0.9498306258279295], 
      Hue[0.633338, 0.253907029975406, 0.9104215998246767], 
      Hue[0.0483667, 0.012726729035840982`, 1], 
      Hue[0.633338, 0.08540560029108507, 0.9698689042173052], 
      Hue[0.633338, 0.2888657416563746, 0.8980881663436311], 
      Hue[0.0483667, 0.2279436043538605, 1], 
      Hue[0.0483667, 0.22794360435386105`, 1], 
      Hue[0.633338, 0.08540560029108514, 0.9698689042173052], 
      Hue[0.0483667, 0.012726729035840862`, 1], 
      Hue[0.633338, 0.25390702997540604`, 0.9104215998246767], 
      Hue[0.633338, 0.2888657416563753, 0.8980881663436308], 
      Hue[0.633338, 0.28940682395412476`, 0.8978972725089848], 
      Hue[0.0483667, 0.6402982538992302, 1], 
      Hue[0.633338, 0.11891999614336196`, 0.9580450253606219], 
      Hue[0.633338, 0.16983437578863864`, 0.9400824322217682], 
      Hue[0.633338, 0.6485668852035216, 0.7711856029001976], 
      Hue[0.633338, 0.06322240327260802, 0.9776951361254239], 
      Hue[0.633338, 0.16983437578863828`, 0.9400824322217685], 
      Hue[0.633338, 0.2263082139917693, 0.9201584621037038], 
      Hue[0.633338, 0.19986401499368034`, 0.9294879755102295], 
      Hue[0.633338, 0.3731000003636732, 0.8683703198716961], 
      Hue[0.633338, 0.2752839608384612, 0.9028798186161909], 
      Hue[0.633338, 0.28940682395412487`, 0.8978972725089848], 
      Hue[0.633338, 0.11891999614336193`, 0.9580450253606219], 
      Hue[0.0483667, 0.3073520889778192, 1], 
      Hue[0.0483667, 0.46497115317748006`, 1], 
      Hue[0.0483667, 0.4649711531774806, 1], 
      Hue[0.0483667, 0.3073520889778196, 1], 
      Hue[0.633338, 0.11891999614336214`, 0.9580450253606219], 
      Hue[0.633338, 0.289406823954125, 0.8978972725089847], 
      Hue[0.633338, 0.2752839608384613, 0.9028798186161908], 
      Hue[0.633338, 0.3731000003636741, 0.8683703198716958], 
      Hue[0.633338, 0.2894068239541253, 0.8978972725089845], 
      Hue[0.633338, 0.19986401499368073`, 0.9294879755102294], 
      Hue[0.633338, 0.2263082139917697, 0.9201584621037037], 
      Hue[0.633338, 0.06322240327260807, 0.9776951361254239], 
      Hue[0.633338, 0.5967433744855961, 0.7894689374814816], 
      Hue[0.633338, 0.5967433744855967, 0.7894689374814815], 
      Hue[0.633338, 0.07335026399103582, 0.9741220268639625], 
      Hue[0.633338, 0.5967433744855968, 0.7894689374814815], 
      Hue[0.633338, 0.5967433744855972, 0.7894689374814813], 
      Hue[0.633338, 0.33052986150644614`, 0.8833890648605258], 
      Hue[0.633338, 0.32582679826036953`, 0.8850483055737416], 
      Hue[0.633338, 0.32582679826036876`, 0.8850483055737419], 
      Hue[0.633338, 0.3305298615064458, 0.8833890648605259], 
      Hue[0.633338, 0.09691370797351069, 0.9658088438269454], 
      Hue[0.633338, 0.32582679826036975`, 0.8850483055737416], 
      Hue[0.633338, 0.0011899009295814503`, 0.9995802029520436], 
      Hue[0.633338, 0.0011899009295814503`, 0.9995802029520436], 
      Hue[0.633338, 0.33052986150644537`, 0.883389064860526], 
      Hue[0.633338, 0.30421413486301513`, 0.8926732532203283], 
      Hue[0.633338, 0.30421413486301513`, 0.8926732532203283], 
      Hue[0.633338, 0.016460905349794323`, 0.9941925925925925], 
      Hue[0.0483667, 0.012726729035840647`, 1], 
      Hue[0.0483667, 0.00920714610766143, 1], 
      Hue[0.633338, 0.04319118502272351, 0.9847621499239831], 
      Hue[0.633338, 0.04319118502272365, 0.9847621499239831], 
      Hue[0.0483667, 0.009207146107661004, 1], 
      Hue[0.0483667, 0.2802441079802693, 1], 
      Hue[0.0483667, 0.17147592806185658`, 1], 
      Hue[0.0483667, 0.1714759280618561, 1], 
      Hue[0.0483667, 0.280244107980269, 1], 
      Hue[0.0483667, 0.750207185270622, 1], 
      Hue[0.0483667, 0.7502071852706225, 1], 
      Hue[0.0483667, 0.6155030170484266, 1], 
      Hue[0.633338, 0.01646090534979415, 0.9941925925925926], 
      Hue[0.633338, 0.3305298615064457, 0.8833890648605259], 
      Hue[0.633338, 0.0011899009295814503`, 0.9995802029520436], 
      Hue[0.633338, 0.0011899009295814503`, 0.9995802029520436], 
      Hue[0.633338, 0.15081695765456454`, 0.9467917773394696], 
      Hue[0.633338, 0.1998640149936806, 0.9294879755102294], 
      Hue[0.0483667, 0.528917192973203, 1], 
      Hue[0.0483667, 0.5703547154521281, 1], 
      Hue[0.0483667, 0.5289171929732039, 1], 
      Hue[0.633338, 0.2473413962185738, 0.9127379554140872], 
      Hue[0.633338, 0.30285534298192, 0.8931526349959786], 
      Hue[0.633338, 0.8115657183613483, 0.7136796145621163], 
      Hue[0.633338, 0.8929106884662439, 0.6849811091091091], 
      Hue[0.0483667, 0.8189218765432094, 1], 
      Hue[0.0483667, 0.837359974406835, 1], 
      Hue[0.0483667, 0.8373599744068363, 1], 
      Hue[0.0483667, 0.8189218765432101, 1], 
      Hue[0.0483667, 0.7759041744809277, 1], 
      Hue[0.0483667, 0.9030913534194444, 1], 
      Hue[0.0483667, 0.8373599744068362, 1], 
      Hue[0.633338, 0.24734139621857432`, 0.912737955414087], 
      Hue[0.633338, 0.3028553429819206, 0.8931526349959784], 
      Hue[0.633338, 0.8115657183613487, 0.7136796145621161], 
      Hue[0.633338, 0.8929106884662443, 0.6849811091091089], 
      Hue[0.633338, 0.8115657183613492, 0.713679614562116], 
      Hue[0.0483667, 0.37732314052072696`, 1], 
      Hue[0.0483667, 0.9480640253419953, 1], 
      Hue[0.0483667, 0.9480640253419953, 1], 
      Hue[0.0483667, 0.37732314052072813`, 1], 
      Hue[0.0483667, 0.6320987654320991, 1], 
      Hue[0.0483667, 0.6110806451148681, 1], 
      Hue[0.0483667, 0.9560953459871329, 1], 
      Hue[0.0483667, 0.9560953459871334, 1], 
      Hue[0.633338, 0.811565718361348, 0.7136796145621165], 
      Hue[0.633338, 0.8929106884662434, 0.6849811091091094], 
      Hue[0.0483667, 0.17194563933302706`, 1], 
      Hue[0.0483667, 0.292214413265066, 1], 
      Hue[0.0483667, 0.5047898970038373, 1], 
      Hue[0.0483667, 0.5047898970038385, 1], 
      Hue[0.0483667, 0.17194563933302837`, 1], 
      Hue[0.633338, 0.09144208524197014, 0.967739232326633], 
      Hue[0.633338, 0.1795100494460391, 0.9366688545554374], 
      Hue[0.633338, 0.12223947325102892`, 0.956873913837037], 
      Hue[0.0483667, 0.5486824150958368, 1], 
      Hue[0.0483667, 0.5372138213163854, 1], 
      Hue[0.0483667, 0.5486824150958372, 1], 
      Hue[0.0483667, 0.5372138213163854, 1], 
      Hue[0.0483667, 0.5486824150958372, 1], 
      Hue[0.0483667, 0.4649711531774808, 1], 
      Hue[0.633338, 0.15081695765456443`, 0.9467917773394696], 
      Hue[0.633338, 0.12223947325102874`, 0.956873913837037], 
      Hue[0.633338, 0.1998640149936804, 0.9294879755102295], 
      Hue[0.633338, 0.17951004944603913`, 0.9366688545554374], 
      Hue[0.633338, 0.0914420852419703, 0.9677392323266328], 
      Hue[0.0483667, 0.0008710045187619966, 1], 
      Hue[0.633338, 0.42511740498668577`, 0.8500185795206973], 
      Hue[0.633338, 0.4046801023052222, 0.8572288599067176], 
      Hue[0.633338, 0.3731000003636734, 0.868370319871696], 
      Hue[0.633338, 0.42511740498668593`, 0.8500185795206971], 
      Hue[0.633338, 0.09638197529609738, 0.9659964391155369], 
      Hue[0.633338, 0.005060425367802613, 0.9982146819302392], 
      Hue[0.0483667, 0.05842023576960438, 1], 
      Hue[0.633338, 0.0050604253678027565`, 0.9982146819302392], 
      Hue[0.633338, 0.04352862099030491, 0.9846431025146204], 
      Hue[0.0483667, 0.05842023576960383, 1], 
      Hue[0.0483667, 0.6402982538992297, 1], 
      Hue[0.0483667, 0.7069504823968161, 1], 
      Hue[0.0483667, 0.6155030170484261, 1], 
      Hue[0.0483667, 0.6155030170484261, 1], 
      Hue[0.0483667, 0.7502071852706229, 1], 
      Hue[0.0483667, 0.6402982538992308, 1], 
      Hue[0.0483667, 0.7069504823968171, 1], 
      Hue[0.0483667, 0.2802441079802698, 1], 
      Hue[0.0483667, 0.17147592806185719`, 1], 
      Hue[0.0483667, 0.058420235769605124`, 1], 
      Hue[0.633338, 0.005060425367802495, 0.9982146819302393], 
      Hue[0.633338, 0.09638197529609728, 0.9659964391155369], 
      Hue[0.0483667, 0.17147592806185682`, 1], 
      Hue[0.0483667, 0.2802441079802696, 1], 
      Hue[0.0483667, 0.05842023576960458, 1], 
      Hue[0.633338, 0.0963819752960976, 0.9659964391155368], 
      Hue[0.633338, 0.005060425367802636, 0.9982146819302392], 
      Hue[0.633338, 0.04319118502272346, 0.9847621499239831], 
      Hue[0.633338, 0.37310000036367386`, 0.8683703198716959], 
      Hue[0.633338, 0.4251174049866864, 0.850018579520697], 
      Hue[0.633338, 0.42511740498668643`, 0.850018579520697], 
      Hue[0.633338, 0.40468010230522294`, 0.8572288599067174], 
      Hue[0.633338, 0.04319118502272357, 0.9847621499239831], 
      Hue[0.0483667, 0.009207146107661207, 1], 
      Hue[0.633338, 0.3042141348630155, 0.8926732532203281], 
      Hue[0.633338, 0.3042141348630155, 0.8926732532203281], 
      Hue[0.0483667, 0.5703547154521275, 1], 
      Hue[0.633338, 0.3028822611857305, 0.8931431382536743], 
      Hue[0.633338, 0.30288226118573097`, 0.8931431382536741], 
      Hue[0.633338, 0.3201137653103465, 0.8870638635985097], 
      Hue[0.0483667, 0.5703547154521276, 1], 
      Hue[0.0483667, 0.4751342065435123, 1], 
      Hue[0.0483667, 0.6805781674137146, 1], 
      Hue[0.0483667, 0.6378429850051754, 1], 
      Hue[0.0483667, 0.7069504823968167, 1], 
      Hue[0.0483667, 0.6805781674137151, 1], 
      Hue[0.0483667, 0.5703547154521282, 1], 
      Hue[0.0483667, 0.47513420654351324`, 1], 
      Hue[0.0483667, 0.47513420654351296`, 1], 
      Hue[0.633338, 0.07335026399103566, 0.9741220268639627], 
      Hue[0.633338, 0.30288226118573114`, 0.8931431382536741], 
      Hue[0.0483667, 0.19730980212606405`, 1], 
      Hue[0.0483667, 0.1973098021260634, 1], 
      Hue[0.0483667, 0.824039576635692, 1], 
      Hue[0.0483667, 0.8240395766356924, 1], 
      Hue[0.0483667, 0.8325226688341257, 1], 
      Hue[0.0483667, 0.887123304374333, 1], 
      Hue[0.0483667, 0.9247666384559872, 1], 
      Hue[0.0483667, 0.8871233043743333, 1], 
      Hue[0.0483667, 0.9480640253419953, 1], 
      Hue[0.0483667, 0.887123304374333, 1], 
      Hue[0.0483667, 0.8240395766356929, 1], 
      Hue[0.0483667, 0.9247666384559878, 1], 
      Hue[0.0483667, 0.19730980212606514`, 1], 
      Hue[0.0483667, 0.19730980212606444`, 1], 
      Hue[0.0483667, 0.8373599744068351, 1], 
      Hue[0.0483667, 0.9030913534194437, 1], 
      Hue[0.0483667, 0.9741552341245958, 1], 
      Hue[0.0483667, 0.9987903563101215, 1], 
      Hue[0.0483667, 0.9706384323007555, 1], 
      Hue[0.0483667, 0.9741552341245958, 1], 
      Hue[0.0483667, 0.9706384323007561, 1], 
      Hue[0.0483667, 0.9741552341245959, 1], 
      Hue[0.0483667, 0.9706384323007557, 1], 
      Hue[0.633338, 0.0025002621622714862`, 0.9991179075091506], 
      Hue[0.0483667, 0.9559518366102729, 1], 
      Hue[0.633338, 0.0025002621622714862`, 0.9991179075091506], 
      Hue[0.0483667, 0.0008710045187619966, 1], 
      Hue[0.633338, 0.3028822611857306, 0.8931431382536742], 
      Hue[0.633338, 0.32011376531034635`, 0.8870638635985097], 
      Hue[0.0483667, 0.9560953459871334, 1], 
      Hue[0.0483667, 0.8776924260204192, 1], 
      Hue[0.0483667, 0.8776924260204192, 1], 
      Hue[0.0483667, 0.9283066848986956, 1], 
      Hue[0.0483667, 0.9741552341245959, 1], 
      Hue[0.0483667, 0.9904959199447454, 1], 
      Hue[0.0483667, 0.9960734056534313, 1], 
      Hue[0.0483667, 0.9904959199447456, 1], 
      Hue[0.0483667, 0.9686662159404017, 1], 
      Hue[0.0483667, 0.9186168347879287, 1], 
      Hue[0.0483667, 0.974572260915457, 1], 
      Hue[0.0483667, 0.594674833469202, 1], 
      Hue[0.0483667, 0.5571264958652343, 1], 
      Hue[0.633338, 0.0025002621622714862`, 0.9991179075091506], 
      Hue[0.0483667, 0.0008710045187619966, 1], 
      Hue[0.633338, 0.30807141187827036`, 0.8913124058893462], 
      Hue[0.633338, 0.016998858753536156`, 0.9940028026317524], 
      Hue[0.633338, 0.016998858753536284`, 0.9940028026317524], 
      Hue[0.0483667, 0.24061761207277407`, 1], 
      Hue[0.0483667, 0.24061761207277382`, 1], 
      Hue[0.0483667, 0.7652116479305067, 1], 
      Hue[0.0483667, 0.8776924260204196, 1], 
      Hue[0.0483667, 0.8835041732913503, 1], 
      Hue[0.0483667, 0.6155030170484266, 1], 
      Hue[0.0483667, 0.6244277396738305, 1], 
      Hue[0.0483667, 0.012726729035841197`, 1], 
      Hue[0.0483667, 0.0008710045187619966, 1], 
      Hue[0.633338, 0.0025002621622714862`, 0.9991179075091506], 
      Hue[0.0483667, 0.4649711531774802, 1], 
      Hue[0.0483667, 0.6805781674137154, 1], 
      Hue[0.0483667, 0.6378429850051761, 1], 
      Hue[0.0483667, 0.5486824150958374, 1], 
      Hue[0.633338, 0.07335026399103531, 0.9741220268639628], 
      Hue[0.633338, 0.09691370797350998, 0.9658088438269457], 
      Hue[0.0483667, 0.7759041744809271, 1], 
      Hue[0.0483667, 0.9030913534194438, 1], 
      Hue[0.0483667, 0.8765732013268759, 1], 
      Hue[0.0483667, 0.9030913534194444, 1], 
      Hue[0.0483667, 0.8765732013268768, 1], 
      Hue[0.0483667, 0.8765732013268768, 1], 
      Hue[0.633338, 0.892910688466245, 0.6849811091091087], 
      Hue[0.0483667, 0.43608916235388834`, 1], 
      Hue[0.0483667, 0.6320987654320984, 1], 
      Hue[0.0483667, 0.6110806451148675, 1], 
      Hue[0.0483667, 0.6320987654320982, 1], 
      Hue[0.0483667, 0.6110806451148671, 1], 
      Hue[0.0483667, 0.9559518366102727, 1], 
      Hue[0.0483667, 0.983006840720502, 1], 
      Hue[0.0483667, 0.9960734056534314, 1], 
      Hue[0.0483667, 0.9930037144551515, 1], 
      Hue[0.0483667, 0.6320987654320992, 1], 
      Hue[0.0483667, 0.6110806451148684, 1], 
      Hue[0.0483667, 0.43608916235388945`, 1], 
      Hue[0.0483667, 0.9281903429137237, 1], 
      Hue[0.0483667, 0.29221441326506725`, 1], 
      Hue[0.633338, 0.11632401241336071`, 0.9589608884205664], 
      Hue[0.633338, 0.1698343757886385, 0.9400824322217683], 
      Hue[0.633338, 0.1698343757886384, 0.9400824322217683], 
      Hue[0.633338, 0.11632401241336082`, 0.9589608884205663], 
      Hue[0.633338, 0.40468010230522233`, 0.8572288599067175], 
      Hue[0.633338, 0.043528620990304745`, 0.9846431025146205], 
      Hue[0.0483667, 0.6244277396738299, 1], 
      Hue[0.0483667, 0.7652116479305074, 1], 
      Hue[0.0483667, 0.24061761207277482`, 1], 
      Hue[0.633338, 0.04352862099030464, 0.9846431025146205], 
      Hue[0.0483667, 0.24061761207277443`, 1], 
      Hue[0.633338, 0.04352862099030481, 0.9846431025146205], 
      Hue[0.0483667, 0.009207146107661634, 1], 
      Hue[0.633338, 0.016998858753536086`, 0.9940028026317524], 
      Hue[0.633338, 0.4046801023052227, 0.8572288599067175], 
      Hue[0.633338, 0.016998858753536218`, 0.9940028026317524], 
      Hue[0.633338, 0.30807141187827075`, 0.891312405889346], 
      Hue[0.0483667, 0.4751342065435121, 1], 
      Hue[0.633338, 0.3201137653103461, 0.8870638635985099], 
      Hue[0.0483667, 0.6378429850051753, 1], 
      Hue[0.0483667, 0.6378429850051761, 1], 
      Hue[0.633338, 0.09691370797351052, 0.9658088438269454], 
      Hue[0.633338, 0.32011376531034685`, 0.8870638635985096], 
      Hue[0.0483667, 0.29293452918481633`, 1], 
      Hue[0.0483667, 0.32164902160638414`, 1], 
      Hue[0.0483667, 0.26900309509544384`, 1], 
      Hue[0.0483667, 0.29293452918481605`, 1], 
      Hue[0.0483667, 0.3216490216063838, 1], 
      Hue[0.0483667, 0.2690030950954434, 1], 
      Hue[0.0483667, 0.8325226688341253, 1], 
      Hue[0.0483667, 0.9247666384559876, 1], 
      Hue[0.0483667, 0.9247666384559874, 1], 
      Hue[0.0483667, 0.8325226688341262, 1], 
      Hue[0.0483667, 0.9147998829594466, 1], 
      Hue[0.0483667, 0.9230400781640337, 1], 
      Hue[0.0483667, 0.29293452918481716`, 1], 
      Hue[0.0483667, 0.3216490216063851, 1], 
      Hue[0.0483667, 0.26900309509544484`, 1], 
      Hue[0.0483667, 0.2929345291848169, 1], 
      Hue[0.0483667, 0.32164902160638476`, 1], 
      Hue[0.0483667, 0.26900309509544434`, 1], 
      Hue[0.0483667, 0.8765732013268758, 1], 
      Hue[0.0483667, 0.9904959199447453, 1], 
      Hue[0.0483667, 0.9904959199447455, 1], 
      Hue[0.0483667, 0.8835041732913499, 1], 
      Hue[0.0483667, 0.9319910068314465, 1], 
      Hue[0.0483667, 0.9327901845798752, 1], 
      Hue[0.0483667, 0.9706384323007563, 1], 
      Hue[0.0483667, 0.9957842459981053, 1], 
      Hue[0.0483667, 0.7759041744809276, 1], 
      Hue[0.0483667, 0.8624133049632987, 1], 
      Hue[0.0483667, 0.8367971448921486, 1], 
      Hue[0.0483667, 0.8535920752288866, 1], 
      Hue[0.0483667, 0.965754757456777, 1], 
      Hue[0.0483667, 0.5823231963512117, 1], 
      Hue[0.0483667, 0.9905730624991133, 1], 
      Hue[0.0483667, 0.983006840720502, 1], 
      Hue[0.0483667, 0.9905730624991135, 1], 
      Hue[0.0483667, 0.18312348001499737`, 1], 
      Hue[0.0483667, 0.25001817265191817`, 1], 
      Hue[0.0483667, 0.7487992451869652, 1], 
      Hue[0.0483667, 0.7660093528116788, 1], 
      Hue[0.0483667, 0.801573660607013, 1], 
      Hue[0.0483667, 0.7948504978900854, 1], 
      Hue[0.0483667, 0.7838120691148884, 1], 
      Hue[0.0483667, 0.30014064675181856`, 1], 
      Hue[0.0483667, 0.24069832768632488`, 1], 
      Hue[0.0483667, 0.06782065895324421, 1], 
      Hue[0.633338, 0.35306661363867364`, 0.8754380987082759], 
      Hue[0.633338, 0.43507104674840114`, 0.8465069347071641], 
      Hue[0.633338, 0.43507104674840213`, 0.8465069347071636], 
      Hue[0.633338, 0.4350710467484012, 0.8465069347071641], 
      Hue[0.633338, 0.43507104674840236`, 0.8465069347071636], 
      Hue[0.633338, 0.3530666136386738, 0.8754380987082759], 
      Hue[0.633338, 0.9987739679814418, 0.6476325440961473], 
      Hue[0.633338, 0.1456633397661924, 0.9486099737304873], 
      Hue[0.633338, 0.998773967981443, 0.6476325440961469], 
      Hue[0.633338, 0.9987739679814434, 0.6476325440961468], 
      Hue[0.633338, 0.9987739679814416, 0.6476325440961475], 
      Hue[0.633338, 0.7610786236510926, 0.7314914615758945], 
      Hue[0.633338, 0.3589821578595134, 0.8733510947071637], 
      Hue[0.633338, 0.14566333976619342`, 0.9486099737304869], 
      Hue[0.0483667, 0.2406983276863232, 1], 
      Hue[0.633338, 0.35898215785951343`, 0.8733510947071637], 
      Hue[0.633338, 0.14566333976619206`, 0.9486099737304874], 
      Hue[0.633338, 0.1456633397661931, 0.948609973730487], 
      Hue[0.633338, 1.0127147139726402`, 0.6427142489104525], 
      Hue[0.633338, 0.2544890141968195, 0.9102162757913621], 
      Hue[0.633338, 0.2544890141968184, 0.9102162757913624], 
      Hue[0.633338, 0.35898215785951226`, 0.8733510947071641], 
      Hue[0.633338, 0.3995480314366289, 0.8590394545091573], 
      Hue[0.633338, 0.39954803143663, 0.859039454509157], 
      Hue[0.0483667, 0.8357161956370158, 1], 
      Hue[0.0483667, 0.3991609305827679, 1], 
      Hue[0.0483667, 0.9940059567071147, 1], 
      Hue[0.0483667, 0.39916093058276936`, 1], 
      Hue[0.0483667, 0.15084584866397904`, 1], 
      Hue[0.0483667, 0.7633769090548513, 1], 
      Hue[0.0483667, 0.763376909054851, 1], 
      Hue[0.0483667, 0.8357161956370165, 1], 
      Hue[0.0483667, 0.7633769090548519, 1], 
      Hue[0.633338, 0.399548031436629, 0.8590394545091573], 
      Hue[0.633338, 0.3995480314366302, 0.8590394545091569], 
      Hue[0.0483667, 0.7633769090548524, 1], 
      Hue[0.0483667, 0.9838699871612808, 1], 
      Hue[0.633338, 0.30881329298362586`, 0.8910506702353768], 
      Hue[0.0483667, 0.39916093058276925`, 1], 
      Hue[0.633338, 0.9393472914826302, 0.668598275564928], 
      Hue[0.633338, 0.9393472914826312, 0.6685982755649278], 
      Hue[0.633338, 0.9393472914826315, 0.6685982755649276], 
      Hue[0.0483667, 0.8978552229861467, 1], 
      Hue[0.0483667, 0.9509091581241285, 1], 
      Hue[0.0483667, 0.8871562697122584, 1], 
      Hue[0.0483667, 0.8978552229861476, 1], 
      Hue[0.0483667, 0.8978552229861474, 1], 
      Hue[0.633338, 0.9393472914826299, 0.6685982755649282], 
      Hue[0.0483667, 0.3991609305827706, 1], 
      Hue[0.0483667, 0.43279364524149355`, 1], 
      Hue[0.0483667, 0.15084584866398099`, 1], 
      Hue[0.0483667, 0.996503235977706, 1], 
      Hue[0.0483667, 0.9879477297012915, 1], 
      Hue[0.0483667, 0.974008611064336, 1], 
      Hue[0.0483667, 0.9965032359777062, 1], 
      Hue[0.633338, 0.7733067511760844, 0.7271773781850774], 
      Hue[0.633338, 0.7733067511760858, 0.7271773781850769], 
      Hue[0.0483667, 0.1508458486639796, 1], 
      Hue[0.633338, 0.16797049567830083`, 0.9407400091246955], 
      Hue[0.633338, 1.0127147139726385`, 0.6427142489104531], 
      Hue[0.633338, 0.1768559670781899, 0.9376052148148146], 
      Hue[0.633338, 0.16797049567830105`, 0.9407400091246954], 
      Hue[0.633338, 0.16797049567829983`, 0.9407400091246958], 
      Hue[0.633338, 0.2544890141968197, 0.910216275791362], 
      Hue[0.633338, 0.7889018457341759, 0.7216754288249827], 
      Hue[0.633338, 0.7889018457341767, 0.7216754288249825], 
      Hue[0.633338, 0.8591648570236687, 0.6968866384420497], 
      Hue[0.0483667, 0.8137119234411336, 1], 
      Hue[0.0483667, 0.8137119234411347, 1], 
      Hue[0.0483667, 0.8137119234411333, 1], 
      Hue[0.0483667, 0.8137119234411342, 1], 
      Hue[0.633338, 0.788901845734177, 0.7216754288249824], 
      Hue[0.633338, 0.859164857023669, 0.6968866384420496], 
      Hue[0.633338, 0.7889018457341775, 0.7216754288249821], 
      Hue[0.633338, 0.21125607440208555`, 0.9254688569509442], 
      Hue[0.0483667, 0.9933760896649446, 1], 
      Hue[0.0483667, 0.9933760896649446, 1], 
      Hue[0.0483667, 0.1508458486639776, 1], 
      Hue[0.0483667, 0.9421853723876454, 1], 
      Hue[0.0483667, 0.9547764646732457, 1], 
      Hue[0.0483667, 0.9993692103925798, 1], 
      Hue[0.633338, 0.2112560744020845, 0.9254688569509446], 
      Hue[0.633338, 0.7250829529322879, 0.7441907342054888], 
      Hue[0.0483667, 0.4327936452414908, 1], 
      Hue[0.0483667, 0.4327936452414922, 1], 
      Hue[0.633338, 0.5104107389691306, 0.8199270912916907], 
      Hue[0.633338, 0.859164857023668, 0.69688663844205], 
      Hue[0.0483667, 0.4327936452414921, 1], 
      Hue[0.0483667, 0.9974371877659431, 1], 
      Hue[0.0483667, 0.9720285845034506, 1], 
      Hue[0.0483667, 0.983869987161281, 1], 
      Hue[0.0483667, 0.9629261756933283, 1], 
      Hue[0.0483667, 0.9879477297012917, 1], 
      Hue[0.633338, 0.8591648570236696, 0.6968866384420493], 
      Hue[0.0483667, 0.9720285845034504, 1], 
      Hue[0.0483667, 0.9768473506991258, 1], 
      Hue[0.0483667, 0.9696497328825096, 1], 
      Hue[0.0483667, 0.9720285845034506, 1], 
      Hue[0.0483667, 0.96964973288251, 1], 
      Hue[0.633338, 0.7250829529322858, 0.7441907342054896], 
      Hue[0.633338, 0.12236136831275701`, 0.9568309092592593], 
      Hue[0.633338, 0.17685596707818907`, 0.9376052148148148], 
      Hue[0.633338, 0.16797049567830014`, 0.9407400091246957], 
      Hue[0.633338, 0.2544890141968186, 0.9102162757913624], 
      Hue[0.633338, 0.980189911472712, 0.6541889992324272], 
      Hue[0.633338, 0.9211200167521814, 0.6750288580898304], 
      Hue[0.633338, 0.9211200167521835, 0.6750288580898296], 
      Hue[0.633338, 0.4650561560650884, 0.8359281881402368], 
      Hue[0.633338, 0.5104107389691317, 0.8199270912916903], 
      Hue[0.633338, 0.47770659950084965`, 0.8314651116961003], 
      Hue[0.633338, 0.3088132929836259, 0.8910506702353768], 
      Hue[0.0483667, 0.9940059567071149, 1], 
      Hue[0.633338, 0.4650561560650881, 0.835928188140237], 
      Hue[0.633338, 0.5104107389691311, 0.8199270912916905], 
      Hue[0.633338, 0.47770659950084937`, 0.8314651116961004], 
      Hue[0.633338, 0.46505615606508705`, 0.8359281881402373], 
      Hue[0.633338, 0.5104107389691301, 0.819927091291691], 
      Hue[0.633338, 0.47770659950084815`, 0.8314651116961007], 
      Hue[0.633338, 0.4777065995008485, 0.8314651116961007], 
      Hue[0.0483667, 0.9700804970697733, 1], 
      Hue[0.633338, 0.3528736127268182, 0.8755061894299785], 
      Hue[0.633338, 0.9464976938684165, 0.6660756136032226], 
      Hue[0.633338, 0.9647813720423347, 0.6596251319434643], 
      Hue[0.633338, 0.5599146316597332, 0.8024621179504461], 
      Hue[0.633338, 0.39561972482787156`, 0.8604253610807269], 
      Hue[0.633338, 0.4403042097197874, 0.8446606748108589], 
      Hue[0.633338, 0.6269180498836493, 0.7788233120010486], 
      Hue[0.633338, 0.693734840804946, 0.755250348164015], 
      Hue[0.633338, 0.7804389090503988, 0.7246611528870193], 
      Hue[0.633338, 0.8211113941028465, 0.7103119001605158], 
      Hue[0.633338, 0.7492581975269865, 0.7356617079124792], 
      Hue[0.633338, 0.7498307728457894, 0.7354597033400055], 
      Hue[0.633338, 0.31951430168165496`, 0.8872753543667121], 
      Hue[0.633338, 0.8290664036700442, 0.7075053727852083], 
      Hue[0.633338, 0.9433781524026831, 0.6671761878323335], 
      Hue[0.633338, 0.6567635715393001, 0.7682938119609349], 
      Hue[0.633338, 0.9801899114727123, 0.6541889992324271], 
      Hue[0.633338, 0.9801899114727135, 0.6541889992324267], 
      Hue[0.633338, 0.9464976938684171, 0.6660756136032224], 
      Hue[0.633338, 0.9801899114727137, 0.6541889992324266], 
      Hue[0.633338, 0.9464976938684175, 0.6660756136032222], 
      Hue[0.633338, 0.31951430168165496`, 0.8872753543667121], 
      Hue[0.0483667, 0.9973195597899072, 1], 
      Hue[0.0483667, 0.9857752075153172, 1], 
      Hue[0.0483667, 0.9857752075153172, 1], 
      Hue[0.633338, 0.21122975493756035`, 0.9254781424580287], 
      Hue[0.633338, 0.9211200167521822, 0.67502885808983], 
      Hue[0.633338, 0.9211200167521829, 0.6750288580898298], 
      Hue[0.0483667, 0.9955760336066636, 1], 
      Hue[0.0483667, 0.9955760336066638, 1], 
      Hue[0.0483667, 0.9509917872092963, 1], 
      Hue[0.0483667, 0.9537769999275656, 1], 
      Hue[0.633338, 0.6933351676869984, 0.7553913528400269], 
      Hue[0.633338, 0.5251358372981711, 0.8147320766012052], 
      Hue[0.0483667, 0.9731351288079542, 1], 
      Hue[0.0483667, 0.9731351288079539, 1], 
      Hue[0.0483667, 0.9731351288079544, 1], 
      Hue[0.633338, 0.21122975493755936`, 0.9254781424580291], 
      Hue[0.633338, 0.5251358372981724, 0.8147320766012047], 
      Hue[0.633338, 0.3839167371506963, 0.8645541751332344], 
      Hue[0.633338, 0.5251358372981718, 0.814732076601205], 
      Hue[0.633338, 0.5251358372981707, 0.8147320766012054], 
      Hue[0.0483667, 0.9643150792252206, 1], 
      Hue[0.633338, 0.9647813720423353, 0.6596251319434641], 
      Hue[0.633338, 0.9647813720423359, 0.6596251319434638], 
      Hue[0.633338, 0.9647813720423365, 0.6596251319434636], 
      Hue[0.633338, 0.6763865773920135, 0.7613708154960976], 
      Hue[0.633338, 0.8051464044857163, 0.7159443484974393], 
      Hue[0.633338, 0.7492581975269872, 0.735661707912479], 
      Hue[0.633338, 0.995317703092908, 0.6488519143488221], 
      Hue[0.633338, 0.7492581975269884, 0.7356617079124785], 
      Hue[0.633338, 0.943378152402684, 0.667176187832333], 
      Hue[0.633338, 0.9433781524026845, 0.6671761878323329], 
      Hue[0.633338, 0.9433781524026849, 0.6671761878323328], 
      Hue[0.0483667, 0.9768473506991258, 1], 
      Hue[0.0483667, 0.9736915580230805, 1], 
      Hue[0.633338, 0.3146975955008835, 0.8889746883072883], 
      Hue[0.633338, 0.3359700802109638, 0.8814697557015719], 
      Hue[0.0483667, 0.34304655244276816`, 1], 
      Hue[0.0483667, 0.40034120529110656`, 1], 
      Hue[0.633338, 0.7492581975269872, 0.735661707912479], 
      Hue[0.633338, 0.7498307728457905, 0.7354597033400051], 
      Hue[0.633338, 0.795033372769634, 0.7195122260868732], 
      Hue[0.633338, 0.7498307728457902, 0.7354597033400052], 
      Hue[0.633338, 0.7498307728457914, 0.7354597033400048], 
      Hue[0.0483667, 0.9806982622686795, 1], 
      Hue[0.633338, 0.9955013031081947, 0.6487871402634289], 
      Hue[0.0483667, 0.40034120529110795`, 1], 
      Hue[0.633338, 0.24879675908126453`, 0.9122245033961298], 
      Hue[0.0483667, 0.4003412052911051, 1], 
      Hue[0.0483667, 0.40034120529110656`, 1], 
      Hue[0.633338, 0.9949381313661769, 0.6489858272540128], 
      Hue[0.633338, 0.9949381313661766, 0.6489858272540129], 
      Hue[0.633338, 0.5599146316597337, 0.802462117950446], 
      Hue[0.633338, 0.62691804988365, 0.7788233120010483], 
      Hue[0.633338, 0.6567635715393008, 0.7682938119609347], 
      Hue[0.633338, 0.3936309505994413, 0.8611270006285171], 
      Hue[0.633338, 0.4213512253122027, 0.8513472877098549], 
      Hue[0.633338, 0.28913780693674745`, 0.8979921817127154], 
      Hue[0.633338, 0.2487967590812657, 0.9122245033961295], 
      Hue[0.633338, 0.42135122531220137`, 0.8513472877098553], 
      Hue[0.633338, 0.36670075079899594`, 0.8706279751181143], 
      Hue[0.0483667, 0.28451138728433, 1], 
      Hue[0.0483667, 0.2154890170556677, 1], 
      Hue[0.0483667, 0.28451138728433134`, 1], 
      Hue[0.0483667, 0.2154890170556691, 1], 
      Hue[0.633338, 0.6933351676869993, 0.7553913528400267], 
      Hue[0.0483667, 0.2845113872843327, 1], 
      Hue[0.0483667, 0.21548901705567078`, 1], 
      Hue[0.0483667, 0.9166262239546754, 1], 
      Hue[0.0483667, 0.976847350699126, 1], 
      Hue[0.0483667, 0.32805476500697506`, 1], 
      Hue[0.0483667, 0.3290966626805419, 1], 
      Hue[0.0483667, 0.2921589098628595, 1], 
      Hue[0.633338, 0.48290075072064137`, 0.8296326151457577], 
      Hue[0.633338, 0.48746599118780615`, 0.828021998308942], 
      Hue[0.633338, 0.48290075072064165`, 0.8296326151457576], 
      Hue[0.633338, 0.44864270081307717`, 0.8417188551531464], 
      Hue[0.633338, 0.4874659911878064, 0.8280219983089419], 
      Hue[0.633338, 0.48290075072064287`, 0.8296326151457571], 
      Hue[0.633338, 0.4874659911878077, 0.8280219983089414], 
      Hue[0.633338, 0.013008721232604723`, 0.995410523149137], 
      Hue[0.633338, 0.06186861512580752, 0.9781727525836151], 
      Hue[0.633338, 0.1196007298589879, 0.957804862505749], 
      Hue[0.633338, 1.002834814092524, 0.6461998775881574], 
      Hue[0.633338, 0.7825041803550201, 0.7239325251707489], 
      Hue[0.633338, 0.01300872123260525, 0.9954105231491369], 
      Hue[0.633338, 0.06186861512580827, 0.9781727525836148], 
      Hue[0.633338, 0.1196007298589888, 0.9578048625057487], 
      Hue[0.633338, 0.09341809027663495, 0.9670420977504032], 
      Hue[0.0483667, 0.2026499934881812, 1], 
      Hue[0.633338, 0.36731813781305744`, 0.8704101609795534], 
      Hue[0.633338, 0.013008721232604357`, 0.9954105231491371], 
      Hue[0.633338, 0.061868615125807144`, 0.9781727525836152], 
      Hue[0.633338, 0.11960072985898758`, 0.9578048625057491], 
      Hue[0.633338, 0.09341809027663361, 0.9670420977504036], 
      Hue[0.633338, 0.013008721232604908`, 0.995410523149137], 
      Hue[0.633338, 0.06186861512580792, 0.9781727525836149], 
      Hue[0.633338, 0.3150715659817105, 0.8888427515216525], 
      Hue[0.633338, 0.28253327813093215`, 0.9003222594754071], 
      Hue[0.633338, 0.3870264217936259, 0.8634570783912088], 
      Hue[0.633338, 0.4448304384353591, 0.8430638213200053], 
      Hue[0.0483667, 0.20264999348818258`, 1], 
      Hue[0.0483667, 0.7963569990902841, 1], 
      Hue[0.633338, 0.43674424695469166`, 0.8459166296743847], 
      Hue[0.633338, 0.4448304384353604, 0.8430638213200048], 
      Hue[0.0483667, 0.7963569990902855, 1], 
      Hue[0.633338, 0.9955013031081933, 0.6487871402634294], 
      Hue[0.633338, 0.9955013031081947, 0.6487871402634289], 
      Hue[0.633338, 0.995501303108193, 0.6487871402634295], 
      Hue[0.0483667, 0.2026499934881844, 1], 
      Hue[0.633338, 0.5599146316597327, 0.8024621179504463], 
      Hue[0.633338, 0.6763865773920129, 0.7613708154960979], 
      Hue[0.633338, 0.6933351676869979, 0.7553913528400271], 
      Hue[0.633338, 0.7825041803550198, 0.723932525170749], 
      Hue[0.633338, 0.782504180355021, 0.7239325251707486], 
      Hue[0.633338, 0.5599146316597321, 0.8024621179504465], 
      Hue[0.633338, 0.6933351676869972, 0.7553913528400273], 
      Hue[0.0483667, 0.2845113872843314, 1], 
      Hue[0.0483667, 0.21548901705566947`, 1], 
      Hue[0.0483667, 0.20264999348818302`, 1], 
      Hue[0.633338, 0.19037519542309078`, 0.9328356310547335], 
      Hue[0.633338, 0.22194972375297312`, 0.921696137459951], 
      Hue[0.633338, 0.11960072985898851`, 0.9578048625057488], 
      Hue[0.633338, 0.1584172534183034, 0.9441103929940226], 
      Hue[0.633338, 0.15841725341830235`, 0.9441103929940229], 
      Hue[0.633338, 0.6763865773920144, 0.7613708154960973], 
      Hue[0.633338, 0.23433327972987206`, 0.9173272189113011], 
      Hue[0.633338, 0.2067870192376146, 0.9270455396129695], 
      Hue[0.0483667, 0.9806982622686797, 1], 
      Hue[0.0483667, 0.9305327916840167, 1], 
      Hue[0.0483667, 0.9410313512379944, 1], 
      Hue[0.633338, 0.9347182247845724, 0.6702314102960029], 
      Hue[0.633338, 0.9347182247845742, 0.6702314102960023], 
      Hue[0.0483667, 0.6537657333768433, 1], 
      Hue[0.0483667, 0.6842407034582245, 1], 
      Hue[0.0483667, 0.6485305516556525, 1], 
      Hue[0.633338, 0.7430981357521507, 0.7378349777066413], 
      Hue[0.633338, 0.8086967187315391, 0.714691797631513], 
      Hue[0.633338, 0.8850384328972067, 0.6877584408738655], 
      Hue[0.633338, 0.28253327813093226`, 0.9003222594754071], 
      Hue[0.0483667, 0.6537657333768422, 1], 
      Hue[0.0483667, 0.6842407034582234, 1], 
      Hue[0.0483667, 0.6537657333768419, 1], 
      Hue[0.0483667, 0.684240703458223, 1], 
      Hue[0.0483667, 0.6485305516556508, 1], 
      Hue[0.0483667, 0.653765733376843, 1], 
      Hue[0.0483667, 0.6842407034582242, 1], 
      Hue[0.633338, 0.7430981357521516, 0.7378349777066409], 
      Hue[0.633338, 0.8086967187315401, 0.7146917976315126], 
      Hue[0.633338, 0.7430981357521522, 0.7378349777066406], 
      Hue[0.633338, 0.8086967187315409, 0.7146917976315124], 
      Hue[0.633338, 0.8850384328972087, 0.6877584408738647], 
      Hue[0.633338, 0.7430981357521513, 0.737834977706641], 
      Hue[0.633338, 0.8086967187315399, 0.7146917976315128], 
      Hue[0.633338, 0.8850384328972076, 0.6877584408738652], 
      Hue[0.633338, 0.39363095059944114`, 0.8611270006285172], 
      Hue[0.0483667, 0.04638033660377337, 1], 
      Hue[0.0483667, 0.03587314712859477, 1], 
      Hue[0.633338, 0.2891378069367475, 0.8979921817127154], 
      Hue[0.0483667, 0.04638033660377505, 1], 
      Hue[0.0483667, 0.03587314712859686, 1], 
      Hue[0.0483667, 0.9259545730356309, 1], 
      Hue[0.0483667, 0.9305361975541628, 1], 
      Hue[0.0483667, 0.9421853723876457, 1], 
      Hue[0.0483667, 0.9259545730356314, 1], 
      Hue[0.0483667, 0.9305361975541635, 1], 
      Hue[0.0483667, 0.9421853723876463, 1], 
      Hue[0.0483667, 0.9166262239546763, 1], 
      Hue[0.0483667, 0.910930838879912, 1], 
      Hue[0.0483667, 0.9259545730356316, 1], 
      Hue[0.0483667, 0.9305361975541635, 1], 
      Hue[0.0483667, 0.9421853723876461, 1], 
      Hue[0.0483667, 0.9166262239546763, 1], 
      Hue[0.0483667, 0.9109308388799118, 1], 
      Hue[0.0483667, 0.9166262239546756, 1], 
      Hue[0.0483667, 0.9109308388799112, 1], 
      Hue[0.0483667, 0.9974318809817766, 1], 
      Hue[0.0483667, 0.9990019925590983, 1], 
      Hue[0.0483667, 0.99936033080062, 1], 
      Hue[0.0483667, 0.32805476500697384`, 1], 
      Hue[0.0483667, 0.32909666268054055`, 1], 
      Hue[0.0483667, 0.04638033660377631, 1], 
      Hue[0.0483667, 0.03587314712859815, 1], 
      Hue[0.0483667, 0.046380336603774615`, 1], 
      Hue[0.0483667, 0.03587314712859608, 1], 
      Hue[0.633338, 0.4874659911878073, 0.8280219983089416], 
      Hue[0.633338, 0.023204251462274856`, 0.9918135400841094], 
      Hue[0.0483667, 0.2717718910313216, 1], 
      Hue[0.633338, 0.190375195423091, 0.9328356310547334], 
      Hue[0.633338, 0.19037519542308995`, 0.9328356310547339], 
      Hue[0.0483667, 0.9976435172307532, 1], 
      Hue[0.0483667, 0.99790960266959, 1], 
      Hue[0.0483667, 0.7329065906420595, 1], 
      Hue[0.0483667, 0.7329065906420602, 1], 
      Hue[0.633338, 0.750199458562777, 0.7353296310190522], 
      Hue[0.633338, 0.7888748946279454, 0.7216849371752609], 
      Hue[0.633338, 0.8438282243762864, 0.7022974024400461], 
      Hue[0.0483667, 0.3280547650069739, 1], 
      Hue[0.0483667, 0.2717718910313215, 1], 
      Hue[0.633338, 0.5325353298881381, 0.8121215356154649], 
      Hue[0.633338, 0.5922924260403808, 0.7910392320929537], 
      Hue[0.633338, 0.6592958442642969, 0.7674004261435561], 
      Hue[0.633338, 0.5325353298881385, 0.8121215356154647], 
      Hue[0.633338, 0.5922924260403813, 0.7910392320929535], 
      Hue[0.633338, 0.6592958442642975, 0.7674004261435559], 
      Hue[0.633338, 0.5325353298881377, 0.812121535615465], 
      Hue[0.633338, 0.5922924260403803, 0.7910392320929538], 
      Hue[0.633338, 0.6592958442642964, 0.7674004261435562], 
      Hue[0.633338, 0.7359215892891313, 0.7403668632987945], 
      Hue[0.633338, 0.8226256575345845, 0.7097776680217986], 
      Hue[0.633338, 0.8920464136818431, 0.6852860252530457], 
      Hue[0.633338, 0.19662331643605696`, 0.9306312939613591], 
      Hue[0.633338, 0.22014154580197354`, 0.9223340626410638], 
      Hue[0.633338, 0.25893174989676293`, 0.9086488786364221], 
      Hue[0.0483667, 0.9793001276602618, 1], 
      Hue[0.0483667, 0.9812670419676124, 1], 
      Hue[0.0483667, 0.9776378265159742, 1], 
      Hue[0.0483667, 0.9773560015904137, 1], 
      Hue[0.633338, 0.5815634669796055, 0.7948244088495952], 
      Hue[0.633338, 0.6042407584316272, 0.7868238604253219], 
      Hue[0.0483667, 0.9793001276602621, 1], 
      Hue[0.0483667, 0.9799952037616093, 1], 
      Hue[0.0483667, 0.9843326075681298, 1], 
      Hue[0.0483667, 0.9224508113714168, 1], 
      Hue[0.0483667, 0.9294040952360875, 1], 
      Hue[0.633338, 0.5325353298881372, 0.8121215356154652], 
      Hue[0.633338, 0.5922924260403799, 0.791039232092954], 
      Hue[0.633338, 0.659295844264296, 0.7674004261435564], 
      Hue[0.0483667, 0.5914959097531697, 1], 
      Hue[0.0483667, 0.6327874544037094, 1], 
      Hue[0.0483667, 0.9515137214686009, 1], 
      Hue[0.0483667, 0.9410249595113819, 1], 
      Hue[0.0483667, 0.9515137214686015, 1], 
      Hue[0.0483667, 0.9410249595113824, 1], 
      Hue[0.633338, 0.7359215892891313, 0.7403668632987945], 
      Hue[0.633338, 0.8226256575345842, 0.7097776680217986], 
      Hue[0.633338, 0.8920464136818431, 0.6852860252530457], 
      Hue[0.633338, 0.06502310857866454, 0.9770598472934472], 
      Hue[0.633338, 0.04210477608557213, 0.9851454349970101], 
      Hue[0.633338, 0.05167308489613828, 0.9817697356486424], 
      Hue[0.0483667, 0.558299536217207, 1], 
      Hue[0.0483667, 0.5056584238420392, 1], 
      Hue[0.0483667, 0.46986253462312044`, 1], 
      Hue[0.0483667, 0.7702440808650028, 1], 
      Hue[0.0483667, 0.7261972614044914, 1], 
      Hue[0.0483667, 0.7052189824313574, 1], 
      Hue[0.0483667, 0.7702440808650037, 1], 
      Hue[0.0483667, 0.726197261404492, 1], 
      Hue[0.0483667, 0.7052189824313582, 1], 
      Hue[0.633338, 0.6102677071728287, 0.784697552909426], 
      Hue[0.633338, 0.6012800666066048, 0.7878683925011898], 
      Hue[0.633338, 0.6102677071728286, 0.784697552909426], 
      Hue[0.633338, 0.6012800666066045, 0.78786839250119], 
      Hue[0.0483667, 0.8711685117640138, 1], 
      Hue[0.0483667, 0.8803509678823742, 1], 
      Hue[0.0483667, 0.8999144846102909, 1], 
      Hue[0.633338, 0.23161607478534743`, 0.9182858488157294], 
      Hue[0.633338, 0.22999890101638223`, 0.9188563877214203], 
      Hue[0.633338, 0.20887988683127548`, 0.926307175925926], 
      Hue[0.633338, 0.2648440941877299, 0.9065630035705688], 
      Hue[0.633338, 0.3039403591738241, 0.8927698412834748], 
      Hue[0.0483667, 0.9515137214686008, 1], 
      Hue[0.0483667, 0.9633668891439442, 1], 
      Hue[0.0483667, 0.9653338034512948, 1], 
      Hue[0.633338, 0.6419266077385736, 0.7735282927898313], 
      Hue[0.633338, 0.7035083897574249, 0.7518022400935804], 
      Hue[0.633338, 0.7233032627547882, 0.7448186089001108], 
      Hue[0.633338, 0.7432006811021423, 0.7377987997071642], 
      Hue[0.633338, 0.7848035929984755, 0.7231212923901378], 
      Hue[0.633338, 0.11010479791753931`, 0.9611550272946922], 
      Hue[0.633338, 0.07768027856916793, 0.9725943977207976], 
      Hue[0.0483667, 0.9726053466081064, 1], 
      Hue[0.0483667, 0.9769361942878594, 1], 
      Hue[0.0483667, 0.46036678505443895`, 1], 
      Hue[0.0483667, 0.48412988965570036`, 1], 
      Hue[0.0483667, 0.45093351611973775`, 1], 
      Hue[0.0483667, 0.8007190509463842, 1], 
      Hue[0.0483667, 0.7634581561754377, 1], 
      Hue[0.0483667, 0.800719050946385, 1], 
      Hue[0.0483667, 0.7634581561754386, 1], 
      Hue[0.0483667, 0.9509091581241289, 1], 
      Hue[0.0483667, 0.06782065895324635, 1], 
      Hue[0.633338, 0.7950333727696353, 0.7195122260868727], 
      Hue[0.633338, 0.7950333727696349, 0.7195122260868728], 
      Hue[0.633338, 0.7250829529322873, 0.744190734205489], 
      Hue[0.633338, 1.0028348140925254`, 0.646199877588157], 
      Hue[0.0483667, 0.06782065895324499, 1], 
      Hue[0.0483667, 0.7085582907270876, 1], 
      Hue[0.0483667, 0.7085582907270888, 1], 
      Hue[0.0483667, 0.7085582907270871, 1], 
      Hue[0.0483667, 0.7085582907270882, 1], 
      Hue[0.0483667, 0.8357161956370156, 1], 
      Hue[0.0483667, 0.8357161956370167, 1], 
      Hue[0.0483667, 0.9940059567071149, 1], 
      Hue[0.0483667, 0.9983571985405322, 1], 
      Hue[0.0483667, 0.5065004967032407, 1], 
      Hue[0.633338, 0.7250829529322866, 0.7441907342054892], 
      Hue[0.633338, 1.0028348140925243`, 0.6461998775881574], 
      Hue[0.0483667, 0.5061156919898075, 1], 
      Hue[0.0483667, 0.6171415379132282, 1], 
      Hue[0.0483667, 0.5061156919898064, 1], 
      Hue[0.0483667, 0.5061156919898078, 1], 
      Hue[0.0483667, 0.6171415379132288, 1], 
      Hue[0.0483667, 0.06782065895324282, 1], 
      Hue[0.633338, 0.01928759032417928, 0.9931953381336296], 
      Hue[0.633338, 0.9003215787884109, 0.6823665470034486], 
      Hue[0.633338, 0.9003215787884118, 0.6823665470034483], 
      Hue[0.0483667, 0.7963569990902843, 1], 
      Hue[0.0483667, 0.796356999090285, 1], 
      Hue[0.633338, 0.900321578788412, 0.6823665470034482], 
      Hue[0.633338, 0.9003215787884129, 0.6823665470034479], 
      Hue[0.0483667, 0.9940059567071147, 1], 
      Hue[0.633338, 0.5795489215257146, 0.7955351404857278], 
      Hue[0.0483667, 0.9974371877659434, 1], 
      Hue[0.0483667, 0.9283066848986965, 1], 
      Hue[0.633338, 0.9464976938684158, 0.6660756136032229], 
      Hue[0.633338, 0.5795489215257159, 0.7955351404857274], 
      Hue[0.633338, 0.418527123952806, 0.8523436306694501], 
      Hue[0.633338, 0.5795489215257154, 0.7955351404857276], 
      Hue[0.633338, 0.579548921525714, 0.795535140485728], 
      Hue[0.0483667, 0.9283066848986963, 1], 
      Hue[0.0483667, 0.9768473506991262, 1], 
      Hue[0.0483667, 0.9993570009536351, 1], 
      Hue[0.0483667, 0.9573004502648019, 1], 
      Hue[0.633338, 0.7825041803550189, 0.7239325251707494], 
      Hue[0.633338, 0.7610786236510912, 0.731491461575895], 
      Hue[0.0483667, 0.96964973288251, 1], 
      Hue[0.633338, 0.8293028354103946, 0.7074219596672128], 
      Hue[0.633338, 1.0028348140925258`, 0.6461998775881569], 
      Hue[0.0483667, 0.3430465524427696, 1], 
      Hue[0.633338, 0.8290664036700452, 0.7075053727852081], 
      Hue[0.0483667, 0.3430465524427666, 1], 
      Hue[0.0483667, 0.34304655244276816`, 1], 
      Hue[0.633338, 0.8293028354103935, 0.7074219596672131], 
      Hue[0.0483667, 0.24069832768632177`, 1], 
      Hue[0.633338, 0.7950333727696361, 0.7195122260868724], 
      Hue[0.633338, 0.995317703092908, 0.6488519143488221], 
      Hue[0.0483667, 0.910930838879911, 1], 
      Hue[0.0483667, 0.9509091581241289, 1], 
      Hue[0.633338, 0.09341809027663397, 0.9670420977504035], 
      Hue[0.633338, 0.09341809027663457, 0.9670420977504033], 
      Hue[0.633338, 0.6763865773920124, 0.7613708154960981], 
      Hue[0.633338, 0.19037519542308967`, 0.932835631054734], 
      Hue[0.0483667, 0.9396335929987274, 1], 
      Hue[0.633338, 0.5335483858643792, 0.811764129467047], 
      Hue[0.633338, 0.5335483858643775, 0.8117641294670476], 
      Hue[0.633338, 0.48290075072064254`, 0.8296326151457574], 
      Hue[0.633338, 0.23433327972987095`, 0.9173272189113015]}], {{}, {
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{-3.1056409663804465`, -2.9941310574233087`}, \
{-2.8943590336195535`, -3.005868942576692}}], 
       ArrowBox[{{-3.1049188572422057`, -2.677731602658796}, \
{-2.8950811427577943`, -2.6906894499727834`}}], 
       ArrowBox[{{-3.103962777905652, -2.3613874685828082`}, \
{-2.8960372220943476`, -2.3754546366803493`}}], 
       ArrowBox[{{-3.102744646352852, -2.04517958887637}, \
{-2.897255353647148, -2.0600835690183663`}}], 
       ArrowBox[{{-3.1012635866448655`, -1.729218168890354}, \
{-2.898736413355134, -1.744466041635961}}], 
       ArrowBox[{{-3.0995678647276144`, -1.4136347717029873`}, \
{-2.900432135272386, -1.4284704914549065`}}], 
       ArrowBox[{{-3.097776234193678, -1.0985579695560168`}, \
{-2.902223765806322, -1.1119683462334558`}}], 
       ArrowBox[{{-3.0960852835596677`, -0.7840701730916331}, \
{-2.903914716440332, -0.7948771953294185}}], 
       ArrowBox[{{-3.0947457396294555`, -0.47015564277173294`}, \
{-2.9052542603705445`, -0.4772127782808976}}], 
       ArrowBox[{{-3.094000177374207, -0.15666598689144615`}, \
{-2.905999822625793, -0.15912348679276336`}}], 
       ArrowBox[{{-3.094000177374207, 
        0.15666598689144715`}, {-2.905999822625793, 0.1591234867927644}}], 
       ArrowBox[{{-3.0947457396294555`, 
        0.47015564277173394`}, {-2.9052542603705445`, 0.47721277828089864`}}],
        ArrowBox[{{-3.0960852835596677`, 
        0.7840701730916341}, {-2.903914716440332, 0.7948771953294195}}], 
       ArrowBox[{{-3.097776234193678, 
        1.0985579695560177`}, {-2.902223765806322, 1.1119683462334566`}}], 
       ArrowBox[{{-3.0995678647276144`, 
        1.4136347717029882`}, {-2.900432135272386, 1.4284704914549073`}}], 
       ArrowBox[{{-3.1012635866448655`, 
        1.729218168890355}, {-2.898736413355134, 1.7444660416359619`}}], 
       ArrowBox[{{-3.102744646352852, 2.045179588876371}, {-2.897255353647148,
         2.060083569018367}}], 
       ArrowBox[{{-3.103962777905652, 
        2.361387468582809}, {-2.8960372220943476`, 2.37545463668035}}], 
       ArrowBox[{{-3.1049188572422057`, 
        2.6777316026587967`}, {-2.8950811427577943`, 2.6906894499727843`}}], 
       ArrowBox[{{-3.1056409663804465`, 
        2.9941310574233095`}, {-2.8943590336195535`, 3.0058689425766927`}}], 
       ArrowBox[{{-2.7905736018344767`, -2.9935210763430065`}, \
{-2.577847450797102, -3.006478923656994}}], 
       ArrowBox[{{-2.789851492696236, -2.6768794250348704`}, \
{-2.578569559935343, -2.691541627596709}}], 
       ArrowBox[{{-2.7888250119827362`, -2.360241284445878}, \
{-2.5795960406488425`, -2.3766008208172793`}}], 
       ArrowBox[{{-2.7874274104664702`, -2.0437028760677314`}, \
{-2.580993642165108, -2.0615602818270045`}}], 
       ArrowBox[{{-2.7856166369033604`, -1.727414509629018}, \
{-2.5828044157282184`, -1.7462697008972972`}}], 
       ArrowBox[{{-2.7834134041615592`, -1.4115812128692786`}, \
{-2.585007648470019, -1.4305240502886154`}}], 
       ArrowBox[{{-2.780949752826404, -1.0964355991904862`}, \
{-2.587471299805175, -1.1140907165989864`}}], 
       ArrowBox[{{-2.7785055211897043`, -0.7821675661949561}, \
{-2.589915531441875, -0.7967798022260956}}], 
       ArrowBox[{{-2.776490997320983, -0.4688171729253303}, \
{-2.5919300553105957`, -0.4785512481273002}}], 
       ArrowBox[{{-2.775340619406974, -0.1561816476343447}, \
{-2.5930804332246047`, -0.15960782604986484`}}], 
       ArrowBox[{{-2.775340619406974, 
        0.15618164763434567`}, {-2.5930804332246047`, 0.15960782604986584`}}],
        ArrowBox[{{-2.776490997320983, 
        0.4688171729253313}, {-2.5919300553105957`, 0.4785512481273012}}], 
       ArrowBox[{{-2.7785055211897043`, 
        0.7821675661949571}, {-2.589915531441875, 0.7967798022260966}}], 
       ArrowBox[{{-2.780949752826404, 1.096435599190487}, {-2.587471299805175,
         1.1140907165989873`}}], 
       ArrowBox[{{-2.7834134041615592`, 
        1.4115812128692795`}, {-2.585007648470019, 1.4305240502886163`}}], 
       ArrowBox[{{-2.7856166369033604`, 
        1.727414509629019}, {-2.5828044157282184`, 1.7462697008972978`}}], 
       ArrowBox[{{-2.7874274104664702`, 
        2.0437028760677323`}, {-2.580993642165108, 2.0615602818270053`}}], 
       ArrowBox[{{-2.7888250119827362`, 
        2.360241284445879}, {-2.5795960406488425`, 2.37660082081728}}], 
       ArrowBox[{{-2.789851492696236, 
        2.6768794250348713`}, {-2.578569559935343, 2.6915416275967097`}}], 
       ArrowBox[{{-2.7905736018344767`, 
        2.9935210763430073`}, {-2.577847450797102, 3.006478923656995}}], 
       ArrowBox[{{-2.4757402074868198`, -2.9929664159512295`}, \
{-2.2611018977763377`, -3.0070335840487705`}}], 
       ArrowBox[{{-2.475088499725525, -2.676030758130089}, \
{-2.2617536055376326`, -2.69239029450149}}], 
       ArrowBox[{{-2.4740620190120253`, -2.3590046603196426`}, \
{-2.2627800862511322`, -2.377837444943515}}], 
       ArrowBox[{{-2.472533423285127, -2.041986001563612}, \
{-2.2643086819780303`, -2.0632771563311243`}}], 
       ArrowBox[{{-2.4703809140619883`, -1.7251616760947714`}, \
{-2.2664611912011687`, -1.7485225344315436`}}], 
       ArrowBox[{{-2.4675454845400973`, -1.4088341294440818`}, \
{-2.2692966207230603`, -1.4332711337138122`}}], 
       ArrowBox[{{-2.4641283748233986`, -1.0934105142605794`}, \
{-2.272713730439759, -1.1171158015288931`}}], 
       ArrowBox[{{-2.4605024140828373`, -0.7793039805136348}, \
{-2.27633969118032, -0.7996433879074167}}], 
       ArrowBox[{{-2.4573465297008963`, -0.46671942331334476`}, \
{-2.2794955755622617`, -0.4806489977392857}}], 
       ArrowBox[{{-2.455478489662758, -0.1554058713042565}, \
{-2.281363615600399, -0.160383602379953}}], 
       ArrowBox[{{-2.4554784896627586`, 
        0.15540587130425748`}, {-2.281363615600399, 0.160383602379954}}], 
       ArrowBox[{{-2.4573465297008963`, 
        0.46671942331334576`}, {-2.2794955755622612`, 0.48064899773928677`}}],
        ArrowBox[{{-2.4605024140828373`, 
        0.7793039805136358}, {-2.27633969118032, 0.7996433879074178}}], 
       ArrowBox[{{-2.4641283748233986`, 
        1.0934105142605803`}, {-2.272713730439759, 1.117115801528894}}], 
       ArrowBox[{{-2.4675454845400973`, 
        1.4088341294440827`}, {-2.2692966207230603`, 1.433271133713813}}], 
       ArrowBox[{{-2.4703809140619883`, 
        1.7251616760947723`}, {-2.2664611912011687`, 1.7485225344315445`}}], 
       ArrowBox[{{-2.472533423285127, 
        2.041986001563613}, {-2.2643086819780303`, 2.063277156331125}}], 
       ArrowBox[{{-2.4740620190120253`, 
        2.3590046603196435`}, {-2.2627800862511322`, 2.377837444943516}}], 
       ArrowBox[{{-2.475088499725525, 
        2.6760307581300897`}, {-2.2617536055376326`, 2.692390294501491}}], 
       ArrowBox[{{-2.4757402074868198`, 
        2.9929664159512304`}, {-2.2611018977763377`, 3.0070335840487714`}}], 
       ArrowBox[{{-2.161168865355409, -2.992548009929002}, \
{-1.944094292539327, -3.007451990070998}}], 
       ArrowBox[{{-2.1606966275575803`, -2.6752818234361526`}, \
{-1.944566530337156, -2.6931392291954257`}}], 
       ArrowBox[{{-2.159801141054713, -2.3577754752478226`}, \
{-1.9454620168400232`, -2.379066630015335}}], 
       ArrowBox[{{-2.1582725453278147`, -2.040094961964021}, \
{-1.9469906125669214`, -2.065168195930715}}], 
       ArrowBox[{{-2.1558540664462713`, -1.7224320019272934`}, \
{-1.9494090914484652`, -1.7512522085990216`}}], 
       ArrowBox[{{-2.152306319158972, -1.405187893811797}, \
{-1.9529568387357643`, -1.4369173693460968`}}], 
       ArrowBox[{{-2.147573000153912, -1.089035514380984}, \
{-1.9576901577408243`, -1.1214908014084888`}}], 
       ArrowBox[{{-2.1420598175721164`, -0.7748371938755204}, \
{-1.9632033403226197`, -0.8041101745455311}}], 
       ArrowBox[{{-2.1368743555014227`, -0.46325259298594923`}, \
{-1.9683888023933134`, -0.4841158280666813}}], 
       ArrowBox[{{-2.1336400450239266`, -0.15408256417602684`}, \
{-1.97162311287081, -0.1617069095081827}}], 
       ArrowBox[{{-2.1336400450239266`, 
        0.1540825641760278}, {-1.97162311287081, 0.1617069095081837}}], 
       ArrowBox[{{-2.1368743555014227`, 
        0.46325259298595023`}, {-1.9683888023933134`, 0.4841158280666823}}], 
       ArrowBox[{{-2.1420598175721164`, 
        0.7748371938755214}, {-1.9632033403226197`, 0.8041101745455321}}], 
       ArrowBox[{{-2.147573000153912, 
        1.089035514380985}, {-1.9576901577408243`, 1.1214908014084897`}}], 
       ArrowBox[{{-2.152306319158972, 
        1.4051878938117979`}, {-1.9529568387357643`, 1.4369173693460977`}}], 
       ArrowBox[{{-2.1558540664462713`, 
        1.7224320019272943`}, {-1.9494090914484652`, 1.7512522085990225`}}], 
       ArrowBox[{{-2.1582725453278147`, 
        2.040094961964022}, {-1.9469906125669214`, 2.065168195930716}}], 
       ArrowBox[{{-2.159801141054713, 
        2.3577754752478235`}, {-1.9454620168400232`, 2.379066630015336}}], 
       ArrowBox[{{-2.1606966275575803`, 
        2.6752818234361535`}, {-1.944566530337156, 2.6931392291954266`}}], 
       ArrowBox[{{-2.161168865355409, 
        2.9925480099290027`}, {-1.944094292539327, 3.007451990070999}}], 
       ArrowBox[{{-1.846860451379185, -2.9923760636271965`}, \
{-1.6268237591471302`, -3.0076239363728035`}}], 
       ArrowBox[{{-1.8467179274364796`, -2.67478293068165}, \
{-1.6269662830898355`, -2.693638121949929}}], 
       ArrowBox[{{-1.846164176593641, -2.3567406234631925`}, \
{-1.627520033932674, -2.3801014817999646`}}], 
       ArrowBox[{{-1.8449015505251478`, -2.038221475611504}, \
{-1.6287826600011674`, -2.0670416822832323`}}], 
       ArrowBox[{{-1.842483071643604, -1.7193322848484003`}, \
{-1.631201138882711, -1.7543519256779148`}}], 
       ArrowBox[{{-1.8383291881612287`, -1.4004909083411883`}, \
{-1.6353550223650866`, -1.4416143548167057`}}], 
       ArrowBox[{{-1.8319262857990806`, -1.0826833659495054`}, \
{-1.6417579247272345`, -1.1278429498399671`}}], 
       ArrowBox[{{-1.823399371705734, -0.7676069446983829}, \
{-1.650284838820581, -0.8113404237226686}}], 
       ArrowBox[{{-1.814401049600907, -0.45713587610829737`}, \
{-1.659283160925408, -0.49023254494433316`}}], 
       ArrowBox[{{-1.808319863847007, -0.1516314820793953}, \
{-1.665364346679308, -0.1641579916048142}}], 
       ArrowBox[{{-1.808319863847007, 
        0.15163148207939628`}, {-1.665364346679308, 0.16415799160481523`}}], 
       ArrowBox[{{-1.814401049600907, 
        0.45713587610829837`}, {-1.659283160925408, 0.49023254494433416`}}], 
       ArrowBox[{{-1.823399371705734, 
        0.7676069446983839}, {-1.650284838820581, 0.8113404237226696}}], 
       ArrowBox[{{-1.8319262857990806`, 
        1.0826833659495063`}, {-1.6417579247272345`, 1.127842949839968}}], 
       ArrowBox[{{-1.8383291881612287`, 
        1.4004909083411892`}, {-1.6353550223650866`, 1.4416143548167066`}}], 
       ArrowBox[{{-1.842483071643604, 
        1.7193322848484012`}, {-1.6312011388827108`, 1.7543519256779156`}}], 
       ArrowBox[{{-1.8449015505251478`, 
        2.038221475611505}, {-1.6287826600011674`, 2.067041682283233}}], 
       ArrowBox[{{-1.846164176593641, 
        2.3567406234631934`}, {-1.627520033932674, 2.3801014817999655`}}], 
       ArrowBox[{{-1.8467179274364796`, 
        2.674782930681651}, {-1.6269662830898355`, 2.6936381219499297`}}], 
       ArrowBox[{{-1.846860451379185, 
        2.9923760636271974`}, {-1.6268237591471302`, 3.0076239363728043`}}], 
       ArrowBox[{{-1.5327666996122258`, -2.9925821401240404`}, \
{-1.3093385635456678`, -3.0074178598759596`}}], 
       ArrowBox[{{-1.53313168649407, -2.674739107606121}, \
{-1.3089735766638237`, -2.6936819450254577`}}], 
       ArrowBox[{{-1.5332101324313216`, -2.3562025504967137`}, \
{-1.3088951307265724`, -2.380639554766444}}], 
       ArrowBox[{{-1.5326598241282363`, -2.036766841180218}, \
{-1.3094454390296577`, -2.068496316714518}}], 
       ArrowBox[{{-1.530847481441769, -1.716280382025399}, \
{-1.3112577817161248`, -1.7574038285009164`}}], 
       ArrowBox[{{-1.5266935979593934`, -1.3948959862680133`}, \
{-1.3154116651985002`, -1.4472092768898805`}}], 
       ArrowBox[{{-1.5186701630900514`, -1.0736708830967021`}, \
{-1.3234351000678424`, -1.1368554326927705`}}], 
       ArrowBox[{{-1.505574597758184, -0.7555324338871534}, \
{-1.3365306653997098`, -0.8234149345338982}}], 
       ArrowBox[{{-1.489028028711649, -0.44543503359050696`}, \
{-1.3530772344462447`, -0.5019333874621236}}], 
       ArrowBox[{{-1.4762786480442092`, -0.1465513731111883}, \
{-1.3658266151136849`, -0.16923810057302122`}}], 
       ArrowBox[{{-1.4762786480442092`, 
        0.14655137311118924`}, {-1.3658266151136849`, 0.1692381005730223}}], 
       ArrowBox[{{-1.489028028711649, 
        0.4454350335905079}, {-1.3530772344462447`, 0.5019333874621247}}], 
       ArrowBox[{{-1.505574597758184, 
        0.7555324338871543}, {-1.3365306653997098`, 0.8234149345338991}}], 
       ArrowBox[{{-1.5186701630900514`, 
        1.073670883096703}, {-1.3234351000678424`, 1.1368554326927713`}}], 
       ArrowBox[{{-1.5266935979593934`, 
        1.3948959862680141`}, {-1.3154116651985002`, 1.4472092768898814`}}], 
       ArrowBox[{{-1.530847481441769, 
        1.7162803820253998`}, {-1.3112577817161248`, 1.7574038285009173`}}], 
       ArrowBox[{{-1.5326598241282363`, 
        2.036766841180219}, {-1.3094454390296577`, 2.0684963167145187`}}], 
       ArrowBox[{{-1.5332101324313216`, 
        2.3562025504967146`}, {-1.3088951307265724`, 2.3806395547664447`}}], 
       ArrowBox[{{-1.53313168649407, 
        2.674739107606122}, {-1.3089735766638237`, 2.6936819450254585`}}], 
       ArrowBox[{{-1.5327666996122258`, 
        2.9925821401240413`}, {-1.3093385635456678`, 3.0074178598759604`}}], 
       ArrowBox[{{-1.2187688564619517`, -2.9932948116612805`}, \
{-0.9917574593275209, -3.0067051883387195`}}], 
       ArrowBox[{{-1.219805864145015, -2.6753829676115393`}, \
{-0.9907204516444577, -2.6930380850200395`}}], 
       ArrowBox[{{-1.2208377684638096`, -2.356568408997422}, \
{-0.9896885473256629, -2.3802736962657356`}}], 
       ArrowBox[{{-1.2216036694490855`, -2.036403935433616}, \
{-0.9889226463403871, -2.0688592224611204`}}], 
       ArrowBox[{{-1.2214609101197065`, -1.7142623133179267`}, \
{-0.9890654056697662, -1.7594218972083884`}}], 
       ArrowBox[{{-1.218927559144525, -1.3894603567809127`}, \
{-0.9915987566449477, -1.452644906376981}}], 
       ArrowBox[{{-1.2109041242751828`, -1.062024621768499}, \
{-0.9996221915142898, -1.1485016940209736`}}], 
       ArrowBox[{{-1.192332715040539, -0.7353070739428144}, \
{-1.0181936007489336`, -0.8436402944782372}}], 
       ArrowBox[{{-1.160519147576357, -0.42077998499254815`}, \
{-1.0500071682131156`, -0.5265884360600824}}], 
       ArrowBox[{{-1.1295464947000549`, -0.1341654282160258}, \
{-1.0809798210894177`, -0.1816240454681837}}], 
       ArrowBox[{{-1.1295464947000549`, 
        0.13416542821602667`}, {-1.0809798210894177`, 0.18162404546818484`}}],
        ArrowBox[{{-1.1605191475763572`, 
        0.42077998499254915`}, {-1.0500071682131156`, 0.5265884360600833}}], 
       ArrowBox[{{-1.192332715040539, 
        0.7353070739428154}, {-1.0181936007489334`, 0.8436402944782381}}], 
       ArrowBox[{{-1.2109041242751828`, 
        1.0620246217684999`}, {-0.9996221915142897, 1.1485016940209742`}}], 
       ArrowBox[{{-1.2189275591445248`, 
        1.3894603567809136`}, {-0.9915987566449477, 1.452644906376982}}], 
       ArrowBox[{{-1.2214609101197065`, 
        1.7142623133179276`}, {-0.9890654056697661, 1.7594218972083893`}}], 
       ArrowBox[{{-1.2216036694490855`, 
        2.0364039354336168`}, {-0.9889226463403871, 2.0688592224611213`}}], 
       ArrowBox[{{-1.2208377684638096`, 
        2.356568408997423}, {-0.989688547325663, 2.3802736962657365`}}], 
       ArrowBox[{{-1.219805864145015, 2.67538296761154}, {-0.9907204516444577,
         2.6930380850200404`}}], 
       ArrowBox[{{-1.2187688564619517`, 
        2.9932948116612814`}, {-0.991757459327521, 3.0067051883387204`}}], 
       ArrowBox[{{-0.9046703334117511, -2.994596488881107}, \
{-0.6742770350093006, -3.0054035111188924`}}], 
       ArrowBox[{{-0.9064606220975041, -2.67690440830022}, \
{-0.6724867463235473, -2.6915166443313594`}}], 
       ArrowBox[{{-0.9086742555201603, -2.358251348934688}, \
{-0.6702731129008912, -2.37859075632847}}], 
       ArrowBox[{{-0.9113273783466707, -2.037995088612363}, \
{-0.6676199900743809, -2.0672680692823735`}}], 
       ArrowBox[{{-0.9141983505288425, -1.7149753657510147`}, \
{-0.6647490178922091, -1.7587088447753005`}}], 
       ArrowBox[{{-0.9162336507921819, -1.3871113812555744`}, \
{-0.6627137176288698, -1.4549938819023192`}}], 
       ArrowBox[{{-0.9136860598256162, -1.0510965476270249`}, \
{-0.6652613085954352, -1.1594297681624477`}}], 
       ArrowBox[{{-0.8951146505909724, -0.7047261534031007}, \
{-0.6838327178300792, -0.8742212150179508}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{-0.8951146505909724, 
        0.7047261534031019}, {-0.6838327178300792, 0.8742212150179517}}], 
       ArrowBox[{{-0.9136860598256162, 
        1.0510965476270258`}, {-0.6652613085954353, 1.1594297681624484`}}], 
       ArrowBox[{{-0.9162336507921819, 
        1.3871113812555755`}, {-0.6627137176288698, 1.4549938819023203`}}], 
       ArrowBox[{{-0.9141983505288425, 
        1.7149753657510156`}, {-0.664749017892209, 1.7587088447753012`}}], 
       ArrowBox[{{-0.9113273783466707, 
        2.0379950886123637`}, {-0.6676199900743809, 2.0672680692823744`}}], 
       ArrowBox[{{-0.9086742555201603, 
        2.358251348934689}, {-0.6702731129008912, 2.378590756328471}}], 
       ArrowBox[{{-0.9064606220975041, 
        2.6769044083002207`}, {-0.6724867463235473, 2.6915166443313603`}}], 
       ArrowBox[{{-0.904670333411751, 
        2.994596488881108}, {-0.6742770350093005, 3.0054035111188933`}}], 
       ArrowBox[{{-0.590220403657753, -2.996471432245418}, \
{-0.3571480173948776, -3.0035285677545827`}}], 
       ArrowBox[{{-0.5926856722820146, -2.6793434887148044`}, \
{-0.3546827487706159, -2.6890775639167743`}}], 
       ArrowBox[{{-0.5960406662178911, -2.3614562654186084`}, \
{-0.3513277548347395, -2.3753858398445495`}}], 
       ArrowBox[{{-0.6007233667331537, -2.042199961407002}, \
{-0.3466450543194768, -2.063063196487734}}], 
       ArrowBox[{{-0.6074071989494589, -1.7202937708451396`}, \
{-0.3399612221031716, -1.7533904396811753`}}], 
       ArrowBox[{{-0.6169907461545063, -1.3928034546431385`}, \
{-0.3303776748981242, -1.449301808514755}}], 
       ArrowBox[{{-0.6297101536055877, -1.0523589323609692`}, \
{-0.31765826744704284`, -1.1581673834285033`}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{-0.6297101536055877, 
        1.0523589323609701`}, {-0.31765826744704284`, 1.158167383428504}}], 
       ArrowBox[{{-0.6169907461545063, 
        1.3928034546431396`}, {-0.33037767489812425`, 1.4493018085147562`}}], 
       ArrowBox[{{-0.6074071989494588, 
        1.7202937708451405`}, {-0.3399612221031717, 1.7533904396811761`}}], 
       ArrowBox[{{-0.6007233667331537, 
        2.042199961407003}, {-0.3466450543194768, 2.063063196487735}}], 
       ArrowBox[{{-0.596040666217891, 
        2.3614562654186093`}, {-0.3513277548347395, 2.3753858398445504`}}], 
       ArrowBox[{{-0.5926856722820146, 
        2.6793434887148053`}, {-0.3546827487706159, 2.689077563916775}}], 
       ArrowBox[{{-0.590220403657753, 
        2.9964714322454187`}, {-0.3571480173948776, 3.0035285677545835`}}], 
       ArrowBox[{{-0.2751764922287908, -2.9987712500493413`}, \
{-0.04061298145541868, -3.0012287499506587`}}], 
       ArrowBox[{{-0.27804657651181314`, -2.6824974371080295`}, \
{-0.03774289717239636, -2.6859236155235497`}}], 
       ArrowBox[{{-0.28211923257181826`, -2.3659321870937307`}, \
{-0.033670241112391225`, -2.3709099181694273`}}], 
       ArrowBox[{{-0.28816820352643957`, -2.0488194062812903`}, \
{-0.02762127015776994, -2.0564437516134464`}}], 
       ArrowBox[{{-0.29769891101914836`, -1.730578850500448}, \
{-0.018090562665061177`, -1.7431053600258668`}}], 
       ArrowBox[{{-0.31395065313773574`, -1.4097092678480305`}, \
{-0.0018388205464738017`, -1.4323959953098635`}}], 
       ArrowBox[{{-0.3448933327976794, -1.0815338492686573`}, {
        0.02910385911346991, -1.128992466520815}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{-0.34489333279767925`, 1.0815338492686584`}, {
        0.029103859113469743`, 1.1289924665208162`}}], 
       ArrowBox[{{-0.3139506531377356, 
        1.4097092678480314`}, {-0.0018388205464738572`, 
        1.4323959953098644`}}], 
       ArrowBox[{{-0.2976989110191483, 
        1.730578850500449}, {-0.018090562665061205`, 1.7431053600258677`}}], 
       ArrowBox[{{-0.28816820352643957`, 
        2.0488194062812912`}, {-0.02762127015776994, 2.0564437516134473`}}], 
       ArrowBox[{{-0.28211923257181826`, 
        2.3659321870937315`}, {-0.033670241112391225`, 2.370909918169428}}], 
       ArrowBox[{{-0.27804657651181314`, 
        2.6824974371080303`}, {-0.037742897172396386`, 2.6859236155235506`}}],
        ArrowBox[{{-0.2751764922287908, 
        2.998771250049342}, {-0.04061298145541868, 3.0012287499506596`}}], 
       ArrowBox[{{0.04061298145541968, -3.0012287499506587`}, {
        0.2751764922287918, -2.9987712500493413`}}], 
       ArrowBox[{{0.03774289717239736, -2.6859236155235493`}, {
        0.27804657651181414`, -2.682497437108029}}], 
       ArrowBox[{{0.033670241112392224`, -2.370909918169427}, {
        0.28211923257181926`, -2.36593218709373}}], 
       ArrowBox[{{0.027621270157770966`, -2.056443751613446}, {
        0.28816820352644057`, -2.04881940628129}}], 
       ArrowBox[{{0.018090562665062176`, -1.743105360025867}, {
        0.29769891101914936`, -1.730578850500448}}], 
       ArrowBox[{{0.0018388205464747731`, -1.4323959953098635`}, {
        0.31395065313773673`, -1.4097092678480305`}}], 
       ArrowBox[{{-0.029103859113468827`, -1.1289924665208153`}, {
        0.3448933327976803, -1.081533849268657}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{-0.029103859113468633`, 1.1289924665208162`}, {
        0.34489333279768014`, 1.0815338492686581`}}], 
       ArrowBox[{{0.0018388205464748564`, 1.4323959953098644`}, {
        0.3139506531377366, 1.4097092678480314`}}], 
       ArrowBox[{{0.018090562665062204`, 1.743105360025868}, {
        0.2976989110191493, 1.730578850500449}}], 
       ArrowBox[{{0.027621270157770966`, 2.056443751613447}, {
        0.28816820352644057`, 2.048819406281291}}], 
       ArrowBox[{{0.03367024111239224, 2.3709099181694278`}, {
        0.28211923257181926`, 2.365932187093731}}], 
       ArrowBox[{{0.037742897172397386`, 2.68592361552355}, {
        0.27804657651181414`, 2.68249743710803}}], 
       ArrowBox[{{0.04061298145541968, 3.0012287499506596`}, {
        0.2751764922287918, 2.998771250049342}}], 
       ArrowBox[{{0.3571480173948786, -3.003528567754582}, {
        0.5902204036577539, -2.9964714322454173`}}], 
       ArrowBox[{{0.3546827487706169, -2.6890775639167743`}, {
        0.5926856722820156, -2.6793434887148044`}}], 
       ArrowBox[{{0.3513277548347405, -2.375385839844549}, {
        0.5960406662178921, -2.361456265418608}}], 
       ArrowBox[{{0.3466450543194778, -2.063063196487734}, {
        0.6007233667331546, -2.042199961407002}}], 
       ArrowBox[{{0.3399612221031727, -1.7533904396811755`}, {
        0.6074071989494599, -1.7202937708451396`}}], 
       ArrowBox[{{0.3303776748981253, -1.4493018085147553`}, {
        0.6169907461545073, -1.3928034546431387`}}], 
       ArrowBox[{{0.31765826744704395`, -1.1581673834285033`}, {
        0.6297101536055887, -1.0523589323609692`}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{0.317658267447044, 1.1581673834285042`}, {
        0.6297101536055885, 1.0523589323609701`}}], 
       ArrowBox[{{0.3303776748981253, 1.449301808514756}, {0.6169907461545072,
         1.3928034546431394`}}], 
       ArrowBox[{{0.3399612221031727, 1.7533904396811764`}, {
        0.6074071989494599, 1.7202937708451407`}}], 
       ArrowBox[{{0.34664505431947784`, 2.063063196487735}, {
        0.6007233667331546, 2.042199961407003}}], 
       ArrowBox[{{0.3513277548347405, 2.37538583984455}, {0.5960406662178921, 
        2.361456265418609}}], 
       ArrowBox[{{0.3546827487706169, 2.689077563916775}, {0.5926856722820156,
         2.6793434887148053`}}], 
       ArrowBox[{{0.3571480173948786, 3.003528567754583}, {0.5902204036577539,
         2.9964714322454182`}}], 
       ArrowBox[{{0.6742770350093016, -3.005403511118893}, {
        0.904670333411752, -2.994596488881107}}], 
       ArrowBox[{{0.6724867463235484, -2.691516644331359}, {
        0.9064606220975051, -2.6769044083002194`}}], 
       ArrowBox[{{0.6702731129008922, -2.3785907563284696`}, {
        0.9086742555201613, -2.3582513489346875`}}], 
       ArrowBox[{{0.667619990074382, -2.0672680692823735`}, {
        0.9113273783466715, -2.037995088612363}}], 
       ArrowBox[{{0.6647490178922101, -1.7587088447753003`}, {
        0.9141983505288435, -1.7149753657510145`}}], 
       ArrowBox[{{0.6627137176288708, -1.4549938819023194`}, {
        0.9162336507921828, -1.3871113812555746`}}], 
       ArrowBox[{{0.6652613085954364, -1.1594297681624477`}, {
        0.9136860598256171, -1.0510965476270249`}}], 
       ArrowBox[{{0.6838327178300803, -0.8742212150179507}, {
        0.8951146505909733, -0.7047261534031009}}]}}, 
     {GrayLevel[0], 
      {Arrowheads[{{0.01863961030678928, 1.}}], 
       ArrowBox[{{0.6838327178300802, 0.8742212150179516}, {
        0.8951146505909734, 0.704726153403102}}], 
       ArrowBox[{{0.6652613085954363, 1.1594297681624484`}, {
        0.9136860598256172, 1.0510965476270258`}}], 
       ArrowBox[{{0.6627137176288707, 1.45499388190232}, {0.9162336507921827, 
        1.3871113812555755`}}], 
       ArrowBox[{{0.6647490178922101, 1.7587088447753012`}, {
        0.9141983505288435, 1.7149753657510156`}}], 
       ArrowBox[{{0.667619990074382, 2.0672680692823744`}, {
        0.9113273783466715, 2.0379950886123637`}}], 
       ArrowBox[{{0.6702731129008922, 2.3785907563284705`}, {
        0.9086742555201613, 2.3582513489346884`}}], 
       ArrowBox[{{0.6724867463235484, 2.69151664433136}, {0.9064606220975051, 
        2.6769044083002203`}}], 
       ArrowBox[{{0.6742770350093016, 3.0054035111188937`}, {
        0.904670333411752, 2.9945964888811085`}}], 
       ArrowBox[{{0.9917574593275218, -3.0067051883387195`}, {
        1.2187688564619525`, -2.9932948116612805`}}], 
       ArrowBox[{{0.9907204516444584, -2.6930380850200395`}, {
        1.219805864145016, -2.6753829676115393`}}], 
       ArrowBox[{{0.9896885473256639, -2.3802736962657356`}, {
        1.2208377684638103`, -2.356568408997422}}], 
       ArrowBox[{{0.988922646340388, -2.0688592224611204`}, {
        1.2216036694490864`, -2.036403935433616}}], 
       ArrowBox[{{0.9890654056697671, -1.7594218972083884`}, {
        1.2214609101197071`, -1.7142623133179267`}}], 
       ArrowBox[{{0.9915987566449486, -1.452644906376981}, {
        1.2189275591445259`, -1.3894603567809127`}}], 
       ArrowBox[{{0.9996221915142907, -1.1485016940209736`}, {
        1.2109041242751837`, -1.0620246217684992`}}], 
       ArrowBox[{{1.0181936007489345`, -0.8436402944782371}, {
        1.1923327150405398`, -0.7353070739428145}}], 
       ArrowBox[{{1.0500071682131165`, -0.5265884360600822}, {
        1.160519147576358, -0.4207799849925483}}], 
       ArrowBox[{{1.0809798210894186`, -0.18162404546818364`}, {
        1.129546494700056, -0.13416542821602587`}}], 
       ArrowBox[{{1.0809798210894184`, 0.18162404546818478`}, {
        1.1295464947000557`, 0.13416542821602673`}}], 
       ArrowBox[{{1.0500071682131162`, 0.5265884360600833}, {
        1.160519147576358, 0.42077998499254926`}}], 
       ArrowBox[{{1.0181936007489345`, 0.8436402944782381}, {
        1.1923327150405398`, 0.7353070739428155}}], 
       ArrowBox[{{0.9996221915142905, 1.1485016940209745`}, {
        1.210904124275184, 1.0620246217684999`}}], 
       ArrowBox[{{0.9915987566449486, 1.452644906376982}, {
        1.2189275591445259`, 1.3894603567809136`}}], 
       ArrowBox[{{0.9890654056697671, 1.7594218972083893`}, {
        1.2214609101197071`, 1.7142623133179276`}}], 
       ArrowBox[{{0.988922646340388, 2.0688592224611213`}, {
        1.2216036694490864`, 2.0364039354336168`}}], 
       ArrowBox[{{0.9896885473256639, 2.3802736962657365`}, {
        1.2208377684638103`, 2.356568408997423}}], 
       ArrowBox[{{0.9907204516444584, 2.6930380850200404`}, {
        1.219805864145016, 2.67538296761154}}], 
       ArrowBox[{{0.9917574593275218, 3.0067051883387204`}, {
        1.2187688564619525`, 2.9932948116612814`}}], 
       ArrowBox[{{1.309338563545669, -3.0074178598759596`}, {
        1.532766699612227, -2.9925821401240404`}}], 
       ArrowBox[{{1.3089735766638246`, -2.6936819450254577`}, {
        1.533131686494071, -2.674739107606121}}], 
       ArrowBox[{{1.308895130726573, -2.380639554766444}, {
        1.5332101324313223`, -2.3562025504967137`}}], 
       ArrowBox[{{1.3094454390296586`, -2.0684963167145183`}, {
        1.5326598241282372`, -2.0367668411802184`}}], 
       ArrowBox[{{1.3112577817161257`, -1.7574038285009161`}, {
        1.5308474814417699`, -1.7162803820253987`}}], 
       ArrowBox[{{1.3154116651985013`, -1.4472092768898805`}, {
        1.5266935979593945`, -1.3948959862680133`}}], 
       ArrowBox[{{1.3234351000678433`, -1.1368554326927705`}, {
        1.5186701630900523`, -1.0736708830967021`}}], 
       ArrowBox[{{1.3365306653997107`, -0.8234149345338981}, {
        1.505574597758185, -0.7555324338871534}}], 
       ArrowBox[{{1.3530772344462456`, -0.5019333874621236}, {
        1.48902802871165, -0.445435033590507}}], 
       ArrowBox[{{1.3658266151136855`, -0.1692381005730212}, {
        1.47627864804421, -0.14655137311118832`}}], 
       ArrowBox[{{1.3658266151136855`, 0.16923810057302227`}, {
        1.47627864804421, 0.14655137311118926`}}], 
       ArrowBox[{{1.3530772344462456`, 0.5019333874621246}, {1.48902802871165,
         0.44543503359050796`}}], 
       ArrowBox[{{1.3365306653997107`, 0.8234149345338991}, {
        1.505574597758185, 0.7555324338871544}}], 
       ArrowBox[{{1.3234351000678433`, 1.1368554326927713`}, {
        1.5186701630900523`, 1.0736708830967032`}}], 
       ArrowBox[{{1.3154116651985013`, 1.4472092768898814`}, {
        1.5266935979593945`, 1.3948959862680141`}}], 
       ArrowBox[{{1.3112577817161257`, 1.757403828500917}, {
        1.5308474814417699`, 1.7162803820253996`}}], 
       ArrowBox[{{1.3094454390296586`, 2.068496316714519}, {
        1.5326598241282372`, 2.0367668411802193`}}], 
       ArrowBox[{{1.308895130726573, 2.3806395547664447`}, {
        1.5332101324313223`, 2.3562025504967146`}}], 
       ArrowBox[{{1.3089735766638246`, 2.6936819450254585`}, {
        1.533131686494071, 2.674739107606122}}], 
       ArrowBox[{{1.309338563545669, 3.0074178598759604`}, {1.532766699612227,
         2.9925821401240413`}}], 
       ArrowBox[{{1.6268237591471308`, -3.0076239363728035`}, {
        1.8468604513791858`, -2.9923760636271965`}}], 
       ArrowBox[{{1.6269662830898364`, -2.693638121949929}, {
        1.8467179274364804`, -2.67478293068165}}], 
       ArrowBox[{{1.627520033932675, -2.380101481799965}, {
        1.8461641765936418`, -2.356740623463193}}], 
       ArrowBox[{{1.6287826600011681`, -2.0670416822832323`}, {
        1.8449015505251485`, -2.038221475611504}}], 
       ArrowBox[{{1.631201138882712, -1.7543519256779148`}, {
        1.842483071643605, -1.7193322848484003`}}], 
       ArrowBox[{{1.6353550223650872`, -1.4416143548167055`}, {
        1.8383291881612296`, -1.400490908341188}}], 
       ArrowBox[{{1.6417579247272354`, -1.1278429498399671`}, {
        1.8319262857990815`, -1.0826833659495054`}}], 
       ArrowBox[{{1.650284838820582, -0.8113404237226686}, {
        1.8233993717057349`, -0.7676069446983829}}], 
       ArrowBox[{{1.6592831609254088`, -0.4902325449443331}, {
        1.814401049600908, -0.45713587610829737`}}], 
       ArrowBox[{{1.6653643466793089`, -0.16415799160481417`}, {
        1.8083198638470082`, -0.15163148207939534`}}], 
       ArrowBox[{{1.6653643466793089`, 0.16415799160481523`}, {
        1.8083198638470082`, 0.1516314820793963}}], 
       ArrowBox[{{1.6592831609254088`, 0.49023254494433416`}, {
        1.814401049600908, 0.45713587610829837`}}], 
       ArrowBox[{{1.650284838820582, 0.8113404237226696}, {
        1.8233993717057349`, 0.7676069446983839}}], 
       ArrowBox[{{1.6417579247272354`, 1.127842949839968}, {
        1.8319262857990815`, 1.0826833659495063`}}], 
       ArrowBox[{{1.6353550223650872`, 1.4416143548167064`}, {
        1.8383291881612294`, 1.400490908341189}}], 
       ArrowBox[{{1.631201138882712, 1.7543519256779156`}, {
        1.8424830716436051`, 1.7193322848484012`}}], 
       ArrowBox[{{1.6287826600011681`, 2.067041682283233}, {
        1.8449015505251485`, 2.038221475611505}}], 
       ArrowBox[{{1.627520033932675, 2.380101481799966}, {1.8461641765936418`,
         2.356740623463194}}], 
       ArrowBox[{{1.6269662830898364`, 2.6936381219499297`}, {
        1.8467179274364804`, 2.674782930681651}}], 
       ArrowBox[{{1.6268237591471308`, 3.0076239363728043`}, {
        1.8468604513791858`, 2.9923760636271974`}}], 
       ArrowBox[{{1.944094292539328, -3.007451990070998}, {
        2.16116886535541, -2.992548009929002}}], 
       ArrowBox[{{1.9445665303371569`, -2.693139229195426}, {
        2.160696627557581, -2.675281823436153}}], 
       ArrowBox[{{1.945462016840024, -2.379066630015335}, {
        2.159801141054714, -2.3577754752478226`}}], 
       ArrowBox[{{1.9469906125669225`, -2.065168195930715}, {
        2.1582725453278155`, -2.040094961964021}}], 
       ArrowBox[{{1.949409091448466, -1.7512522085990216`}, {
        2.155854066446272, -1.7224320019272934`}}], 
       ArrowBox[{{1.9529568387357652`, -1.4369173693460968`}, {
        2.152306319158973, -1.405187893811797}}], 
       ArrowBox[{{1.9576901577408252`, -1.1214908014084886`}, {
        2.147573000153913, -1.0890355143809838`}}], 
       ArrowBox[{{1.9632033403226208`, -0.8041101745455311}, {
        2.1420598175721173`, -0.7748371938755204}}], 
       ArrowBox[{{1.9683888023933143`, -0.4841158280666813}, {
        2.136874355501424, -0.4632525929859493}}], 
       ArrowBox[{{1.9716231128708106`, -0.16170690950818267`}, {
        2.1336400450239275`, -0.15408256417602684`}}], 
       ArrowBox[{{1.9716231128708106`, 0.1617069095081837}, {
        2.1336400450239275`, 0.1540825641760278}}], 
       ArrowBox[{{1.9683888023933143`, 0.4841158280666823}, {
        2.136874355501424, 0.46325259298595023`}}], 
       ArrowBox[{{1.9632033403226208`, 0.8041101745455321}, {
        2.1420598175721173`, 0.7748371938755214}}], 
       ArrowBox[{{1.957690157740825, 1.1214908014084894`}, {
        2.1475730001539133`, 1.0890355143809847`}}], 
       ArrowBox[{{1.9529568387357652`, 1.4369173693460977`}, {
        2.152306319158973, 1.4051878938117979`}}], 
       ArrowBox[{{1.949409091448466, 1.7512522085990225`}, {2.155854066446272,
         1.7224320019272943`}}], 
       ArrowBox[{{1.9469906125669225`, 2.065168195930716}, {
        2.1582725453278155`, 2.040094961964022}}], 
       ArrowBox[{{1.945462016840024, 2.379066630015336}, {2.159801141054714, 
        2.3577754752478235`}}], 
       ArrowBox[{{1.9445665303371569`, 2.693139229195427}, {2.160696627557581,
         2.675281823436154}}], 
       ArrowBox[{{1.944094292539328, 3.007451990070999}, {2.16116886535541, 
        2.9925480099290027`}}], 
       ArrowBox[{{2.2611018977763386`, -3.0070335840487705`}, {
        2.4757402074868207`, -2.9929664159512295`}}], 
       ArrowBox[{{2.2617536055376335`, -2.69239029450149}, {
        2.475088499725526, -2.676030758130089}}], 
       ArrowBox[{{2.262780086251133, -2.377837444943515}, {
        2.474062019012026, -2.3590046603196426`}}], 
       ArrowBox[{{2.2643086819780316`, -2.0632771563311243`}, {
        2.472533423285128, -2.041986001563612}}], 
       ArrowBox[{{2.26646119120117, -1.7485225344315436`}, {
        2.4703809140619897`, -1.7251616760947714`}}], 
       ArrowBox[{{2.269296620723061, -1.433271133713812}, {
        2.467545484540098, -1.4088341294440816`}}], 
       ArrowBox[{{2.2727137304397598`, -1.1171158015288931`}, {
        2.4641283748233995`, -1.0934105142605794`}}], 
       ArrowBox[{{2.276339691180321, -0.7996433879074167}, {
        2.460502414082838, -0.7793039805136348}}], 
       ArrowBox[{{2.279495575562262, -0.48064899773928577`}, {
        2.457346529700897, -0.4667194233133448}}], 
       ArrowBox[{{2.2813636156004, -0.160383602379953}, {
        2.4554784896627595`, -0.1554058713042565}}], 
       ArrowBox[{{2.2813636156004, 0.160383602379954}, {2.4554784896627595`, 
        0.15540587130425748`}}], 
       ArrowBox[{{2.279495575562262, 0.48064899773928677`}, {
        2.457346529700897, 0.46671942331334576`}}], 
       ArrowBox[{{2.276339691180321, 0.7996433879074177}, {2.460502414082838, 
        0.7793039805136358}}], 
       ArrowBox[{{2.2727137304397598`, 1.117115801528894}, {
        2.4641283748233995`, 1.0934105142605803`}}], 
       ArrowBox[{{2.269296620723061, 1.4332711337138129`}, {2.467545484540098,
         1.4088341294440825`}}], 
       ArrowBox[{{2.26646119120117, 1.7485225344315445`}, {
        2.4703809140619897`, 1.7251616760947723`}}], 
       ArrowBox[{{2.2643086819780316`, 2.063277156331125}, {2.472533423285128,
         2.041986001563613}}], 
       ArrowBox[{{2.262780086251133, 2.377837444943516}, {2.474062019012026, 
        2.3590046603196435`}}], 
       ArrowBox[{{2.2617536055376335`, 2.692390294501491}, {2.475088499725526,
         2.6760307581300897`}}], 
       ArrowBox[{{2.2611018977763386`, 3.0070335840487714`}, {
        2.4757402074868207`, 2.9929664159512304`}}], 
       ArrowBox[{{2.577847450797103, -3.0064789236569935`}, {
        2.7905736018344776`, -2.993521076343006}}], 
       ArrowBox[{{2.5785695599353438`, -2.6915416275967083`}, {
        2.789851492696237, -2.67687942503487}}], 
       ArrowBox[{{2.5795960406488434`, -2.3766008208172793`}, {
        2.788825011982737, -2.360241284445878}}], 
       ArrowBox[{{2.5809936421651094`, -2.061560281827005}, {
        2.7874274104664716`, -2.043702876067732}}], 
       ArrowBox[{{2.5828044157282193`, -1.746269700897297}, {
        2.7856166369033613`, -1.727414509629018}}], 
       ArrowBox[{{2.5850076484700204`, -1.4305240502886152`}, {
        2.7834134041615606`, -1.4115812128692784`}}], 
       ArrowBox[{{2.5874712998051757`, -1.1140907165989864`}, {
        2.7809497528264044`, -1.0964355991904862`}}], 
       ArrowBox[{{2.5899155314418754`, -0.7967798022260955}, {
        2.7785055211897047`, -0.7821675661949561}}], 
       ArrowBox[{{2.5919300553105966`, -0.4785512481273002}, {
        2.7764909973209844`, -0.4688171729253303}}], 
       ArrowBox[{{2.5930804332246056`, -0.15960782604986481`}, {
        2.775340619406975, -0.15618164763434467`}}], 
       ArrowBox[{{2.5930804332246056`, 0.15960782604986584`}, {
        2.775340619406975, 0.1561816476343457}}], 
       ArrowBox[{{2.5919300553105966`, 0.4785512481273012}, {
        2.7764909973209844`, 0.4688171729253313}}], 
       ArrowBox[{{2.5899155314418754`, 0.7967798022260965}, {
        2.7785055211897047`, 0.782167566194957}}], 
       ArrowBox[{{2.5874712998051757`, 1.1140907165989873`}, {
        2.7809497528264044`, 1.096435599190487}}], 
       ArrowBox[{{2.5850076484700204`, 1.430524050288616}, {
        2.7834134041615606`, 1.4115812128692793`}}], 
       ArrowBox[{{2.5828044157282193`, 1.7462697008972978`}, {
        2.7856166369033613`, 1.727414509629019}}], 
       ArrowBox[{{2.5809936421651094`, 2.061560281827006}, {
        2.7874274104664716`, 2.0437028760677327`}}], 
       ArrowBox[{{2.5795960406488434`, 2.37660082081728}, {2.788825011982737, 
        2.360241284445879}}], 
       ArrowBox[{{2.5785695599353438`, 2.6915416275967092`}, {
        2.789851492696237, 2.676879425034871}}], 
       ArrowBox[{{2.577847450797103, 3.0064789236569944`}, {
        2.7905736018344776`, 2.993521076343007}}], 
       ArrowBox[{{2.8943590336195544`, -3.0058689425766913`}, {
        3.1056409663804474`, -2.994131057423308}}], 
       ArrowBox[{{2.895081142757795, -2.690689449972783}, {
        3.1049188572422066`, -2.6777316026587954`}}], 
       ArrowBox[{{2.896037222094349, -2.3754546366803493`}, {
        3.1039627779056533`, -2.3613874685828082`}}], 
       ArrowBox[{{2.897255353647149, -2.0600835690183663`}, {
        3.102744646352853, -2.04517958887637}}], 
       ArrowBox[{{2.8987364133551354`, -1.744466041635961}, {
        3.101263586644867, -1.729218168890354}}], 
       ArrowBox[{{2.9004321352723865`, -1.4284704914549065`}, {
        3.099567864727615, -1.4136347717029873`}}], 
       ArrowBox[{{2.902223765806323, -1.1119683462334558`}, {
        3.0977762341936788`, -1.0985579695560168`}}], 
       ArrowBox[{{2.903914716440333, -0.7948771953294185}, {
        3.096085283559669, -0.7840701730916331}}], 
       ArrowBox[{{2.9052542603705453`, -0.4772127782808976}, {
        3.0947457396294564`, -0.47015564277173294`}}], 
       ArrowBox[{{2.9059998226257937`, -0.15912348679276336`}, {
        3.094000177374208, -0.15666598689144615`}}], 
       ArrowBox[{{2.9059998226257937`, 0.15912348679276436`}, {
        3.094000177374208, 0.15666598689144712`}}], 
       ArrowBox[{{2.9052542603705453`, 0.4772127782808986}, {
        3.0947457396294564`, 0.4701556427717339}}], 
       ArrowBox[{{2.903914716440333, 0.7948771953294195}, {3.096085283559669, 
        0.7840701730916341}}], 
       ArrowBox[{{2.902223765806323, 1.1119683462334566`}, {
        3.0977762341936788`, 1.0985579695560177`}}], 
       ArrowBox[{{2.9004321352723865`, 1.4284704914549073`}, {
        3.099567864727615, 1.4136347717029882`}}], 
       ArrowBox[{{2.8987364133551354`, 1.7444660416359619`}, {
        3.101263586644867, 1.729218168890355}}], 
       ArrowBox[{{2.897255353647149, 2.060083569018367}, {3.102744646352853, 
        2.045179588876371}}], 
       ArrowBox[{{2.896037222094349, 2.37545463668035}, {3.103962777905653, 
        2.361387468582809}}], 
       ArrowBox[{{2.895081142757795, 2.690689449972784}, {3.1049188572422066`,
         2.6777316026587963`}}], 
       ArrowBox[{{2.8943590336195544`, 3.0058689425766922`}, {
        3.1056409663804474`, 2.994131057423309}}]}}}}, 
   GraphicsComplexBox[CompressedData["
1:eJyVnXl4VUW29pOTcAhoIw7tgK2tIqig4tTOUCUKKKLt0K04tCioOKBiO1xn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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVzbtPU2EAxuHPWIO9BJqI2i6EumpCC1QB+yegAySIg9UYUQeRARIus6OG
QAQHEx1p1cSFAdhIuphoCrJh44WoMKGLDkYIzxme/M739px+udtjAw+PhRCe
UY+H8JuJZAjjzKRCmOa9bZ9R2wPu2+7xznbXeYQ7lBIhDNlr9lvONynTY++3
r9uvOw9zjaJ9ij2/TWpBO7VDC5rXCT2nF7Rdz2tO3/CaDFlOc5YzVKl7b4Pn
NJyX3f3B81vdoeT+y6T8loz+z/aNPlsvJ2yx6A5bj/MlLpLzH4f6yl7Ubrpo
s//Tqv0rnZ4L/OUPFdsX8p47+MU+S7bP3PD9ovvKusoKT513vbPHd37ygzn7
PA3PWe9ta0Y/6aBuaVo3tUU/6hXd8c1VbXU+RcJzTRfcn47epZkm+5rO2+N6
MtqI2Ss6a98i5vk4L3nBY9smB977z5No45F7jwAW8U8X
          "]]},
        "2.64`"],
       Annotation[#, 2.64, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVz78uQ2EYx/FHLBSzgUXYtK6CTdLEwMCAC+ACXEFPbSZaJv13AVpmF9AO
Bu2kSHSWNJFo6Ocdvvn+3uf8nnPes3Z6vnc2ExFFlOcjsoWIXy7xhMu8nYuo
8p9zhf/5lnfMazzL99xAHdliRJs7eMATHnGZ5rrX9l/kXbmBvvMNujo9rGAV
g/Qd9OVlvXXewIH8aX+fh6nPb/yBd1x51kl3s/sqH8pNtFBP7zM7ksfyiH/4
wt6XnOdNbKGAO92T9P98zHNL7iRn8jc/Y4wpjHs0TQ==
          "]], LineBox[CompressedData["
1:eJwVz71KgmEYgOGnsWzp5wSiTcgTCIpaMm3y5wTEatOtmipIqFNQCoISmhrC
LZBazexvCBoabQ1dGru+4eLmed+Hl+9bqNQLtYmIKHI8FXEwHbGue7qm+3qk
O7qqVV3RbT3Usi5rQUsU6ZAjzwabZLnjw+6LnutAL/SdN7qTET+UUt4h436J
e2db5jw50nbrDN3VdF4XdUbnmOWGgbMn7dOjZX7WXe1z690vczP5Pz454Zur
5JvcXeuIMW0aPDo/0wc91Ve9THb0lz/+AX72Mhs=
          "]]},
        "1.76`"],
       Annotation[#, 1.76, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], 
         LineBox[{2442, 2949, 2950, 2948, 2952, 2951, 3203, 2967, 2968, 2966, 
          2970, 2969, 3207, 2740, 2741, 2632, 3209, 2631, 2517, 2449, 2995, 
          2996, 2828, 2829, 2519, 2452, 3010, 3011, 2833, 2834, 2520, 2456, 
          3022, 2574, 2840, 2841, 2842, 2460, 3285, 2642, 2581, 3031, 2582, 
          3032, 2645, 3216, 2702, 3306, 2703, 2551, 2787, 2788, 2739, 3309, 
          2738, 3310, 2857, 2858, 2525, 2467, 2799, 2721, 2798, 2722, 2781, 
          2780, 2546, 3327, 3322, 3334, 3197, 3329}], 
         LineBox[{3259, 3188, 3189, 3185, 3187, 3186, 3257, 3170, 3171, 3167, 
          3169, 3168, 3255, 2773, 2774, 2718, 3297, 2504, 2772, 2499, 2539, 
          2909, 2908, 3142, 3141, 2496, 2537, 2902, 2901, 3130, 3129, 2493, 
          2898, 2897, 2896, 2608, 3116, 2490, 3294, 2675, 2601, 3102, 2600, 
          3103, 2669, 3242, 2700, 3305, 2701, 2550, 2704, 3307, 2705, 2553, 
          2804, 2805, 2806, 3200, 3199, 2483, 2879, 2878, 2877, 2719, 2779, 
          2778, 2548, 3325, 3323, 3195, 3330}]},
        "0.88`"],
       Annotation[#, 0.88, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], 
         LineBox[{13, 38, 63, 88, 113, 138, 163, 188, 1999, 2399}], 
         LineBox[{565, 540, 515, 490, 465, 440, 415, 390, 657, 2020, 3332, 
          3333}]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], 
         LineBox[{2510, 2543, 2930, 2929, 3184, 3183, 2507, 2541, 2923, 2922, 
          3166, 3165, 2503, 2540, 2733, 2685, 3296, 2502, 2750, 3251, 3139, 
          3140, 3136, 3138, 3137, 3249, 3127, 3128, 3124, 3126, 3125, 3247, 
          2678, 3115, 2607, 3113, 2606, 3114, 2673, 3303, 2674, 2889, 2888, 
          2599, 3101, 2488, 2534, 2732, 2668, 2789, 2790, 2726, 2487, 2776, 
          2777, 2736, 2737, 2786, 2785, 2547, 3328, 3324, 3335, 3198, 3331}], 
         LineBox[{3202, 2946, 2947, 2810, 2811, 2512, 2441, 2964, 2965, 2817, 
          2818, 2514, 2446, 2751, 2752, 2706, 3269, 3271, 3270, 2753, 3208, 
          2991, 2992, 2990, 2994, 2993, 3211, 3006, 3007, 3005, 3009, 3008, 
          3214, 2635, 3020, 2572, 3019, 2573, 3021, 2640, 3299, 2641, 2580, 
          2848, 2849, 2850, 2464, 2757, 2758, 2648, 2793, 2795, 2794, 2796, 
          2797, 2734, 2735, 2784, 2783, 2545, 3326, 3319, 3196, 3321}]},
        RowBox[{"-", "0.88`"}]],
       Annotation[#, -0.88, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVz7tOAlEUBdBjiY9ID43G108gBvkApFQbQOMrAUqVjsKG71ATE4ihoFFC
YqQx8RPsIDE0SmPtmmJl37Pv3Dsza9VGub4QESU+UxHNpYgGdfYW5XLEh/7C
fM4ZOf2xfqyvmatUONCVeNPPONIdktftMtJ9c+v8s7klh7zSM2+zwwZbbNKl
aT+bdDKT9PKKL+uB+4resU+BtG6Vvn6SfLfnHsyX8lGuyxdOmJpP5RP31jX5
y5yus0Nd23ok7+S1+29IrfgH2dH92Hvnj38TjCyV
          "]], LineBox[CompressedData["
1:eJwVzb9KwmEUxvFTkKA25ebWVPfhriAttQRdgE3V7BDoIAqCWg2CNdYdRINF
ao2VLUE30CIIVtCfz2/48j3P8x7Ou763X64sRUQRhUxENRvxnY5YmD/xhZrc
1v/wr/yHkBvyOS/LK5zCs66FS/MVMshimtzA0G6Xn1Zl8x1u0ZBH9sa4xwMm
aOpL3qfmNX7hHG8lnbe+W++6vLzBm3jTDTDRXfCrvY55G4/J//jQ9XgHZ+Zd
7vEpTnCNqu6Gj/nA3UMcoS7P9EPM8Q8lgDOr
          "]]},
        RowBox[{"-", "1.76`"}]],
       Annotation[#, -1.76, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV0D9IlGEAx/HnCs3zSmhQIbr+YLq1pBhqgQ4VBp7QotbmpP3RqSEw06Hc
tCITFOrudFGXGoxKV9Eao03UQRxKAyvBIqM+z/Dh+7w/3nvv7j3d2XutJxFC
GGcoGcL9VAj99DHAAwYPhzCijxnmKU94aH9EzjkUh5DVhOb1ss5ogU5roc5q
sy5okc5rUq/yyXOe+/5FW8p1qZZRzoT9sx61p/UEJ3lhX9U1KqlixZZjyb3L
jMZ69jP9oB/jpl/du8UXvrHNmP27/mCHXX7y0p7ll/Nxn9/TtP7WTt2Pv0f/
6Cn9q/n4Xggk+Gc7qAeY5BBFFFJMkine+/wrv3/FuSu+MzZcv+aIrYRGz2pi
0zbHMdsZ912K750rvLNX2M/aW1xnaGXBvm6/a6/mnHNNPOs9vaC12qDn9aL2
aUbr4rO0Xlv1DXO000EbN7jOW25yi27ucDv+P/4DdeBRXg==
          "]]},
        RowBox[{"-", "2.64`"}]],
       Annotation[#, -2.64, 
        "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJyU/XmcztX/P45fs10zJEmKLNGunUgSHk8kUmlRSCqRUJZSRCoTEmXLUshW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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0UdWk1EAR/GXiYxEdAcuAaSMhC1gcAO4AFkBQ2kKTFkBKAgCUg01IaE3
UVGqdJhRlI7yy+Cem//93neSnPf0VVn0dSSE0ICiRyG8zAqhIDOEn09COLMT
2Mce6rR8z2q5xLnWxyF8xDs7T3/LUb1Fa0aVnauXe7cQ1fZzruF6jnh26NwR
9nCAfQR9h3fxG9vYwv+HIWzwJlaxjjX801d4Lv27eZZ/8Z2+zDP2d57mH3yr
f+Mp+ytP8hLf6Is8Yc/zOC/wtT7HKXuGkzzLV/o0j9mTnOApvtQnOG6neJTH
+UJP8oid4GEe43M9zkP2CA/yKP/Vh3nAHuQYD/EfPZbu6MMX9ONM7+FefEY3
unCqd3An2tCOTzjRO93Dcfr/uZNSnzvQjm77me/r4hfu9IPz71Fp5+gVXKw3
aY14Y2fry3zq/Th2sYMM5x7gHpOedxI=
          "]]},
        "2.52`"],
       Annotation[#, 2.52, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0WdSU1EcQPHLAhRlBywA8QuCwAIUEGZYgcNQrEGREiHEhISqYAcpNtQZ
LCGY2HAL6hqkqEh1C/7y4cx5//Puu+++pLSlszlSFEKYxp9DIQwdDSGFG0gi
gd96nD8cDiHGeR7kX/oA58zX+T3386b+oySE2uIQ0tx0JIQV96Lu1WgpbQiN
elbv06v1pJbAGb1X6ymcw3zcmjg36N3aNQyYywvn8dxJxMxVPMhT/M8ZXlr3
Cs/xAos40J/yMyzgCR5jX5/jeTzCV3vP8p4+w6vmh/yFp3lXf8Cfzff4E9/n
Hf0ufzRP8R3cxrZ+iycxjpuYwF99lMeQxgiGsaVnfccGf/dNZ10vI4O8+Zj9
c1zvN+my/ir6zWWF/4Lr9GXXV/RKz0S1PpzWM3qnfkLv1XpwSn+nV2jfzOve
G7HmrXaJ3/BlXtMv8mvzeV7iC/xT7+BzaEU72tBtr/+Oe16f
          "]]},
        "1.8900000000000001`"],
       Annotation[#, 1.8900000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0VlSU0EUh/F2AaC4A54EI4oGRcWQAYw4a3AgCZmZVEwctgEPVGnxhrNU
QUTZho9WCSoma+F3H7769/lOd5+ue/vrrVzzSAhhDb96Qoj3hfCmN4TEsRDy
x0MoIHY0hBH+LT/OF7lZnOJL8rzeBST12uoT9pX0vlnvoIwO1g1alE+whN/m
XXEugTG8j+6Xe3xKflAn5Ud51n1dZ4ZlmvvETZr3lHuG51hGRm8CV/W+q0/a
90NuOVfGrnVFtrGNf2bdtz+He3iAaRzwj+RjPEQeM/jPF+UsCiijhA5flTVU
0EAdXX7FnFWcw0/z97mYdzWtJ6O3Iuu9reib8i/kS2T5z+preq/UrxGP/gW+
RF7/q5ySf9x5Q26qr8tbuIm//B15F7ejvn+Qcl/FXQP2VuUofxFpvqYe5Oty
yJxL/IY6o9fg5nCav8y/4yf4eW4BZ/hDikhHAQ==
          "]]},
        "1.26`"],
       Annotation[#, 1.26, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0WdOlFEUh/GLyEdBioKAMgNDRykJxbIDbCACgp9cgC6ABdAFNBELhFBE
R7fBzEAUIsFEqQor4fd+ePKc83/PufdmJv7iVe/LrBDCEjYuhZCfH0IB2i+H
0F0QQkVuCPe5UFaEDvmqPiZf4+W8EAbwWT3Iq1hB2lml5stwDddRjoy8gift
3+ApjvGmPO2MSrvTstvuWdd/wTPZV16L7sEQMvotO+vqHW50RhMaMGe/Vn5k
poZvyt7I7jozKatWf4vO9m0Y39XPORndgz3nZZn9q35n9g/P8z5fkB/ye/0B
f+Ajzpaf8Ef9MX/if3xRfsoL+v+8yGecI//tngn1JOqw5R2/ZDVm+tW3vLsZ
98wORL8v6s014K2ZFt/a0Ipde+PyJ2b60IuEfgQJsz36KnXc7Gv9HWc+jX4L
2Sb/sF/l24xvlTzLCf4ZvYdrUY161GFbPmp3DDGknJGSxe09UF8xcxWd7nkY
/a/yR1wsK0GX/HH0Jnnc/jncRU5z
          "]]},
        "0.63`"],
       Annotation[#, 0.63, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[{3509, 3610, 4955, 4958, 4960}], 
         LineBox[{281, 282, 283, 284, 285, 286, 287, 288, 687, 2502, 3117, 
          5084, 3523}], 
         LineBox[{297, 296, 295, 294, 293, 292, 291, 2614, 290, 652, 2500, 
          3059, 3394}], LineBox[{3530, 5057, 3535, 5100, 5101}], 
         LineBox[{3641, 4927, 4926, 5060, 3640, 5061}], 
         LineBox[{3643, 4928, 3642, 5098, 3644, 5099}], LineBox[{3645, 5016}],
          LineBox[{3646, 5070, 3647, 5073, 5075, 5074, 4818, 5076, 5077}], 
         LineBox[{3652, 4952, 3653, 5029, 5030}], 
         LineBox[{3654, 4936, 3655, 4939, 4941}], 
         LineBox[{3656, 4942, 3657, 4947, 4949}], 
         LineBox[{3658, 5081, 3659, 5093, 5094, 4914}], 
         LineBox[{3662, 3808, 3513, 5119, 3661, 3818, 4853}], 
         LineBox[{3663, 3819, 3664, 5120, 3518, 3806, 4854}], 
         LineBox[{3665, 3820, 3666, 5121, 3519, 3807, 4855}], 
         LineBox[{3667, 3905, 5103, 5102, 3668, 3821, 4856}], 
         LineBox[{3795, 3805, 3793, 5122, 3794, 3823, 4846}], 
         LineBox[{3801, 3809, 3800, 5105, 3802, 3824, 4852}], 
         LineBox[{3811, 4907, 4906, 5065, 3810, 5066, 4864}], 
         LineBox[{3812, 4908, 5123, 5124, 3813, 5067, 4898}], 
         LineBox[{3814, 4931, 4930, 4934, 3815, 4909}], 
         LineBox[{3817, 4933, 4932, 4910, 3816, 4911}], 
         LineBox[{3907, 5118, 3908, 5024, 5025}], 
         LineBox[{3909, 5043, 3910, 5031, 5033}], 
         LineBox[{3911, 4865, 4866, 4817, 4893, 4967, 4892}], 
         LineBox[{3912, 5026, 3913, 5038, 5040}], 
         LineBox[{3914, 5089, 3915, 4835, 5011}], 
         LineBox[{3916, 5091, 3917, 4839, 5010}], 
         LineBox[{3943, 4966, 3944, 4922, 4923}], 
         LineBox[{3950, 4940, 3951, 4956, 4957}], 
         LineBox[{3952, 4959, 3953, 4943, 4944}], 
         LineBox[{3954, 4948, 3955, 4945, 4946, 4975, 4998}], 
         LineBox[{3956, 4912, 4913, 4986}], LineBox[{3957, 4915, 4916, 4987}],
          LineBox[{3958, 4961, 5017, 5018}], 
         LineBox[{3959, 5108, 5107, 4895}], LineBox[{4033, 4999, 5006}], 
         LineBox[{4072, 5110, 5109, 4040, 4929, 4039, 4979}], 
         LineBox[{4751, 5112, 5111, 4182, 4925, 4181, 4984}], 
         LineBox[{4790, 5116, 4791, 5090, 4904}], 
         LineBox[{4792, 5117, 4793, 5092, 4905}], 
         LineBox[{4815, 5115, 4816, 5071, 5072}], 
         LineBox[{4819, 5079, 4820, 5027, 5028}], 
         LineBox[{4821, 5032, 4822, 5082, 5083}], 
         LineBox[{4831, 5039, 4832, 5085, 5086}], 
         LineBox[{4833, 4836, 4834, 5087, 5088}], 
         LineBox[{4837, 4840, 4838, 5058, 5059}], 
         LineBox[{4842, 4841, 4875, 4876}], 
         LineBox[{4843, 3822, 3792, 5104, 3791, 3904, 4857}], 
         LineBox[{4845, 4844, 4877, 4878}], LineBox[{4848, 4847, 4883, 4884}],
          LineBox[{4849, 5069, 3799, 5062, 3798, 5063, 5064, 4860}], 
         LineBox[{4851, 5106, 4850, 5114, 5113, 4885, 4886}], 
         LineBox[{4863, 3906, 4903}], LineBox[{4869, 3942, 4983}], 
         LineBox[{4870, 4019, 5023, 4020, 5021, 5020, 5022, 5041}], 
         LineBox[{4871, 4021, 5008, 4022, 4994, 4993, 3938, 5012}], 
         LineBox[{4873, 4037, 4861, 3803, 4887, 4888}], 
         LineBox[{4874, 4872, 4036, 4919}], 
         LineBox[{4880, 4879, 3796, 4858, 4896, 4897, 4978}], 
         LineBox[{4882, 5125, 4881, 3797, 4859, 3940, 4867, 4976}], 
         LineBox[{4890, 4889, 3804, 4862, 3941, 4868, 4977}], 
         LineBox[{4891, 5042}], 
         LineBox[{4901, 4985, 4902, 4894, 4900, 4962, 4899, 4963, 3939, 
          4981}], LineBox[{4917, 4025, 5049, 4026, 5047, 5046, 5048, 5053}], 
         LineBox[{4918, 4027, 5052, 4028, 5051, 5126, 5050, 5054}], 
         LineBox[{4938, 4937, 3949, 4935, 3948, 4971, 4997}], 
         LineBox[{4954, 4953, 4091, 4964, 4090, 5015}], 
         LineBox[{4970, 4968, 4969, 4990}], LineBox[{4973, 4972, 4974, 4991}],
          LineBox[{4982, 3650, 4951, 3651, 5036, 5037}], 
         LineBox[{4988, 4921, 4920, 4088, 5003}], 
         LineBox[{4992, 4980, 3648, 4950, 3649, 5034, 5035}], 
         LineBox[{5002, 4038, 5000, 5001, 4071, 5009}], 
         LineBox[{5004, 4089, 5005}], LineBox[{5013, 4996, 4995, 5068}], 
         LineBox[{5014, 4185, 5007, 4183, 4965, 4184, 4924, 4989, 5019}], 
         LineBox[{5044, 4752, 5045}], LineBox[{5055, 5056}], 
         LineBox[{5080, 5078, 3660, 5095, 5097, 5096}]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0jdPlmEUBuADKgpKRwQphl9gTWSgiZ2RIIM4uakJzgq6UFQ22KiCizsQ
MdgA/QeAC/9AqUqzIdc7XLmfc3/nzVvyVdx92NiaEhGvmcuMyM6NyOEYWWQy
q8+QRzlMOkeY0Y9mR7yTX/Iimp1fMsIrc3lWxJi8kBPxlz/cMN/kOtc4r+ux
91uWu25Jd0q+0O3qnstfcto9hvTD3GLUXpMcTO7pXGJvRJ6x2+lcrP9snnLd
A+fb+hbuMGV+y32m7dxL3kG+sdsr+wh7//V7FDJAP9vssMUmMzx1v6/yOBus
84kn+kVZwBqrfKRdvyDzWWGZD7Tp5+V3vlFkfiTzuOiZcmWl7JCTnnXDM/5g
jQ6763JCP2enyE61PK1bZYUqc7G9cTuzzifsdNGZfA/djp1nft+W3bJMX8pV
u1c4p+/Sb8nL5nrKzJfkWd0mP6kxl+ofu7aEWvNJWSe7k3d1r0P+P2mkcpAD
vNeHTOFf8v3Zo8F1+zByYFE=
          "]]},
        RowBox[{"-", "0.63`"}]],
       Annotation[#, -0.63, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0UdSVFEYhuHjWDtIcszA1k4kQ5W4i2YHLECCoMBE7A04ExSdialRcQYo
dCuCgJIFJBgQE+oifHrw1nu+757/v7fq1ra25S4dCSHcwPNICP/iIeSjIfzh
6/yXR/WH3C//4mv8m5/pf/BPfMN3HOCpvrkihIu4gILdO3wed3EHLbEQTtgz
5Fxn5orzOsf053RnkZW79VFdSX5s75quS7fCl3mVH+mXeBnvsIj3eKgfNHuP
p8znnAdwE7flavO3OOluEVOok6v0WT4tT+IlMnKlPs2n5BeYQEqu0Cc5IY9j
DCfl4/oe7zqKRHlfeRZ5+YFvmndvAbOYw1vc189wp9lp7uA3PKwvmo2YPcMZ
Xbtnr/mYrknXiLT8CiU0yDXu1HNKHvIfvvA+vuKJnZ/4M3awh12M6Le5z+wW
9/JHLug3uUf+wFd5g+Pe/x/TzlfC
          "]]},
        RowBox[{"-", "1.26`"}]],
       Annotation[#, -1.26, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0dleEnEAR/E/miYgS2q5gMrW+6gvkFmamsEr5JUttiJqKITanppL6VUP
4stY37k4nzO/M8MMDMW52kw1FkLYxE4qhI1sCA0UMDoQQiYdwhh3ZVyjzdlF
zml5dOtb9gO9xOPaBG7oPXiob+vz/IF3PWOHF+wmP+JdbultXrRb3MFHtPV9
PsAePuNTdE5/6v6ruPaZv57Z1OKOE47XXPMMI0jaCb2fn9svot+GlJ3U0/zS
XscYMnYW/5x7Zd/jHN/SBhA887U9q+d5UBtCTH9j39fH+bbW7/gOv7XfYQLD
dkof4fd2HZPYtNP6Ftfdawrbjqe5gQ10/Mavrv2GL/iB79G70Q/5CD+x5D7H
vK+f8LL9ix/zafQ+9XNesc/4Cd90/yvP6+XfWlUrR99NK6BP/2PX9AoXtRLi
epkvtEvcRSV6h9F/4dx/TglEZA==
          "]]},
        RowBox[{"-", "1.8900000000000001`"}]],
       Annotation[#, -1.8900000000000001`, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0ddSU1EARuFNCz0EULzmhXCGGYoFBRRQepNiCwhyjSS0d+EFRIr6FkoH
IRAS8DsXa9ZZf87OxT6N3SPNwwUhhHXk4yH8qQlhGz/wHbvYQbo6hMlECO8w
gWlMYdU+y+8xg4/4gDX7Z+eSOPO/W3UhpGyFnv/WhtDhnRcow4Eush/yS92J
chzpYvsxd+luVOBEl9hP+Zxf2Vq4ks+iDRf6tW7lKr6w/YvQPbqNq/nSdoVL
3avbOc4Z23X0m+7TT7iGb2xZZPQb/ZQTfGvLRWf0W/2Mazlvu8ON7tfPuY7v
bcGdZPWA7uB6LrAV4lYPRnfED7jIVoycLuEh2zAeIqZj9lIe0aNoiO5Wl9rL
eUyP4xFSusye5mXfpwmrnh/zCr5hPfp+3k3iE+Yxhw37Ai/iC5bwFZv2fed+
Yg+/8Qt55PAfiMBZRA==
          "]]},
        RowBox[{"-", "2.52`"}]],
       Annotation[#, -2.52, "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}}}], 
   {GrayLevel[0.85], EdgeForm[Thickness[Large]], DiskBox[{0, 0}]}},
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->{{{-3., 
      FormBox[
       RowBox[{"-", "3.`"}], TraditionalForm]}, {-2.5, 
      FormBox[
       RowBox[{"-", "2.5`"}], TraditionalForm]}, {-2., 
      FormBox[
       RowBox[{"-", "2.`"}], TraditionalForm]}, {-1.5, 
      FormBox[
       RowBox[{"-", "1.5`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2., 
      FormBox["2.`", TraditionalForm]}, {2.5, 
      FormBox["2.5`", TraditionalForm]}, {3., 
      FormBox["3.`", TraditionalForm]}}, {{-3., 
      FormBox[
       RowBox[{"-", "3.`"}], TraditionalForm]}, {-2.5, 
      FormBox[
       RowBox[{"-", "2.5`"}], TraditionalForm]}, {-2., 
      FormBox[
       RowBox[{"-", "2.`"}], TraditionalForm]}, {-1.5, 
      FormBox[
       RowBox[{"-", "1.5`"}], TraditionalForm]}, {-1., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {-0.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {1., 
      FormBox["1.`", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2., 
      FormBox["2.`", TraditionalForm]}, {2.5, 
      FormBox["2.5`", TraditionalForm]}, {3., 
      FormBox["3.`", TraditionalForm]}}, None, None},
  ImageSize->504,
  PlotLabel->FormBox[
   "\"Potential Flow Over a Circular Cylinder\"", TraditionalForm],
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  RotateLabel->False]], "Output",
 ImageSize->{508, 519},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[22]=",
 CellID->48952892],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnQd8FGX6xzmvqPe3nOcV9fTsHVHsXU89C1V6R3rvHUQQLChiQUAQRUTp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    "], {{0, 193}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 193},
  PlotRange->{{0, 504}, {0, 193}}]], "Output",
 ImageSize->{508, 193},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->79959952]
}, Open  ]],

Cell[TextData[{
 "These two graphs provide much information about the flow.  Black arrows \
show a grid of velocity vectors, scaled to the speed of the fluid.  \
Equipotential lines are red and streamlines are blue.  Note that \
equipotential lines and streamlines are orthogonal, and streamlines are \
parallel to the velocity field.  The pressure coefficient in the flow field \
is shown as a color-coded density plot.  The saturation of both orange (",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["C",
     FontSlant->"Italic"], 
    StyleBox["p", "TI"]], ">", "0"}]], "InlineFormula"],
 ") and blue (",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["C", "TI",
     FontSlant->"Plain"], 
    StyleBox["p", "TI"]], "<", "0"}]], "InlineFormula"],
 ") decrease as free stream conditions are approached (",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["C",
     FontSlant->"Italic"], 
    StyleBox["p", "TI"]], "=", "0"}]], "InlineFormula"],
 ").  The second graph shows the surface pressure coefficient on the circle \
as a function of the angle theta made with the positive ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis.  The thickened line is also color coded to provide a calibration for \
the colors used used in the graph of the flow-field. "
}], "Text",
 CellID->140583623],

Cell["\<\
Clear the symbol for free stream velocity; the same symbol is used in the \
next section in a different context.\
\>", "Text",
 CellID->363436394],

Cell[BoxData[
 RowBox[{"Clear", "[", "v\[Infinity]", "]"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->77435478]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.3  Flat Plate at Angle of Attack", "Section",
 CellID->588183864],

Cell[TextData[{
 "This example of uniform uniform flow over a flat plate at an angle of \
attack is chosen primarily for its simplicity.  The layout for discretization \
is fortuitous in that the results are in perfect agreement with those of \
thin-airfoil theory regardless of the discretization number chosen.  Although \
this example does not generalize to any practical configuration, it does \
suggest a common layout procedure for three-dimensional vortex lattice \
models.  ",
 ButtonBox["Anderson (1991)",
  BaseStyle->"Hyperlink",
  ButtonData->{"References.nb", "anderson1984"}],
 " discusses thin airfoil theory in Section 4.7.  Results for thin airfoil \
theory are that the lift coefficient is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    StyleBox["\[Pi]", "TR"], " ", 
    StyleBox["\[Alpha]", "TR"]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  StyleBox["\[Alpha]", "TR"]], "InlineFormula"],
 " is the angle of attack, and the moment coefficient about the leading edge \
is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     StyleBox["\[Pi]", "TR"]}], " ", 
    RowBox[{
     StyleBox["\[Alpha]", "TR"], "/", "2"}]}], TraditionalForm]]],
 ", where the negative sign denotes a nose down moment.  Another way of \
stating this result for pitching moment is that the aerodynamic center is \
located at the quarter chord point.  "
}], "Text",
 CellID->28328877],

Cell["\<\
This example also illustrates the primary steps in the model-building \
procedure common to all panel methods.\
\>", "Text",
 CellID->357950111],

Cell[CellGroupData[{

Cell["Discretize the airfoil", "Subsection",
 CellID->238497841],

Cell[TextData[{
 "Choose the flat plate to lie along the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-axis with the leading edge at ",
 Cell[BoxData["0"], "InlineFormula"],
 " and the trailing edge at ",
 Cell[BoxData[
  StyleBox["c", "TI"]], "InlineFormula"],
 ", which denotes the length of the flat plate.  Divide the flat plate into a \
specified number of panels of equal length, and compute the collection of \
vectors locating panel endpoints. "
}], "Text",
 CellID->104585889],

Cell[CellGroupData[{

Cell["\<\
n=5;
rP=MakeCartesianVectors[{Range[0,c,c/n],Table[0,{n+1}]}]\
\>", "Input",
 CellLabel->"In[25]:=",
 CellID->171676843],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["c", "5"], ",", 
     FractionBox[
      RowBox[{"2", " ", "c"}], "5"], ",", 
     FractionBox[
      RowBox[{"3", " ", "c"}], "5"], ",", 
     FractionBox[
      RowBox[{"4", " ", "c"}], "5"], ",", "c"}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{
    0, Rational[1, 5] $CellContext`c, Rational[2, 5] $CellContext`c, 
     Rational[3, 5] $CellContext`c, 
     Rational[4, 5] $CellContext`c, $CellContext`c}, {0, 0, 0, 0, 0, 0}], 
   "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{282, 32},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->23258951]
}, Open  ]],

Cell["\<\
Locate collocation points at which tangent-flow boundary conditions are \
applied at the three-quarter point of each panel.\
\>", "Text",
 CellID->273354443],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rC", "=", 
  RowBox[{"PanelPoints", "[", 
   RowBox[{"rP", ",", 
    RowBox[{"PanelOffset", "\[Rule]", 
     RowBox[{"3", "/", "4"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[27]:=",
 CellID->8311199],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c"}], "20"], ",", 
     FractionBox[
      RowBox[{"7", " ", "c"}], "20"], ",", 
     FractionBox[
      RowBox[{"11", " ", "c"}], "20"], ",", 
     FractionBox[
      RowBox[{"3", " ", "c"}], "4"], ",", 
     FractionBox[
      RowBox[{"19", " ", "c"}], "20"]}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{
    Rational[3, 20] $CellContext`c, Rational[7, 20] $CellContext`c, 
     Rational[11, 20] $CellContext`c, Rational[3, 4] $CellContext`c, 
     Rational[19, 20] $CellContext`c}, {0, 0, 0, 0, 0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{284, 32},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]=",
 CellID->648561013]
}, Open  ]],

Cell[TextData[{
 "Unit normals to the panels are simply unit vectors in the ",
 Cell[BoxData[
  FormBox[
   StyleBox["z", "TI"], TraditionalForm]]],
 " direction."
}], "Text",
 CellID->243032495],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uN", "=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", "n", "}"}]}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[28]:=",
 CellID->170332998],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{0, 0, 0, 0, 0}, {1, 1, 1, 
    1, 1}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{199, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->35100752]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choose singularity", "Subsection",
 CellID->377269594],

Cell["\<\
Place point singularities at the quarter-chord of each panel.\
\>", "Text",
 CellID->985472164],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rV", "=", 
  RowBox[{"PanelPoints", "[", 
   RowBox[{"rP", ",", 
    RowBox[{"PanelOffset", "\[Rule]", 
     RowBox[{"1", "/", "4"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[29]:=",
 CellID->410305847],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["c", "20"], ",", 
     FractionBox["c", "4"], ",", 
     FractionBox[
      RowBox[{"9", " ", "c"}], "20"], ",", 
     FractionBox[
      RowBox[{"13", " ", "c"}], "20"], ",", 
     FractionBox[
      RowBox[{"17", " ", "c"}], "20"]}], "}"}], "\[UpArrow]", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}],
  Infix[
   Aerodynamics`CartesianVectors`CartesianVectors[{
    Rational[1, 20] $CellContext`c, Rational[1, 4] $CellContext`c, 
     Rational[9, 20] $CellContext`c, Rational[13, 20] $CellContext`c, 
     Rational[17, 20] $CellContext`c}, {0, 0, 0, 0, 0}], "\[UpArrow]"],
  Editable->False]], "Output",
 ImageSize->{271, 32},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->80613820]
}, Open  ]],

Cell["\<\
Sketch the geometry, showing panel normals, locations of point vortices and \
the direction of the onset flow.\
\>", "Text",
 CellID->58453545],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gFPN", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rP", "/", "c"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gPEN", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[CapitalDelta]z", "=", "0.005"}], ",", "x", ",", "zm", ",", 
        "zp"}], "}"}], ",", 
      RowBox[{
       RowBox[{"x", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Components", "[", "rP", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "c"}]}], ";", 
       RowBox[{"zm", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalDelta]z"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", "+", "1"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"zp", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"\[CapitalDelta]z", ",", 
          RowBox[{"{", 
           RowBox[{"n", "+", "1"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"Map", "[", 
        RowBox[{"Line", ",", 
         RowBox[{"Thread", "[", 
          RowBox[{"List", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "zm"}], "}"}], "]"}], ",", 
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "zp"}], "}"}], "]"}]}], "]"}], "]"}]}], 
        "]"}]}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grV", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{
     RowBox[{"rV", "/", "c"}], ",", 
     RowBox[{"Joined", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsolutePointSize", "[", "7", "]"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gN", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Arrow", "[", 
     RowBox[{
      RowBox[{"rC", "/", "c"}], ",", 
      RowBox[{
       RowBox[{"rC", "/", "c"}], "+", 
       RowBox[{"0.2", "uN"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gFPN", ",", "gPEN", ",", "grV", ",", "gN"}], "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", 
           RowBox[{"-", "0.2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", 
           RowBox[{"-", "0.11"}]}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[OverscriptBox[\(V\), \(\[RightVector]\)], \(\
\[Infinity]\)]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.25"}], ",", 
          RowBox[{"-", "0.12"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"AbsoluteDashing", "[", 
       RowBox[{"{", 
        RowBox[{"5", ",", "5"}], "}"}], "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", 
           RowBox[{"-", "0.2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", 
           RowBox[{"-", "0.2"}]}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[Alpha]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.12"}], ",", 
          RowBox[{"-", "0.17"}]}], "}"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"7", " ", "72"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "1.25"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[30]:=",
 CellID->33804278],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    LineBox[{{0., 0.}, {0.2, 0.}, {0.4, 0.}, {0.6, 0.}, {0.8, 0.}, {1., 
     0.}}]}, {LineBox[{{0, -0.005}, {0, 0.005}}], 
    LineBox[NCache[{{Rational[1, 5], -0.005}, {Rational[1, 5], 0.005}}, {{
      0.2, -0.005}, {0.2, 0.005}}]], 
    LineBox[NCache[{{Rational[2, 5], -0.005}, {Rational[2, 5], 0.005}}, {{
      0.4, -0.005}, {0.4, 0.005}}]], 
    LineBox[NCache[{{Rational[3, 5], -0.005}, {Rational[3, 5], 0.005}}, {{
      0.6, -0.005}, {0.6, 0.005}}]], 
    LineBox[NCache[{{Rational[4, 5], -0.005}, {Rational[4, 5], 0.005}}, {{
      0.8, -0.005}, {0.8, 0.005}}]], LineBox[{{1, -0.005}, {1, 0.005}}]}, 
   {Hue[0.67, 0.6, 0.6], AbsolutePointSize[7], 
    PointBox[{{0.05, 0.}, {0.25, 0.}, {0.45, 0.}, {0.65, 0.}, {0.85, 0.}}]}, {
    ArrowBox[NCache[{{Rational[3, 20], 0}, {Rational[3, 20], 0.2}}, {{
       0.15, 0}, {0.15, 0.2}}]], 
    ArrowBox[NCache[{{Rational[7, 20], 0}, {Rational[7, 20], 0.2}}, {{
       0.35, 0}, {0.35, 0.2}}]], 
    ArrowBox[NCache[{{Rational[11, 20], 0}, {Rational[11, 20], 0.2}}, {{
       0.55, 0}, {0.55, 0.2}}]], 
    ArrowBox[NCache[{{Rational[3, 4], 0}, {Rational[3, 4], 0.2}}, {{
       0.75, 0}, {0.75, 0.2}}]], 
    ArrowBox[NCache[{{Rational[19, 20], 0}, {Rational[19, 20], 0.2}}, {{
       0.95, 0}, {0.95, 0.2}}]]}},
  AspectRatio->Automatic,
  Axes->False,
  Epilog->{
    ArrowBox[{{-0.4, -0.2}, {0., -0.11}}], 
    InsetBox[
     FormBox[
     "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(V\\), \\(\[RightVector]\\)], \
\\(\[Infinity]\\)]\\)\"", TraditionalForm], {-0.25, -0.12}], 
    AbsoluteDashing[{5, 5}], 
    LineBox[{{-0.4, -0.2}, {0., -0.2}}], 
    InsetBox[
     FormBox["\"\[Alpha]\"", TraditionalForm], {-0.12, -0.17}]},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  FrameTicks->None,
  ImageSize->504,
  PlotRange->{{-0.5, 1.25}, {-0.3, 0.3}},
  PlotRangeClipping->True,
  RotateLabel->False]], "Output",
 ImageSize->{508, 188},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->61094745]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply boundary conditions", "Subsection",
 CellID->81322843],

Cell[TextData[{
 "Tangent-flow boundary conditions are applied at collocation points to \
provide a linear system of algebraic equations in the unknown strengths of \
the point vortices.  First, velocity influence coefficients are computed at \
collocation points due to point vortices representing the flat plate.  The \
matrix to the left of the infix arrow represents ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-components of the velocity influence coefficients and the matrix to the \
right of the infix arrow represents ",
 Cell[BoxData[
  StyleBox["z", "TI"]], "InlineFormula"],
 " components.  Each row of a matrix represents influence coefficients at a \
given collocation point due to all vortices, and each column represents \
influence coefficients at all collocation points due to a given vortex."
}], "Text",
 CellID->42996539],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ic", "=", 
    RowBox[{"ICVortexPoint", "[", 
     RowBox[{"rC", ",", "rV"}], "]"}]}], ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[35]:=",
 CellID->152545659],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnat26zgUhjNrnmReYeB5jHmCrgOyyiawrLCwYYGFhWUJLCzsAwQUFhYG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    "], {{0, 127}, {306, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{306, 127},
  PlotRange->{{0, 306}, {0, 127}}]], "Output",
 ImageSize->{310, 127},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[35]=",
 CellID->65001378]
}, Open  ]],

Cell["", "Text",
 CellID->24983735],

Cell["\<\
Compute components of the velocity influence coefficients normal to the flat \
plate.\
\>", "Text",
 CellID->129192552],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"icn", "=", 
    RowBox[{"ic", ".", "uN"}]}], ")"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[36]:=",
 CellID->173747007],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnT1yIjsURqmalbxtzDLeClwTkD6HzhwSQkbo0KEzCB0SUjUpCyB0SOjX
GLD5kdt0695PQjqnyjNTwPBJcFrdNH2v//nz379/fg0Gg8fm52/zs/33O0AJ
zIaDHcNZsYk5RO+ya3iRr2E2/D0pPTGD6NXk93C2/RHlec10s9mMx+Pop2Gt
0yG1ru9MHx8fW+59eXlZr9cRAzthJXxFUiUmj9bH9phpu1cWC93HNvExrMPf
/ugTc4j+QGddxEybfeh0Og3etVwu5/N5/OjeP9di4QGPPjF9dLPoDKR795iZ
Ngta497l7aPRKHpcAGGaNW2xWFze3n7IBxDD29tbcCd7f3+vHwzUQ3BZu7u7
a/1PR4cRoUOJx+swnIIy7vrEAmbtNNPgvYYvDsAlQcHYw4IrQet+2sMCRIF1
oEdk3ecXd7tziyvjp1ezm06yywyEfL1xlu+ah3Wfn3BPBrqaTGa7PyT4eb79
BL/92L698KL9afXbmnniYZKz4U9fenSJNreueU+C49z5Npu4vPZJPD+zTj8G
YeL5pU2R0X7WnbJ30MO6FJ6fX0SpH4M0cTUZHj1ffLRkD3t0bcLPK3Vn1J6H
rrhIuK0JEk+lM4gu4zOs2PPDIczJE4vHoExspLONLsM6uC2wDvRgHejBOtCD
daAH60CPs3VVVadWNNnIVgPu1lVUiV/NZKNbDbDW3XJiyuiMrdtTVSV+JZPN
17qqKvGrmmzO1lVWiV/LZKNbDXDmBPRgHejBOtDTxbq2kn+nIvFOY7h+GF0S
2xDHXZ/oMQzDlODDWOvAFawDPVgHeiytq6c2GeIwsy7b2mTaDuSH+R42bW0y
bQfcx2CRYmpd4tpk2g64jsEwxcy6DGqTaTvgNwbbFMO1LofaZNoOOI3BNoUz
J5HU03bAMAXrQA/WgR6sAz1YB3qwDvRgHejxtk77++gvkkNXfpYYLU6MjfO1
Tv376I+pphI/QWJsnGAPm8w61rpc48q1bk8llfhJEnvHFWtdVZX44sToOPfj
ukHq/VzxlfgpEiPjOHMCerAO9GAd6Ollnb4An7YD52jier2oP0cH72WtA1ew
DvRgHegpxLoiapPrQWSda1FwbrXJqeKccNiiPaxLVYBP2wF7z322aHPrkhTg
03bgLNLcc9st2s+6UxwL8Gk74Oy5/RYt2cO6/y5y2g4csPbcZ4su5DNslWg8
99iisQ70YB3owTrQg3WgB+tAD9aBHmfrEhal0nYg3xR361JdB0LbgYxTCl7r
3mk7kGuK5rguVQE+bQfyTPG1LmEB/ge0HcgzxXutS1aAT9uBjFM4cwJ6sA70
YB3o6WJdnQX4dc46gGFK8GGsdeAK1oEerAM9ZtZ9lUPebLlxP2g70B1D64LV
asFHHh0Y33gBPm0HemG9hz2/GqGSAvxK2w70ddvYutVkeJRdQwF+PW0HDN22
te5UuvIL8OtpO2Drtq11jXTntxRdgP9eTdsBW7c5cwJXYug21oEerAM9WAd6
sA70YB3owTrQ42xd8ZWhLdmVlOL2SXS3rvAq+BB1tR3ok8ha50Q1bQcyXOv2
FF8Ff0ltbQc6JfpaV3wV/PfU0nagV6L3Wld8FXyAytoO9EjkzAnowTrQg3Wg
p4t1Cavg6yzAv+0XvOXZg/c+PDxcMTCAnmAd6Alax3EduGK41u3P2yT87iu/
cmNfbrbtQNC60WjU+YkO34gkqIKn7UAObQeuTlmv18/Pz5e3N9ZtNptuoZ/f
w53WxArL0mk7oBtGTMrr6+tyuby8vbFxPp/Hj0RaBU/bAdUwIlOm0+l3d43H
475D+nrzlVXwtB2QDSMmpVnQnp6evrt3sVgEl8G2oRxWuuObZVXwtB1QDqN3
SqNc+8Fbs/+1GSLAAaQCgDr5Hy0SH7k=
    "], {{0, 127}, {210, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{210, 127},
  PlotRange->{{0, 210}, {0, 127}}]], "Output",
 ImageSize->{214, 127},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[36]//MatrixForm=",
 CellID->345870438]
}, Open  ]],

Cell[TextData[{
 "Compute the component of free stream velocity normal to the flat plate at \
collocation points.  The function UniformFlow computes a free stream velocity \
of unit magnitude at collocation points.  This is multiplied by the free \
stream speed ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["\[Infinity]", "TI"]]], "InlineFormula"],
 " to provide a free stream velocity of magnitude ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["v", "TI"], 
   StyleBox["\[Infinity]", "TI"]]], "InlineFormula"],
 "."
}], "Text",
 CellID->230898689],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v\[Infinity]n", "=", 
  RowBox[{"v\[Infinity]", " ", 
   RowBox[{
    RowBox[{"UniformFlow", "[", 
     RowBox[{"n", ",", "\[Alpha]"}], "]"}], ".", "uN"}]}]}]], "Input",
 CellLabel->"In[37]:=",
 CellID->101324213],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{"v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{"v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{"v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{"v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}], "}"}]], "Output",
 ImageSize->{362, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[37]=",
 CellID->790869987]
}, Open  ]],

Cell[TextData[{
 "Solve the system of linear algebraic equations for the list of unknown \
strengths ",
 Cell[BoxData[
  StyleBox["\[CapitalGamma]", "TR"]], "InlineFormula"],
 "."
}], "Text",
 CellID->340043933],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalGamma]", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{"icn", ",", 
    RowBox[{"-", "v\[Infinity]n"}]}], "]"}]}]], "Input",
 CellLabel->"In[38]:=",
 CellID->77133674],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["63", "128"], " ", "c", " ", "\[Pi]", " ", "v\[Infinity]", 
    " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["7", "32"], " ", "c", " ", "\[Pi]", " ", "v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["9", "64"], " ", "c", " ", "\[Pi]", " ", "v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["3", "32"], " ", "c", " ", "\[Pi]", " ", "v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["7", "128"], " ", "c", " ", "\[Pi]", " ", "v\[Infinity]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}], "}"}]], "Output",
 ImageSize->{352, 63},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[38]=",
 CellID->116034478]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aerodynamics", "Subsection",
 CellID->562395899],

Cell["\<\
Once the circulations are known, the lift associated with each vortex \
representing the airfoil can be computed using the Kutta-Joukowski theorem.\
\>", "Text",
 CellID->101804324],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[ScriptL]", "=", " ", 
  RowBox[{"\[Rho]", " ", "v\[Infinity]", " ", "\[CapitalGamma]"}]}]], "Input",
 CellLabel->"In[39]:=",
 CellID->726944217],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["63", "128"], " ", "c", " ", "\[Pi]", " ", 
    SuperscriptBox["v\[Infinity]", "2"], " ", "\[Rho]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["7", "32"], " ", "c", " ", "\[Pi]", " ", 
    SuperscriptBox["v\[Infinity]", "2"], " ", "\[Rho]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["9", "64"], " ", "c", " ", "\[Pi]", " ", 
    SuperscriptBox["v\[Infinity]", "2"], " ", "\[Rho]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["3", "32"], " ", "c", " ", "\[Pi]", " ", 
    SuperscriptBox["v\[Infinity]", "2"], " ", "\[Rho]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    FractionBox["7", "128"], " ", "c", " ", "\[Pi]", " ", 
    SuperscriptBox["v\[Infinity]", "2"], " ", "\[Rho]", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}], "}"}]], "Output",
 ImageSize->{400, 63},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[39]=",
 CellID->32467142]
}, Open  ]],

Cell["\<\
Compute the two-dimensional lift coefficient for the airfoil by summing the \
contributions of all vortices and writing the result in the conventional \
dimensionless form as an airfoil lift coefficient.\
\>", "Text",
 CellID->970971],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[ScriptL]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Plus", "@@", "\[ScriptL]"}], "/", 
    RowBox[{"(", 
     RowBox[{"q\[Infinity]", " ", "c"}], ")"}]}], "/.", 
   RowBox[{"q\[Infinity]", "\[Rule]", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      RowBox[{"v\[Infinity]", "^", "2"}], "/", "2"}]}]}]}]}]], "Input",
 CellLabel->"In[40]:=",
 CellID->638352067],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", 
  RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]], "Output",
 ImageSize->{66, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[40]=",
 CellID->63292726]
}, Open  ]],

Cell["\<\
In the small-angle approximation, this result is the same as the result of \
thin airfoil theory.\
\>", "Text",
 CellID->288193638],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[ScriptL]", "/.", 
  RowBox[{
   RowBox[{"Sin", "[", "\[Alpha]", "]"}], "\[Rule]", "\[Alpha]"}]}]], "Input",
 CellLabel->"In[41]:=",
 CellID->183555680],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", "\[Alpha]"}]], "Output",
 ImageSize->{31, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[41]=",
 CellID->257563369]
}, Open  ]],

Cell["\<\
The perfect agreement between the result of this model and thin-airfoil \
theory is independent of the number of vortices used to represent the flat \
plate.  This agreement, however, is unique to a flat plate with the layout \
scheme used in this example.  Next, compute the pitching moment for the flat \
plate using the small-angle approximation to show that it also matches the \
result of thin-airfoil theory.\
\>", "Text",
 CellID->342936796],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"\[ScriptL]", "/.", 
       RowBox[{
        RowBox[{"Sin", "[", "\[Alpha]", "]"}], "\[Rule]", "\[Alpha]"}]}], 
      ")"}]}], " ", 
    RowBox[{
     RowBox[{"Components", "[", "rV", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"cm", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Plus", "@@", "m"}], "/", 
    RowBox[{"(", 
     RowBox[{"q\[Infinity]", " ", 
      RowBox[{"c", "^", "2"}]}], ")"}]}], "/.", 
   RowBox[{"q\[Infinity]", "\[Rule]", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      RowBox[{"v\[Infinity]", "^", "2"}], "/", "2"}]}]}]}]}]}], "Input",
 CellLabel->"In[42]:=",
 CellID->974369142],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[Pi]", " ", "\[Alpha]"}], "2"]}]], "Output",
 ImageSize->{34, 30},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[43]=",
 CellID->528551635]
}, Open  ]],

Cell[TextData[{
 "Compute the location of the aerodynamic center defined by ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["c", "TI"], 
    StyleBox["m", "TI"]], "=", 
   RowBox[{
    FractionBox[
     SubscriptBox[
      StyleBox["x", "TI"], 
      StyleBox["ac", "TI"]], "c"], " ", 
    SubscriptBox[
     StyleBox["c", "TI"], 
     StyleBox["\[ScriptL]", "TI"]]}]}]], "InlineFormula"],
 "."
}], "Text",
 CellID->79200027],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xac", "=", 
  RowBox[{
   RowBox[{"-", "c"}], " ", 
   RowBox[{"cm", "/", 
    RowBox[{"(", 
     RowBox[{"c\[ScriptL]", " ", "/.", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Alpha]", "]"}], "\[Rule]", "\[Alpha]"}]}], " ", 
     ")"}]}]}]}]], "Input",
 CellLabel->"In[44]:=",
 CellID->253615541],

Cell[BoxData[
 FractionBox["c", "4"]], "Output",
 ImageSize->{16, 30},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[44]=",
 CellID->408697575]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/guide/InfluenceCoefficients"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["2.1 Introduction to Influence Coefficients",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToInfluenceCoefficients"]], \
"RelatedTutorials",
 CellID->360236970],

Cell[TextData[ButtonBox["2.3 Isolated Panel",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IsolatedPanel"]], "RelatedTutorials",
 CellID->134434831],

Cell[TextData[ButtonBox["Table of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->806871991]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"2.2 Point Singularities - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 11, 0, 38.9946000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "Although the primary purpose of Aerodynamics is to support the \
development of two-dimensional panels methods for uniform flow over airfoils, \
the package includes influence coefficients for point singularities as well. \
Two simple flows that are treated in most undergraduate textbooks on \
aerodynamics are discussed in this section: uniform flow over a circular \
cylinder, and a flat plate at an angle of attack. The capability of \
Mathematica to handle algebraic and numerical computation in a seamless \
manner is utilized in these examples. Aerodynamics is designed to handle \
large collections of vectors used in computing the flow over airfoils, so \
using these tools for simple problems actually causes some minor \
inconveniences. A data type, CartesianVectors is defined to facilitate the \
manipulation of collections of vectors. The constructor and selector for this \
data type are MakeCartesianVectors and Components. Although explicit use of \
the data type is hidden in normal use, it is currently necessary to use the \
constructor and selector for simple problems. Load the Aerodynamics \
packages.", "synonyms" -> {}, "title" -> "2.2 Point Singularities", "type" -> 
    "Tutorial", "uri" -> "Aerodynamics/tutorial/PointSingularities"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[604, 21, 78, 1, 70, "TutorialColorBar"],
Cell[685, 24, 191, 5, 70, "LinkTrail"],
Cell[879, 31, 2984, 68, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3888, 103, 60, 1, 70, "Title",
 CellID->509267359],
Cell[3951, 106, 512, 10, 70, "Text",
 CellID->739302563],
Cell[4466, 118, 1003, 23, 70, "Text",
 CellID->370043398],
Cell[5472, 143, 125, 6, 70, "Text",
 CellID->819798417],
Cell[5600, 151, 98, 3, 70, "Input",
 CellID->5378332],
Cell[CellGroupData[{
Cell[5723, 158, 111, 3, 70, "Section",
 CellID->100587181],
Cell[5837, 163, 508, 10, 70, "Text",
 CellID->1534169418],
Cell[CellGroupData[{
Cell[6370, 177, 55, 1, 70, "Subsection",
 CellID->215672006],
Cell[6428, 180, 760, 22, 70, "Text",
 CellID->629377630],
Cell[CellGroupData[{
Cell[7213, 206, 246, 8, 70, "Input",
 CellID->490239154],
Cell[7462, 216, 361, 12, 36, "Output",
 CellID->5880638]
}, Open  ]],
Cell[7838, 231, 160, 6, 70, "Text",
 CellID->141085961],
Cell[CellGroupData[{
Cell[8023, 241, 263, 9, 70, "Input",
 CellID->320702810],
Cell[8289, 252, 384, 13, 36, "Output",
 CellID->461790718]
}, Open  ]],
Cell[8688, 268, 254, 8, 70, "Text",
 CellID->516541598],
Cell[CellGroupData[{
Cell[8967, 280, 244, 8, 70, "Input",
 CellID->96784033],
Cell[9214, 290, 389, 13, 36, "Output",
 CellID->9322882]
}, Open  ]],
Cell[9618, 306, 580, 18, 70, "Text",
 CellID->836781195],
Cell[CellGroupData[{
Cell[10223, 328, 209, 6, 70, "Input",
 CellID->497839038],
Cell[10435, 336, 1341, 42, 63, "Output",
 CellID->249638242]
}, Open  ]],
Cell[11791, 381, 231, 8, 70, "Text",
 CellID->126311503],
Cell[CellGroupData[{
Cell[12047, 393, 192, 6, 70, "Input",
 CellID->222401865],
Cell[12242, 401, 219, 7, 36, "Output",
 CellID->101916841]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12510, 414, 72, 1, 70, "Subsection",
 CellID->89762736],
Cell[12585, 417, 450, 18, 70, "Text",
 CellID->438888709],
Cell[CellGroupData[{
Cell[13060, 439, 165, 5, 70, "Input",
 CellID->264747966],
Cell[13228, 446, 363, 12, 36, "Output",
 CellID->522069498]
}, Open  ]],
Cell[13606, 461, 78, 1, 70, "Text",
 CellID->636578530],
Cell[CellGroupData[{
Cell[13709, 466, 127, 4, 70, "Input",
 CellID->748303819],
Cell[13839, 472, 1350, 42, 63, "Output",
 CellID->18798916]
}, Open  ]],
Cell[15204, 517, 134, 4, 70, "Text",
 CellID->373058785],
Cell[CellGroupData[{
Cell[15363, 525, 211, 7, 70, "Input",
 CellID->400889610],
Cell[15577, 534, 840, 29, 63, "Output",
 CellID->169256835]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16466, 569, 60, 1, 70, "Subsection",
 CellID->440858664],
Cell[16529, 572, 434, 14, 70, "Text",
 CellID->280989992],
Cell[CellGroupData[{
Cell[16988, 590, 416, 15, 70, "Input",
 CellID->23226259],
Cell[17407, 607, 286, 10, 36, "Output",
 CellID->72728038]
}, Open  ]],
Cell[17708, 620, 515, 19, 70, "Text",
 CellID->61000964],
Cell[CellGroupData[{
Cell[18248, 643, 123, 4, 70, "Input",
 CellID->559540791],
Cell[18374, 649, 159, 5, 36, "Output",
 CellID->499496773]
}, Open  ]],
Cell[18548, 657, 149, 4, 70, "Text",
 CellID->14002195],
Cell[CellGroupData[{
Cell[18722, 665, 217, 8, 70, "Input",
 CellID->51306124],
Cell[18942, 675, 719, 26, 62, "Output",
 CellID->838689689]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19710, 707, 94, 1, 70, "Subsection",
 CellID->344238109],
Cell[19807, 710, 266, 6, 70, "Text",
 CellID->125144588],
Cell[CellGroupData[{
Cell[20098, 720, 763, 22, 70, "Input",
 CellID->31426684],
Cell[20864, 744, 463, 17, 51, "Output",
 CellID->770633589]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21376, 767, 62, 1, 70, "Subsection",
 CellID->668703906],
Cell[21441, 770, 109, 3, 70, "Text",
 CellID->335981067],
Cell[CellGroupData[{
Cell[21575, 777, 214, 7, 70, "Input",
 CellID->87854713],
Cell[21792, 786, 457, 17, 62, "Output",
 CellID->83259421]
}, Open  ]],
Cell[22264, 806, 209, 7, 70, "Text",
 CellID->694048433],
Cell[CellGroupData[{
Cell[22498, 817, 533, 17, 70, "Input",
 CellID->23700232],
Cell[23034, 836, 285, 10, 36, "Output",
 CellID->176594109]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23368, 852, 59, 1, 70, "Subsection",
 CellID->22002075],
Cell[23430, 855, 526, 9, 70, "Text",
 CellID->477749764],
Cell[CellGroupData[{
Cell[23981, 868, 6979, 192, 19, "Input",
 CellOpen->False,
 CellID->121377790],
Cell[30963, 1062, 208712, 3685, 540, "Output",
 CellID->48952892],
Cell[239678, 4749, 13102, 222, 214, "Output",
 CellID->79959952]
}, Open  ]],
Cell[252795, 4974, 1334, 34, 70, "Text",
 CellID->140583623],
Cell[254132, 5010, 156, 4, 70, "Text",
 CellID->363436394],
Cell[254291, 5016, 112, 3, 70, "Input",
 CellID->77435478]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[254452, 5025, 75, 1, 70, "Section",
 CellID->588183864],
Cell[254530, 5028, 1398, 34, 70, "Text",
 CellID->28328877],
Cell[255931, 5064, 154, 4, 70, "Text",
 CellID->357950111],
Cell[CellGroupData[{
Cell[256110, 5072, 64, 1, 70, "Subsection",
 CellID->238497841],
Cell[256177, 5075, 502, 13, 70, "Text",
 CellID->104585889],
Cell[CellGroupData[{
Cell[256704, 5092, 130, 5, 70, "Input",
 CellID->171676843],
Cell[256837, 5099, 847, 25, 53, "Output",
 CellID->23258951]
}, Open  ]],
Cell[257699, 5127, 167, 4, 70, "Text",
 CellID->273354443],
Cell[CellGroupData[{
Cell[257891, 5135, 222, 7, 70, "Input",
 CellID->8311199],
Cell[258116, 5144, 923, 27, 53, "Output",
 CellID->648561013]
}, Open  ]],
Cell[259054, 5174, 195, 7, 70, "Text",
 CellID->243032495],
Cell[CellGroupData[{
Cell[259274, 5185, 370, 12, 70, "Input",
 CellID->170332998],
Cell[259647, 5199, 507, 16, 36, "Output",
 CellID->35100752]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[260203, 5221, 60, 1, 70, "Subsection",
 CellID->377269594],
Cell[260266, 5224, 105, 3, 70, "Text",
 CellID->985472164],
Cell[CellGroupData[{
Cell[260396, 5231, 224, 7, 70, "Input",
 CellID->410305847],
Cell[260623, 5240, 868, 25, 53, "Output",
 CellID->80613820]
}, Open  ]],
Cell[261506, 5268, 153, 4, 70, "Text",
 CellID->58453545],
Cell[CellGroupData[{
Cell[261684, 5276, 4124, 125, 19, "Input",
 CellOpen->False,
 CellID->33804278],
Cell[265811, 5403, 2122, 50, 209, "Output",
 CellID->61094745]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[267982, 5459, 66, 1, 70, "Subsection",
 CellID->81322843],
Cell[268051, 5462, 859, 16, 70, "Text",
 CellID->42996539],
Cell[CellGroupData[{
Cell[268935, 5482, 221, 7, 28, "Input",
 CellID->152545659],
Cell[269159, 5491, 3306, 62, 148, "Output",
 CellID->65001378]
}, Open  ]],
Cell[272480, 5556, 35, 1, 70, "Text",
 CellID->24983735],
Cell[272518, 5559, 129, 4, 70, "Text",
 CellID->129192552],
Cell[CellGroupData[{
Cell[272672, 5567, 179, 6, 28, "Input",
 CellID->173747007],
Cell[272854, 5575, 2428, 47, 162, "Output",
 CellID->345870438]
}, Open  ]],
Cell[275297, 5625, 574, 16, 70, "Text",
 CellID->230898689],
Cell[CellGroupData[{
Cell[275896, 5645, 237, 7, 70, "Input",
 CellID->101324213],
Cell[276136, 5654, 605, 17, 36, "Output",
 CellID->790869987]
}, Open  ]],
Cell[276756, 5674, 211, 7, 70, "Text",
 CellID->340043933],
Cell[CellGroupData[{
Cell[276992, 5685, 202, 6, 70, "Input",
 CellID->77133674],
Cell[277197, 5693, 903, 23, 84, "Output",
 CellID->116034478]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278149, 5722, 54, 1, 70, "Subsection",
 CellID->562395899],
Cell[278206, 5725, 191, 4, 70, "Text",
 CellID->101804324],
Cell[CellGroupData[{
Cell[278422, 5733, 170, 4, 70, "Input",
 CellID->726944217],
Cell[278595, 5739, 1102, 27, 84, "Output",
 CellID->32467142]
}, Open  ]],
Cell[279712, 5769, 244, 5, 70, "Text",
 CellID->970971],
Cell[CellGroupData[{
Cell[279981, 5778, 386, 12, 70, "Input",
 CellID->638352067],
Cell[280370, 5792, 231, 7, 36, "Output",
 CellID->63292726]
}, Open  ]],
Cell[280616, 5802, 141, 4, 70, "Text",
 CellID->288193638],
Cell[CellGroupData[{
Cell[280782, 5810, 178, 5, 70, "Input",
 CellID->183555680],
Cell[280963, 5817, 202, 6, 36, "Output",
 CellID->257563369]
}, Open  ]],
Cell[281180, 5826, 458, 8, 70, "Text",
 CellID->342936796],
Cell[CellGroupData[{
Cell[281663, 5838, 760, 25, 70, "Input",
 CellID->974369142],
Cell[282426, 5865, 232, 8, 51, "Output",
 CellID->528551635]
}, Open  ]],
Cell[282673, 5876, 436, 17, 70, "Text",
 CellID->79200027],
Cell[CellGroupData[{
Cell[283134, 5897, 322, 11, 70, "Input",
 CellID->253615541],
Cell[283459, 5910, 179, 6, 51, "Output",
 CellID->408697575]
}, Open  ]],
Cell[CellGroupData[{
Cell[283675, 5921, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[283743, 5924, 180, 4, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[283960, 5933, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[284035, 5936, 217, 5, 70, "RelatedTutorials",
 CellID->360236970],
Cell[284255, 5943, 169, 4, 70, "RelatedTutorials",
 CellID->134434831],
Cell[284427, 5949, 170, 4, 70, "RelatedTutorials",
 CellID->806871991]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[284648, 5959, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

