(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     57790,       1323]
NotebookOptionsPosition[     52498,       1159]
NotebookOutlinePosition[     54545,       1205]
CellTagsIndexPosition[     54502,       1202]
WindowTitle->3.2  ValidationExample - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Aerodynamics",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Aerodynamics/guide/Aerodynamics"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["AERODYNAMICS TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"3.1 Introduction to Panel Methods\"\>":>
       Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"], "\<\"3.3 \
Implementation\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/Implementation"], "\<\"Table Of Contents\
\"\>":>Documentation`HelpLookup[
       "paclet:Aerodynamics/tutorial/TableOfContents"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"PanelMethods\"\>":>
       Documentation`HelpLookup["paclet:Aerodynamics/guide/PanelMethods"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Aerodynamics/tutorial/ValidationExample\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Aerodynamics/tutorial/ValidationExample"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/Aerodynamics/\
tutorial/ValidationExample.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "Aerodynamics/tutorial/ValidationExample", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["3.2  ValidationExample", "Title",
 CellID->509267359],

Cell[TextData[{
 "An exact solution for the van de Vooren airfoil is used to validate the \
three panel methods implemented in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 ".  The family of van de Vooren airfoil airfoils are symmetric airfoils \
obtained by mapping a circle to an airfoil shape using the van de Vooren \
transformation.  Surface pressure coefficient is chosen as the quantity to \
compare between the exact solution and numerical panel-method solutions."
}], "Text",
 CellID->25608729],

Cell[TextData[{
 "Refer to ",
 ButtonBox["Katz and Plotkin (2001)",
  BaseStyle->"Hyperlink",
  ButtonData->{"References.nb", "katz2001"}],
 " for a discussion of the van de Vooren airfoil and the exact potential-flow \
solution for this airfoil.  The functions in ",
 StyleBox["Aerodynamics",
  FontSlant->"Italic"],
 " for the airfoil geometry and the exact solution are from this reference as \
I have been unable to locate a copy of the original paper."
}], "Text",
 CellID->124571872],

Cell["Load the package", "Text",
 CellID->836781195],

Cell[BoxData[
 RowBox[{"<<", "Aerodynamics`"}]], "Input",
 CellLabel->"In[0]:=",
 CellID->2058623809],

Cell[CellGroupData[{

Cell["3.2.1  van de Vooren Airfoil", "Section",
 CellID->631983245],

Cell["\<\
Specify parameters for a 12% maximum thickness van de Vooren airfoil, and an \
angle of attack of 6 degrees.\
\>", "Text",
 CellID->405071093],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "=", "0.12"}], ";", " ", 
  RowBox[{"\[Tau]", "=", 
   RowBox[{"9.81", " ", "Degree"}]}], ";", 
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"6.", " ", "Degree"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->692274660],

Cell["Specify parameters for discretizing the airfoil. ", "Text",
 CellID->14124012],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "50"}], ";", 
  RowBox[{"layout", "=", "CosineSpacing"}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->361350040],

Cell[TextData[{
 "Compute panel endpoints for the discretized airfoil using ",
 Cell[BoxData[
  ButtonBox["AirfoilSurfacePoints",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/AirfoilSurfacePoints"]], 
  "InlineFormula"],
 ".  The discretization is specified by a list of ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values computed by ",
 Cell[BoxData[
  ButtonBox["NDiscretizeUnitSegment",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/NDiscretizeUnitSegment"]], 
  "InlineFormula"],
 " and converted to ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 "-values by ",
 Cell[BoxData[
  ButtonBox["XToTheta",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/XToTheta"]], "InlineFormula"],
 ".  Note that the number of panels is twice the specified discretization \
number ",
 Cell[BoxData[
  StyleBox["n", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->565396260],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rP", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"t", ",", "\[Tau]", ",", 
     RowBox[{"XToTheta", "[", 
      RowBox[{"t", ",", "\[Tau]", ",", 
       RowBox[{"NDiscretizeUnitSegment", "[", 
        RowBox[{"n", ",", 
         RowBox[{"Layout", "\[Rule]", "layout"}]}], "]"}]}], "]"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"nP", "=", 
  RowBox[{
   RowBox[{"NumberOfVectors", "[", "rP", "]"}], "-", "1"}]}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->11132],

Cell[BoxData["100"], "Output",
 ImageSize->{25, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->513845788]
}, Open  ]],

Cell[TextData[{
 "Compute the surface pressure coefficient at a relatively large number of ",
 Cell[BoxData[
  StyleBox["\[Theta]", "TR"]], "InlineFormula"],
 "-values using the exact solution.  The function ",
 Cell[BoxData[
  ButtonBox["SurfaceSpeed",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/SurfaceSpeed"]], "InlineFormula"],
 " computes surface speeds from the exact solution, and Bernoulli's equation \
is used to compute surface pressure coefficient."
}], "Text",
 CellID->332686776],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n\[Theta]", "=", "250"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", 
     RowBox[{"\[Pi]", "/", "n\[Theta]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vE", "=", 
   RowBox[{"SurfaceSpeed", "[", 
    RowBox[{"\[Alpha]", ",", "t", ",", "\[Tau]", ",", "\[Theta]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cpE", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vE", "^", "2"}]}]}], ";"}]}], "Input",
 CellLabel->"In[5]:=",
 CellID->663191981],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 "-values for a conventional plot of surface pressure coefficient using ",
 Cell[BoxData[
  ButtonBox["Components",
   BaseStyle->"Link",
   ButtonData->"paclet:Aerodynamics/ref/Components"]], "InlineFormula"],
 ", which is the selector for the data type CartesianVectors."
}], "Text",
 CellID->472644503],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rE", "=", 
   RowBox[{"AirfoilSurfacePoints", "[", 
    RowBox[{"t", ",", "\[Tau]", ",", 
     RowBox[{"Take", "[", 
      RowBox[{"\[Theta]", ",", 
       RowBox[{"n\[Theta]", "+", "1"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rE", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[9]:=",
 CellID->494361716],

Cell["\<\
Generate graphic for surface pressure coefficient using the exact solution.\
\>", "Text",
 CellID->191818375],

Cell[BoxData[{
 RowBox[{
  RowBox[{"grP", "=", 
   RowBox[{"PlotAirfoil", "[", 
    RowBox[{"rP", ",", 
     RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCpE", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"x", ",", "cpE", ",", "rE", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[11]:=",
 CellID->527771544]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2.2  PMVortexLinearNeumann", "Section",
 CellID->234765418],

Cell["\<\
In addition to strength parameters, the output of PMVortexLinearNeumann \
includes locations of collocation points and surface velocities at \
collocation points.  Bernoulli's equation is used to compute surface pressure \
coefficient at collocation points.\
\>", "Text",
 CellID->815037782],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMVortexLinearNeumann", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}]}], "Input",
 CellLabel->"In[13]:=",
 CellID->349582656],

Cell["\<\
Plot the surface pressure coefficient at collocation points superimposed on a \
line showing results from the exact solution.  The shape of the discretized \
airfoil is included on the graph.\
\>", "Text",
 CellID->63663458],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCp", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xC", ",", "cp", ",", "rP"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpE", ",", "gCp"}], "]"}]}], "Input",
 CellLabel->"In[15]:=",
 CellID->726630446],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3X9MHOedx3Gf7s876U66k+7+uT9Ouuv9d3e6++ssORgTp/4V2zgmJME0
CSQE6gSaxjQtTls7aewotVtqJwpgYozBxBjiQEjWcQKNa1KObRLTWqaXeq1z
obLwH0aWjCzdSpa4L3zhyXh/eWFmf8wz75emDcbrndnd2c9855lnnucfK+q2
Vfz5ihUrNvzZihX/J/+b+3kWAAAAAAAAQRBpXLlizsrGSK43BQCQAZHIfL6H
qgh6ALBYpLExlOttAABkxkLLTdVdQb8CAJAjrjI9VHXXc33dViN/cVfQu10R
AGBZMha/kcaqu9rnyXkAyAnP43exwI+9CkvOA0BOZC1+yXkAyAlyHgDsRs4D
gN3IeQCwGzkPAHYj5wHAbuQ8ANiNnAcAu5HzAGA3ch4A7EbOA4DdyHkAsBs5
DwB2I+cBwG7kPADYjZwHALuR8wBgN3IeAOxGzgOA3ch5ALAbOQ8AdiPnAcBu
5DwA2M1fOR+N3unvG3f/PAAQHP7K+ROdYxvXt/Wcuuj+qQAgIPyV83W1A2dC
X5WWdLl/KgAICH/lfPGWjunp25UVvZHLN9w/GwAEgY9yPhq9s7aoVX5obgqf
6BzzYqMAwH4+yvmpqVvaYjN24Vpd7YAXGwUA9vNRzpt4l8J+4/o2+X8vtgsA
LOejnA+PTtbvCunPNNEDQJp8lPNnQl/t33dOfz58aITelQCQDp/m/PD5q7sb
zrreKACwn49yvu3oF7LozzMz0Y3r29xuEwAEgE9zXpSXdU9M3HT5nABgPR/l
/OFDIwd/el5viZU/7t93Tn8AAKTgo5yXYN+8qb1gVbPeLeVsrgcAJOOvnP/x
Dz+WnD94YHjWcdsUACAFH+X87oazw+ev6s/h0cm62oGN69qmp2+73TIAsJqP
cl6CfezCNf1ZKnkp7AsLWkzyAwAS8mnOn+gck5zfWdN/+NCI600DAJv5KOdr
qvvGL113/iZy+UZlRa/LpwUAu/ko50tLuqambsX8cuP6tpmZqMtnBgCL+T3n
nRdnAQDx/J7zPacu0kQPACn4PedpogeA1HyU82uLWhPOLUITPQCk4KOcL1jV
nPD3NNEDQAoW5DxN9ACQggU5TxM9AKTg95zXgW42b2qPv0QLAJj1T85Ho3d0
OOIYZqAbxqIHgIT8kvPJRiHWgW6++/yHe/cMunl+ALCVX3L+ozN/WFv0drKi
fWYmWrylI2GvSwAIOL/k/PZtnWYmqYSco1kCAAy/5HzTW6NmJqmE+vvGU/wt
AASWX3L+nrMEMo0gACRkTc6LyoreyOUbbtYCAPbxS86PX7peU92X+jFtR7+Q
xc1aAMA+fsn5sQvX6moHUj+GG2MBIJ5NOT+bZOxiAAiyDOR8qGrFnJWNEQ9X
lGbONzeFT3SOuVkRAFjG85yPNDaG5v4raX9X0mch58Ojk1VPn354e6ebFQGA
ZTLXbhOqynbO61g3q+9rnpi46WZdAGCTjOV8qKoq5OGK0sl5Heum6qnT9LoB
AMNtzi80xi9aLOEXW2/uWpHTUteTZvu8mJ6+XbylY6nPDwC2ykQ9H2lcOZ/3
oUZHw012rsOq+l2h8Oikm9UBgDU8z3lnge9suXG5ouHzV3c3nE3zwUODVxim
GACUX/rPnwl9tX/fuTQfHI3eKS3pmp6+7WaNAGAHK3NeHD400nPqops1AoAd
bM15hq8EAGVrzovdDWeHz191s1IAsIDFOR8enazfFbr34wDAahbn/Cwj0gOA
1Tkv9fxjj57c9d0P3KwXAPzO4pw3w93QwRJAkFmc8zrczc6a/sOHRtysGgB8
zeKcV9wzBSDgrM950XPqIiU9gMAKQs5T0gMIsiDk/CwlPYAAC0jOS0lfXtbN
FOEAAiggOT+7xJGNAcAawcl5UVPdN37pussnAQB/CVTORy7fqKzodfkkAOAv
gcr58Ohk8daO119z+zwA4CN+yfn+vvGDB4ZdboMZCWFmJuryqQDAL/yS821H
v5DF5TboSAjPPfu++0MGAPhFoHLeqKsdGLtwzatnA4B8Fsycn5q6VV7WHY3e
8eoJASBvBTPnZz1q8AeA/BfYnJ+l9QZAMAQ556emblVW9NL3BoDdgpzzswyG
ACAAAp7z4dHJ7Q+deGXvoOfPDAB5IuA5v3jnVAvj3gCwVcBzXu+c2vfqpzXV
fYxaDMBKAc95Q+r5utoBetQDsA85b3gyVBoA5BtyPvtrAYBsIudjSEkvhX0W
VgQA2eGXnD94YLi/b9yrjUmtflcoPDqZnXUBQKb5JeezWWb/+rM/bn6w/c03
RrKzOgDIKHI+Hp3qAdiEnI+nnepf2/+rutqByOUb2VkpAGQIOZ/CzEyUqAfg
d37J+Ree/7B8R3dOor6muo/LsgD8yy85v+6BowWrmtcWtXq1PemLRu/sbjhL
1APwKb/k/NNPnZacz9UMUBL19btC9KsH4Ed+yfl8uH1JtqG5KZzbbQCApSLn
0xcenXyk9J3qZ04z3BkAHyHn06f96osKj9TvCk1P387txgBAmsj59Gm/+oMH
hscuXKus6OUuKgC+QM4vj9TzdbUDWRtyBwCWjZxftmj0jtT2smE01wPIZ+S8
S7JVlRW93DMLIG+R8+5NTNws39H9SOk7ebuFAIKMnPfEw9sXhrikHw6AfEPO
e0K74rzU8HF5WQ4G4QGAFMh5b83MRGVT6WAPIH+Q85kQHp2ksAeQJ8j5DDGF
/dTUrVxvC4BAI+czSgr7km2dpQ93Dbz/+1xvC4CAIuczbbErTjMj2APICXI+
07Qrzisv/7J+V2h3w1macQBkGTmfTcPnr5aXdTc3hWdmorneFgBBQc5nWTR6
Ryr80pIu+X8GxgGQBeR8Tkg9L1W91PZS4ed6WwBYjpzPoampW9+u6Vv3zaOH
Gj/L9bYAsBY5n1s6R1VhQUtlRe/YhWu53hwAFspAzkcaV8qzVoU8XZGtOW/m
qIpcvlFXOyALLTkAvJWZel6inpxfDinpdzecldqetAfgFXI+D0ltr2kfnJcM
IHPI+bwlaf/C8x+uLXp736u/pAcmgGVzm/OhqhVOKxsjc79NnPNOS11PAHN+
1nGVtnhLR3NTmLGOASyDI3IXI1uyOtSoeb1c1PPeMFdpZ2ai8rOk/d49g8xF
C2BJFuJ3ro/MQi0+/3NsSi/JwgFj5V3HCnLeE0ODVyoremuq++SHXG8LAH+Y
j19JdmcoRxqr3JXzSVe0fOS80/il61LYS3n/2v5zz+7s550BkMJc/MbEfOZW
5AI5H296+vaGdW3agC/Jn+vNAZCn5uI3VOWunSbtFblAziekDfjfqR2oqe4r
L+vuOXWRa7UAYszHrwT91wW9o9VmrqG9qnHu9lb39T45n2kTEzcPHxrRa7XM
aQLAcFyHvbtr5Ly5oJ/7c6jKdcFPzmfN0OCV+l0hHfqY8h5AyvgNVWnoL/43
Yyu6N3J+qaambjU3hTdtOLZpY/vrr53jTisgsFLF70IV703zPTmfE+ZOq43r
2+Q9pD0HCKAU8eu4byqzK0oHOb885k4rqeflDazfFSre0qHDY+Z60wBkSfL4
9aBNPr0VpYWc98r09O3+vvHKit7ysu62o18wLzlgvSTxq7W8l73qyfl8MzFx
U3K+tKTr0dKuxx49efKd3+Z6iwBkBPNJYdvWzoJVzavva5Yiv+fURSp8wDLk
PJxzWh0+NCIVPoEP2IScRzxn4MtRYGLiZq63CMDykfNIQQK/uSlcXtZdsq1z
+0Mn2tu+yPUWAVgych7peKh4oQ1fu2UOn7/KjVeAX5DzSIdpw9dumbsbzq4t
aq3fFZKfacYH8hw5j2ULj05K8mszftvRL95791Jd7QAfE5BvyHm4F7l8Q3K+
qLBVx1gYGrwyMxPN9UYBWEDOwytmMPy9ewY3rm+rqe6jrw6QD8h5ZMj4peva
V6e0pEsv3VLkAzlBziPTpqZu6aVbLfJ/8vLQU5Xv8mkCWUPOI5ukyN+4/ljB
qmZZ6neFTnSOMXImkGnkPLJMm/F/+vr58Ohkc1O4sqJX6vy9ewbl86WLJpAJ
5DxybmYmOjR4RT7i0pKu8rLugweG5Y+Dn0TopQl4gpxHXpmYuNnfNy7lfWFB
i5T9a1a3cAEXcImcR37S5p2dNf16AbeyovfwoZHw6CTjLQBLRc7DFyKXb/Sc
uli/K7S2qLWmuk8ynzofSBM5D98Zv3RdMl/r/JJtnduKO3924DzXcIFkyHn4
mg6kWVjQUlrSJYvuJ9yECzj5JecPHhju7xv3amNgDTOQ5uz8DVkS8hL15WXd
xVs69u4ZlLKf/vmAX3K+7egXsni1MbDe9PTtocErhw+NVFb0ri1qrXrq9COl
7zS/NcplXAQQOQ/rSbZv3Xx8fp6UFsl8SX7tok+TPgKCnEcQOJt3IpdvaBf9
0pKu4i0duxvOyt+OXbiW620EMoWcR5BNT98ePn+1uSlcVzsgB4Ka6j6J/W+V
n+rtuZjrTQM8Q84Dxvil65s2zA2ztnpVs1T7UvNT6sMC5DzgZFp4pqZuDQ1e
cZb68ks6bcKPyHkgHVLq9/eNa6fNtUWtFU/0lGw/cajxs+np27neNOAeyHlg
qaLRO8VbOvT+LPlBL+bK/jl24Rr9NpGHyHlgGZwdePRiruyfdbUD2m9Tyv6e
UxflFCA8Osnoysg5ch7wVuTyDQn2w4dGaqr7dOasNatb+vvGJfZzvWkIKHLe
SmMXrqVepBzVt3R5i5Sv91wFDdezjtGVpfLX2JfyXg4BxD6yiZzPQ5IAyQJ5
d8NZCQqzlJZ0acUYszgfk3Bpbgq7yfmYzUi4aAt2mpsnMRizip5TF+OPHRa0
fsurkJdmYl/HWJb6v6f7d7TwIEPI+WySElfzSptzYwJzbVGrxqB895MFckwh
7dM79+MDXOrbmJyX9Is/HJi3SJbysu5kRy7t9G6WfB6mXsdY3r/v3P1rWnVk
Bo19qn14iJz3nKSKZIt8VWWDtfe1LBvXt8m3WEpc/aN2z4jJbQuK1WyamLiZ
rCXKvO3ON18W+SHhocF57pCrg4K28LzU8LHGvqn25WcaeeASOe+GdqgwxadU
mCZM5OvpLCzzuaQMDj0Exx8anOcOCQ8K8gB95NDglWyeSckOJgWDs5Hnxfoz
jz16svmt0SysHdbwS86/tv9cyfYTOWy91IiQb7p86UwayPeuflfIFITcKWkT
50FBPl/N+b17BuOvjOhv5K/MCYX+K8+LcHnCBze2a/OOtlzpSikkkJpfcn7z
prnde21Rq1fbc08S2nJY0RaA4i0dWt3Jd0pOovlawUlTXUp9k/Oa/KZfpfPS
c8yxYKm1gbPfvvxbXakWHrKXatUh55gfnfkDV3Vh+CXnf/zDj83unSHyrZEM
11N4LZb27zunDS90EYRL5tQg5ligbX2yVFb06m+0xU/jWh6f/nxYspdqK6Kk
/ZrVR7Ts14nYGIot4PyS8zofnFcbYzhnlJZvnHwptAXG8xUBqUme64FAr+Br
XEvsS/7H9C/Sv9X0TnZqqWX/D77/kTxMWxr1UGJKF73oz+26ARHAnJcvlGb7
2qJW7b08fP4q7TDIc6Z/kea8pre5VCQ7c8LTAWcnLr1RV5si5fGlJV3aT7Wo
8IhPO+giTcHJednnJdJl35aqRrOdfoywhuzMCU8HNMlNh17tOKQnrUODkVdf
GZK/LX24Sy8r6w1rdOO0j905Lzu/5Ln8Q72KKrs3dQsCyNygpx2HTD9SvWfZ
cS7w6fdfPFP/Qujx8lMFq5rKy7rlYPGTl4eeeLzn5Du/zfWLwPLZmvNSkEhl
ogPGyr+lWQZIxpwLOO/RNp2FCuf7cBbcN3c4kMp/z48+aX5r9PPf/CnXW40l
sCznZY+VR0odInupnH4S74BLb77x35LzL9afaW4KS8G/47GTxVs7tAP/mtVH
Nj/YLuG/s6b/oW2dPztwns5p+cmanJe9S0oRKeDlYdyvBGTBxYtTx499uf/V
T4sKjyzcRLzh2AP3vy0/rHvg7eeefd8MLiHf30zcOIY0WZDzUrTLvlRa0iW7
EwU8kH3m7i0dku7woZFnd75/f+GR4i3Hpf6XtP9O3Qc7yrrXr2tz3iyghwAd
SoLaLKP8nvOyU5WXdctuRucZIN9MTd3SW7d2N5wtWrx1S44CrS2/6em+qOML
6VASer+YuSLMIcBb/s15+fRrqvukhKA9EMh/5tYtHX7f3HWuYzUMn7868P7/
1D73fvNbo2aIuRSHAB3olYagNPk05+WPcurHpwz4mlRrCQv++NvSTacgPQTE
dAriEJCaH3NePkr5mYYawCbOgt85zJQZnG3wk0iyURqSHQLMWYBzWOkANgT5
Lud1gjmPNgpAXjMFv6R9YUHLUqfcirk1wNkQZOYXcF4LsLUR2F85rwd6rzYJ
gI84C34z5VZlRa/OzvbOibHnnn0//THZzPwCzmsBeoNwzCFAO4WmP3BoHspE
zoeq5FlXrGyMeLgieatf/N4Z+WTdbRoAq0j86mzLOpLP6vuazYXdZbfPxBwC
5JhiBg6NuRyso4bm/yHA+5yXlK8Kzf/3rqR3n/ObNh7L//cTQE5otf/Ky780
F3a1fUYHZ3vzjZGqp0+7H4E55nKwdhwyY0dLIaqrc84Z6smrc8nznI80rpyP
+digd7mi5rdGi7d2uNs0AIGjt26te+Co6Zlz+NCIc0xODwfhl+fU1Tkno9f1
lpZ0Oa8IZ7lTkOc5v1jOe5zzcnSurHjX3aYBCCjnHbvagd9Mrb7+m3OHgPvX
HMnoBkxN3UoxWJzeIKwXGszA0R6eC2SznnfjX77xxN//3X+5fBIAyEN/+Rf/
8Nd/9Y2//Zt//+d/Kvu3f33hP//jJTOzsC7uV+Ftzmeoff4HL3705OM9LjcN
GRVz/mvmP3Iucrr6k5eHSh/u2t3wkZkpNX7Zu2dw8bJai5lBO+Hi5mF6KS1m
2bj+2PxIjC3xf+V8Ie+cGJMaTG/eTDGjd/ptAkzhlw/GL113zrR4/5qF+bY8
7HKvhb1eOzb9fGJmhDGFvXb1cV/Ye5/zmelvc/zYl5sfbHe3XUgsWcKYM01Z
fvHzz5zhrGedZompPWLmM3Uu81PxJg1SswwNXjnw+q+0E138wcK5uHmYXkqL
Wb77/AfyyKqnTsf/VeoDh5nRO9liZvqOWXSOp/i3RSf+cy6RyzfSPBxw1PDE
zw8Oy4eyo6xbPtyN69tk79Wrq+c+/d/Ub2/CWV10n9GGepPk2m8/ZoZHz2Ui
5zOxos9/8yd5l2y9iyHLzOxCOsecJoyJLO1C7LxyJIu2YZoU0qtIZtGnNU2g
qdee5sPy3DJerJnpO2bRNIg/vujEf87F9OtIffhIeDCN+cj0q5TO4YBDhpqZ
icp7qFdXdfj9wvuaj7Z+fvTtz03lY4718bM0ZjrJU/NLzsu7VL6j26upwINA
L/1rHf7szv74c8O6xTmjNWFMrZvwYGpHOFsg/oOIP3xIHMUfNWJOwczRPP6Y
rov2QneeaMScWTi3ytZjgelI73wPdS5dWTasP7Zl8/H132yTt+j5ug9+2HD2
ySd68/NN8FHO674ne5RXm2QBeTeeqny3+a1RrQmdrSjalVfr8KLCIzmvKJCH
zFHD2Uani/ZCN2VAZcW7Kc4stL41p4RaPzhb4ZxXNJLthLk6WOjprZk/3Xkc
NDfGOs+J4ueYlt/IP9fv2upVzXv3DMof5Wnz5/Dnr5yXPUTiK7B3S+k9GjqP
g7Ou0BE/zIVC5z+hDkcWyL7nPCU0mem81GiuaOgPC/NPLQapeYBpazKXIGXR
+YPcxKZW5ubgpZW58/TWHJtSnNWmpt+1fa9+Ksc1eTZ52qLChcu4Oa+v/JXz
s/Ofl0S9vJMebVde6+n+XfmO7he/N9dOK98IvedaQltb/KSKIMbhFwn3VdMw
Yq6Vm7YmHW1AF9n5vz53WGz9djYuyXK8/csnn+h5Zc/g8WNfak8qZ2W+7oG3
N2449uTjPc7KPNPxe6jx13NtYg93yTdXjixSoaUYcjOjfJfzs/NlrVQIUsHm
/CjpuYmJm7IPyHdBz4u1W5c2jTIlIgJOjxQ//tEnPd0X5+al3ffpnh99Iikq
y+ZN7QsHgvtaNj/Y7jxl2PntvviTBXNVWjIkO60rskb5XuuQm1LhZ7lLiR9z
XklNW17W7ffm+l9/9sf5Afc+kspEdkV5RVLGyHFf26Yo1xFMCS+AamXu7GFu
xpCRAinZlyXhyYK5Km2OCKvvWzhNkBpSHyNfQ72m0N4WOxD6sg8NupGPl/fI
q5Cv/JtvjCxpjM1l82/Oz85f/pD3ShZ/tdhrBy05H5FdaPWqFi0zZM+x7/QE
SEEvgMa0metVp4QXQDNUA5sB0PSIMDR4RVcqhwwzBmZMF1btg2S6Nyzv8oE8
Xkfdka9/pst7X+e8krdLx6DO87SXzZOdp6a6T2+4kPMR+Q0VO+yWcJh3bW/X
yty0sSfrzZJDMV9P04VV+yBJWe68fLBmft7DwoIW02f+vXcvpU5+ff7qZ96T
t+KF5z+UcMhQbe+XnJfzsvKy7hQPkJ1E0l72GfnBzYo8d7z9y23FnZs3tcvm
yQ7AtJWwj3bLTN010Tltk5UXm5reGpXX+93nPzT3wGp/G20R0v48R1s/Txbm
eolBavtMvDl+yXnZkeSE7p4Pk9peSmV5pBwoc3vzrBxu5JOVnfyB+9/WK6o5
3BjAPeegu+Zefi1l9TYr910TLeNsEdKDoKZBweLwyL/4+WfPVL2nsa8P3lnT
X7Kt0/P7rSzLefNgKR70rFB2y2wWD/JdkLM8bZmRT0pWTcsM/EKHnjMN5qZn
o/POO51Ew9zLb2VlnjmaBj99/byOd6G3VhXM31r15hsj366ZK/VLHjqhhb2H
67Uy5w15MzV163eFJPAz1/Q3+EnksUdPbtt6XL4LWT6yAOkz0yFpWR5zD7UO
PWcazL0aLBHJaOy/tv9XQ4NX9Jrs6vtantvZr73uX3j+Q686fNqd84aUKBL4
8gyyJ8vpkoe9MaWAl2OxdovN9FQFQDqc1z11iF3TwGKmN9WyPOE91MgJzfyX
Gj5e7IRzZNOGY/qRuX/ygOS8IWemcrqkndW1bln2Ti7HWane9eZcGmeQNaYH
S0xNHjNYonOiahpYfETD5Mknerdt7dCTLPfPGbScN/Q+OP2O6FdDvhfym3Ta
diThZWP27ztH5xl4zgwpFt9Ort25TQ+WmJrcw7kwkA8052UZeP/3Lp8qsDkf
Q89zpcKXtegFXO3Q64x9+d6V7+jevKldvnd51csXPmL6YJv7cWKmCjVDBMe3
k3MnXaBoYa998l0+lV9yXs46pYzxaFvuQW/T0y+g3p0nX7rv1H2w2AhPD0kk
Zkpxk+Gm/6FpVDH3VJr76/X+IM4NEU+b6AtWBSXnhbxeT7ZkqaQAq3yy9+nK
3ppn3tNjq/Yx0xE2LL7vA4ZpEjfTerY5ZvY0GW5KcZPhpv8hjSpYBlPSu0wY
cj4FOU1ubgpLARZ/rVaqL/3KO+/j1g7Gev1Lz7XJ/3ymN/7EVODOCftMgJsm
cTOtp3NmTzIcGSX1g8vTPXI+no5H9OYbc+OMyfE0/X+ouaH92fTamXMcD3MI
aHNM8cyBwEPOSZFMX5SYKfOcs3XrcTmmAnd+OgQ48oHedOnmGcj5eHo/WmFB
i1dfczPvth4CnBWjmUDBNNuaY4EzcAJyUDB38ZjFOS1RW9zU2M7pJwrunuTU
9EVpu3sKbKIbviNFY8+pi26egZyPITX5w9tPZL8zvOmGYY4FS4q1+Ol1Ei5m
vG5PFmdbR7JFDlsxG5nwtehi7uIxS8yzBe3AB8zOT8soi5tnIOedJAblXN4v
JV+KuZuXmrrLW5xtHUs9shDRQJrkS3T40IibZ/BRzksFmLlwiEbv7G44KzGY
oecHgOU5E/pq/75zbp7BRzlfWtKVobuT5GmljM+3gesBYJacdy08Oln19OlH
H3knz+eiAhBYnR0Xap9LPJtemgKe8zrlDbe4Ashbr7927rFHTrp5hiDnvBTz
Ox47yTiTAPLW8fYvpRDdsO6omycJbM4PDV7Z3XCWgaEA5DOdXtxlb0Mf5Xxl
Ra9Xreg6jSwhDyDP1e8KScgXFbpqW/ZRztfVDngy8Q0hD8BHAtU+70nOyxlB
TXUfIQ/AL8j5JfnozB/Wr2vr7XE1UgQAZBM5nz6p4e9f0+rVvLoAkB2Byvn9
+865GZxT/vmPf/gxvSgB+Etwcj48Olm8tUNe7/L+ec+piy4HAgKAnAhOzus8
rUWFR5bxb8cvXa+rHeDaKwA/Ck7O6zyJ36ld8iAPMzPRyoreDA2ABgCZFpyc
F81N4SXN4qf27hkcGrzictUAkCuByvmlTqoSHp38Vvmp6mdOu1wvAOQQOZ+C
TvPKWJQAfI2cT6HmmffoRQnA7wKV80uaVGXswrW6pV+0BYB8Q84n4+HglgCQ
Q+R8QtwVBcAagcr54fNXdzecvefDotE7pSVd09O3Xa4OAPJBoHI+zSZ3qeSl
nne5LgDIE+R8DCnjpZhniAMA1ghUzo9ful5T3ZfiAeHRye0PnXhl76DLFQFA
/ghUzk9N3ZJaPcUD9MYohpcHYBNy3unZb/dzYxQAywQq56PROylqdVrmAVgp
UDkvpFxP9ld0swFgpaDlfPGWjoQd46WMl7+amYm6XwUA5JWg5XxpSVfCGUO4
ARaArYKW8zXVfeOXrsf8khtgAVgsaDm/u+Hs8PmrMb9c0vhmAOAvQcv5gweG
+/vGnb8Jj06u++bR9rYljEsPAD4StJyPn2pk29YO7o0CYLGg5Xx8E83j3zrF
vVEALBa0nI8Zyixy+UZlRa/7pwWAvJWXOR9pXCnPWhXKwIoGP4kUrWmVql7/
GN9cDwCWycucn52P+ozkfGlJl2mNZ6ADAEEQtJw/0TkmOf/i986ERyeLt3bI
y3f/nACQz4KW86K/b/zggWG62QAICH/lvNOynzoavVNZ0btpwzG62QAIgpam
8FMV77p5Bt/V8wCAJclE/Iaq5kv2lY2RDK8IAHBP/uo/DwBYKnIeAOxGzgOA
3ch5ALAbOQ8AdiPnAcBu5DwA2M0vOc9hIuDvAC8/15uQSwF/+bP+yU+/bCcb
kJ94+bnehFzK+cv3+wYEJ+dzuwFsv6+3P+AvP+cbwPbnfAOysyK/v1Fsv6+3
P+AvP+cbwPbnfAPSXxEAICeyk/MAAAAAAAAAACDP6Uwld09Ukur39knyShNO
4WKhVB90gsnKbJPi5curt34HSPLy9aXb/uLn6CtNsJdbFYDyYuZfYqjq7heU
7Pf2SfJKI42NoYW/tvodSPVBz+/pdud88pcv33+rP/h5yV7+4vF98e/tlqia
sSsAv36Fd7+eZL+3zz1fqd1vQIqXH6qqCtlezyd9+Yv1rN3HueSf/kLMze0D
udm0bEqwl1sWgF8fr+9+Ocl+b597vVLL9/SkL19ft+05n+zlm2Le7tO5VDt/
AE7mFiXYyy0LQOr51K90sfXGWkle/tflrD1NlIkEfP9PVc9rOW/zh2/YX8/T
Pp9GC22o0eK3IPUHbXs9n2r/n/+F5W/Avb7+gbhIEYD2+dnYy8rO8xXLazkj
4Tuw0NvG+iba5DvAHMtjbk7q/d/yzz7pyzcndLa//th+dUEMQAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAA8tXCAIlVjXP/tX+QRAAIormol5y3fGYX
AAi0gExgBADBpFM83D3RCQDAEpGFdnltp6eoBwAAAAAAAAAAwFL8P9VBGhI=

    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->56640754]
}, Open  ]],

Cell["Clear variables for use in next section.", "Text",
 CellID->386399333],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "a", ",", "b", ",", "rC", ",", "vC", ",", "cp", ",", "xC", ",", "gCp"}], 
  "]"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->437524282]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2.3  PMDoubletConstantDirichlet", "Section",
 CellID->617689357],

Cell["\<\
The same procedure is followed to compute data for the validation graph using \
the model PMDoubletConstantDirichlet.\
\>", "Text",
 CellID->311897436],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "aW", ",", "rC", ",", "vC"}], "}"}], "=", 
   RowBox[{"PMDoubletConstantDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCp", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xC", ",", "cp", ",", "rP"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpE", ",", "gCp"}], "]"}]}], "Input",
 CellLabel->"In[19]:=",
 CellID->186135957],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3X9sFGd+x3Gq/tlKrdRK7T/9o1J7/a+t2r+KFCBAfhAIjnMh3MWxLtgX
n32Xg/zAl5zdJHC5QJSDngutYhuCAWMSY+diQrI5J3ZCcI/ihGDVwtWJpUXm
hJY/sJBsIXUlJPdrf+0nj2d/eO2Z3dl55v3SXM6YZWd2d/Yz33nmmef5y5od
j9b8/ooVKx76vRUr/k/+N/PzNAAAAAAAAOIg2bJyxYyVLcmwNwUAUATJ5Gy+
J+oIegBwWLKlJRH2NgAAimOu5aZuQdCvAACExFemJ+oWPNc3bTXyFwuC3u+K
AADLUrT4TbbULWifJ+cBIBSBx+98ge+9CkvOA0AoSha/5DwAhIKcBwC3kfMA
4DZyHgDcRs4DgNvIeQBwGzkPAG4j5wHAbeQ8ALiNnAcAt5HzAOA2ch4A3EbO
A4DbyHkAcBs5DwBuI+cBwG3kPAC4jZwHALeR8wDgNnIeANxGzgOA28h5AHAb
OQ8AbotWzqfTd0/3jfl/HgCIj2jlfNeJkY0bOnpOjfp/KgCIiWjlfM1TPdVP
dm/edGz4wvUd2898nPit/+cEALdFK+fvXd2++p62NavaHn3khPxw37rD/p8T
ANwWoZxPp++uW3NI4r225r3GnQn5Yf++oUC2DQAcFqGcT6Umt245KT+MXLqx
Y/uZIDYKANwXoZw38S6F/cYNHfLfILYLABwXoZwfvnC9cWdCf66t6U1eueV7
owDAfRHK+Y8Tv92756z+fPDAeXpXAkAhIprzQ+euNTf1+94oAHBfhHK+48hF
WfTnqan0xg0dfrcJAGIgojkvqqu6x8dv+3xOAHBehHLe0ya/d89Z7ocFgEVF
KOc9wW431wMAcoluzuttUwx0AwD5RSjnm5v6h85ds39TWdG55dtdDHQDAHlE
KOelbh+5dMP+jST/6z//jIFuACCPSOd8z6nRgwfO+3xaAHBbhHK+ob5v7PJN
+zfJK7dqa3p9Pi0AuC1COb91y8lUatLzy40bOqam0j6fGQAcFvWcz7w4CwCw
RT3naaIHgPyinvM00QNAfhHK+fvWHc46twhN9ACQR4RyfvU9bVl/TxM9AOTh
QM7TRA8AeTiQ8zTRA0AeDuT8dI5LtACA6ejkfDp9N89gZYxFDwC5RCXndRTi
XH87OHB1964BxigGgExu5PzUVLqyovPxx04yRjEAeLiR89Ozo1nue/MLxigG
AA9ncv503xgJDwCZnMn5RR8AAPHkTM6L2pre5JVbftYCAO6JSs73dP/Xhgc7
8vel6ThyURY/awEA90Ql5ysrOhftS8ONsQCQKSo5X2BfGm6MBQCPIuR8om7F
jJUtyQBXNHLpxo7tZxZ9WFvrcNeJET8rAgDHBJ7zyZaWxMz/S9ovSPrS5DxN
NwDgUbx2m0RdCDkvqqu6x8dv+1kXALikaDmfqKtLBLiiwnOeXjcAYPOb83ON
8fPmS/j51psFK7ItdT2F5/zExJ3Kis6lPj8AuKoY9XyyZeVs3idarIabktXz
onFnYvjCdYavBIDpIuS8XeDbLTc+VzR07lpzU3+BD9ZhirduYfhKAIhM/3kp
y/fuOVvgg9PpuxLyh9q/ZPhKAHAy58XBA+d7To36WSMAuMHVnGf4SgBQrua8
aG7qHzp3zc9KAcABDuf88IXrjTsTiz8OAJzmcM5PMyI9ALie8z2nRg8eOO9n
vQAQdW7nvHawnJi442fVABBpbuf8NCU9gNhzPucp6QHEnPM5P22V9Ix4AyCG
4pDzpqRnxBsAMRSHnJ+eL+m7Toww4g2AuIlJzktJX13VzRThAGIoJjk/vcSR
jQHAGfHJedFQ3zd2+abPJwGAaIlVziev3Kqt6fX5JAAQLbHKeSFPQr9KALES
lZw/3TcWSD+ZiYk71VXdU1Np/08FAJEQlZzvOHJRlkC2JKhDBgBEQgxzXuzY
fmbk0o1p7pAFEAPxzPlUarK6qlvvk+UOWQBui2fOT8+33nCHLADnxTbnp63W
GwBwWJxzPpWarK3ppe8NALfFOeenGQwBQAzEPOfFwQPne06NFuOZAaAckPPp
9N0d288w7g0AV5Hz07M3yTbU9zFqMQAnkfNK6nmp6qW2n+bmKQBuIecNM1Qa
N08BcAk5n7kWbp4C4BJy3oOBiwE4Jio5L9X16b6xoDYmv8adieEL10uzLgAo
tqjkfCnL7HT6bnNTP1EPwA3kfFZ0qgfgDHI+l6mptER98sqtUq4UAAJHzufh
iXr61QOIInI+P4n6hvo+baunXz2AKCLnF2Uuy9KvHkAUkfOFkKhv3JmgxQZA
FJHzS9qGttbhcLcBAJaKnF+SrhMju3cN6HBnABAJ5PxSDQ5cbdyZmJi4E/aG
AEBByPllGLl0o7am176Lii6XAMoWOb88Us9LsJshd+hyCaBskfPLlk7f3b9v
SDZMfqDLJYCyRc77JFtVW9PL8AgAyhY579/4+O2G+j4p6cPeEADIgpwPRDp9
t611WNKefjgAyg05H6Cxyzerq7o920lXHADhIueDNTWVlk21O9jTFQdAuMj5
YpAa3hT2dMUBEC5yvkhMYZ9KTYa9LQBijZwvKi3sO45cZEgcAGEh54tNEl5y
XtKeicUBhIKcL41UarJxZ6K5qd/TjENvHADFRs6X0tC5a1LYt7UOT02l9Tf0
xgFQbOR8ielgOBLv8l8GxgFQAuR8KKSel6peanup8MPeFgCOI+dDlEpNNjf1
19b0kvYAioecD13yyi1N+5FLN8LeFgAOKkLOJ1tWyrPWJQJdkcM5ryTtd2w/
I4td29MbB4B/xannJerJ+eWQkt5uyaE3DgD/opLzLzz3UfWT3qEgXWVacl59
+RN64wDwKSo5/+D9R+JW2Uray1mMlPSn+8YYNgHAsvnN+UTdCtvKluTMb7Pn
vG2p63n6+7+KZ2WbSk3Kq66s6GxrHc6cxIQGfACLsiJ3PrIlqxMtmtfLRft8
wKam0l0nRiTtd+8asOeipQEfwKLm4nemj8xcLT77szell2TugLFywbGCnA/E
4MDV2prehvo++WGawe0BFGA2fiXZ7VBOttT5K+dzrmj5yHnb2OWbUthLeS85
b4bKAYCsZuLXE/PFW5EP5HymiYk7ba3Dkvby5kjyh705AMrUTPwm6vy10xS8
Ih/I+VzS6bvyzjTU91VXdfecGvVcq+VCLYDZ+JWg/6agt1ptZhra61pmbm/1
X++T88U2Pn774IHzeq3WzGnChVoA1nXYhV0jZ80E/cyfE3W+C35yvmQGB642
7kzo0MeH2r/kQi0Qc3njN1GnoT///0Vb0eLI+aVKpSa19V4yX9467rQCYitf
/M5V8cE035PzYRm+cF3evY0bOuS/WeeopQ0fcFue+LXumyruigpBzvukl2ul
tpcKf/++IW62AuIjd/wG0CZf2IoKQs4HZWLizum+sdqa3uqq7o4jF1OpSW62
AtyWI361lg+yVz05X27Gx29LzksxL5nfc2pUAj/sLQJQFMwnheSVWwcPnM8f
+LThA9FFzsPIE/i04QPRRc4jkx34XSdGxsdv04YPRBc5jzwk8Ntah6urumWR
5Ld76QCICnIehZCSvufUqJT32i1z6Ny1zBuvaMMHyhM5jyXRbpnNTf33rTvc
uDMhP5tmfNrwgfJEzmPZpICX2l6b8TuOXDzQ8hva8IEyRM7Dv+SVW5Lz2qoj
n9TgwFVmPwHKBzmPAE1M3JGPafeugY0bOhrq+7SvjucxNOMDJUbOo0jGLt/U
vjpbt5zUS7da5NOMD5QYOY9iS6Um9dKtFvnPP/chzfhAKZHzKCUp8juOXJS0
1+46XSdGcvXJp3kHCAo5j1Ck03clydtah2treqXO371rQD5fRloAioGcR+im
ptKDA1flI5Zsr67q3r9vSP7IjIdAUMh5lJXx8dun+8akvK+s6JRS/+CB8+YC
LoDlIedRtpJXbvWcGtULuJr5wxeue8ZboBkfWBQ5j0jQzG/cmbhv3eGG+j5T
59OMDyyKnEfkjF2+aer8ioePSc4//9xHzIcF5ELOI9JMe74U9rLofsJNuIAt
Kjm/f9+QfJ2D2hg4SUp6SXKJ+uqq7sqKTgl/Kfu1fz7NO4izqOR8x5GLsgS1
MXDexMSdwYGrBw+cr63plXh/8ol3Jed/+tKvM4fNB5xHzsN55p6sHdvPSOZL
8msXfWY8R0yQ84ib5JVbpkm/sqKzuam/68TIyKUb+re08MA95DzibGLiztC5
a1rqS7w31Pc988PT8sOe1z8Pe9OAwJDzgKE9NvVuXCns5Qe71LfRvIMIIeeB
rFKpycGBq3apv3/fkOm0SfMOIoScBwohpf7pvjHttCnx/t2t70jON76QmJi4
E/amAYsg54GlSqfvjly60XVipLmpv7KiUy/myv4pv2T4HZQhch7wSS/myv5p
+m1K2d9zalROAWjeQTkg54FgJa/ckgL+4IHzDfV9EvKybHuq93TfmMR+2JuG
mCLnnTRy6Ub+pevEiL6ly1ukfF10FTRcK3krpLbfv29IY19qfjkEZMY+LTwo
HnK+DEkC5Ark5qZ+SQOzaLNA5mI/JuvS1jrsJ+c9m5F1qazozLptWTdPYtCz
CsnGzGOHA6MWeGJfx1iWeH/0kU5aeFAk5HwpSYmreaXNuZ7AlO+4xqB893MF
sqeQjuhgvJkBLvWtJ+cl/TIPB+YtkqW6qjvXkUs7vZulnKej0h77e/ecffyx
LnlRj2zu1NjP1chD2Y9lIOcDJ6ki2SLfRNlg7X0ty8YNHfItlhJX/6jdMzy5
7UCxWkrj47dztUSZt91+82WRH7IeGuxzh3APCib2TbUvP9uNPFzYxTKQ837I
t0/qK1N8SoVpwkS+nnZhWc4lZXzoITjz0GCfO2Q9KMgD9JGDA1dLeSYlO5gU
DHYjT8MP3teBN0uwdjgjKjkvX0mpvoLamGXQiJBvunzpTBrI965xZ8IUhJnT
WyC67IOCfL6a87t3DWReGdHfyF+ZEwr9V4F3sNF7tfSopC1XutLMQoLmHdii
kvM6f0RQG1MICW1ZqbYAVFZ0anUn3yn5olGfw6apLqW+yXlNftOv0r707DkW
+KkN5N/qSrXwkL1Uqw4J+ccePUHzDgxy3tAZ6OxiSdaoDS90EYRP5tTAcyzQ
tj5Zamt69Tfa4qdxLY/X+bAKIXuptiJK2m966Kg856OVJ3QitqxDsU1T9sdG
zHPenlFavnHypdAWmMBXBOQnea4HAr2Cr3EtISz57+lfpH+r6Z3n1FIHZ5CH
aUujHkpM6aIX/bmqGxMxzHn5Qmm2y+6tvZeHzl2jHQZlzvQv0pzX9DaXimRn
zno6YHfi0ht1zbxaEvJmNLY8l5Wp+R0Qn5yXfV4iXfZtqWo02+nHCGdo9Z55
OqB3HJgOvdpxSE9aBweS5774H72JQwt7vWHNc68uNb8D3M552fklz+Uf6lVU
2b0jemMR4Ie5QU87Dpl+pHrPsnUu8PlLL34s5f33qk+tvqe1uqpbDhbPP/eh
POa1n30W9ovA8rma81KQSGWiA8bKv6VZBsjFnAvY92ibzkKbNx3b/PCx+9e/
PdPU8/jJXa982vbWha++/J39DLTtlDnHcl72WHmk1CGyl8rpJ/EO+KTXBSTJ
21qHpeB/8ol3Kx/pXLOqXQ4Ba9cckkOAhL8cBeSP6+49ROe08uRMzsveJaWI
FPDyMO5XAkpgdDR1/OjXe1///JGK43M3ET90VDP/wfvf/vEzH5jBJeT7+07X
yNO171Hzh8KBnJeiXfalrVtOyu5EAQ+ESHtyHjxw/pkffbD+3kOVFcel/pe0
f3bHh+vXHl59T7t9s4AeAnQoCWqzoop6zstOVV3V3XVihM4zQLlJpSb11q3m
pv6Kh4/prVtyFDjc/mVP96iOL6RDSej9YmtWtVc/2c0hIHDRzXn59Bvq+/bv
G6I9EIgEveCrw++bu851rIahc9e+XTkzVsP62Ub+zEOA6RSkhwAd6JUpugoU
0ZyXP8qpH58yEGlSrWUt+DNvS5djxDtdI7Xbel99+ZPMTkEcAvKLYs7LRyk/
01ADOMYU/PYwU2Zwti3f7sp1x5Y90LR9CDBnAfaw0jFsCIpczusEcwFtFICy
Zgp+SfsNDxwxBX/mlFtZ+/B7bg2wG4LM/AL2tQBXG4GjlfN6oA9qkwBEiyn4
zZRbtTW9Ojubube3wKcy8wvY1wL0STyHAAmfJQ0cWoaKkfOJOnnWFStbkgGu
SN7qF3/ysXyy/jYNgFMkfnW2ZR2T7cEHOsyFXbt9Zkl37HoOAXJMMQOHei4H
66ih5X8ICD7nJeXrErP/vyDp/ef8po1Hy//9BBAiuyents/o4GybNx0LZDQ2
0xCkhwDtOGTGjpZCVFdnzxkayOvyKfCcT7asnI15b9D7XFHbWxcqH+n0t2kA
Ykdv3Xr6+78yPXMOHjhvj8kZ4OA88py6Onsyel3v1i0n7SvCJe4UFHjOz5fz
Aee8HJ1ra97zt2kA4s504DdTq+vl3fVrD2U+OMBDgJxo5BksTm8Q1gsNZuDo
AM8FSlnP+/E333rqz//sn3w+CQCUoT/8g7/44z/61p/+yd//9V9V/d3fvvCP
//DPZmZhXfyvIticL1L7/E9f/PW27/X43DQsWyGFjWdCCjP/kb3I6erGDUdn
hzpsNzOlZi67dw3oBBlrVrWbGbSzLn4eppfSPEuezbNfyMw9OzW9bW9dML/J
2iu78IKQoX3Lwdjlm/ZMi48/NtNj/9ntZzwfrp8PSwt7vXZs+vl4ZoQxhb12
9fFf2Aef88Xpb3P86NebHz7mb7uQXa6d1pxpyvLwxmN2+ulZp1k8tYdnPlN7
kX+o81bUff9XeXJ+cODqvje/kIf99KVfZx4s7MXPw/RSmmfJs3n5DxxmRu9c
i5np27PoHE+Zxxed+M9eklduFZgwHDUCofNH791zVj7cjRs6ZO/Vq6t57thS
WWd10X1GG+pNkmu/fc8Mj4ErRs4XY0Vfffk7eZdcvYuheLJ+383sQjrHnCaM
iSztQmxfOZppSPzB+3b66VUks4T16kIk33d5Q6TwK/xhZqZvz6JpkHl80Yn/
7MX068h/+Jid19571PB8ZPpV4nBQuKmptLyHenX1/vVziX3k8FdH3v5KK59t
T/XqmMxmHAZ7lsZiJ3l+Ucl5eZeqn+wOaipwZ+T5nuqlf63D713dnnluuGN+
zmhNGFPrcjAtZ5nHl8zDh8RR5lHDcwpmjuaZx3RdtBe6LD//2eDWx0+++vIn
njMLe6tcPV6YjvT2e6jtk5s3Hat64t2Kzcc3PNAhR9Xndnz40AMdZTuRboRy
Xvc92aOC2qTyt+jXR3e5dfce0prQbkXRrrxahz+7/UzoFQXKkDlq2G10umgv
dLtBKc+ZhU4vZU4JtX6wW+HsKxq5dsKwDhZ6emvmT7ePg+bGWPucKHOOafmN
/HP9rklJv3vXgPxRnrZ8Dn/RynnZQyS+4nO3lOfKpt6jofM4mLrCjPhhLhSG
u81wTCEtVLLv2aeEJjPtS43miob+MDf/1HyQmgeYtiZzCVIWnT/IT2xqZW4O
XlqZ26e35tjk86xW/qEc1+TZ5GnX3XtYyzBzaAsr+aOV89Ozn5dEvbyTAW1X
yPJ/7r/cPzTbAPuePEa+EXrPtXzjtMUvs64AylbW44VpGDHXyk1bk442oIvs
/N+cO8y3ftuNS7IcP/b1tqd6Xts1cPzo19qTyq7MH7z/7Y0PHd32vR67Mi/2
6e2Blt/MtIk9flK+uXJkkQpt0Qu4RRK5nJ+eLWulQpAK1oFWiMy+iJL58l3Q
82I5osnerpf4mRIRMadHildf+bSne3RmXto9n+965VNJUVl0WIOZZVX75oeP
2acMP/phX+bJgrkqLRlSmhpb1ijfa70n68fPfFDi6+BRzHklNW11VXfUm+ul
CNEaRioT2RXlFUmwy3E/Pm1TQKasF0C1Mrd7mJsxZKRAytW+lPVkwVyVNkeE
NavmThOkhtTHyNdQrykc6whyIHTZGNlIeRXylQ9q1J1FRSXn5Q2X0y7PgS+V
mpT3SpZyTsXMQ7Z20JLzEdmFtClGO0s7cHoCFE4vgHrazPUMN+sF0CL1BNMD
xGs/+0yPCIMDV3Wlksbz1xS8XVi1D9Ke1z/zc/lAHq+j7tTWvFfsi7ZRyfk8
g0vL+6NjUJdn2puWGdk82Xka6vv0hgs5HynPDQYClHWYd21v18rctLHn6s0S
Is85gunCqn2QTHdlfTlr1xzSX5o+8++/d3nR6JaEl7XIW/Hg/UeKV9tHJef/
/d/+M/9Ff9lJJO1ln5Ef/KwocG/sPbt6dlhs2TzZAZi2Eu7Rbpn5uyba0zZF
/WJT1jai1rcuyC+ff+4jcw+s9rfRFiHtz3Pk8FdS6WVN/ldf/kQevO2p3rOf
/2/ghX1Ucl52JCmMF32Y1PZSKssj5YMo5f0+medccriRT1Z2cjn0nO4bK6sq
BVgGe9Bdcy+/lrJ6m1VQXROdYbcI6UHQvmFW3sN//eV//KDufZMb6fRdORFY
N3teEGxh71jOmwdL8aBnhbJblqB4MI0z8l2Qo7y2zMjHF/W6BbGiQ8+ZBnPT
s9G+804n0TD38rOHL4km/y/ePKfjXWj3G1nMrVXymEPtX+ol4wDX62TOG3pp
uwRFtX40Gzccle9CaY4swDKY6ZC0LPfcQ61Dz5kG86AGS0QuGvtv7P1icODq
C899tG7t4e9+5x2tD+X9l98E1YDjds4bUqJI4MszyJ4sp0vL642Z9YK4FPBy
LJZzB3narCPTAiVmX/fUIXZNA4uZ3lTLcu6hLh/aJrB+7SGJ9/vWvf3a7oFN
Dx0NqgEnJjlvSBTL6ZJ2Vte6pfCd3HNP08yIFvV9Lt2ci0gwPVg8NbkZGNm+
7qkTVdPAUv7MtV3NmbVr2nVm82cX3je0PHHLeUPvg9PviH415Hshv8nTtmM+
CEl42Zi9e87SeQaBM0OKZbaTa3du04PFU5NzOukGkzMSL49sPr5u7eEzH/y3
z+eMbc576HmuVPiyFr2Aqx16PbFvEp7+M1ge0wfb3I/jmSrUDBGc2U7OnXSx
Igf69fMjofl8qqjkvJx1ShkT0LYsYuDTZO22mRuvtIumVvvP7vhw00NHG19I
XL9O1YTsTCluMtz0PzSNKuaeSnN/vd4fxLkhPOwBaX0+VVRyXsjrDWRLFuVp
h5cCTGL/6dref9k/ZM6dpfrSETbcuO8D+ZkmcTOtZ4c1s6fJcFOKmww3/Q9p
VMFSaQPOKy9/Kv/1mTDkfCbTPianyW2tw1KAZV6rlepLv/L2fdzawVivf+m5
NvlfzvTGH08Fbk/YZwLcNImbaT3tmT3JcBTJ8IXr33n85JpV7U0vfeznecj5
XHTYHMn8wv+J5ob2Z9NrZ/Y4HuYQ0GFN8cyBIED2pEimL4pnyjx7tm49Lnsq
cPvTIcARLtN04zP9yPlMkr2S0lLUBfU1N/Nu6yHArhjNBAqm2dYcC+zAiclB
wdzFYxZ7WqKOjKmx7eknVi+c5NT0RelYOAU20Y0I0bYFrRX9PA857yE1ea6B
horKdMMwx4IlxVrm9DpZFzNedyCL3daRa5HDlmcjs74WXcxdPGbxPFvcDnzA
9Oy0jLL4eYaY57znFleJQQn5qJR8eeZuXmrqLm+x2zqWemQhooECyZfo4IHz
fp4hQjkvFWDg4WC61qTTd5ub+iUGg31+APBJCtG9e876eYYI5bxkcuB3J5mB
Q6WML7eB6wFgmpwPQvLKLQl5pnYCUJ5OdF7a/mNfo9zEPOdHZqcXZ0IEAGXr
zTfOPvGdd/08Q5xzfvjC9cadCS4IAihn5PyS2L1rBgeuNjf1MzAUgDIXq5yv
ren12YpuetfoNLKEPIDyF6ucl1Lc58Q32rvmxZ98TMgDiApyfqm0dw0hDyAq
yPklSaUmJeTpXQMgQsj5wkkNTz95AJETq5zfu+esn+HFfP5zAAgFOZ+H3Yuy
59Soz4GAACAU5Hwephfl2OWbEvhcewUQReR8HtqL8o29X9TW9BZjYBwAKIFY
5Xxb6/CSZvFTu3cNDA5c9blqAAhLrHJ+GZOqSMJLzvtcLwCEiJzPY2oqXV3V
TW95AJFGzuexf9/Q6b4xnysFgHDFKueXNKmKDizvc40AEDpy3mZ3mPc/uCUA
lANy3mY6zHNXFABnxCrnh85da27qz/MA7TD/izfPSeBz+RWAG2KV8wU2uUsl
L/W8z3UBQJkg5z2kjJdiniEOADgjVjk/dvlmQ31f/sdQzANwTKxyPpWalFo9
zwMo5gG4h5y3UcwDcE+scl4K9fvWHc71txTzAJwUn5zXe6BW39Oa9fcfJ35L
MQ/ASfHJeb0Has09bZ6O8ebeqMqKzqmptL9tBICyE5+c13ugHnygwzNjiP7+
Rw2nuQEWgJPik/Oqob5v7PJNzy/T6bvcAAvAVXHL+eam/qFz1zy/XNI4lgAQ
LXHL+axDyjM0JQCHxS3nM6caKeQmWQCIrrjlfGYTTdaWHABwRtxy3gxlpt3m
j3VcrK3p9f+0AFC2yjLnky0r5VnrEkVY0cTEncqKzun5bvP3rm5nBlgAbivL
nJ+ejfqi5LzYuKFjaiptutMz0AEAt8Uw5xt3JoYvXJcf9u45q1PBAoDD4pbz
kvBVT7z77PYzdLMBEBPRynnb8p53bpSbVW3yg2cABABwUnvr8Pdr3vPzDNGq
57VZfv++If9PBQAxUYycT9TNluwrW5JFXhEAYFHR6j8PAFgqch4A3EbOA4Db
yHkAcBs5DwBuI+cBwG3kPAC4LSo5z2Ei5u8ALz/sTQhTzF/+dHTyMyrbyQaU
J15+2JsQptBfftQ3ID45H+4GsP2R3v6Yv/zQN4DtD30DSrOiqL9RbH+ktz/m
Lz/0DWD7Q9+AwlcEAAhFaXIeAAAAAAAAAACUOZ2pZOFEJfl+754crzTrFC4O
yvdBZ5mszDV5Xr68eud3gBwvX1+66y9+hr7SLHu5UwEoL2b2JSbqFr6gXL93
T45XmmxpScz9tdPvQL4PenZPdzvnc798+f47/cHPyvXy54/v83/vtmzVjFsB
+M0rXPh6cv3ePYu+UrffgDwvP1FXl3C9ns/58ufrWbePc7k//bmYm9kHwtm0
UsqylzsWgN8crxe+nFy/d89ir9TxPT3ny9fX7XrO53r5pph3+3Qu384fg5O5
eVn2cscCkHo+/yudb71xVo6X/005604TZTYx3//z1fNazrv84Rvu1/O0zxfQ
QptocfgtyP9Bu17P59v/Z3/h+Buw2Nc/FhcpYtA+P+29rGyfrzheyxlZ34G5
3jbON9Hm3gFmOB5zM/Lv/45/9jlfvjmhc/31e/vVxTEAAQAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAoV3MDJNa1zPy/+4MkAkAczUS95LzjM7sAQKzF
ZAIjAIgnneJh4UQnAABHJOfa5bWdnqIeAAAAAAAAAAAAS/H/QGOK7w==
    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->7734644]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellLabel->"In[24]:=",
 CellID->672251866],

Cell["Clear variables for use in next section.", "Text",
 CellID->499431756],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "a", ",", "aW", ",", "rC", ",", "vC", ",", "cp", ",", "xC", ",", "gCp"}], 
  "]"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->755557078]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2.4  PMDoubletQuadraticDirichlet", "Section",
 CellID->246523140],

Cell["\<\
Repeat the procedure for the model PMDoubletQuadraticDirichlet.\
\>", "Text",
 CellID->140642404],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "aW", ",", "rC", ",", "vC"}], "}"}],
    "=", 
   RowBox[{"PMDoubletQuadraticDirichlet", "[", 
    RowBox[{"rP", ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"1", "-", 
    RowBox[{"vC", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xC", "=", 
   RowBox[{
    RowBox[{"Components", "[", "rC", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gCp", "=", 
   RowBox[{"PlotSurfacePressureCoefficient", "[", 
    RowBox[{"xC", ",", "cp", ",", "rP"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"gCpE", ",", "gCp"}], "]"}]}], "Input",
 CellLabel->"In[26]:=",
 CellID->519865160],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3X9sFGd+x3Gq/tlKrdRK7T/9o1J7919btX8VKYGE/AInOM4FuItjXWIn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    "], {{0, 330}, {504, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{504, 330},
  PlotRange->{{0, 504}, {0, 330}}]], "Output",
 ImageSize->{508, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->67456412]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2.5  Summary", "Section",
 CellID->135714564],

Cell["\<\
Although there are noticeable differences in surface pressure coefficient \
between each of the three models and the exact solution, each models can be \
characterized as providing plausible results for this  example.  Changing \
input parameters and re-evaluating the notebook enables the user to judge \
agreement of the three panel methods implemented with the results of an exact \
solution over a range of input parameters.\
\>", "Text",
 CellID->20514405],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[ButtonBox["PanelMethods",
 BaseStyle->"Link",
 ButtonData->"paclet:Aerodynamics/guide/PanelMethods"]], "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["3.1 Introduction to Panel Methods",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/IntroductionToPanelMethods"]], \
"RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["3.3 Implementation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/Implementation"]], "RelatedTutorials",
 CellID->289624919],

Cell[TextData[ButtonBox["Table Of Contents",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Aerodynamics/tutorial/TableOfContents"]], "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"3.2  ValidationExample - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2009, 11, 25, 11, 0, 48.1830000}", "context" -> 
    "Aerodynamics`", "keywords" -> {}, "index" -> True, "label" -> 
    "Aerodynamics Tutorial", "language" -> "en", "paclet" -> "Aerodynamics", 
    "status" -> "", "summary" -> 
    "An exact solution for the van de Vooren airfoil is used to validate the \
three panel methods implemented in Aerodynamics. The family of van de Vooren \
airfoil airfoils are symmetric airfoils obtained by mapping a circle to an \
airfoil shape using the van de Vooren transformation. Surface pressure \
coefficient is chosen as the quantity to compare between the exact solution \
and numerical panel-method solutions. Refer to Katz and Plotkin (2001) for a \
discussion of the van de Vooren airfoil and the exact potential-flow solution \
for this airfoil. The functions in Aerodynamics for the airfoil geometry and \
the exact solution are from this reference as I have been unable to locate a \
copy of the original paper. Load the package", "synonyms" -> {}, "title" -> 
    "3.2  ValidationExample", "type" -> "Tutorial", "uri" -> 
    "Aerodynamics/tutorial/ValidationExample"}, "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[603, 21, 78, 1, 70, "TutorialColorBar"],
Cell[684, 24, 191, 5, 70, "LinkTrail"],
Cell[878, 31, 2926, 66, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3829, 101, 59, 1, 70, "Title",
 CellID->509267359],
Cell[3891, 104, 511, 10, 70, "Text",
 CellID->25608729],
Cell[4405, 116, 489, 12, 70, "Text",
 CellID->124571872],
Cell[4897, 130, 52, 1, 70, "Text",
 CellID->836781195],
Cell[4952, 133, 101, 3, 70, "Input",
 CellID->2058623809],
Cell[CellGroupData[{
Cell[5078, 140, 67, 1, 70, "Section",
 CellID->631983245],
Cell[5148, 143, 152, 4, 70, "Text",
 CellID->405071093],
Cell[5303, 149, 258, 8, 70, "Input",
 CellID->692274660],
Cell[5564, 159, 84, 1, 70, "Text",
 CellID->14124012],
Cell[5651, 162, 161, 5, 70, "Input",
 CellID->361350040],
Cell[5815, 169, 950, 30, 70, "Text",
 CellID->565396260],
Cell[CellGroupData[{
Cell[6790, 203, 527, 15, 70, "Input",
 CellID->11132],
Cell[7320, 220, 160, 5, 36, "Output",
 CellID->513845788]
}, Open  ]],
Cell[7495, 228, 511, 12, 70, "Text",
 CellID->332686776],
Cell[8009, 242, 627, 20, 70, "Input",
 CellID->663191981],
Cell[8639, 264, 391, 11, 70, "Text",
 CellID->472644503],
Cell[9033, 277, 470, 15, 70, "Input",
 CellID->494361716],
Cell[9506, 294, 119, 3, 70, "Text",
 CellID->191818375],
Cell[9628, 299, 440, 13, 70, "Input",
 CellID->527771544]
}, Open  ]],
Cell[CellGroupData[{
Cell[10105, 317, 67, 1, 70, "Section",
 CellID->234765418],
Cell[10175, 320, 301, 6, 70, "Text",
 CellID->815037782],
Cell[10479, 328, 385, 12, 70, "Input",
 CellID->349582656],
Cell[10867, 342, 234, 5, 70, "Text",
 CellID->63663458],
Cell[CellGroupData[{
Cell[11126, 351, 463, 14, 65, "Input",
 CellID->726630446],
Cell[11592, 367, 12387, 211, 351, "Output",
 CellID->56640754]
}, Open  ]],
Cell[23994, 581, 76, 1, 70, "Text",
 CellID->386399333],
Cell[24073, 584, 187, 6, 70, "Input",
 CellID->437524282]
}, Open  ]],
Cell[CellGroupData[{
Cell[24297, 595, 72, 1, 70, "Section",
 CellID->617689357],
Cell[24372, 598, 161, 4, 70, "Text",
 CellID->311897436],
Cell[CellGroupData[{
Cell[24558, 606, 809, 24, 101, "Input",
 CellID->186135957],
Cell[25370, 632, 12076, 205, 351, "Output",
 CellID->7734644]
}, Open  ]],
Cell[37461, 840, 70, 2, 70, "Input",
 CellID->672251866],
Cell[37534, 844, 76, 1, 70, "Text",
 CellID->499431756],
Cell[37613, 847, 188, 6, 70, "Input",
 CellID->755557078]
}, Open  ]],
Cell[CellGroupData[{
Cell[37838, 858, 73, 1, 70, "Section",
 CellID->246523140],
Cell[37914, 861, 107, 3, 70, "Text",
 CellID->140642404],
Cell[CellGroupData[{
Cell[38046, 868, 834, 25, 101, "Input",
 CellID->519865160],
Cell[38883, 895, 12065, 205, 351, "Output",
 CellID->67456412]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50997, 1106, 53, 1, 70, "Section",
 CellID->135714564],
Cell[51053, 1109, 471, 8, 70, "Text",
 CellID->20514405],
Cell[CellGroupData[{
Cell[51549, 1121, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[51617, 1124, 158, 3, 70, "TutorialMoreAbout",
 CellID->1567025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[51812, 1132, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[51887, 1135, 199, 5, 70, "RelatedTutorials",
 CellID->806871991],
Cell[52089, 1142, 170, 4, 70, "RelatedTutorials",
 CellID->289624919],
Cell[52262, 1148, 170, 4, 70, "RelatedTutorials",
 CellID->280152894]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[52471, 1157, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

