(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    160144,       4561]
NotebookOptionsPosition[    146028,       4124]
NotebookOutlinePosition[    146599,       4146]
CellTagsIndexPosition[    146556,       4143]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["InfluenceCoefficients", "Section",
 CellChangeTimes->{3.4008382974375*^9}],

Cell["\<\
Richard L. Fearn, Professor Emeritus, Mechanical and Aerospace Engineering, \
University of Florida, Gainesville, Florida\
\>", "Text",
 CellChangeTimes->{{3.4204666790505023`*^9, 3.4204667126588287`*^9}, {
   3.420466747458869*^9, 3.4204667487707553`*^9}, 3.4206306460534973`*^9, 
   3.4241862706073823`*^9}],

Cell["Copyright 2006-2009, Richard L. Fearn , All Rights Reserved", "Text",
 CellChangeTimes->{{3.4204663156779985`*^9, 3.4204663350859056`*^9}, 
   3.4204663759346433`*^9, {3.420466407029355*^9, 3.420466418926462*^9}, {
   3.42046656167172*^9, 3.420466575721923*^9}, {3.420466617952648*^9, 
   3.420466659742739*^9}, {3.467028255586939*^9, 3.467028256460539*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Version 7.0.1.0\nPackage Version 1.1.0.  12/01/09"
}], "Text",
 CellChangeTimes->{{3.400833022484375*^9, 3.40083303303125*^9}, {
  3.410521828109375*^9, 3.410521874078125*^9}, {3.410694370296875*^9, 
  3.410694371390625*^9}, {3.410694408609375*^9, 3.41069443165625*^9}, {
  3.417767474484375*^9, 3.4177674815*^9}, {3.418376642903555*^9, 
  3.418376643754779*^9}, {3.4204664483487697`*^9, 3.42046648389989*^9}, {
  3.4224518308906336`*^9, 3.422451871288723*^9}, {3.467028265726939*^9, 
  3.467028307956139*^9}}],

Cell[CellGroupData[{

Cell["Reference", "Subsection"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell["\<\
This package contains functions to compute velocity, velocity-potential and \
stream-function influence coefficients for commonly used two-dimensional \
potential-flow singularities.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubsection",
 CellChangeTimes->{3.422454229547064*^9}],

Cell[TextData[{
 "Katz J, Plotkin A.  2001.  ",
 StyleBox["Low-Speed Aerodynamics - From Wing Theory to Panel Methods, 2nd \
edition",
  FontSlant->"Italic"],
 StyleBox[", Cambridge University Press.",
  FontVariations->{"CompatibilityType"->0}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Warnings", "Subsubsection"],

Cell["\<\
1.   Self-induced influence coefficients may be indeterminate.\
\>", "Text",
 ParagraphIndent->-19]
}, Closed]],

Cell[CellGroupData[{

Cell["Discussion", "Subsubsection"],

Cell["\<\
A detailed description of the approach to solve Laplace's equation for \
incompressible irrotational flow over airfoils using singular solutions is \
discussed by  Katz & Plotkin (2001).  Functions are defined in this package \
for velocity, velocity-potential and stream-function influence coefficients \
for the following singularities.
\tPoint singularities:  vortex, source and doublet.
\tLine singularities with constant strength:  vortex, source and doublet.
\tLine singularities with linearly varying strength:  vortex, source and \
doublet.
\tLine singularities with quadratically varying strength:  doublet.\
\>", "Text",
 CellChangeTimes->{{3.39841707565625*^9, 3.3984170771875*^9}, {
  3.4224519933943024`*^9, 3.4224520284847603`*^9}}],

Cell[TextData[{
 "Shown below is the notation used when writing algebraic influence \
coefficients for a line singularity (called a panel) in a local coordinate \
system.  One end of the line is desiginated as the origin, and the \
singlularity lies along the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " axis from 0 to ",
 Cell[BoxData[
  FormBox["\[Delta]", TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39841715884375*^9, 3.3984174708125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AnnotatedArrow", "[", 
    RowBox[{"p_", ",", "q_", ",", "label_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrowheads", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{".03", ",", ".4", ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"label", ",", "Medium"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Center", ",", "Top"}], "}"}]}], "]"}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{".05", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AnnotatedArrow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(r\), \(1\)]\)\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AnnotatedArrow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(r\), \(2\)]\)\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", "Thick", ",", " ", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PointSize", "[", "Large", "]"}], ",", 
     RowBox[{"Point", "[", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<P\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1.08"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<\[Delta]\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0.55", ",", "0.05"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(1\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0.26", ",", "0.05"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(2\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"1.18", ",", "0.05"}], "}"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBGIQzdDgceh74EtHhga2wxB68jUwzWB8F8I/xP8DTDMJ
Q+iHYhD6pjSYZhBRgfBbtCC0uj6ELjSA0KdsIerUvSD0iWgIvToWQmsnQ9Sx
ZUFo5kKIeC+EbkjN/wmmf1eAaYaFtRD+ygYI/0InhP8LSh/uhdAvoPSFyRB1
C2ZB+BoLIXzzxRD++jUQftsuCD9lH4R/7RKEXqP7C0wL20DoriYIndILoTUn
QugdELqhfSqEfxZCN2ycDaH150DovEsQmvcJRJ3TJwht+QVEAwB2pruV
  "]],

Cell[BoxData[
 GraphicsBox[{
   {Arrowheads[{{0.03, 0.4, 
       GraphicsBox[
        InsetBox[
         BoxData[
          FormBox[
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(r\\), \\(1\\)]\\)\"", Medium, 
            StripOnInput -> False], TraditionalForm]], {Center, Top}]]}, {
      0.05, 1}}], ArrowBox[{{0, 0}, {2, 1}}]}, 
   {Arrowheads[{{0.03, 0.4, 
       GraphicsBox[
        InsetBox[
         BoxData[
          FormBox[
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(r\\), \\(2\\)]\\)\"", Medium, 
            StripOnInput -> False], TraditionalForm]], {Center, Top}]]}, {
      0.05, 1}}], ArrowBox[{{1, 0}, {2, 1}}]}, 
   {Thickness[Large], LineBox[{{0, 0}, {1, 0}}], 
    {PointSize[Large], PointBox[{2, 1}], InsetBox["\<\"P\"\>", {2, 1.08}], 
     InsetBox["\<\"\[Delta]\"\>", {0.55, 0.05}], 
     InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \\(1\\)]\\)\"\>", \
{0.26, 0.05}], 
     InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \\(2\\)]\\)\"\>", \
{1.18, 0.05}]}}},
  Axes->True,
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.398424499453125*^9, 3.398425927625*^9, 3.398427820484375*^9, 
   3.398427974703125*^9, 3.398433464765625*^9, 3.398686067421875*^9, 
   3.398686228515625*^9, 3.399719772625*^9, 3.399892793875*^9, 
   3.4002324894375*^9, 3.400500882328125*^9, {3.400500956828125*^9, 
   3.4005009805*^9}, 3.400508351578125*^9, 3.400508452953125*^9, 
   3.400508544078125*^9, 3.400508807421875*^9, 3.400509060625*^9, 
   3.400509165578125*^9, 3.400509632796875*^9, 3.400509844234375*^9, 
   3.4005101485625*^9, 3.400510632859375*^9, 3.400838424515625*^9, 
   3.40083909728125*^9, 3.40083960378125*^9, 3.40083973946875*^9, 
   3.40222140740625*^9, 3.405334823046875*^9, {3.410260493265625*^9, 
   3.41026050875*^9}, 3.41027771365625*^9, 3.410517470078125*^9, 
   3.41051756590625*^9, 3.410518950609375*^9, 3.4105192780625*^9, 
   3.4105200320625*^9, 3.41052017278125*^9, 3.41052056709375*^9, 
   3.410520872*^9, 3.410687068296875*^9, 3.410687183328125*^9, 
   3.41068734471875*^9, 3.41431709503125*^9, 3.41431910771875*^9, 
   3.414321671125*^9, 3.41432191828125*^9, 3.41432204028125*^9, 
   3.41433338521875*^9, 3.41433344925*^9, 3.414399166*^9, 3.41439948428125*^9,
    3.41439957509375*^9, 3.414401888625*^9, 3.41440426596875*^9, 
   3.41440488165625*^9, 3.4144066365625*^9, 3.41440809596875*^9, 
   3.4144196691875*^9, 3.414420272609375*^9, 3.41442054953125*^9, 
   3.414421404171875*^9, 3.414422039109375*^9, 3.41442225490625*^9, 
   3.414422319359375*^9, 3.414422599234375*^9, 3.414744266953125*^9, 
   3.414745393453125*^9, 3.4147470236875*^9, 3.4147477446875*^9, 
   3.4147480350625*^9, 3.414748096859375*^9, 3.414748230734375*^9, 
   3.414750325625*^9, 3.41475168678125*^9, 3.414751744078125*^9, 
   3.41475494209375*^9, 3.414768980453125*^9, 3.41476937065625*^9, 
   3.4224543923912225`*^9, 3.4224618062858686`*^9, 3.4224628045913615`*^9, 
   3.4224629424696207`*^9, 3.422463132723192*^9, 3.4224632431319523`*^9, 
   3.422464060337035*^9, 3.422464091101272*^9, 3.4224642424689283`*^9, 
   3.4224643212722416`*^9, 3.422464369922197*^9, 3.422464438280491*^9, 
   3.4224650135176415`*^9, 3.4225528468418036`*^9, 3.422553055011136*^9, 
   3.4225531780780973`*^9, 3.422553312932008*^9, 3.4225538145132465`*^9, 
   3.4225540373236322`*^9, 3.4225541488940625`*^9, 3.4225544135345964`*^9, 
   3.4225548480493984`*^9, 3.422555098249168*^9, 3.422555399081744*^9, 
   3.4226383852300653`*^9, 3.422813144562558*^9, 3.4228164498252926`*^9, 
   3.422817675667968*^9, 3.422898188848784*^9, 3.4228983241533422`*^9, 
   3.42289838953736*^9, 3.4228984834824467`*^9, 3.422898651403906*^9, 
   3.422900734579365*^9, 3.422901126272592*^9, 3.4229014529022627`*^9, 
   3.422988864532358*^9, 3.423337330397973*^9, 3.423337410012453*^9, 
   3.4233376366182957`*^9, {3.4233377262371616`*^9, 3.423337746726624*^9}, 
   3.4234250028728895`*^9, 3.4234252805221295`*^9, 3.423496704775072*^9, 
   3.423505269019851*^9, 3.4235055266002336`*^9, 3.4235056557058783`*^9, 
   3.423591365947581*^9, 3.4235985479147425`*^9, 3.423662094451133*^9, 
   3.4236621331968465`*^9, 3.423665534577792*^9, 3.423672065548867*^9, 
   3.4240143499692574`*^9, 3.4240159387838607`*^9, 3.431863222237405*^9, 
   3.432304396717038*^9, 3.4443950227273407`*^9, 3.446288473620761*^9, 
   3.4525251584384003`*^9, 3.4527025208732*^9, 3.4527633997597923`*^9, 
   3.452770278751392*^9, 3.452771479779792*^9, {3.4527882899066*^9, 
   3.452788313291*^9}, 3.4528668325337768`*^9, 3.4528721147518*^9, 
   3.4529345279926*^9, 3.4529406774189997`*^9, 3.4529424509158*^9, 
   3.4547718963627634`*^9, 3.4547807090417633`*^9, 3.4580461823426*^9, 
   3.4580503469786*^9, 3.467028531363739*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set up package context", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BeginPackage", "[", 
   RowBox[{"\"\<Aerodynamics`InfluenceCoefficients`\>\"", ",", 
    RowBox[{"{", "\"\<Aerodynamics`CartesianVectors`\>\"", "}"}]}], "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.3968595658125*^9, 3.400838305609375*^9, {3.4224521803230925`*^9, 
   3.4224521817651663`*^9}, {3.4224642010794125`*^9, 
   3.4224642108634815`*^9}, {3.4224642879042606`*^9, 3.42246430169409*^9}, {
   3.42246434216228*^9, 3.4224643470292788`*^9}, 3.444395004834141*^9, {
   3.446288425229561*^9, 3.446288448520361*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Interface", "Subsection"],

Cell[CellGroupData[{

Cell[" Usage messages for context and exported functions", "Subsubsection",
 CellChangeTimes->{{3.422452440777608*^9, 3.422452451543088*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InfluenceCoefficients", "::", "usage"}], "=", 
   "\"\<is a package  containing functions to compute geometric influence \
coefficients for two-dimensional potential-flow point and line singularities. \
 Functions for velocity, velocity-potential and stream-function influence \
coefficients are defined for commonly used distributions of source, doublet \
and vortex singularities.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838314078125*^9, 3.40083831809375*^9}, 
   3.458046094967*^9, 3.4580461266506*^9, {3.4580503025498*^9, 
   3.4580503086493998`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UniformFlow", "::", "usage"}], "=", 
   "\"\<UniformFlow[n, \[Alpha]] computes a collection of \!\(\*
StyleBox[\"n\", \"TI\"]\)\!\(\*
StyleBox[\" \", \"TI\"]\)uniform velocity vectors inclined at an angle \!\(\*
StyleBox[\"\[Alpha]\", \"TR\"]\) to the \!\(\*
StyleBox[\"x\", \"TI\"]\) axis.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4240114314526367`*^9, 3.4240114359190593`*^9}, {
   3.424013160699171*^9, 3.4240131794361134`*^9}, 3.4547805906377635`*^9, {
   3.4547806418993635`*^9, 3.4547806537553635`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UniformFlow\[Phi]", "::", "usage"}], "=", 
   "\"\<UniformFlow\[Phi][rf, \[Alpha]] computes a list of \
velocity-potentials at \!\(\*SubscriptBox[
StyleBox[\"r\", \"TI\"], 
StyleBox[\"f\", \"TI\"]]\) for uniform flow inclined at an angle \!\(\*
StyleBox[\"\[Alpha]\", \"TR\"]\) to the \!\(\*
StyleBox[\"x\", \"TI\"]\) axis. \>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424013190301738*^9, 3.4240132247813168`*^9}, {
   3.424013262545619*^9, 3.424013315571867*^9}, {3.424013369188965*^9, 
   3.424013395036131*^9}, 3.4547806160501633`*^9, {3.4547806585445633`*^9, 
   3.4547806724753637`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UniformFlow\[Psi]", "::", "usage"}], "=", 
   "\"\<IC\[Psi]UniformFlow[rf, \[Alpha]] computes a list of stream-functions \
at \!\(\*SubscriptBox[
StyleBox[\"r\", \"TI\"], 
StyleBox[\"f\", \"TI\"]]\) for uniform flow inclined at an angle \!\(\*
StyleBox[\"\[Alpha]\", \"TR\"]\) to the \!\(\*
StyleBox[\"x\", \"TI\"]\) axis. \>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4240133990719347`*^9, 3.424013472848019*^9}, 
   3.454780634645364*^9, {3.4547806803065634`*^9, 3.454780692708564*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DisplacementVectors", "::", "usage"}], "=", 
   "\"\<DisplacementVectors[ra, rb] computes the displacement vectors between \
all pairs of points for the two collections of vectors, ra and rb.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4525251435404*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICVortexPoint", "::", "usage"}], " ", "=", " ", 
   "\"\<ICVortexPoint[rF, rP] computes velocity influence coefficients at \
field points rF, due to vortices at rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4529422709230003`*^9, {3.4529423199538*^9, 3.4529423386893997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]VortexPoint", "::", "usage"}], "=", 
   "\"\<IC\[Phi]VortexPoint[rF, rP] computes velocity-potential influence \
coefficients at field points rF, due to vortices at rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4529422907818003`*^9, {3.4529423439778*^9, 3.4529423636806*^9}, {
   3.452942396425*^9, 3.4529424043342*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexPoint", "::", "usage"}], "=", 
   "\"\<IC\[Psi]VortexPoint[rF, rP] computes stream-function influence \
coefficients at field points rF, due to vortices at rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4529423133862*^9, {3.4529423677054*^9, 3.4529424184365997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICVortexConstant", "::", "usage"}], "=", 
   "\"\<ICVortexConstant[rF, rP] computes velocity influence coefficients at \
field points rF, due to connected vortex panels of constant strength whose \
endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4529342073346*^9, 3.452934238987*^9}, {
  3.4529342739309998`*^9, 3.4529342746174*^9}, {3.4529343554254*^9, 
  3.4529343728974*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]VortexConstant", "::", "usage"}], "=", 
   "\"\<IC\[Phi]VortexConstant[rF, rP] computes velocity-potential influence \
coefficients at field points rF due to connected vortex panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4529342604058*^9, 3.4529343060982*^9}, {
  3.4529343818361998`*^9, 3.4529344022878*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexConstant", "::", "usage"}], "=", 
   "\"\<IC\[Psi]VortexConstant[rF, rP] computes stream-function influence \
coefficients at field points rF due to connected vortex panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4529343247714*^9, 3.4529343306682*^9}, {
  3.4529344066401997`*^9, 3.4529344897726*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICVortexLinear", "::", "usage"}], "=", 
   "\"\<ICVortexLinear[rF, rP] computes velocity influence coefficients at \
field points rF, due to connected vortex panels of linearly varying strength \
whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4224631144068546`*^9, 3.4224631174111743`*^9}, {
   3.4224631713387184`*^9, 3.4224631728709216`*^9}, 3.423330528102683*^9, {
   3.4233372980214176`*^9, 3.4233372989627714`*^9}, {3.423337386058008*^9, 
   3.423337386728973*^9}, {3.423337527110832*^9, 3.4233376203448963`*^9}, 
   3.423337652060501*^9, {3.4233376972054157`*^9, 3.423337732916766*^9}, 
   3.4529382479374*^9, {3.4529404666162*^9, 3.452940506131*^9}, {
   3.452940583507*^9, 3.4529406050193996`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]VortexLinear", "::", "usage"}], "=", 
   "\"\<IC\[Phi]VortexLinear[rF, rP] computes velocity-potential influence \
coefficients at field points rF due to connected vortex panels of linear \
varying strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4529382701518*^9, {3.4529404778482*^9, 3.4529404832458*^9}, {
   3.4529405169262*^9, 3.4529405240086*^9}, {3.4529406123982*^9, 
   3.4529406301354*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexLinear", "::", "usage"}], "=", 
   "\"\<IC\[Psi]VortexLinear[rF, rP] computes stream-function influence \
coefficients at field points rF due to connected vortex panels of linear \
varying strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4529382946906*^9, {3.4529405290474*^9, 3.4529405521198*^9}, {
   3.4529406362974*^9, 3.4529406555322*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICSourcePoint", "::", "usage"}], "=", 
   "\"\<ICSourcePoint[rF, rP] computes velocity influence coefficients at \
field points rF, due to point sources at rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4528718507530003`*^9, {3.4528719068974*^9, 3.4528719085198*^9}, {
   3.4528719501094*^9, 3.4528719831502*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]SourcePoint", "::", "usage"}], "=", 
   "\"\<IC\[Phi]SourcePoint[rF, rP] computes velocity-potential influence \
coefficients at field points rF, due to point sources at rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4528719278794003`*^9, {3.452871992401*^9, 3.4528720363306*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]SourcePoint", "::", "usage"}], "=", 
   "\"\<IC\[Psi]SourcePoint[rF, rP] computes stream-function influence \
coefficients at field points rF, due to point sources at rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4528719455854*^9, {3.452872044895*^9, 3.4528720874518003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICSourceConstant", "::", "usage"}], "=", 
   "\"\<ICSourceConstant[rF, rP] computes velocity influence coefficients at \
field points rF, due to connected source panels of constant strength whose \
endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527863851466*^9, 3.4527864489505997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]SourceConstant", "::", "usage"}], "=", 
   "\"\<IC\[Phi]SourceConstant[rF, rP] computes velocity-potential influence \
coefficients at field points rF due to connected source panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527881157794*^9, 3.4527881788034*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]SourceConstant", "::", "usage"}], "=", 
   "\"\<IC\[Psi]SourceConstant[rF, rP] computes stream-function influence \
coefficients at field points rF due to connected source panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527882145741997`*^9, 3.4527882587534*^9}, {
  3.4529381858806*^9, 3.4529382056458*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICSourceLinear", "::", "usage"}], "=", 
   "\"\<ICSourceLinear[rF, rP] computes velocity influence coefficients at \
field points rF, due to connected source panels of linearly varying strength \
whose endpoints are located by rP\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4528664683049765`*^9, 3.452866524028177*^9}, {
  3.452866643274577*^9, 3.452866671557377*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]SourceLinear", "::", "usage"}], "=", 
   "\"\<IC\[Phi]SourceLinear[rF, rP] computes velocity-potential influence \
coefficients at field points rF, due to connected source panels of linearly \
varying strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452866558488577*^9, 3.4528665835421767`*^9}, {
  3.4528666831169767`*^9, 3.4528667208689766`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]SourceLinear", "::", "usage"}], "=", 
   "\"\<IC\[Psi]SourceLinear[rF, rP] computes stream-function influence \
coefficients at field points rF, due to connected source panels of linearly \
varying strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452866604726977*^9, 3.452866637362177*^9}, {
  3.452866733364577*^9, 3.452866777637377*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletPoint", "::", "usage"}], "=", 
   "\"\<ICDoubletPoint[rF, rP, uD] computes velocity nfluence coefficients at \
field points rF, due to doublets at rP. Orientation of doublets is specified \
by unit vectors uD.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452769983178192*^9, 3.452770093532592*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletPoint", "::", "usage"}], "=", 
   "\"\<IC\[Phi]DoubletPoint[rF, rP, uD] computes elocity-potential influence \
coefficients at field points rF, due to doublets at rP.  Orientation of \
doublets is specified by unit vectors uD.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527701193505917`*^9, 3.452770173903792*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletPoint", "::", "usage"}], "=", 
   "\"\<IC\[Psi]DoubletPoint[rF, rP, uD] computes stream-function influence \
coefficients at field points rF, due to doublets at rP.  Orientation of \
doublets is specified by unit vectors uD.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527701960869923`*^9, 3.4527702596413918`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletConstant", "::", "usage"}], "=", 
   "\"\<ICDoubletConstant[rF, rP] computes velocity influence coefficients at \
field points rF due to connected doublet panels of constant strength whose \
endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527021999968*^9, 3.452702344484*^9}, 
   3.452763328498992*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletConstant", "::", "usage"}], "=", 
   "\"\<IC\[Phi]DoubletConstant[rF, rP] computes velocity-potential influence \
coefficients at field points rF, due to connected doublet panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4527023955428*^9, 3.4527024315164003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletConstant", "::", "usage"}], "=", 
   "\"\<ICDoubletConstant[rF, rP] computes stream-function influence \
coefficients at field points rF, due to connected doublet panels of constant \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4527024034208*^9, {3.4527024549632*^9, 3.4527024997664003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletLinear", "::", "usage"}], "=", 
   "\"\<ICDoubletLinear[rF, rP] computes velocity influence coefficients at \
field points rF due to connected doublet panels of linearly varying strength \
whose end points are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452762725527792*^9, 3.4527627406441917`*^9}, 
   3.452762778224592*^9, {3.452762808691392*^9, 3.452762809705392*^9}, {
   3.452762963973792*^9, 3.452763074047392*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletLinear", "::", "usage"}], "=", 
   "\"\<IC\[Phi]DoubletLinear[rF, rP] computes velocity-potential influence \
coefficients at field points rF due to connected doublet panels of linearly \
varying strength whose end points are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452762790517392*^9, 3.452762796757392*^9}, {
  3.452762841451392*^9, 3.452762859687792*^9}, {3.4527631372585917`*^9, 
  3.4527632157733917`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletLinear", "::", "usage"}], "=", 
   "\"\<IC\[Psi]DoubletLinear[rF, rP] computes stream-function influence \
coefficients at field points rF due to connected doublet panels of linearly \
varying strength whose end points are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452762865334992*^9, 3.452762896238592*^9}, 
   3.452763144496992*^9, {3.452763230562192*^9, 3.452763295364592*^9}, 
   3.4527633787309923`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletQuadratic", "::", "usage"}], "=", 
   "\"\<ICDoubletQuadratic[rF, rP] computes velocity influence coefficients \
at field points rF, due to connected doublet panels of quadratically varying \
strength whose endpoints are located by rP.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452771192427792*^9, 3.452771220367392*^9}, {
  3.4527712517857924`*^9, 3.452771271254592*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletQuadratic", "::", "usage"}], "=", 
   "\"\<IC\[Phi]DoubletQuadratic[rF, rP] computes velocity-potential \
influence coefficients at field points rF due to connected doublet panels of \
quadratically varying strength whose endpoints are located by rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452771247246192*^9, 3.4527712911757917`*^9}, {
  3.452771326260192*^9, 3.452771386600992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletQuadratic", "::", "usage"}], "=", 
   "\"\<IC\[Psi]DoubletQuadratic[rF, rD] computes stream-function influence \
coefficients at field points rF due to connected doublet panels of \
quadratically varying strength whose endpoints are located by rP.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452771410921392*^9, 3.452771459094192*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TestArguments", "::", "usage"}], "=", 
   "\"\<TestArguments[rF,rP] tests arguments for an influence-coefficient \
function, returning true if arguments are valid and a message if they are \
not.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4547717229219637`*^9, 3.4547717494731636`*^9}, {
  3.454771852370764*^9, 3.4547718563331633`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Messages for exported functions", "Subsubsection",
 CellChangeTimes->{{3.4224525485425663`*^9, 3.4224525544410477`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InfluenceCoefficients", "::", "dataType"}], "=", 
   "\"\<Input arguments specifying locations of field points and \
singularities must be collections of two-dimensional vectors of the data type \
CartesianVectors.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838320265625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], "=", 
   "\"\<Input arguments specifying locations of line singularities must \
contain coordinates for at least two points.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083832175*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Implementation", "Subsection"],

Cell[CellGroupData[{

Cell[" Begin private context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Begin", "[", "\"\<Aerodynamics`InfluenceCoefficients`Private`\>\"", "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838324078125*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Unprotect and set attributes for exported functions", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", 
   RowBox[{
   "DisplacementVectors", ",", "ICDoubletConstant", ",", "ICDoubletLinear", 
    ",", "ICDoubletPoint", ",", "ICDoubletQuadratic", ",", "ICSourceConstant",
     ",", "ICSourceLinear", ",", "ICSourcePoint", ",", "ICVortexConstant", 
    ",", "ICVortexLinear", ",", "ICVortexPoint", ",", 
    "IC\[Phi]DoubletConstant", ",", "IC\[Phi]DoubletLinear", ",", 
    "IC\[Phi]DoubletQuadratic", ",", "IC\[Phi]DoubletPoint", ",", 
    "IC\[Phi]SourceConstant", ",", "IC\[Phi]SourceLinear", ",", 
    "IC\[Phi]SourcePoint", ",", "IC\[Phi]VortexConstant", ",", 
    "IC\[Phi]VortexLinear", ",", "IC\[Phi]VortexPoint", ",", 
    "IC\[Psi]DoubletConstant", ",", "IC\[Psi]DoubletLinear", ",", 
    "IC\[Psi]DoubletQuadratic", ",", "IC\[Psi]DoubletPoint", ",", 
    "IC\[Psi]SourceConstant", ",", "IC\[Psi]SourceLinear", ",", 
    "IC\[Psi]SourcePoint", ",", "IC\[Psi]VortexConstant", ",", 
    "IC\[Psi]VortexLinear", ",", "IC\[Psi]VortexPoint", ",", 
    "InfluenceCoefficients", ",", "TestArguments", ",", "UniformFlow", ",", 
    "UniformFlow\[Phi]", ",", "UniformFlow\[Psi]"}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4008383274375*^9, {3.4240135652108307`*^9, 3.424013640278773*^9}, {
   3.4240136736467533`*^9, 3.424013681688317*^9}, {3.4240137952816563`*^9, 
   3.424013844212014*^9}, {3.4240138964671535`*^9, 3.4240139418223715`*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "DisplacementVectors", ",", "ICDoubletConstant", ",", "ICDoubletLinear", 
     ",", "ICDoubletQuadratic", ",", "ICDoubletPoint", ",", 
     "ICSourceConstant", ",", "ICSourceLinear", ",", "ICSourcePoint", ",", 
     "ICVortexConstant", ",", "ICVortexLinear", ",", "ICVortexPoint", ",", 
     "IC\[Phi]DoubletConstant", ",", "IC\[Phi]DoubletLinear", ",", 
     "IC\[Phi]DoubletQuadratic", ",", "IC\[Phi]DoubletPoint", ",", 
     "IC\[Phi]SourceConstant", ",", "IC\[Phi]SourceLinear", ",", 
     "IC\[Phi]SourcePoint", ",", "IC\[Phi]VortexConstant", ",", 
     "IC\[Phi]VortexLinear", ",", "IC\[Phi]VortexPoint", ",", 
     "IC\[Psi]DoubletConstant", ",", "IC\[Psi]DoubletLinear", ",", 
     "IC\[Psi]DoubletQuadratic", ",", "IC\[Psi]DoubletPoint", ",", 
     "IC\[Psi]SourceConstant", ",", "IC\[Psi]SourceLinear", ",", 
     "IC\[Psi]SourcePoint", ",", "IC\[Psi]VortexConstant", ",", 
     "IC\[Psi]VortexLinear", ",", "IC\[Psi]VortexPoint", ",", "UniformFlow", 
     ",", "UniformFlow\[Phi]", ",", "UniformFlow\[Psi]"}], "}"}], ",", 
   "NumericFunction"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424014029037781*^9, 3.4240141473979745`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Auxillary function", "Subsubsection",
 CellChangeTimes->{{3.422453558985512*^9, 3.4224535982619886`*^9}, {
  3.4224621169225426`*^9, 3.4224621173731904`*^9}}],

Cell["\<\
The following function is used in DisplacementVectors when the input argument \
(CartesianVectors) consists of machine numbers.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"displacementList", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "_Real", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Outer", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"u", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"v", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"Outer", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"u", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"v", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Uniform Flow", "Subsubsection",
 CellChangeTimes->{{3.4224536086469216`*^9, 3.4224536172092333`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UniformFlow", "[", 
   RowBox[{
    RowBox[{"n_Integer", "?", "Positive"}], ",", "\[Alpha]_"}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Alpha]", "]"}], ",", 
       RowBox[{"{", "n", "}"}]}], "]"}]}], "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414399144328125*^9, 3.414399149453125*^9}, {
  3.424014165053362*^9, 3.4240141936945457`*^9}, {3.4240159029923954`*^9, 
  3.4240159033228703`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UniformFlow\[Phi]", "[", 
   RowBox[{
    RowBox[{"rf_CartesianVectors", "?", "TwoDimQ"}], ",", "\[Alpha]_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "z"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rf", "]"}]}], ";", 
     RowBox[{
      RowBox[{"x", " ", 
       RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{"z", " ", 
       RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424015906707738*^9, 3.424015915951029*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UniformFlow\[Psi]", "[", 
   RowBox[{
    RowBox[{"rf_CartesianVectors", "?", "TwoDimQ"}], ",", "\[Alpha]_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "z"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rf", "]"}]}], ";", 
     RowBox[{
      RowBox[{"z", " ", 
       RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], "-", 
      RowBox[{"x", " ", 
       RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424015909732086*^9, 3.4240159215490785`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Displacement vectors", "Subsubsection",
 CellChangeTimes->{{3.4224536331822014`*^9, 3.422453640823189*^9}, {
  3.4240113402014236`*^9, 3.4240113404718127`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplacementVectors", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ra_CartesianVectors", "?", "TwoDimQ"}], " ", "/;", " ", 
     RowBox[{"MatrixQ", "[", 
      RowBox[{
       RowBox[{"Components", "[", "ra", "]"}], ",", "MachineNumberQ"}], 
      "]"}]}], ",", 
    RowBox[{
     RowBox[{"rb_CartesianVectors", "?", "TwoDimQ"}], " ", "/;", " ", 
     RowBox[{"MatrixQ", "[", 
      RowBox[{
       RowBox[{"Components", "[", "rb", "]"}], ",", "MachineNumberQ"}], 
      "]"}]}]}], "]"}], ":=", 
  RowBox[{"MakeCartesianVectors", "[", 
   RowBox[{"displacementList", "[", 
    RowBox[{
     RowBox[{"Components", "[", "ra", "]"}], ",", 
     RowBox[{"Components", "[", "rb", "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplacementVectors", "[", 
   RowBox[{
    RowBox[{"ra_CartesianVectors", "?", "TwoDimQ"}], ",", 
    RowBox[{"rb_CartesianVectors", "?", "TwoDimQ"}]}], "]"}], ":=", 
  RowBox[{"Outer", "[", 
   RowBox[{"Plus", ",", "ra", ",", 
    RowBox[{"-", "rb"}]}], "]"}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Vortex, point", "Subsubsection",
 CellChangeTimes->{{3.4224528510775905`*^9, 3.42245285642528*^9}, 
   3.422453140233376*^9, 3.4224536604714413`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexPoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexPoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexPoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["Define functions for influence coefficients.", "Text",
 CellChangeTimes->{{3.4229883167446785`*^9, 3.422988320970755*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexPoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfs", ",", "rSq", ",", "x", ",", "z"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rfs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rSq", "=", 
      RowBox[{"rfs", ".", "rfs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["z", 
         RowBox[{"2", "\[Pi]", " ", "rSq"}]], ",", 
        RowBox[{"-", 
         FractionBox["x", 
          RowBox[{"2", "\[Pi]", " ", "rSq"}]]}]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4229883386962433`*^9, 3.4229884093979073`*^9}, {
  3.4229884400319567`*^9, 3.422988451698733*^9}, {3.422988516041253*^9, 
  3.42298861130824*^9}, {3.4235051907172575`*^9, 3.4235052222325745`*^9}, {
  3.423505440736768*^9, 3.4235054578714066`*^9}, {3.4235055089748898`*^9, 
  3.4235055096158113`*^9}, {3.42350564057412*^9, 3.423505643117778*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexPoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]]}], 
      RowBox[{"ArcTan", "[", "r", "]"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4229886850242386`*^9, 3.4229887083678045`*^9}, {
  3.4229887513496094`*^9, 3.4229887588003235`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexPoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "\[Pi]"}]], 
      RowBox[{"Log", "[", 
       RowBox[{"r", ".", "r"}], "]"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.422988774022211*^9, 3.4229888241042256`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[" ",
  FontWeight->"Bold"],
 "Vortex panel, constant strength"
}], "Subsubsection",
 CellChangeTimes->{3.4224530271607857`*^9, 3.4224536866390686`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICVortexConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083832921875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]VortexConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838330484375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838331484375*^9}],

Cell["\<\
Define functions for influence coefficients for collections of field points \
and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ic", ",", "rfs", ",", "r1", ",", "r2", ",", "\[Theta]p"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     RowBox[{"ic", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", "\[Pi]"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
            RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"4", "\[Pi]"}]], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"r2", ".", "r2"}], 
            RowBox[{"r1", ".", "r1"}]], "]"}]}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "ic", "]"}], ",", "\[Theta]p"}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.39730250003125*^9, 3.39730253946875*^9}, {
   3.40083833240625*^9, 3.400838340703125*^9}, {3.40083869521875*^9, 
   3.400838700046875*^9}, 3.4008389400625*^9, {3.4234240933150096`*^9, 
   3.4234241026083727`*^9}, {3.423424325929493*^9, 3.4234243296248064`*^9}, {
   3.4234243646952353`*^9, 3.4234243994752464`*^9}, {3.4234244566174126`*^9, 
   3.4234245476483088`*^9}, {3.4234246249594765`*^9, 3.423424659238768*^9}, {
   3.4234252560569506`*^9, 3.423425260974021*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rfs", ",", "r1", ",", "r2", ",", "x", ",", "x2", ",", "z", ",", 
      "\[Delta]", ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x2", " ", 
         RowBox[{"ArcTan", "[", "r2", "]"}]}], "-", 
        RowBox[{"x", " ", 
         RowBox[{"ArcTan", "[", "r1", "]"}]}], "+", 
        RowBox[{
         FractionBox["z", "2"], 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"r2", ".", "r2"}], 
           RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ")"}]}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4008383420625*^9, 3.400838343015625*^9}, {
  3.400838721765625*^9, 3.40083872375*^9}, {3.4234246875895343`*^9, 
  3.4234247636789455`*^9}, {3.4234248044976397`*^9, 3.4234248100856752`*^9}, {
  3.4234248927445326`*^9, 3.4234248970407104`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rfs", ",", "r1", ",", "r2", ",", "x", ",", "x2", ",", "z", ",", 
      "\[Delta]", ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Delta]", "=", 
      RowBox[{"Rest", "[", 
       RowBox[{"rs", "-", 
        RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
           RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x2", " ", 
            RowBox[{"Log", "[", 
             RowBox[{"r2", ".", "r2"}], "]"}]}], "-", 
           RowBox[{"x", " ", 
            RowBox[{"Log", "[", 
             RowBox[{"r1", ".", "r1"}], "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838343953125*^9, 3.40083834490625*^9}, {
   3.400838731546875*^9, 3.40083873384375*^9}, 3.4234247889653053`*^9, {
   3.4234248416811075`*^9, 3.42342494895536*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Vortex panel, linearly varying strength", "Subsubsection",
 CellChangeTimes->{3.4224530623413725`*^9, 3.4224539328631215`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICVortexLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.400838345984375*^9, {3.422461331703453*^9, 3.422461340876643*^9}, {
   3.4224613746452*^9, 3.422461377629491*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]VortexLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838346921875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838348453125*^9}],

Cell["\<\
Define functions for influence coefficients for collections of field points \
and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICVortexLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ica", ",", "icax", ",", "icaz", ",", "icb", ",", "icbx", ",", "icbz", 
      ",", "x", ",", "x2", ",", "z", ",", "rfs", ",", "r1", ",", "r1Sq", ",", 
      "r2", ",", "r2Sq", ",", "\[Theta]1", ",", "\[Theta]2", ",", 
      "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icax", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"icaz", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "\[Pi]"}]], 
       RowBox[{"Log", "[", 
        FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icbx", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["z", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"icbz", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "x2"}], ")"}], "-", 
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["x", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ica", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icax", ",", "icaz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"icb", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icbx", ",", "icbz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "ica", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "icb", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.39731162903125*^9, 3.397311686453125*^9}, {
   3.397311745234375*^9, 3.397311814515625*^9}, {3.397311879125*^9, 
   3.397311923234375*^9}, {3.39731196321875*^9, 3.39731197846875*^9}, {
   3.397312045265625*^9, 3.397312069578125*^9}, 3.397312118140625*^9, {
   3.39731322925*^9, 3.397313247953125*^9}, {3.398425483109375*^9, 
   3.3984255265625*^9}, {3.398425654125*^9, 3.398425659171875*^9}, {
   3.398425709828125*^9, 3.398425743125*^9}, {3.398425810390625*^9, 
   3.398425834703125*^9}, {3.398427293078125*^9, 3.398427445140625*^9}, {
   3.398427778859375*^9, 3.398427804359375*^9}, {3.398427880609375*^9, 
   3.398427892546875*^9}, {3.398427934109375*^9, 3.398427937375*^9}, {
   3.3984334056875*^9, 3.39843343409375*^9}, {3.39868508384375*^9, 
   3.398685089609375*^9}, {3.3986851273125*^9, 3.398685137265625*^9}, {
   3.398685215453125*^9, 3.39868534778125*^9}, {3.39868537815625*^9, 
   3.398685427625*^9}, {3.39868601565625*^9, 3.3986860378125*^9}, {
   3.398686209875*^9, 3.39868621309375*^9}, {3.39971971434375*^9, 
   3.39971974796875*^9}, {3.39989273196875*^9, 3.399892745359375*^9}, {
   3.40023239178125*^9, 3.400232403109375*^9}, {3.40048913284375*^9, 
   3.40048913684375*^9}, {3.40050081346875*^9, 3.40050086521875*^9}, {
   3.400500940640625*^9, 3.40050094440625*^9}, {3.40050832515625*^9, 
   3.4005083280625*^9}, 3.400508432625*^9, {3.400508480703125*^9, 
   3.400508531625*^9}, {3.4005086635*^9, 3.400508737234375*^9}, 
   3.400508783734375*^9, {3.400508969015625*^9, 3.400509047828125*^9}, {
   3.4005091225*^9, 3.4005091488125*^9}, {3.4005095125*^9, 
   3.400509616703125*^9}, {3.400509722984375*^9, 3.400509826671875*^9}, {
   3.400509987546875*^9, 3.4005099923125*^9}, {3.410260441*^9, 
   3.410260474*^9}, {3.41027746253125*^9, 3.410277693171875*^9}, 
   3.410517457015625*^9, {3.410517521953125*^9, 3.41051755225*^9}, {
   3.4105189025*^9, 3.4105189375*^9}, {3.410519240828125*^9, 
   3.410519265546875*^9}, {3.410519938171875*^9, 3.4105199800625*^9}, {
   3.410520137171875*^9, 3.410520146453125*^9}, {3.410520444296875*^9, 
   3.410520553640625*^9}, {3.410520851890625*^9, 3.410520858546875*^9}, {
   3.410687033359375*^9, 3.4106870518125*^9}, {3.410687161265625*^9, 
   3.410687165734375*^9}, {3.41431697853125*^9, 3.414317083859375*^9}, {
   3.414319014921875*^9, 3.41431909265625*^9}, 3.414321839328125*^9, {
   3.414321885828125*^9, 3.41432188959375*^9}, {3.414322011828125*^9, 
   3.414322015109375*^9}, {3.414333344046875*^9, 3.414333371171875*^9}, {
   3.4225530163154945`*^9, 3.422553040009565*^9}, 3.4225531251720223`*^9, {
   3.422553681992691*^9, 3.4225536878411007`*^9}, {3.4225537351591406`*^9, 
   3.4225537872240067`*^9}, {3.4225539432984304`*^9, 
   3.4225539931200705`*^9}, {3.422554099483013*^9, 3.4225541329210944`*^9}, {
   3.422554285230104*^9, 3.4225543954385757`*^9}, {3.4225547993293424`*^9, 
   3.4225548214411373`*^9}, {3.422898125838179*^9, 3.4228981624708543`*^9}, {
   3.422898253361549*^9, 3.422898308020144*^9}, {3.422898367615838*^9, 
   3.422898372813312*^9}, {3.422898443194515*^9, 3.4228984597983904`*^9}, 
   3.422898612287659*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]VortexLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Phi]a", ",", "ic\[Phi]b", ",", "r1", ",", 
      "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", "x2", ",", "z", ",", 
      "rfs", ",", "\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]p"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]a", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x2", " ", "\[Theta]2"}], "-", 
         RowBox[{"x", " ", "\[Theta]1"}], "+", 
         RowBox[{
          FractionBox["z", "2"], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"r2", ".", "r2"}], 
            RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]b", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", " ", "z"}], "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "-", 
            SuperscriptBox["d", "2"]}], ")"}], "\[Theta]2"}], "-", 
         RowBox[{"c", " ", "\[Theta]1"}], "+", 
         RowBox[{"x", " ", "z", " ", 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Phi]a", ",", "ic\[Phi]b"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.39842567403125*^9, 3.398425677203125*^9}, {
   3.398425872546875*^9, 3.3984258745625*^9}, {3.422553144299526*^9, 
   3.4225531604427395`*^9}, {3.422553278202069*^9, 3.422553295236563*^9}, {
   3.4225545580924606`*^9, 3.422554562048149*^9}, {3.4225546525983534`*^9, 
   3.4225546876888113`*^9}, 3.4225550228607645`*^9, 3.422555058682274*^9, {
   3.422555367916931*^9, 3.42255537344488*^9}, {3.422637897608901*^9, 
   3.4226379019851933`*^9}, {3.42263794026023*^9, 3.4226379525378847`*^9}}],

Cell["\<\
Using \[Delta] in following is inconsistant with current notation.\
\>", "Text",
 CellChangeTimes->{{3.41442019509375*^9, 3.414420224*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]VortexLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Psi]a", ",", "ic\[Psi]b", ",", "r1", ",", 
      "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", "x2", ",", "z", ",", 
      "rfs", ",", "\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]p"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]a", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
            RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x2", " ", 
             RowBox[{"Log", "[", 
              RowBox[{"r2", ".", "r2"}], "]"}]}], "-", 
            RowBox[{"x", " ", 
             RowBox[{"Log", "[", 
              RowBox[{"r1", ".", "r1"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]b", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"x", " ", "d"}], "2"], "-", 
         RowBox[{"x", " ", "z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "4"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"c", "-", 
               SuperscriptBox["d", "2"]}], ")"}], 
             RowBox[{"Log", "[", "r2Sq", "]"}]}], "-", 
            RowBox[{"c", " ", 
             RowBox[{"Log", "[", "r1Sq", "]"}]}]}], ")"}]}]}], ")"}]}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Psi]a", ",", "ic\[Psi]b"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.39842589259375*^9, 3.3984259016875*^9}, {
   3.414401626421875*^9, 3.414401659734375*^9}, {3.414401717703125*^9, 
   3.414401875625*^9}, {3.414406596328125*^9, 3.414406602984375*^9}, {
   3.4144078266875*^9, 3.4144080518125*^9}, {3.414419443625*^9, 
   3.41441965165625*^9}, 3.414420047109375*^9, {3.414420242078125*^9, 
   3.41442025684375*^9}, 3.414420312609375*^9, {3.41442051103125*^9, 
   3.414420533734375*^9}, {3.4144212970625*^9, 3.4144213828125*^9}, {
   3.41442200178125*^9, 3.414422019015625*^9}, {3.4144222318125*^9, 
   3.414422240171875*^9}, 3.41442258603125*^9, {3.41474420190625*^9, 
   3.414744250484375*^9}, {3.41474531428125*^9, 3.41474536415625*^9}, {
   3.41474695603125*^9, 3.414747007046875*^9}, {3.414747389109375*^9, 
   3.414747463546875*^9}, {3.414747495515625*^9, 3.414747496734375*^9}, {
   3.41474755665625*^9, 3.4147475768125*^9}, {3.414747654046875*^9, 
   3.41474771825*^9}, {3.414747856046875*^9, 3.41474791178125*^9}, {
   3.414747946609375*^9, 3.414748017125*^9}, {3.414748167890625*^9, 
   3.414748215046875*^9}, {3.414750235828125*^9, 3.41475030078125*^9}, 
   3.4147517299375*^9, 3.4226378469961233`*^9, {3.4226380590009713`*^9, 
   3.4226381509431777`*^9}, {3.422638268372032*^9, 3.422638314668603*^9}, 
   3.4226383525130205`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Source, point", "Subsubsection",
 CellChangeTimes->{3.4224531137753315`*^9, 3.422453962395587*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourcePoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourcePoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourcePoint", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Define velocity influence coefficient for collections of field points and \
collections of point vortices.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourcePoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfs", ",", "rSq", ",", "x", ",", "z"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rfs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rSq", "=", 
      RowBox[{"rfs", ".", "rfs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MakeCartesianVectors", "[", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["x", 
         RowBox[{"2", "\[Pi]", " ", "rSq"}]], ",", 
        FractionBox["z", 
         RowBox[{"2", "\[Pi]", " ", "rSq"}]]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4235050076440115`*^9, 3.4235050863371663`*^9}, {
  3.423505130009965*^9, 3.4235051701476803`*^9}}],

Cell["\<\
The velocity-potential and stream-function influence coefficients for a point \
source can be written in terms of the influence coefficients for a point \
vortex.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourcePoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"IC\[Psi]VortexPoint", "[", 
   RowBox[{"rf", ",", "rs"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4318631945676174`*^9, 3.432304382075986*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourcePoint", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"-", 
   RowBox[{"IC\[Phi]VortexPoint", "[", 
    RowBox[{"rf", ",", "rs"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4318631982729454`*^9, 3.431863200005437*^9}, {
  3.432304384990176*^9, 3.432304385410781*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Source panel, constant strength", "Subsubsection",
 CellChangeTimes->{3.422453188232395*^9, 3.4224539849780593`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourceConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourceConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourceConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICSourceConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838349625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]SourceConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083835034375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]SourceConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838351015625*^9}],

Cell["\<\
Define velocity influence coefficient for collections of field points and \
singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourceConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ic", ",", "icx", ",", "icz", ",", "r1", ",", "r2", ",", "\[Delta]", ",",
       "rfs", ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            RowBox[{"4", "\[Pi]"}]]}], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"r2", ".", "r2"}], 
            RowBox[{"r1", ".", "r1"}]], "]"}]}], ",", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", "\[Pi]"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
            RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}]}], "}"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "ic", "]"}], ",", "\[Theta]p"}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838351890625*^9, 3.4008383544375*^9}, {
   3.4008387735*^9, 3.400838775234375*^9}, 3.400838984515625*^9, {
   3.423598323181592*^9, 3.42359836903753*^9}, {3.423598405870493*^9, 
   3.4235985238601537`*^9}}],

Cell["\<\
The velocity-potential and stream-function influence coefficients for a \
constant-strength source panel can be written in terms of influence \
coefficients for a vortex panel.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourceConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"IC\[Psi]VortexConstant", "[", 
   RowBox[{"rf", ",", "rs"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourceConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"-", 
   RowBox[{"IC\[Phi]VortexConstant", "[", 
    RowBox[{"rf", ",", "rs"}], "]"}]}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Source panel, linearly varying strength", "Subsubsection",
 CellChangeTimes->{3.4224532120266094`*^9, 3.422454013569171*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourceLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourceLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourceLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICSourceLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083835534375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]SourceLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838355984375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]VortexLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083835725*^9}],

Cell["\<\
Define velocity influence coefficient for influence coefficients for \
collections of field points and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICSourceLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ica", ",", "icax", ",", "icaz", ",", "icb", ",", "icbx", ",", "icbz", 
      ",", "x", ",", "x2", ",", "z", ",", "rfs", ",", "r1", ",", "r1Sq", ",", 
      "r2", ",", "r2Sq", ",", "\[Theta]1", ",", "\[Theta]2", ",", 
      "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icax", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"4", "\[Pi]"}]]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"r2", ".", "r2"}], 
         RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icaz", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
         RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}]}], ";", 
     RowBox[{"icbx", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "x2"}], ")"}], "-", 
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["x", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     RowBox[{"icbz", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["z", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ica", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icax", ",", "icaz"}], "}"}], "]"}]}], ";", 
     RowBox[{"icb", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icbx", ",", "icbz"}], "}"}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "ica", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "icb", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838358359375*^9, 3.40083836190625*^9}, {
  3.400838789390625*^9, 3.400838791765625*^9}, {3.400838996765625*^9, 
  3.400839003703125*^9}, {3.422812690609806*^9, 3.42281270440965*^9}, {
  3.422812747601757*^9, 3.4228127822916384`*^9}, {3.4228128142375746`*^9, 
  3.422812817151765*^9}, {3.4228128530133314`*^9, 3.4228129063900833`*^9}, {
  3.4228129679385853`*^9, 3.422812976070278*^9}, {3.4228130277846403`*^9, 
  3.422813099287456*^9}, {3.422816339827123*^9, 3.422816359805851*^9}, {
  3.422816414724821*^9, 3.422816421174094*^9}}],

Cell["\<\
The velocity-potential and stream-function influence coefficients for a \
constant-strength source panel can be written in terms of influence \
coefficients for a vortex panel.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]SourceLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"IC\[Psi]VortexLinear", "[", 
   RowBox[{"rf", ",", "rs"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]SourceLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"-", 
   RowBox[{"IC\[Phi]VortexLinear", "[", 
    RowBox[{"rf", ",", "rs"}], "]"}]}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Doublet, point", "Subsubsection",
 CellChangeTimes->{3.4224532361913567`*^9, 3.4224540331573377`*^9}],

Cell["\<\
Programming note:  This is the only singularity in the package that requires \
three input arguments instead of two.  I haven't looked yet at whether I can \
simplify error trapping as was accomplished for functions with two input \
arguments.\
\>", "Text"],

Cell["\<\
Trap error associated with input arguments being of incorrect data type. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletPoint", "[", 
    RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "rf", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Head", "[", "rs", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Length", "[", "rf", "]"}], "=!=", "2"}], " ", "||", " ", 
    RowBox[{
     RowBox[{"Length", "[", "rs", "]"}], "=!=", "2"}]}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "dataType"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083836265625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletPoint", "[", 
    RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "rf", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Head", "[", "rs", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Length", "[", "rf", "]"}], "=!=", "2"}], " ", "||", " ", 
    RowBox[{
     RowBox[{"Length", "[", "rs", "]"}], "=!=", "2"}]}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "dataType"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838363671875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletPoint", "[", 
    RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "rf", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Head", "[", "rs", "]"}], "=!=", "CartesianVectors"}], " ", "||",
     " ", 
    RowBox[{
     RowBox[{"Length", "[", "rf", "]"}], "=!=", "2"}], " ", "||", " ", 
    RowBox[{
     RowBox[{"Length", "[", "rs", "]"}], "=!=", "2"}]}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "dataType"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838364640625*^9}],

Cell["Trap errors associated with number of input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletPoint", "[", "x_", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argr"}], ",", 
    "\"\<ICDoubletPoint\>\"", ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838366296875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletPoint", "[", "x_", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argr"}], ",", 
    "\"\<IC\[Phi]DoubletPoint\>\"", ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838367046875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletPoint", "[", "x_", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argr"}], ",", 
    "\"\<IC\[Psi]DoubletPoint\>\"", ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838367734375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletPoint", "[", "x___", "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argrx"}], ",", 
    "\"\<ICDoubletPoint\>\"", ",", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838368359375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletPoint", "[", "x___", "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argrx"}], ",", 
    "\"\<ICDoubletPoint\>\"", ",", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838369046875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletPoint", "[", "x___", "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argrx"}], ",", 
    "\"\<ICDoubletPoint\>\"", ",", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], ",", "3"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083836965625*^9}],

Cell["Define functions for the general case.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletPoint", "[", 
   RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ic", ",", "rfs", ",", "rSq", ",", "x", ",", "z", ",", "\[Theta]"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Theta]", "=", 
      RowBox[{
       RowBox[{"ArcTan", "[", "uv", "]"}], "-", 
       FractionBox["\[Pi]", "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rfs", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"DisplacementVectors", "[", 
           RowBox[{"rf", ",", "rs"}], "]"}], "]"}], ",", "\[Theta]"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rSq", "=", 
      RowBox[{"rfs", ".", "rfs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rfs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"x", " ", "z"}], 
          RowBox[{"\[Pi]", " ", 
           SuperscriptBox["rSq", "2"]}]], ",", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["z", "2"]}], 
           RowBox[{"2", "\[Pi]", " ", 
            SuperscriptBox["rSq", "2"]}]]}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "ic", "]"}], ",", 
        RowBox[{"-", "\[Theta]"}]}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083837046875*^9, 3.400838371125*^9}, {
   3.4235868233508034`*^9, 3.4235868570692883`*^9}, {3.4235868957749443`*^9, 
   3.423586962601035*^9}, 3.4235911513590174`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletPoint", "[", 
   RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfs", ",", "rSq", ",", "x", ",", "z", ",", "\[Theta]"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Theta]", "=", 
      RowBox[{
       RowBox[{"ArcTan", "[", "uv", "]"}], "-", 
       FractionBox["\[Pi]", "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rfs", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"DisplacementVectors", "[", 
           RowBox[{"rf", ",", "rs"}], "]"}], "]"}], ",", "\[Theta]"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rSq", "=", 
      RowBox[{"rfs", ".", "rfs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rfs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"-", 
      FractionBox["z", 
       RowBox[{"2", "\[Pi]", " ", "rSq"}]]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.40083837178125*^9, {3.423591176385003*^9, 3.423591264261363*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletPoint", "[", 
   RowBox[{"rf_", ",", "rs_", ",", "uv_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rfs", ",", "rSq", ",", "x", ",", "z", ",", "\[Theta]"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Theta]", "=", 
      RowBox[{
       RowBox[{"ArcTan", "[", "uv", "]"}], "-", 
       FractionBox["\[Pi]", "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rfs", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"DisplacementVectors", "[", 
           RowBox[{"rf", ",", "rs"}], "]"}], "]"}], ",", "\[Theta]"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rSq", "=", 
      RowBox[{"rfs", ".", "rfs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "rfs", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"-", 
      FractionBox["x", 
       RowBox[{"2", "\[Pi]", " ", "rSq"}]]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.400838372453125*^9, {3.4235912889068017`*^9, 3.423591336935864*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Doublet panel, constant strength", "Subsubsection",
 CellChangeTimes->{3.422453262028509*^9, 3.4224541472387104`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletConstant", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4008383733125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.40083837390625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletConstant", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838374578125*^9}],

Cell["\<\
Define functions for influence coefficients for collections of field points \
and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ic", ",", "icx", ",", "icz", ",", "rfs", ",", "r1", ",", "r1Sq", ",", 
      "r2", ",", "r2Sq", ",", "x", ",", "x2", ",", "z", ",", "\[Theta]p"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"icx", ",", "icz"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["z", 
          RowBox[{"2", "\[Pi]"}]], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "r2Sq"], "-", 
           FractionBox["1", "r1Sq"]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           RowBox[{"2", "\[Pi]"}]]}], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["x2", "r2Sq"], "-", 
           FractionBox["x", "r1Sq"]}], ")"}]}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icx", ",", "icz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "ic", "]"}], ",", "\[Theta]p"}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083837525*^9, 3.40083837665625*^9}, {
   3.40083880490625*^9, 3.4008388066875*^9}, 3.400839015625*^9, {
   3.4234961594309053`*^9, 3.4234962852117696`*^9}, {3.4234963364354258`*^9, 
   3.4234964446610465`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rfs", ",", "r1", ",", "r2", ",", "\[Delta]", ",", "\[CapitalDelta]r", 
      ",", "\[Theta]p", ",", "\[Theta]1", ",", "\[Theta]2"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]]}], 
      RowBox[{"(", 
       RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083837740625*^9, 3.400838378078125*^9}, {
  3.400838814171875*^9, 3.4008388159375*^9}, {3.423496476847328*^9, 
  3.4234965471384015`*^9}, {3.423496584922733*^9, 3.4234966006653695`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletConstant", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rfs", ",", "r1", ",", "r2", ",", "\[Delta]", ",", "\[CapitalDelta]r", 
      ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", "\[Pi]"}]], 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"r2", ".", "r2"}], 
        RowBox[{"r1", ".", "r1"}]], "]"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838378734375*^9, 3.40083837940625*^9}, {
  3.40083882375*^9, 3.400838825375*^9}, {3.423496630187821*^9, 
  3.423496682773435*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Doublet panel, linearly varying strength", "Subsubsection",
 CellChangeTimes->{3.422453288316309*^9, 3.4224541778327026`*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletLinear", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4008383803125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838380921875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletLinear", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4008383815*^9}],

Cell["\<\
Define functions for influence coefficients for collections of field points \
and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ica", ",", "icax", ",", "icaz", ",", "icb", ",", "icbx", ",", "icbz", 
      ",", "x", ",", "x2", ",", "z", ",", "rfs", ",", "r1", ",", "r1Sq", ",", 
      "r2", ",", "r2Sq", ",", "\[Theta]1", ",", "\[Theta]2", ",", 
      "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icax", "=", 
      RowBox[{
       FractionBox["z", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "r2Sq"], "-", 
         FractionBox["1", "r1Sq"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"icaz", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         FractionBox["x2", "r2Sq"], "-", 
         FractionBox["x", "r1Sq"]}], ")"}]}]}], ";", 
     RowBox[{"ica", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icax", ",", "icaz"}], "}"}], "]"}]}], ";", 
     RowBox[{"icbx", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"z", 
           RowBox[{"(", 
            RowBox[{"x", "-", "x2"}], ")"}]}], "r2Sq"], "-", 
         RowBox[{"(", 
          RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], ")"}]}]}], ";", 
     RowBox[{"icbz", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"x2", 
           RowBox[{"(", 
            RowBox[{"x", "-", "x2"}], ")"}]}], "r2Sq"], "+", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     RowBox[{"icb", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icbx", ",", "icbz"}], "}"}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "ica", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "icb", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083838228125*^9, 3.400838384390625*^9}, {
  3.400838832390625*^9, 3.400838835125*^9}, {3.4008390361875*^9, 
  3.400839037390625*^9}, {3.4229004937530737`*^9, 3.422900532949435*^9}, {
  3.4229006133250093`*^9, 3.422900690966653*^9}, {3.422901098712963*^9, 
  3.422901112582907*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Phi]a", ",", "ic\[Phi]b", ",", "r1", ",", 
      "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", "x2", ",", "z", ",", 
      "rfs", ",", "\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]p"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]a", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]b", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
            RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["z", "2"], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"r2", ".", "r2"}], 
            RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Phi]a", ",", "ic\[Phi]b"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4008383850625*^9, 3.400838385734375*^9}, {
   3.400838848859375*^9, 3.400838850078125*^9}, {3.4229013155647807`*^9, 
   3.422901366848523*^9}, 3.423665488751898*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletLinear", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Psi]a", ",", "ic\[Psi]b", ",", "r1", ",", 
      "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", "x2", ",", "z", ",", 
      "rfs", ",", "\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]p"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]a", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "\[Pi]"}]], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"r2", ".", "r2"}], 
         RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]b", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "x2"}], ")"}], "-", 
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", "r2", "]"}], "-", 
            RowBox[{"ArcTan", "[", "r1", "]"}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["x", "2"], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"r2", ".", "r2"}], 
            RowBox[{"r1", ".", "r1"}]], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Psi]a", ",", "ic\[Psi]b"}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083838646875*^9, 3.400838387140625*^9}, {
  3.40083885721875*^9, 3.400838858890625*^9}, {3.4229014105213213`*^9, 
  3.422901437790533*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Doublet panel, quadratically varying strength", "Subsubsection",
 CellChangeTimes->{3.4224533232164927`*^9, 3.422454201586859*^9}],

Cell["Trap errors associated with input arguments.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletQuadratic", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletQuadratic", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletQuadratic", "[", "p___", "]"}], ":=", 
  RowBox[{"Null", "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", 
     RowBox[{"TestArguments", "[", "p", "]"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Trap error of specifying coordinates for a single point to locate a line \
singularity.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ICDoubletQuadratic", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838387953125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Phi]DoubletQuadratic", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838388546875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
    RowBox[{"rf_", ",", "rs_"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"NumberOfVectors", "[", "rs", "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "lineSingularity"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838389109375*^9}],

Cell["\<\
Define functions for influence coefficients for collections of field points \
and singularity panels in global coordinates.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ICDoubletQuadratic", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "d", ",", "ica", ",", "icax", ",", "icaz", ",", "icb", ",", "icbx", ",", 
      "icbz", ",", "icc", ",", "iccx", ",", "iccz", ",", "x", ",", "x2", ",", 
      "z", ",", "rfs", ",", "r1", ",", "r1Sq", ",", "r2", ",", "r2Sq", ",", 
      "\[Delta]", ",", "\[Theta]1", ",", "\[Theta]2", ",", "\[Theta]p"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"d", "=", 
      RowBox[{"x", "-", "x2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"icax", ",", "icaz"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["z", 
          RowBox[{"2", "\[Pi]"}]], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "r2Sq"], "-", 
           FractionBox["1", "r1Sq"]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           RowBox[{"2", "\[Pi]"}]]}], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["x2", "r2Sq"], "-", 
           FractionBox["x", "r1Sq"]}], ")"}]}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ica", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icax", ",", "icaz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"icbx", ",", "icbz"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          RowBox[{"2", "\[Pi]"}]], 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"z", 
             RowBox[{"(", 
              RowBox[{"x", "-", "x2"}], ")"}]}], "r2Sq"], "-", 
           RowBox[{"(", 
            RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           RowBox[{"2", "\[Pi]"}]]}], 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"x2", 
             RowBox[{"(", 
              RowBox[{"x", "-", "x2"}], ")"}]}], "r2Sq"], "+", 
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"Log", "[", 
             FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"icb", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"icbx", ",", "icbz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"iccx", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"z", " ", 
           SuperscriptBox["d", "2"]}], "r2Sq"], "-", 
         RowBox[{"2", "x", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "-", 
         RowBox[{"z", " ", 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"iccz", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "d"}], "+", 
         FractionBox[
          RowBox[{"x2", " ", 
           SuperscriptBox["d", "2"]}], "r2Sq"], "-", 
         RowBox[{"2", "z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{"x", " ", 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"icc", "=", 
      RowBox[{"MakeCartesianVectors", "[", 
       RowBox[{"{", 
        RowBox[{"iccx", ",", "iccz"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "ica", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "icb", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Rotate", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "icc", "]"}], ",", "\[Theta]p"}], "]"}], 
        "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4008383898125*^9, 3.400838392421875*^9}, {
  3.40083886575*^9, 3.400838867734375*^9}, {3.40083905425*^9, 
  3.400839055578125*^9}, {3.405334775828125*^9, 3.405334789515625*^9}, {
  3.423604097364459*^9, 3.423604177179227*^9}, {3.4236042576048737`*^9, 
  3.423604286286115*^9}, {3.423604325131973*^9, 3.4236046516514845`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Phi]DoubletQuadratic", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Phi]a", ",", "ic\[Phi]b", ",", "ic\[Phi]c", ",",
       "rfs", ",", "r1", ",", "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", 
      "x2", ",", "z", ",", "\[Delta]", ",", "\[Theta]1", ",", "\[Theta]2", 
      ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]a", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]b", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["z", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic\[Phi]c", "=", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z", " ", "d"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["z", "2"]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", " ", 
         RowBox[{"x", " ", "z", " ", 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Phi]a", ",", "ic\[Phi]b", ",", "ic\[Phi]c"}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400838393046875*^9, 3.40083839371875*^9}, {
   3.400838882421875*^9, 3.40083888665625*^9}, {3.4236047363032084`*^9, 
   3.4236047905712414`*^9}, {3.4236048410938897`*^9, 3.42360505221747*^9}, 
   3.4236720503770514`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IC\[Psi]DoubletQuadratic", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "c", ",", "d", ",", "ic\[Psi]a", ",", "ic\[Psi]b", ",", "ic\[Psi]c", ",",
       "rfs", ",", "r1", ",", "r1Sq", ",", "r2", ",", "r2Sq", ",", "x", ",", 
      "x2", ",", "z", ",", "\[Delta]", ",", "\[Theta]1", ",", "\[Theta]2", 
      ",", "\[Theta]p"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rfs", "=", 
      RowBox[{"DisplacementVectors", "[", 
       RowBox[{"rf", ",", "rs"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Theta]p", "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"Rest", "[", 
        RowBox[{"rs", "-", 
         RowBox[{"RotateRight", "[", "rs", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r1", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r2", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", "rfs", "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"-", "\[Theta]p"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r1Sq", ",", "r2Sq"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", ".", "r1"}], ",", 
        RowBox[{"r2", ".", "r2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]1", ",", "\[Theta]2"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ArcTan", "[", "r1", "]"}], ",", 
        RowBox[{"ArcTan", "[", "r2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "z"}], "}"}], "=", 
      RowBox[{"Components", "[", "r1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"x2", "=", 
      RowBox[{
       RowBox[{"Components", "[", "r2", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "d"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["z", "2"]}], ",", 
        RowBox[{"x", "-", "x2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]a", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"4", "\[Pi]"}]], 
       RowBox[{"Log", "[", 
        FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]b", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "x2"}], ")"}], "-", 
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox["x", "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ic\[Psi]c", "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "x2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "x"}], "-", "x2"}], ")"}]}], "-", 
         RowBox[{"2", "x", " ", "z", 
          RowBox[{"(", 
           RowBox[{"\[Theta]2", "-", "\[Theta]1"}], ")"}]}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["x", "2"], "-", 
            SuperscriptBox["z", "2"]}], "2"], 
          RowBox[{"Log", "[", 
           FractionBox["r2Sq", "r1Sq"], "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ic\[Psi]a", ",", "ic\[Psi]b", ",", "ic\[Psi]c"}], "}"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40083839459375*^9, 3.400838395234375*^9}, {
  3.4008388931875*^9, 3.40083889815625*^9}, {3.423605117451272*^9, 
  3.4236051679138336`*^9}, {3.423605225757008*^9, 3.4236053517682033`*^9}, {
  3.4236054018101597`*^9, 3.423605438182461*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[" Test input arguments", "Subsubsection",
 CellChangeTimes->{3.4224533727377005`*^9, 3.422462232208315*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TestArguments", "[", 
   RowBox[{
    RowBox[{"rf_CartesianVectors", "?", "TwoDimQ"}], ",", 
    RowBox[{"rs_CartesianVectors", "?", "TwoDimQ"}]}], "]"}], ":=", 
  "True"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.422463993040267*^9, 3.4224640035654016`*^9}, {
  3.422464414436205*^9, 3.422464418391893*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TestArguments", "[", 
   RowBox[{"rf_", ",", "rs_"}], "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{"InfluenceCoefficients", "::", "dataType"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.40083839584375*^9, {3.422464012968923*^9, 3.4224640190476637`*^9}, {
   3.422464420925536*^9, 3.4224644242102594`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TestArguments", "[", "x_", "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], "\[Equal]", "1"}]}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argr"}], ",", 
    "\"\<Singularity function\>\"", ",", "2"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838396921875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TestArguments", "[", "x___", "]"}], ":=", 
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"InfluenceCoefficients", "::", "argrx"}], ",", 
    "\"\<Singularity function\>\"", ",", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "x", "}"}], "]"}], ",", "2"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.400838397515625*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[" End private context", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Epilogue", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "DisplacementVectors", ",", "ICDoubletConstant", ",", "ICDoubletLinear", 
    ",", "ICDoubletPoint", ",", "ICDoubletQuadratic", ",", "ICSourceConstant",
     ",", "ICSourceLinear", ",", "ICSourcePoint", ",", "ICVortexConstant", 
    ",", "ICVortexLinear", ",", "ICVortexPoint", ",", 
    "IC\[Phi]DoubletConstant", ",", "IC\[Phi]DoubletLinear", ",", 
    "IC\[Phi]DoubletQuadratic", ",", "IC\[Phi]DoubletPoint", ",", 
    "IC\[Phi]SourceConstant", ",", "IC\[Phi]SourceLinear", ",", 
    "IC\[Phi]SourcePoint", ",", "IC\[Phi]VortexConstant", ",", 
    "IC\[Phi]VortexLinear", ",", "IC\[Phi]VortexPoint", ",", 
    "IC\[Psi]DoubletConstant", ",", "IC\[Psi]DoubletLinear", ",", 
    "IC\[Psi]DoubletQuadratic", ",", "IC\[Psi]DoubletPoint", ",", 
    "IC\[Psi]SourceConstant", ",", "IC\[Psi]SourceLinear", ",", 
    "IC\[Psi]SourcePoint", ",", "IC\[Psi]VortexConstant", ",", 
    "IC\[Psi]VortexLinear", ",", "IC\[Psi]VortexPoint", ",", 
    "InfluenceCoefficients", ",", "TestArguments", ",", "UniformFlow", ",", 
    "UniformFlow\[Phi]", ",", "UniformFlow\[Psi]"}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4008383274375*^9, {3.4240135652108307`*^9, 3.424013640278773*^9}, {
   3.4240136736467533`*^9, 3.424013681688317*^9}, {3.4240137952816563`*^9, 
   3.424013844212014*^9}, {3.4240138964671535`*^9, 3.4240139418223715`*^9}, {
   3.4240143172922707`*^9, 3.424014319815899*^9}}],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{688, 918},
WindowMargins->{{Automatic, 295}, {Automatic, -1}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.,
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 80, 1, 71, "Section"],
Cell[650, 25, 319, 6, 29, "Text"],
Cell[972, 33, 364, 4, 29, "Text"],
Cell[1339, 39, 578, 11, 47, "Text"],
Cell[CellGroupData[{
Cell[1942, 54, 31, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1998, 58, 32, 0, 27, "Subsubsection"],
Cell[2033, 60, 206, 4, 47, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2276, 69, 77, 1, 21, "Subsubsection"],
Cell[2356, 72, 257, 7, 47, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2650, 84, 33, 0, 21, "Subsubsection"],
Cell[2686, 86, 109, 3, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2832, 94, 35, 0, 21, "Subsubsection"],
Cell[2870, 96, 756, 13, 137, "Text"],
Cell[3629, 111, 470, 12, 65, "Text"],
Cell[CellGroupData[{
Cell[4124, 127, 3283, 90, 19, "Input",
 CellOpen->False],
Cell[7410, 219, 4799, 84, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12270, 310, 44, 0, 36, "Subsection"],
Cell[12317, 312, 584, 12, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[12938, 329, 32, 0, 28, "Subsection"],
Cell[CellGroupData[{
Cell[12995, 333, 141, 1, 27, "Subsubsection"],
Cell[13139, 336, 639, 12, 152, "Input",
 InitializationCell->True],
Cell[13781, 350, 589, 12, 72, "Input",
 InitializationCell->True],
Cell[14373, 364, 669, 14, 75, "Input",
 InitializationCell->True],
Cell[15045, 380, 564, 12, 75, "Input",
 InitializationCell->True],
Cell[15612, 394, 333, 8, 92, "Input",
 InitializationCell->True],
Cell[15948, 404, 356, 8, 72, "Input",
 InitializationCell->True],
Cell[16307, 414, 412, 10, 72, "Input",
 InitializationCell->True],
Cell[16722, 426, 364, 9, 72, "Input",
 InitializationCell->True],
Cell[17089, 437, 480, 10, 92, "Input",
 InitializationCell->True],
Cell[17572, 449, 457, 9, 92, "Input",
 InitializationCell->True],
Cell[18032, 460, 454, 9, 92, "Input",
 InitializationCell->True],
Cell[18489, 471, 815, 14, 92, "Input",
 InitializationCell->True],
Cell[19307, 487, 525, 11, 92, "Input",
 InitializationCell->True],
Cell[19835, 500, 476, 10, 92, "Input",
 InitializationCell->True],
Cell[20314, 512, 393, 9, 72, "Input",
 InitializationCell->True],
Cell[20710, 523, 371, 9, 72, "Input",
 InitializationCell->True],
Cell[21084, 534, 368, 9, 72, "Input",
 InitializationCell->True],
Cell[21455, 545, 391, 8, 92, "Input",
 InitializationCell->True],
Cell[21849, 555, 408, 8, 92, "Input",
 InitializationCell->True],
Cell[22260, 565, 454, 9, 92, "Input",
 InitializationCell->True],
Cell[22717, 576, 445, 9, 92, "Input",
 InitializationCell->True],
Cell[23165, 587, 472, 9, 92, "Input",
 InitializationCell->True],
Cell[23640, 598, 463, 9, 92, "Input",
 InitializationCell->True],
Cell[24106, 609, 383, 8, 92, "Input",
 InitializationCell->True],
Cell[24492, 619, 408, 8, 92, "Input",
 InitializationCell->True],
Cell[24903, 629, 408, 8, 92, "Input",
 InitializationCell->True],
Cell[25314, 639, 414, 9, 92, "Input",
 InitializationCell->True],
Cell[25731, 650, 416, 8, 92, "Input",
 InitializationCell->True],
Cell[26150, 660, 430, 9, 92, "Input",
 InitializationCell->True],
Cell[26583, 671, 522, 10, 92, "Input",
 InitializationCell->True],
Cell[27108, 683, 522, 10, 92, "Input",
 InitializationCell->True],
Cell[27633, 695, 517, 10, 92, "Input",
 InitializationCell->True],
Cell[28153, 707, 460, 9, 92, "Input",
 InitializationCell->True],
Cell[28616, 718, 484, 10, 92, "Input",
 InitializationCell->True],
Cell[29103, 730, 430, 9, 92, "Input",
 InitializationCell->True],
Cell[29536, 741, 415, 9, 92, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[29988, 755, 127, 1, 27, "Subsubsection"],
Cell[30118, 758, 355, 8, 112, "Input",
 InitializationCell->True],
Cell[30476, 768, 312, 7, 92, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[30837, 781, 37, 0, 28, "Subsection"],
Cell[CellGroupData[{
Cell[30899, 785, 47, 0, 27, "Subsubsection"],
Cell[30949, 787, 201, 6, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[31187, 798, 77, 0, 21, "Subsubsection"],
Cell[31267, 800, 1427, 24, 192, "Input",
 InitializationCell->True],
Cell[32697, 826, 1260, 22, 192, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[33994, 853, 165, 2, 21, "Subsubsection"],
Cell[34162, 857, 151, 3, 47, "Text"],
Cell[34316, 862, 896, 28, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[35249, 895, 108, 1, 21, "Subsubsection"],
Cell[35360, 898, 717, 19, 52, "Input",
 InitializationCell->True],
Cell[36080, 919, 692, 21, 52, "Input",
 InitializationCell->True],
Cell[36775, 942, 694, 21, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[37506, 968, 166, 2, 21, "Subsubsection"],
Cell[37675, 972, 771, 21, 92, "Input",
 InitializationCell->True],
Cell[38449, 995, 336, 9, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[38822, 1009, 155, 2, 21, "Subsubsection"],
Cell[38980, 1013, 60, 0, 29, "Text"],
Cell[39043, 1015, 243, 7, 31, "Input",
 InitializationCell->True],
Cell[39289, 1024, 249, 7, 31, "Input",
 InitializationCell->True],
Cell[39541, 1033, 249, 7, 31, "Input",
 InitializationCell->True],
Cell[39793, 1042, 128, 1, 29, "Text"],
Cell[39924, 1045, 1349, 33, 134, "Input",
 InitializationCell->True],
Cell[41276, 1080, 667, 18, 95, "Input",
 InitializationCell->True],
Cell[41946, 1100, 613, 17, 95, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[42596, 1122, 177, 5, 21, "Subsubsection"],
Cell[42776, 1129, 60, 0, 29, "Text"],
Cell[42839, 1131, 246, 7, 31, "Input",
 InitializationCell->True],
Cell[43088, 1140, 252, 7, 31, "Input",
 InitializationCell->True],
Cell[43343, 1149, 252, 7, 31, "Input",
 InitializationCell->True],
Cell[43598, 1158, 111, 3, 29, "Text"],
Cell[43712, 1163, 388, 11, 52, "Input",
 InitializationCell->True],
Cell[44103, 1176, 395, 11, 52, "Input",
 InitializationCell->True],
Cell[44501, 1189, 395, 11, 52, "Input",
 InitializationCell->True],
Cell[44899, 1202, 147, 3, 29, "Text"],
Cell[45049, 1207, 2668, 69, 182, "Input",
 InitializationCell->True],
Cell[47720, 1278, 2513, 68, 195, "Input",
 InitializationCell->True],
Cell[50236, 1348, 2782, 77, 215, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[53055, 1430, 133, 1, 21, "Subsubsection"],
Cell[53191, 1433, 60, 0, 29, "Text"],
Cell[53254, 1435, 244, 7, 31, "Input",
 InitializationCell->True],
Cell[53501, 1444, 250, 7, 31, "Input",
 InitializationCell->True],
Cell[53754, 1453, 250, 7, 31, "Input",
 InitializationCell->True],
Cell[54007, 1462, 111, 3, 29, "Text"],
Cell[54121, 1467, 484, 13, 52, "Input",
 InitializationCell->True],
Cell[54608, 1482, 393, 11, 52, "Input",
 InitializationCell->True],
Cell[55004, 1495, 393, 11, 52, "Input",
 InitializationCell->True],
Cell[55400, 1508, 147, 3, 29, "Text"],
Cell[55550, 1513, 7654, 175, 476, "Input",
 InitializationCell->True],
Cell[63207, 1690, 4296, 114, 342, "Input",
 InitializationCell->True],
Cell[67506, 1806, 149, 3, 29, "Text"],
Cell[67658, 1811, 5559, 141, 341, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[73254, 1957, 105, 1, 21, "Subsubsection"],
Cell[73362, 1960, 60, 0, 29, "Text"],
Cell[73425, 1962, 243, 7, 31, "Input",
 InitializationCell->True],
Cell[73671, 1971, 249, 7, 31, "Input",
 InitializationCell->True],
Cell[73923, 1980, 249, 7, 31, "Input",
 InitializationCell->True],
Cell[74175, 1989, 130, 3, 29, "Text"],
Cell[74308, 1994, 1076, 29, 134, "Input",
 InitializationCell->True],
Cell[75387, 2025, 186, 4, 47, "Text"],
Cell[75576, 2031, 289, 7, 31, "Input",
 InitializationCell->True],
Cell[75868, 2040, 360, 9, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[76265, 2054, 123, 1, 21, "Subsubsection"],
Cell[76391, 2057, 60, 0, 29, "Text"],
Cell[76454, 2059, 246, 7, 31, "Input",
 InitializationCell->True],
Cell[76703, 2068, 252, 7, 31, "Input",
 InitializationCell->True],
Cell[76958, 2077, 252, 7, 31, "Input",
 InitializationCell->True],
Cell[77213, 2086, 111, 3, 29, "Text"],
Cell[77327, 2091, 386, 11, 52, "Input",
 InitializationCell->True],
Cell[77716, 2104, 394, 11, 52, "Input",
 InitializationCell->True],
Cell[78113, 2117, 395, 11, 52, "Input",
 InitializationCell->True],
Cell[78511, 2130, 141, 3, 29, "Text"],
Cell[78655, 2135, 2513, 69, 182, "Input",
 InitializationCell->True],
Cell[81171, 2206, 200, 4, 47, "Text"],
Cell[81374, 2212, 229, 6, 31, "Input",
 InitializationCell->True],
Cell[81606, 2220, 249, 7, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[81892, 2232, 131, 1, 21, "Subsubsection"],
Cell[82026, 2235, 60, 0, 29, "Text"],
Cell[82089, 2237, 244, 7, 31, "Input",
 InitializationCell->True],
Cell[82336, 2246, 250, 7, 31, "Input",
 InitializationCell->True],
Cell[82589, 2255, 250, 7, 31, "Input",
 InitializationCell->True],
Cell[82842, 2264, 111, 3, 29, "Text"],
Cell[82956, 2269, 386, 11, 52, "Input",
 InitializationCell->True],
Cell[83345, 2282, 393, 11, 52, "Input",
 InitializationCell->True],
Cell[83741, 2295, 389, 11, 52, "Input",
 InitializationCell->True],
Cell[84133, 2308, 168, 3, 47, "Text"],
Cell[84304, 2313, 5151, 140, 475, "Input",
 InitializationCell->True],
Cell[89458, 2455, 200, 4, 47, "Text"],
Cell[89661, 2461, 225, 6, 31, "Input",
 InitializationCell->True],
Cell[89889, 2469, 245, 7, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[90171, 2481, 108, 1, 21, "Subsubsection"],
Cell[90282, 2484, 267, 5, 65, "Text"],
Cell[90552, 2491, 97, 2, 29, "Text"],
Cell[90652, 2495, 680, 19, 92, "Input",
 InitializationCell->True],
Cell[91335, 2516, 687, 19, 92, "Input",
 InitializationCell->True],
Cell[92025, 2537, 687, 19, 92, "Input",
 InitializationCell->True],
Cell[92715, 2558, 70, 0, 29, "Text"],
Cell[92788, 2560, 421, 12, 52, "Input",
 InitializationCell->True],
Cell[93212, 2574, 433, 12, 52, "Input",
 InitializationCell->True],
Cell[93648, 2588, 433, 12, 52, "Input",
 InitializationCell->True],
Cell[94084, 2602, 378, 10, 52, "Input",
 InitializationCell->True],
Cell[94465, 2614, 384, 10, 52, "Input",
 InitializationCell->True],
Cell[94852, 2626, 383, 10, 52, "Input",
 InitializationCell->True],
Cell[95238, 2638, 54, 0, 29, "Text"],
Cell[95295, 2640, 1997, 53, 201, "Input",
 InitializationCell->True],
Cell[97295, 2695, 1256, 33, 167, "Input",
 InitializationCell->True],
Cell[98554, 2730, 1259, 33, 167, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[99850, 2768, 124, 1, 21, "Subsubsection"],
Cell[99977, 2771, 60, 0, 29, "Text"],
Cell[100040, 2773, 247, 7, 31, "Input",
 InitializationCell->True],
Cell[100290, 2782, 253, 7, 31, "Input",
 InitializationCell->True],
Cell[100546, 2791, 253, 7, 31, "Input",
 InitializationCell->True],
Cell[100802, 2800, 111, 3, 29, "Text"],
Cell[100916, 2805, 388, 11, 52, "Input",
 InitializationCell->True],
Cell[101307, 2818, 395, 11, 52, "Input",
 InitializationCell->True],
Cell[101705, 2831, 396, 11, 52, "Input",
 InitializationCell->True],
Cell[102104, 2844, 147, 3, 29, "Text"],
Cell[102254, 2849, 3261, 91, 283, "Input",
 InitializationCell->True],
Cell[105518, 2942, 2146, 58, 175, "Input",
 InitializationCell->True],
Cell[107667, 3002, 1806, 50, 155, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[109510, 3057, 132, 1, 21, "Subsubsection"],
Cell[109645, 3060, 60, 0, 29, "Text"],
Cell[109708, 3062, 245, 7, 31, "Input",
 InitializationCell->True],
Cell[109956, 3071, 251, 7, 31, "Input",
 InitializationCell->True],
Cell[110210, 3080, 251, 7, 31, "Input",
 InitializationCell->True],
Cell[110464, 3089, 111, 3, 29, "Text"],
Cell[110578, 3094, 386, 11, 52, "Input",
 InitializationCell->True],
Cell[110967, 3107, 394, 11, 52, "Input",
 InitializationCell->True],
Cell[111364, 3120, 389, 11, 52, "Input",
 InitializationCell->True],
Cell[111756, 3133, 147, 3, 29, "Text"],
Cell[111906, 3138, 4762, 134, 419, "Input",
 InitializationCell->True],
Cell[116671, 3274, 3792, 106, 341, "Input",
 InitializationCell->True],
Cell[120466, 3382, 3837, 107, 341, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[124340, 3494, 137, 1, 21, "Subsubsection"],
Cell[124480, 3497, 60, 0, 29, "Text"],
Cell[124543, 3499, 248, 7, 31, "Input",
 InitializationCell->True],
Cell[124794, 3508, 254, 7, 31, "Input",
 InitializationCell->True],
Cell[125051, 3517, 254, 7, 31, "Input",
 InitializationCell->True],
Cell[125308, 3526, 111, 3, 29, "Text"],
Cell[125422, 3531, 391, 11, 52, "Input",
 InitializationCell->True],
Cell[125816, 3544, 397, 11, 52, "Input",
 InitializationCell->True],
Cell[126216, 3557, 397, 11, 52, "Input",
 InitializationCell->True],
Cell[126616, 3570, 147, 3, 29, "Text"],
Cell[126766, 3575, 6749, 191, 553, "Input",
 InitializationCell->True],
Cell[133518, 3768, 4398, 123, 380, "Input",
 InitializationCell->True],
Cell[137919, 3893, 4546, 126, 389, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[142502, 4024, 112, 1, 21, "Subsubsection"],
Cell[142617, 4027, 362, 9, 52, "Input",
 InitializationCell->True],
Cell[142982, 4038, 375, 9, 31, "Input",
 InitializationCell->True],
Cell[143360, 4049, 426, 12, 52, "Input",
 InitializationCell->True],
Cell[143789, 4063, 383, 10, 52, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[144209, 4078, 45, 0, 21, "Subsubsection"],
Cell[144257, 4080, 96, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[144402, 4089, 30, 0, 36, "Subsection"],
Cell[144435, 4091, 1477, 25, 192, "Input",
 InitializationCell->True],
Cell[145915, 4118, 85, 2, 31, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
